// this file is not being transpiled and might be used on old browser so switch off some eslint, also make sure to only use old style javascript (no es5 or es6 features)
/* eslint no-var: off, object-shorthand: off, prefer-template: off, prefer-arrow-callback: off */
// We need to make sure the scripts for the instrument web components complete before we run any scripts in those instrument web components.
// This DOM load order gating will allow us that.

// define these immediately so we can use them to test if this script is loaded
window.NationalInstruments = window.NationalInstruments || {};
window.NationalInstruments.measurementsLive = window.NationalInstruments.measurementsLive || {};
window.NationalInstruments.measurementsLive.instrument = window.NationalInstruments.measurementsLive.instrument || {};

/**
 * Test if the current browser is compatible with our app
 * @returns {Boolean} true if the current browser is compatible, or false otherwise
 */
function isBrowserCompatible() {
	var result = true;
	var FailedOn = [];
	var dummyDiv = document.createElement('div');

	// this should take care of google bot, IE < 10, Safari < 4, chrome < 4, firefox < 3.5
	if (!window.Worker) {
		result = false;
		FailedOn.push('window.Worker');
	} else if (!window.Map) { // IE < 11, Chrome < 38, Firefox < 13, Safari < 7.1
		result = false;
		FailedOn.push('window.Map');
	} else if (dummyDiv.style.flex === undefined) { // Safari < 9, IE < 11, Chrome < 29, Firefox < 20
		result = false;
		FailedOn.push('flex');
	} else if (!('classList' in SVGElement.prototype)) {
		// IE 11
		result = false;
		FailedOn.push('svg classList');
	} else if (!('closest' in Element.prototype)) {
		// Edge < 15
		result = false;
		FailedOn.push('Element.closest');
	} else if (!('createDataChannel' in RTCPeerConnection.prototype)) {
		// Edge
		result = false;
		FailedOn.push('RTCPeerConnection.createDataChannel');
	} else if (typeof InstallTrigger !== 'undefined') {
		// Firefox
		result = false;
		FailedOn.push('InstallTrigger');
	} else if (!('decode' in HTMLImageElement.prototype)) {
		const isSafari = /constructor/i.test(window.HTMLElement) || (function(parameter) { return parameter.toString() === '[object SafariRemoteNotification]'; })(!window['safari'] || window.safari.pushNotification);
		if (isSafari) {
			// safari 11.0 and 11.0.1
			result = false;
			FailedOn.push('HTMLImageElement.decode');
		}
	} else {
		try {
			// safari < 10.1
			eval('let foo = 0'); // eslint-disable-line
		} catch (p_Error) {
			result = false;
			FailedOn.push('let');
		}
	}

	return result;
}

/**
 * Function that is called when the document is ready with loading
 * @param {Function} fn Callback function to be called when the document is ready with loading
 */
function ready(fn) {
	if (document.attachEvent ? document.readyState === 'complete' : document.readyState !== 'loading') {
		fn();
	} else {
		document.addEventListener('DOMContentLoaded', fn);
	}
}

if (!isBrowserCompatible()) {
	// insert html into the page automatically
	ready(function() {
		document.body.innerHTML = '<div class="messagecontainer">' +
			'<div class="message">' +
			'<div class="row"><div class="cell spacer">&nbsp;</div></div>' +
			'<div class="row mainText"><div class="cell">Your browser is incompatible with ELVIS Instruments.</div></div>' +
			'<div class="row subText"><div class="cell">Use the Chrome™ web browser to best experience ELVIS Instruments.</div></div>' +
			'<div class="row"><div class="cell spacer paddedSpacer">&nbsp;</div></div>' +
			'</div>' +
			'<div class="footer">' +
			'   <p>Chrome™ is a trademark of Google Inc.</p>' +
			'<p>© 2019 National Instruments</p>' +
			'</div>' +
			'</div>';
	});
} else {
	const measurementsLive = window.NationalInstruments.measurementsLive;
	// warning: do not modified the exact string pattern of the following contiguous lines; they're searched by the build script
	

	const thisScript = document.currentScript;
	if (thisScript.src === '' && measurementsLive.rootUrl) {
		// we get embedded in a html file?
		measurementsLive.instrument.rootUrl = `${measurementsLive.rootUrl}/instruments`;
	} else {
		const pathParts = thisScript.src.split('/');
		pathParts.pop();
		measurementsLive.instrument.rootUrl = pathParts.join('/');
		measurementsLive.rootUrl = measurementsLive.rootUrl || measurementsLive.instrument.rootUrl;
	}
	measurementsLive.troubleshootUrl = measurementsLive.troubleshootUrl || `${measurementsLive.rootUrl}/elvis-setup.html`;

	const query = document.location.search.substring(1).split('&').reduce(function(p_Previous, p_Pair) { const items = p_Pair.split('='); if (items[0]) { p_Previous[items[0]] = (items.length > 1) ? items[1] : true; } return p_Previous; }, {});
	(function() {
		this.versionInfo = {
			type: 'release',
			gitHash: '12a6d13a3426c3b0a5487784c55ef3aaa6a862f6',
			version: { major: 0, minor: 1, patch: 4 },
			date: new Date('Mon Nov 25 2019 13:08:05 GMT+0800 (China Standard Time)'),
			moduleVersions: { webSfpInstrumentInterface: 'not connected' },
		};

		// add getters and setters like this, because old browsers don't support the direct in object syntax
		Object.defineProperty(this.versionInfo, 'isDevelopment', { get: function() { return this.type === 'development'; } });
		Object.defineProperty(this.versionInfo, 'isInternal', { get: function() { return this.isDevelopment || query.internal; } });
		Object.defineProperty(this.versionInfo, 'isProduction', { get: function() { return !this.isDevelopment; } });
	}).apply(measurementsLive);

	var link = document.createElement('link');
	link.rel = 'stylesheet';
	link.crossOrigin = 'anonymous';
	link.href = measurementsLive.instrument.rootUrl + '/web-sfp.css';
	var head = document.querySelector('head');
	head.appendChild(link);
	var script = document.createElement('script');
	script.src = measurementsLive.instrument.rootUrl + '/web-sfp.js';
	head.appendChild(script);
}
