// this file is not being transpiled and might be used on old browser so switch off some eslint, also make sure to only use old style javascript (no es5 or es6 features)
/* eslint no-var: off, object-shorthand: off, prefer-template: off, prefer-arrow-callback: off */
/* eslint no-unused-vars: ["error", { "varsIgnorePattern": "[current|plus]Slide" }] */
// We need to make sure the scripts in measurementslive.html complete before we run any scripts in measurementslive.js.
// This DOM load order gating will allow us that.

/**
 * Get cookie value by its name
 * @param {String} cname cookie's key
 * @returns {String} cookie value
 */
function getCookie(cname) {
	const name = cname + '=';
	const cookies = document.cookie.split(';');
	for (let index = 0; index < cookies.length; index++) {
		let cookie = cookies[index];
		cookie = cookie.trim();
		if (cookie.indexOf(name) === 0) {
			return cookie.substring(name.length, cookie.length);
		}
	}
	return '';
}

/**
 * Check if the cookie exists.
 * @param {String} cookieName cookie's key
 * @returns {Boolean} true if the cookie exists
 */
function checkSpecifiedCookie(cookieName) {
	const cookieValue = getCookie(cookieName);
	return !!cookieValue;
}

/**
 *  Show the cookie warning banner.
 */
function showCookieBanner() {
	const cookiesHint = document.getElementById('cookies');

	cookiesHint.style.display = 'flex';
	const cookieConfirmBtn = document.getElementById('cookieConfirm');
	cookieConfirmBtn.addEventListener('click', function() {
		const date = new Date();
		date.setFullYear(date.getFullYear() + 1);
		document.cookie = '  verifiedCookies=true; path=/; expires=' + date.toGMTString();

		cookiesHint.remove();
	});
}

/**
 *  Creates the Measurements Live.
 */
function createMeasurementsLive() {
	// parse the url for language
	const language = (new URL(document.location)).searchParams.get('language') || 'en-US';

	// create Measurements Live, set its attributes appropriately and insert it as the first child in the body
	const measurementsLiveElement = document.createElement('measurements-live');
	measurementsLiveElement.onAttached = function() {
		measurementsLiveElement.listeners.addListener('dataPolicyChanged', function(p_Policy) {
			const footer = document.getElementById('footer');
			if (footer) {
				footer.setDataUseNotice(p_Policy.datapolicy || '');
			}
		});
	};
	measurementsLiveElement.setAttribute('landingpage', '');
	measurementsLiveElement.setAttribute('logo', '');
	measurementsLiveElement.setAttribute('language', language);
	measurementsLiveElement.setAttribute('bentoboxmode', '');
	document.getElementById('measurementslivewrapper').appendChild(measurementsLiveElement);
}

/**
 *  Show the default navigation bar if the browser is unsupported or create Measurements Live.
 */
function showNavBar() {
	if (window.NationalInstruments && window.NationalInstruments.measurementsLive && window.NationalInstruments.measurementsLive.isBrowserCompatible) {
		createMeasurementsLive();
		const logo = document.getElementById('measurementslive-logo');
		logo.style.display = 'none';
	}
}

/**
 * Register onload event handler.
 * @param {Function} func the window.onload event handler
 */
function addLoadEventHandler(func) {
	const oldOnLoad = window.onload;
	if (typeof window.onload !== 'function') {
		window.onload = func;
	} else {
		window.onload = function() {
			oldOnLoad();
			func();
		};
	}
}

addLoadEventHandler(showNavBar);
addLoadEventHandler(function() {
	if (window.NationalInstruments === undefined) {
		return;
	}
	if (!window.NationalInstruments.measurementsLive.isBrowserCompatible) {
		return;
	}
	// hide simulate button when connect to device by IP address
	const isOnDevice = !window.NationalInstruments.measurementsLive.instrument.rootUrl.includes('multisim.com')
		&& !window.NationalInstruments.measurementsLive.instrument.rootUrl.includes('ni.com');
	const buttonContainer = document.querySelector('.button-container');
	if (isOnDevice) {
		buttonContainer.setAttribute('offline', true);
	} else {
		buttonContainer.setAttribute('online', true);
	}
	if (!checkSpecifiedCookie('verifiedCookies')) {
		showCookieBanner();
	}
});
