// this file is not being transpiled and might be used on old browser so switch off some eslint, also make sure to only use old style javascript (no es5 or es6 features)
/* eslint no-var: off, object-shorthand: off, prefer-template: off, prefer-arrow-callback: off */
// We need to make sure the scripts in measurements-live.html complete before we run any scripts in measurements-live.js.
// This DOM load order gating will allow us that.

// define these immediately so we can use them to test if this script is loaded
window.NationalInstruments = window.NationalInstruments || {};
window.NationalInstruments.measurementsLive = window.NationalInstruments.measurementsLive || {};

/**
 * Test if the current browser is compatible with our app
 * @returns {Boolean} true if the current browser is compatible, or false otherwise
 */
function isBrowserCompatible() {
	var result = true;
	var FailedOn = [];
	var dummyDiv = document.createElement('div');

	// this should take care of google bot, IE < 10, Safari < 4, chrome < 4, firefox < 3.5
	if (!window.Worker) {
		result = false;
		FailedOn.push('window.Worker');
	} else if (!window.Map) { // IE < 11, Chrome < 38, Firefox < 13, Safari < 7.1
		result = false;
		FailedOn.push('window.Map');
	} else if (dummyDiv.style.flex === undefined) { // Safari < 9, IE < 11, Chrome < 29, Firefox < 20
		result = false;
		FailedOn.push('flex');
	} else if (!('classList' in SVGElement.prototype)) {
		// IE 11
		result = false;
		FailedOn.push('svg classList');
	} else if (!('closest' in Element.prototype)) {
		// Edge < 15
		result = false;
		FailedOn.push('Element.closest');
	} else if (!window.RTCPeerConnection) {
		// Chrome 55
		result = false;
		FailedOn.push('RTCPeerConnection is undefined');
	} else if (!('createDataChannel' in RTCPeerConnection.prototype)) {
		// Edge
		result = false;
		FailedOn.push('RTCPeerConnection.createDataChannel');
	} else if (typeof InstallTrigger !== 'undefined') {
		// Firefox
		result = false;
		FailedOn.push('InstallTrigger');
	} else if (!('decode' in HTMLImageElement.prototype)) {
		const isSafari = /constructor/i.test(window.HTMLElement) || (function(parameter) { return parameter.toString() === '[object SafariRemoteNotification]'; })(!window['safari'] || window.safari.pushNotification);
		if (isSafari) {
			// safari 11.0 and 11.0.1
			result = false;
			FailedOn.push('HTMLImageElement.decode');
		}
	} else {
		try {
			// safari < 10.1
			eval('let foo = 0'); // eslint-disable-line
		} catch (p_Error) {
			result = false;
			FailedOn.push('let');
		}
	}

	return result;
}

/**
 * Function that is called when the document is ready with loading
 * @param {Function} fn Callback function to be called when the document is ready with loading
 */
function ready(fn) {
	if (document.attachEvent ? document.readyState === 'complete' : document.readyState !== 'loading') {
		fn();
	} else {
		document.addEventListener('DOMContentLoaded', fn);
	}
}

(function() {
	/**
	 * Redirect "Set Permission" from MeasurementsLive to WIF. The regex tries to cover two cases:
	 * 1. http://<IP addr>/#/WIFNIAuth;component/WIFNIAuthPage.dyn.xaml => http://<IP addr>/WIF.html#/WIFNIAuth;component/WIFNIAuthPage.dyn.xaml
	 * 2. http://<IP addr>/InstrumentLauncher.html#/WIFNIAuth;component/WIFNIAuthPage.dyn.xaml => http://<IP addr>/WIF.html#/WIFNIAuth;component/WIFNIAuthPage.dyn.xaml
     */
	function redirectWIF() {
		var redirectedWIF = window.location.href.replace(/(\w+\.html)*#\/WIFNIAuth;component\/WIFNIAuthPage\.dyn\.xaml/gi, 'WIF.html#/WIFNIAuth;component/WIFNIAuthPage.dyn.xaml');
		if (redirectedWIF !== window.location.href) {
			window.location.href = redirectedWIF;
		}
	}

	redirectWIF();

	var measurementsLive = window.NationalInstruments.measurementsLive;
	measurementsLive.isBrowserCompatible = true;
	if (typeof measurementsLive.rootUrl === 'undefined') {
		var thisScript = document.scripts[document.scripts.length - 1];
		var pathParts = thisScript.src.split('/');
		pathParts.pop();
		measurementsLive.rootUrl = pathParts.join('/');
	}

	var fontPath = measurementsLive.rootUrl + '/resources/fonts/';

	// add in the fonts here, so we can reduce the size of the landing html to just the loader
	document.readyState === 'complete' || document.write('<style>\n' + // eslint-disable-line no-unused-expressions
        '    @font-face {\n' +
        '        font-family: \'Lato\';\n' +
        '        src: local(\'Lato\'),local(\'lato\'),url(\'' + fontPath + 'Lato/Lato-Regular.ttf\')format(\'truetype\');\n' +
        '    }\n' +
        '    @font-face {\n' +
        '        font-family: \'Lato\';\n' +
        '        src: local(\'Lato\'),local(\'lato\'),url(\'' + fontPath + 'Lato/Lato-Bold.ttf\')format(\'truetype\');\n' +
        '        font-weight: 700;\n' +
		'    }\n' +
		'    @font-face {\n' +
		'        font-family: \'Roboto Mono\';\n' +
		'        src: local(\'Roboto Mono\'),local(\'roboto mono\'),url(\'' + fontPath + 'RobotoMono/RobotoMono-Regular.ttf\')format(\'truetype\');\n' +
        '    }\n' +
		'    @font-face {\n' +
		'        font-family: \'Roboto Mono\';\n' +
		'        src: local(\'Roboto Mono\'),local(\'roboto mono\'),url(\'' + fontPath + 'RobotoMono/RobotoMono-Light.ttf\')format(\'truetype\');\n' +
		'    }\n' +
        '</style>\n');

	/**
     * Creates HTMLLinkElement to reference external stylesheet file.
     */
	function createBrowserWarningStyle() {
		var styleLink = document.createElement('link');
		styleLink.rel = 'stylesheet';
		styleLink.href = measurementsLive.rootUrl + '/resources/css/browserwarning.css';
		styleLink.crossOrigin = 'anonymous';
		document.querySelector('head').appendChild(styleLink);
	}

	/**
     * Creates browser compatibility warning element.
     */
	function createBrowserWarningElement() {
		var element = document.createElement('div');
		var domString =
		'<div class="browser-warning">' +
			'<div class="left-column">' +
					'<p>' +
						'Your browser is incompatible with Measurements Live. Use the Chrome™ browser to best experience Measurements Live. ' +
						'Click <a href="' + measurementsLive.rootUrl + '/supported-browsers.html" target="_blank">here</a> to see supported browsers.' +
					'</p></div></div>';
		element.innerHTML = domString;
		document.body.appendChild(element.firstChild);
	}

	/**
	 * Checks if the user is browsing with a mobile device
	 * @returns {Boolean} true if the user is browsing with a mobile device.
	 */
	function isMobile() {
		return /android|webos|iphone|ipad|ipod|blackberry|windows phone|opera mini/i.test(navigator.userAgent || navigator.vendor || window.opera);
	}

	createBrowserWarningStyle();

	if (!isBrowserCompatible()) {
		measurementsLive.isBrowserCompatible = false;
		ready(function() {
			// show browser compatible warning
			createBrowserWarningElement();
		});
	} else {
		measurementsLive.isMobile = isMobile();
		// warning: do not modified the exact string pattern of the following contiguous lines; they're searched by the build script
		
		var query = document.location.search.substring(1).split('&').reduce(function(p_Previous, p_Pair) { var items = p_Pair.split('='); if (items[0]) { p_Previous[items[0]] = (items.length > 1) ? items[1] : true; } return p_Previous; }, {});
		(function() {
			this.versionInfo = {
				type: 'release',
				gitHash: '6de77d981fc4ae664f44971de9effe1265751637',
				version: { major: 1, minor: 0, patch: 0 },
				date: new Date('Mon Nov 25 2019 13:08:21 GMT+0800 (China Standard Time)'),
				moduleVersions: { webSfpInstrumentInterface: 'not connected' },
			};

			// add getters and setters like this, because old browsers don't support the direct in object syntax
			Object.defineProperty(this.versionInfo, 'isDevelopment', { get: function() { return this.type === 'development'; } });
			Object.defineProperty(this.versionInfo, 'isInternal', { get: function() { return this.isDevelopment || query.internal; } });
			Object.defineProperty(this.versionInfo, 'isProduction', { get: function() { return !this.isDevelopment; } });
		}).apply(measurementsLive);

		var head = document.querySelector('head');
		var loaderScript = document.createElement('script');
		loaderScript.src = measurementsLive.rootUrl + '/webcomponentsjs/webcomponents-loader.js';
		loaderScript.onload = function() {
			var script = document.createElement('script');
			script.src = measurementsLive.rootUrl + '/everything.js';
			ready(function() {
				head.appendChild(script);
			});
		};
		head.appendChild(loaderScript);
	}
})();
