/**
 * Copyright (c) 2014-present, Facebook, Inc.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */

!(function(global) {
  "use strict";

  var Op = Object.prototype;
  var hasOwn = Op.hasOwnProperty;
  var undefined; // More compressible than void 0.
  var $Symbol = typeof Symbol === "function" ? Symbol : {};
  var iteratorSymbol = $Symbol.iterator || "@@iterator";
  var asyncIteratorSymbol = $Symbol.asyncIterator || "@@asyncIterator";
  var toStringTagSymbol = $Symbol.toStringTag || "@@toStringTag";

  var inModule = typeof module === "object";
  var runtime = global.regeneratorRuntime;
  if (runtime) {
    if (inModule) {
      // If regeneratorRuntime is defined globally and we're in a module,
      // make the exports object identical to regeneratorRuntime.
      module.exports = runtime;
    }
    // Don't bother evaluating the rest of this file if the runtime was
    // already defined globally.
    return;
  }

  // Define the runtime globally (as expected by generated code) as either
  // module.exports (if we're in a module) or a new, empty object.
  runtime = global.regeneratorRuntime = inModule ? module.exports : {};

  function wrap(innerFn, outerFn, self, tryLocsList) {
    // If outerFn provided and outerFn.prototype is a Generator, then outerFn.prototype instanceof Generator.
    var protoGenerator = outerFn && outerFn.prototype instanceof Generator ? outerFn : Generator;
    var generator = Object.create(protoGenerator.prototype);
    var context = new Context(tryLocsList || []);

    // The ._invoke method unifies the implementations of the .next,
    // .throw, and .return methods.
    generator._invoke = makeInvokeMethod(innerFn, self, context);

    return generator;
  }
  runtime.wrap = wrap;

  // Try/catch helper to minimize deoptimizations. Returns a completion
  // record like context.tryEntries[i].completion. This interface could
  // have been (and was previously) designed to take a closure to be
  // invoked without arguments, but in all the cases we care about we
  // already have an existing method we want to call, so there's no need
  // to create a new function object. We can even get away with assuming
  // the method takes exactly one argument, since that happens to be true
  // in every case, so we don't have to touch the arguments object. The
  // only additional allocation required is the completion record, which
  // has a stable shape and so hopefully should be cheap to allocate.
  function tryCatch(fn, obj, arg) {
    try {
      return { type: "normal", arg: fn.call(obj, arg) };
    } catch (err) {
      return { type: "throw", arg: err };
    }
  }

  var GenStateSuspendedStart = "suspendedStart";
  var GenStateSuspendedYield = "suspendedYield";
  var GenStateExecuting = "executing";
  var GenStateCompleted = "completed";

  // Returning this object from the innerFn has the same effect as
  // breaking out of the dispatch switch statement.
  var ContinueSentinel = {};

  // Dummy constructor functions that we use as the .constructor and
  // .constructor.prototype properties for functions that return Generator
  // objects. For full spec compliance, you may wish to configure your
  // minifier not to mangle the names of these two functions.
  function Generator() {}
  function GeneratorFunction() {}
  function GeneratorFunctionPrototype() {}

  // This is a polyfill for %IteratorPrototype% for environments that
  // don't natively support it.
  var IteratorPrototype = {};
  IteratorPrototype[iteratorSymbol] = function () {
    return this;
  };

  var getProto = Object.getPrototypeOf;
  var NativeIteratorPrototype = getProto && getProto(getProto(values([])));
  if (NativeIteratorPrototype &&
      NativeIteratorPrototype !== Op &&
      hasOwn.call(NativeIteratorPrototype, iteratorSymbol)) {
    // This environment has a native %IteratorPrototype%; use it instead
    // of the polyfill.
    IteratorPrototype = NativeIteratorPrototype;
  }

  var Gp = GeneratorFunctionPrototype.prototype =
    Generator.prototype = Object.create(IteratorPrototype);
  GeneratorFunction.prototype = Gp.constructor = GeneratorFunctionPrototype;
  GeneratorFunctionPrototype.constructor = GeneratorFunction;
  GeneratorFunctionPrototype[toStringTagSymbol] =
    GeneratorFunction.displayName = "GeneratorFunction";

  // Helper for defining the .next, .throw, and .return methods of the
  // Iterator interface in terms of a single ._invoke method.
  function defineIteratorMethods(prototype) {
    ["next", "throw", "return"].forEach(function(method) {
      prototype[method] = function(arg) {
        return this._invoke(method, arg);
      };
    });
  }

  runtime.isGeneratorFunction = function(genFun) {
    var ctor = typeof genFun === "function" && genFun.constructor;
    return ctor
      ? ctor === GeneratorFunction ||
        // For the native GeneratorFunction constructor, the best we can
        // do is to check its .name property.
        (ctor.displayName || ctor.name) === "GeneratorFunction"
      : false;
  };

  runtime.mark = function(genFun) {
    if (Object.setPrototypeOf) {
      Object.setPrototypeOf(genFun, GeneratorFunctionPrototype);
    } else {
      genFun.__proto__ = GeneratorFunctionPrototype;
      if (!(toStringTagSymbol in genFun)) {
        genFun[toStringTagSymbol] = "GeneratorFunction";
      }
    }
    genFun.prototype = Object.create(Gp);
    return genFun;
  };

  // Within the body of any async function, `await x` is transformed to
  // `yield regeneratorRuntime.awrap(x)`, so that the runtime can test
  // `hasOwn.call(value, "__await")` to determine if the yielded value is
  // meant to be awaited.
  runtime.awrap = function(arg) {
    return { __await: arg };
  };

  function AsyncIterator(generator) {
    function invoke(method, arg, resolve, reject) {
      var record = tryCatch(generator[method], generator, arg);
      if (record.type === "throw") {
        reject(record.arg);
      } else {
        var result = record.arg;
        var value = result.value;
        if (value &&
            typeof value === "object" &&
            hasOwn.call(value, "__await")) {
          return Promise.resolve(value.__await).then(function(value) {
            invoke("next", value, resolve, reject);
          }, function(err) {
            invoke("throw", err, resolve, reject);
          });
        }

        return Promise.resolve(value).then(function(unwrapped) {
          // When a yielded Promise is resolved, its final value becomes
          // the .value of the Promise<{value,done}> result for the
          // current iteration. If the Promise is rejected, however, the
          // result for this iteration will be rejected with the same
          // reason. Note that rejections of yielded Promises are not
          // thrown back into the generator function, as is the case
          // when an awaited Promise is rejected. This difference in
          // behavior between yield and await is important, because it
          // allows the consumer to decide what to do with the yielded
          // rejection (swallow it and continue, manually .throw it back
          // into the generator, abandon iteration, whatever). With
          // await, by contrast, there is no opportunity to examine the
          // rejection reason outside the generator function, so the
          // only option is to throw it from the await expression, and
          // let the generator function handle the exception.
          result.value = unwrapped;
          resolve(result);
        }, reject);
      }
    }

    var previousPromise;

    function enqueue(method, arg) {
      function callInvokeWithMethodAndArg() {
        return new Promise(function(resolve, reject) {
          invoke(method, arg, resolve, reject);
        });
      }

      return previousPromise =
        // If enqueue has been called before, then we want to wait until
        // all previous Promises have been resolved before calling invoke,
        // so that results are always delivered in the correct order. If
        // enqueue has not been called before, then it is important to
        // call invoke immediately, without waiting on a callback to fire,
        // so that the async generator function has the opportunity to do
        // any necessary setup in a predictable way. This predictability
        // is why the Promise constructor synchronously invokes its
        // executor callback, and why async functions synchronously
        // execute code before the first await. Since we implement simple
        // async functions in terms of async generators, it is especially
        // important to get this right, even though it requires care.
        previousPromise ? previousPromise.then(
          callInvokeWithMethodAndArg,
          // Avoid propagating failures to Promises returned by later
          // invocations of the iterator.
          callInvokeWithMethodAndArg
        ) : callInvokeWithMethodAndArg();
    }

    // Define the unified helper method that is used to implement .next,
    // .throw, and .return (see defineIteratorMethods).
    this._invoke = enqueue;
  }

  defineIteratorMethods(AsyncIterator.prototype);
  AsyncIterator.prototype[asyncIteratorSymbol] = function () {
    return this;
  };
  runtime.AsyncIterator = AsyncIterator;

  // Note that simple async functions are implemented on top of
  // AsyncIterator objects; they just return a Promise for the value of
  // the final result produced by the iterator.
  runtime.async = function(innerFn, outerFn, self, tryLocsList) {
    var iter = new AsyncIterator(
      wrap(innerFn, outerFn, self, tryLocsList)
    );

    return runtime.isGeneratorFunction(outerFn)
      ? iter // If outerFn is a generator, return the full iterator.
      : iter.next().then(function(result) {
          return result.done ? result.value : iter.next();
        });
  };

  function makeInvokeMethod(innerFn, self, context) {
    var state = GenStateSuspendedStart;

    return function invoke(method, arg) {
      if (state === GenStateExecuting) {
        throw new Error("Generator is already running");
      }

      if (state === GenStateCompleted) {
        if (method === "throw") {
          throw arg;
        }

        // Be forgiving, per 25.3.3.3.3 of the spec:
        // https://people.mozilla.org/~jorendorff/es6-draft.html#sec-generatorresume
        return doneResult();
      }

      context.method = method;
      context.arg = arg;

      while (true) {
        var delegate = context.delegate;
        if (delegate) {
          var delegateResult = maybeInvokeDelegate(delegate, context);
          if (delegateResult) {
            if (delegateResult === ContinueSentinel) continue;
            return delegateResult;
          }
        }

        if (context.method === "next") {
          // Setting context._sent for legacy support of Babel's
          // function.sent implementation.
          context.sent = context._sent = context.arg;

        } else if (context.method === "throw") {
          if (state === GenStateSuspendedStart) {
            state = GenStateCompleted;
            throw context.arg;
          }

          context.dispatchException(context.arg);

        } else if (context.method === "return") {
          context.abrupt("return", context.arg);
        }

        state = GenStateExecuting;

        var record = tryCatch(innerFn, self, context);
        if (record.type === "normal") {
          // If an exception is thrown from innerFn, we leave state ===
          // GenStateExecuting and loop back for another invocation.
          state = context.done
            ? GenStateCompleted
            : GenStateSuspendedYield;

          if (record.arg === ContinueSentinel) {
            continue;
          }

          return {
            value: record.arg,
            done: context.done
          };

        } else if (record.type === "throw") {
          state = GenStateCompleted;
          // Dispatch the exception by looping back around to the
          // context.dispatchException(context.arg) call above.
          context.method = "throw";
          context.arg = record.arg;
        }
      }
    };
  }

  // Call delegate.iterator[context.method](context.arg) and handle the
  // result, either by returning a { value, done } result from the
  // delegate iterator, or by modifying context.method and context.arg,
  // setting context.delegate to null, and returning the ContinueSentinel.
  function maybeInvokeDelegate(delegate, context) {
    var method = delegate.iterator[context.method];
    if (method === undefined) {
      // A .throw or .return when the delegate iterator has no .throw
      // method always terminates the yield* loop.
      context.delegate = null;

      if (context.method === "throw") {
        if (delegate.iterator.return) {
          // If the delegate iterator has a return method, give it a
          // chance to clean up.
          context.method = "return";
          context.arg = undefined;
          maybeInvokeDelegate(delegate, context);

          if (context.method === "throw") {
            // If maybeInvokeDelegate(context) changed context.method from
            // "return" to "throw", let that override the TypeError below.
            return ContinueSentinel;
          }
        }

        context.method = "throw";
        context.arg = new TypeError(
          "The iterator does not provide a 'throw' method");
      }

      return ContinueSentinel;
    }

    var record = tryCatch(method, delegate.iterator, context.arg);

    if (record.type === "throw") {
      context.method = "throw";
      context.arg = record.arg;
      context.delegate = null;
      return ContinueSentinel;
    }

    var info = record.arg;

    if (! info) {
      context.method = "throw";
      context.arg = new TypeError("iterator result is not an object");
      context.delegate = null;
      return ContinueSentinel;
    }

    if (info.done) {
      // Assign the result of the finished delegate to the temporary
      // variable specified by delegate.resultName (see delegateYield).
      context[delegate.resultName] = info.value;

      // Resume execution at the desired location (see delegateYield).
      context.next = delegate.nextLoc;

      // If context.method was "throw" but the delegate handled the
      // exception, let the outer generator proceed normally. If
      // context.method was "next", forget context.arg since it has been
      // "consumed" by the delegate iterator. If context.method was
      // "return", allow the original .return call to continue in the
      // outer generator.
      if (context.method !== "return") {
        context.method = "next";
        context.arg = undefined;
      }

    } else {
      // Re-yield the result returned by the delegate method.
      return info;
    }

    // The delegate iterator is finished, so forget it and continue with
    // the outer generator.
    context.delegate = null;
    return ContinueSentinel;
  }

  // Define Generator.prototype.{next,throw,return} in terms of the
  // unified ._invoke helper method.
  defineIteratorMethods(Gp);

  Gp[toStringTagSymbol] = "Generator";

  // A Generator should always return itself as the iterator object when the
  // @@iterator function is called on it. Some browsers' implementations of the
  // iterator prototype chain incorrectly implement this, causing the Generator
  // object to not be returned from this call. This ensures that doesn't happen.
  // See https://github.com/facebook/regenerator/issues/274 for more details.
  Gp[iteratorSymbol] = function() {
    return this;
  };

  Gp.toString = function() {
    return "[object Generator]";
  };

  function pushTryEntry(locs) {
    var entry = { tryLoc: locs[0] };

    if (1 in locs) {
      entry.catchLoc = locs[1];
    }

    if (2 in locs) {
      entry.finallyLoc = locs[2];
      entry.afterLoc = locs[3];
    }

    this.tryEntries.push(entry);
  }

  function resetTryEntry(entry) {
    var record = entry.completion || {};
    record.type = "normal";
    delete record.arg;
    entry.completion = record;
  }

  function Context(tryLocsList) {
    // The root entry object (effectively a try statement without a catch
    // or a finally block) gives us a place to store values thrown from
    // locations where there is no enclosing try statement.
    this.tryEntries = [{ tryLoc: "root" }];
    tryLocsList.forEach(pushTryEntry, this);
    this.reset(true);
  }

  runtime.keys = function(object) {
    var keys = [];
    for (var key in object) {
      keys.push(key);
    }
    keys.reverse();

    // Rather than returning an object with a next method, we keep
    // things simple and return the next function itself.
    return function next() {
      while (keys.length) {
        var key = keys.pop();
        if (key in object) {
          next.value = key;
          next.done = false;
          return next;
        }
      }

      // To avoid creating an additional object, we just hang the .value
      // and .done properties off the next function object itself. This
      // also ensures that the minifier will not anonymize the function.
      next.done = true;
      return next;
    };
  };

  function values(iterable) {
    if (iterable) {
      var iteratorMethod = iterable[iteratorSymbol];
      if (iteratorMethod) {
        return iteratorMethod.call(iterable);
      }

      if (typeof iterable.next === "function") {
        return iterable;
      }

      if (!isNaN(iterable.length)) {
        var i = -1, next = function next() {
          while (++i < iterable.length) {
            if (hasOwn.call(iterable, i)) {
              next.value = iterable[i];
              next.done = false;
              return next;
            }
          }

          next.value = undefined;
          next.done = true;

          return next;
        };

        return next.next = next;
      }
    }

    // Return an iterator with no values.
    return { next: doneResult };
  }
  runtime.values = values;

  function doneResult() {
    return { value: undefined, done: true };
  }

  Context.prototype = {
    constructor: Context,

    reset: function(skipTempReset) {
      this.prev = 0;
      this.next = 0;
      // Resetting context._sent for legacy support of Babel's
      // function.sent implementation.
      this.sent = this._sent = undefined;
      this.done = false;
      this.delegate = null;

      this.method = "next";
      this.arg = undefined;

      this.tryEntries.forEach(resetTryEntry);

      if (!skipTempReset) {
        for (var name in this) {
          // Not sure about the optimal order of these conditions:
          if (name.charAt(0) === "t" &&
              hasOwn.call(this, name) &&
              !isNaN(+name.slice(1))) {
            this[name] = undefined;
          }
        }
      }
    },

    stop: function() {
      this.done = true;

      var rootEntry = this.tryEntries[0];
      var rootRecord = rootEntry.completion;
      if (rootRecord.type === "throw") {
        throw rootRecord.arg;
      }

      return this.rval;
    },

    dispatchException: function(exception) {
      if (this.done) {
        throw exception;
      }

      var context = this;
      function handle(loc, caught) {
        record.type = "throw";
        record.arg = exception;
        context.next = loc;

        if (caught) {
          // If the dispatched exception was caught by a catch block,
          // then let that catch block handle the exception normally.
          context.method = "next";
          context.arg = undefined;
        }

        return !! caught;
      }

      for (var i = this.tryEntries.length - 1; i >= 0; --i) {
        var entry = this.tryEntries[i];
        var record = entry.completion;

        if (entry.tryLoc === "root") {
          // Exception thrown outside of any try block that could handle
          // it, so set the completion value of the entire function to
          // throw the exception.
          return handle("end");
        }

        if (entry.tryLoc <= this.prev) {
          var hasCatch = hasOwn.call(entry, "catchLoc");
          var hasFinally = hasOwn.call(entry, "finallyLoc");

          if (hasCatch && hasFinally) {
            if (this.prev < entry.catchLoc) {
              return handle(entry.catchLoc, true);
            } else if (this.prev < entry.finallyLoc) {
              return handle(entry.finallyLoc);
            }

          } else if (hasCatch) {
            if (this.prev < entry.catchLoc) {
              return handle(entry.catchLoc, true);
            }

          } else if (hasFinally) {
            if (this.prev < entry.finallyLoc) {
              return handle(entry.finallyLoc);
            }

          } else {
            throw new Error("try statement without catch or finally");
          }
        }
      }
    },

    abrupt: function(type, arg) {
      for (var i = this.tryEntries.length - 1; i >= 0; --i) {
        var entry = this.tryEntries[i];
        if (entry.tryLoc <= this.prev &&
            hasOwn.call(entry, "finallyLoc") &&
            this.prev < entry.finallyLoc) {
          var finallyEntry = entry;
          break;
        }
      }

      if (finallyEntry &&
          (type === "break" ||
           type === "continue") &&
          finallyEntry.tryLoc <= arg &&
          arg <= finallyEntry.finallyLoc) {
        // Ignore the finally entry if control is not jumping to a
        // location outside the try/catch block.
        finallyEntry = null;
      }

      var record = finallyEntry ? finallyEntry.completion : {};
      record.type = type;
      record.arg = arg;

      if (finallyEntry) {
        this.method = "next";
        this.next = finallyEntry.finallyLoc;
        return ContinueSentinel;
      }

      return this.complete(record);
    },

    complete: function(record, afterLoc) {
      if (record.type === "throw") {
        throw record.arg;
      }

      if (record.type === "break" ||
          record.type === "continue") {
        this.next = record.arg;
      } else if (record.type === "return") {
        this.rval = this.arg = record.arg;
        this.method = "return";
        this.next = "end";
      } else if (record.type === "normal" && afterLoc) {
        this.next = afterLoc;
      }

      return ContinueSentinel;
    },

    finish: function(finallyLoc) {
      for (var i = this.tryEntries.length - 1; i >= 0; --i) {
        var entry = this.tryEntries[i];
        if (entry.finallyLoc === finallyLoc) {
          this.complete(entry.completion, entry.afterLoc);
          resetTryEntry(entry);
          return ContinueSentinel;
        }
      }
    },

    "catch": function(tryLoc) {
      for (var i = this.tryEntries.length - 1; i >= 0; --i) {
        var entry = this.tryEntries[i];
        if (entry.tryLoc === tryLoc) {
          var record = entry.completion;
          if (record.type === "throw") {
            var thrown = record.arg;
            resetTryEntry(entry);
          }
          return thrown;
        }
      }

      // The context.catch method must only be called with a location
      // argument that corresponds to a known catch block.
      throw new Error("illegal catch attempt");
    },

    delegateYield: function(iterable, resultName, nextLoc) {
      this.delegate = {
        iterator: values(iterable),
        resultName: resultName,
        nextLoc: nextLoc
      };

      if (this.method === "next") {
        // Deliberately forget the last sent value so that we don't
        // accidentally pass it on to the delegate.
        this.arg = undefined;
      }

      return ContinueSentinel;
    }
  };
})(
  // In sloppy mode, unbound `this` refers to the global object, fallback to
  // Function constructor if we're in global strict mode. That is sadly a form
  // of indirect eval which violates Content Security Policy.
  (function() { return this })() || Function("return this")()
);

/*! jQuery v3.4.1 | (c) JS Foundation and other contributors | jquery.org/license */
!function(e,t){"use strict";"object"==typeof module&&"object"==typeof module.exports?module.exports=e.document?t(e,!0):function(e){if(!e.document)throw new Error("jQuery requires a window with a document");return t(e)}:t(e)}("undefined"!=typeof window?window:this,function(C,e){"use strict";var t=[],E=C.document,r=Object.getPrototypeOf,s=t.slice,g=t.concat,u=t.push,i=t.indexOf,n={},o=n.toString,v=n.hasOwnProperty,a=v.toString,l=a.call(Object),y={},m=function(e){return"function"==typeof e&&"number"!=typeof e.nodeType},x=function(e){return null!=e&&e===e.window},c={type:!0,src:!0,nonce:!0,noModule:!0};function b(e,t,n){var r,i,o=(n=n||E).createElement("script");if(o.text=e,t)for(r in c)(i=t[r]||t.getAttribute&&t.getAttribute(r))&&o.setAttribute(r,i);n.head.appendChild(o).parentNode.removeChild(o)}function w(e){return null==e?e+"":"object"==typeof e||"function"==typeof e?n[o.call(e)]||"object":typeof e}var f="3.4.1",k=function(e,t){return new k.fn.init(e,t)},p=/^[\s\uFEFF\xA0]+|[\s\uFEFF\xA0]+$/g;function d(e){var t=!!e&&"length"in e&&e.length,n=w(e);return!m(e)&&!x(e)&&("array"===n||0===t||"number"==typeof t&&0<t&&t-1 in e)}k.fn=k.prototype={jquery:f,constructor:k,length:0,toArray:function(){return s.call(this)},get:function(e){return null==e?s.call(this):e<0?this[e+this.length]:this[e]},pushStack:function(e){var t=k.merge(this.constructor(),e);return t.prevObject=this,t},each:function(e){return k.each(this,e)},map:function(n){return this.pushStack(k.map(this,function(e,t){return n.call(e,t,e)}))},slice:function(){return this.pushStack(s.apply(this,arguments))},first:function(){return this.eq(0)},last:function(){return this.eq(-1)},eq:function(e){var t=this.length,n=+e+(e<0?t:0);return this.pushStack(0<=n&&n<t?[this[n]]:[])},end:function(){return this.prevObject||this.constructor()},push:u,sort:t.sort,splice:t.splice},k.extend=k.fn.extend=function(){var e,t,n,r,i,o,a=arguments[0]||{},s=1,u=arguments.length,l=!1;for("boolean"==typeof a&&(l=a,a=arguments[s]||{},s++),"object"==typeof a||m(a)||(a={}),s===u&&(a=this,s--);s<u;s++)if(null!=(e=arguments[s]))for(t in e)r=e[t],"__proto__"!==t&&a!==r&&(l&&r&&(k.isPlainObject(r)||(i=Array.isArray(r)))?(n=a[t],o=i&&!Array.isArray(n)?[]:i||k.isPlainObject(n)?n:{},i=!1,a[t]=k.extend(l,o,r)):void 0!==r&&(a[t]=r));return a},k.extend({expando:"jQuery"+(f+Math.random()).replace(/\D/g,""),isReady:!0,error:function(e){throw new Error(e)},noop:function(){},isPlainObject:function(e){var t,n;return!(!e||"[object Object]"!==o.call(e))&&(!(t=r(e))||"function"==typeof(n=v.call(t,"constructor")&&t.constructor)&&a.call(n)===l)},isEmptyObject:function(e){var t;for(t in e)return!1;return!0},globalEval:function(e,t){b(e,{nonce:t&&t.nonce})},each:function(e,t){var n,r=0;if(d(e)){for(n=e.length;r<n;r++)if(!1===t.call(e[r],r,e[r]))break}else for(r in e)if(!1===t.call(e[r],r,e[r]))break;return e},trim:function(e){return null==e?"":(e+"").replace(p,"")},makeArray:function(e,t){var n=t||[];return null!=e&&(d(Object(e))?k.merge(n,"string"==typeof e?[e]:e):u.call(n,e)),n},inArray:function(e,t,n){return null==t?-1:i.call(t,e,n)},merge:function(e,t){for(var n=+t.length,r=0,i=e.length;r<n;r++)e[i++]=t[r];return e.length=i,e},grep:function(e,t,n){for(var r=[],i=0,o=e.length,a=!n;i<o;i++)!t(e[i],i)!==a&&r.push(e[i]);return r},map:function(e,t,n){var r,i,o=0,a=[];if(d(e))for(r=e.length;o<r;o++)null!=(i=t(e[o],o,n))&&a.push(i);else for(o in e)null!=(i=t(e[o],o,n))&&a.push(i);return g.apply([],a)},guid:1,support:y}),"function"==typeof Symbol&&(k.fn[Symbol.iterator]=t[Symbol.iterator]),k.each("Boolean Number String Function Array Date RegExp Object Error Symbol".split(" "),function(e,t){n["[object "+t+"]"]=t.toLowerCase()});var h=function(n){var e,d,b,o,i,h,f,g,w,u,l,T,C,a,E,v,s,c,y,k="sizzle"+1*new Date,m=n.document,S=0,r=0,p=ue(),x=ue(),N=ue(),A=ue(),D=function(e,t){return e===t&&(l=!0),0},j={}.hasOwnProperty,t=[],q=t.pop,L=t.push,H=t.push,O=t.slice,P=function(e,t){for(var n=0,r=e.length;n<r;n++)if(e[n]===t)return n;return-1},R="checked|selected|async|autofocus|autoplay|controls|defer|disabled|hidden|ismap|loop|multiple|open|readonly|required|scoped",M="[\\x20\\t\\r\\n\\f]",I="(?:\\\\.|[\\w-]|[^\0-\\xa0])+",W="\\["+M+"*("+I+")(?:"+M+"*([*^$|!~]?=)"+M+"*(?:'((?:\\\\.|[^\\\\'])*)'|\"((?:\\\\.|[^\\\\\"])*)\"|("+I+"))|)"+M+"*\\]",$=":("+I+")(?:\\((('((?:\\\\.|[^\\\\'])*)'|\"((?:\\\\.|[^\\\\\"])*)\")|((?:\\\\.|[^\\\\()[\\]]|"+W+")*)|.*)\\)|)",F=new RegExp(M+"+","g"),B=new RegExp("^"+M+"+|((?:^|[^\\\\])(?:\\\\.)*)"+M+"+$","g"),_=new RegExp("^"+M+"*,"+M+"*"),z=new RegExp("^"+M+"*([>+~]|"+M+")"+M+"*"),U=new RegExp(M+"|>"),X=new RegExp($),V=new RegExp("^"+I+"$"),G={ID:new RegExp("^#("+I+")"),CLASS:new RegExp("^\\.("+I+")"),TAG:new RegExp("^("+I+"|[*])"),ATTR:new RegExp("^"+W),PSEUDO:new RegExp("^"+$),CHILD:new RegExp("^:(only|first|last|nth|nth-last)-(child|of-type)(?:\\("+M+"*(even|odd|(([+-]|)(\\d*)n|)"+M+"*(?:([+-]|)"+M+"*(\\d+)|))"+M+"*\\)|)","i"),bool:new RegExp("^(?:"+R+")$","i"),needsContext:new RegExp("^"+M+"*[>+~]|:(even|odd|eq|gt|lt|nth|first|last)(?:\\("+M+"*((?:-\\d)?\\d*)"+M+"*\\)|)(?=[^-]|$)","i")},Y=/HTML$/i,Q=/^(?:input|select|textarea|button)$/i,J=/^h\d$/i,K=/^[^{]+\{\s*\[native \w/,Z=/^(?:#([\w-]+)|(\w+)|\.([\w-]+))$/,ee=/[+~]/,te=new RegExp("\\\\([\\da-f]{1,6}"+M+"?|("+M+")|.)","ig"),ne=function(e,t,n){var r="0x"+t-65536;return r!=r||n?t:r<0?String.fromCharCode(r+65536):String.fromCharCode(r>>10|55296,1023&r|56320)},re=/([\0-\x1f\x7f]|^-?\d)|^-$|[^\0-\x1f\x7f-\uFFFF\w-]/g,ie=function(e,t){return t?"\0"===e?"\ufffd":e.slice(0,-1)+"\\"+e.charCodeAt(e.length-1).toString(16)+" ":"\\"+e},oe=function(){T()},ae=be(function(e){return!0===e.disabled&&"fieldset"===e.nodeName.toLowerCase()},{dir:"parentNode",next:"legend"});try{H.apply(t=O.call(m.childNodes),m.childNodes),t[m.childNodes.length].nodeType}catch(e){H={apply:t.length?function(e,t){L.apply(e,O.call(t))}:function(e,t){var n=e.length,r=0;while(e[n++]=t[r++]);e.length=n-1}}}function se(t,e,n,r){var i,o,a,s,u,l,c,f=e&&e.ownerDocument,p=e?e.nodeType:9;if(n=n||[],"string"!=typeof t||!t||1!==p&&9!==p&&11!==p)return n;if(!r&&((e?e.ownerDocument||e:m)!==C&&T(e),e=e||C,E)){if(11!==p&&(u=Z.exec(t)))if(i=u[1]){if(9===p){if(!(a=e.getElementById(i)))return n;if(a.id===i)return n.push(a),n}else if(f&&(a=f.getElementById(i))&&y(e,a)&&a.id===i)return n.push(a),n}else{if(u[2])return H.apply(n,e.getElementsByTagName(t)),n;if((i=u[3])&&d.getElementsByClassName&&e.getElementsByClassName)return H.apply(n,e.getElementsByClassName(i)),n}if(d.qsa&&!A[t+" "]&&(!v||!v.test(t))&&(1!==p||"object"!==e.nodeName.toLowerCase())){if(c=t,f=e,1===p&&U.test(t)){(s=e.getAttribute("id"))?s=s.replace(re,ie):e.setAttribute("id",s=k),o=(l=h(t)).length;while(o--)l[o]="#"+s+" "+xe(l[o]);c=l.join(","),f=ee.test(t)&&ye(e.parentNode)||e}try{return H.apply(n,f.querySelectorAll(c)),n}catch(e){A(t,!0)}finally{s===k&&e.removeAttribute("id")}}}return g(t.replace(B,"$1"),e,n,r)}function ue(){var r=[];return function e(t,n){return r.push(t+" ")>b.cacheLength&&delete e[r.shift()],e[t+" "]=n}}function le(e){return e[k]=!0,e}function ce(e){var t=C.createElement("fieldset");try{return!!e(t)}catch(e){return!1}finally{t.parentNode&&t.parentNode.removeChild(t),t=null}}function fe(e,t){var n=e.split("|"),r=n.length;while(r--)b.attrHandle[n[r]]=t}function pe(e,t){var n=t&&e,r=n&&1===e.nodeType&&1===t.nodeType&&e.sourceIndex-t.sourceIndex;if(r)return r;if(n)while(n=n.nextSibling)if(n===t)return-1;return e?1:-1}function de(t){return function(e){return"input"===e.nodeName.toLowerCase()&&e.type===t}}function he(n){return function(e){var t=e.nodeName.toLowerCase();return("input"===t||"button"===t)&&e.type===n}}function ge(t){return function(e){return"form"in e?e.parentNode&&!1===e.disabled?"label"in e?"label"in e.parentNode?e.parentNode.disabled===t:e.disabled===t:e.isDisabled===t||e.isDisabled!==!t&&ae(e)===t:e.disabled===t:"label"in e&&e.disabled===t}}function ve(a){return le(function(o){return o=+o,le(function(e,t){var n,r=a([],e.length,o),i=r.length;while(i--)e[n=r[i]]&&(e[n]=!(t[n]=e[n]))})})}function ye(e){return e&&"undefined"!=typeof e.getElementsByTagName&&e}for(e in d=se.support={},i=se.isXML=function(e){var t=e.namespaceURI,n=(e.ownerDocument||e).documentElement;return!Y.test(t||n&&n.nodeName||"HTML")},T=se.setDocument=function(e){var t,n,r=e?e.ownerDocument||e:m;return r!==C&&9===r.nodeType&&r.documentElement&&(a=(C=r).documentElement,E=!i(C),m!==C&&(n=C.defaultView)&&n.top!==n&&(n.addEventListener?n.addEventListener("unload",oe,!1):n.attachEvent&&n.attachEvent("onunload",oe)),d.attributes=ce(function(e){return e.className="i",!e.getAttribute("className")}),d.getElementsByTagName=ce(function(e){return e.appendChild(C.createComment("")),!e.getElementsByTagName("*").length}),d.getElementsByClassName=K.test(C.getElementsByClassName),d.getById=ce(function(e){return a.appendChild(e).id=k,!C.getElementsByName||!C.getElementsByName(k).length}),d.getById?(b.filter.ID=function(e){var t=e.replace(te,ne);return function(e){return e.getAttribute("id")===t}},b.find.ID=function(e,t){if("undefined"!=typeof t.getElementById&&E){var n=t.getElementById(e);return n?[n]:[]}}):(b.filter.ID=function(e){var n=e.replace(te,ne);return function(e){var t="undefined"!=typeof e.getAttributeNode&&e.getAttributeNode("id");return t&&t.value===n}},b.find.ID=function(e,t){if("undefined"!=typeof t.getElementById&&E){var n,r,i,o=t.getElementById(e);if(o){if((n=o.getAttributeNode("id"))&&n.value===e)return[o];i=t.getElementsByName(e),r=0;while(o=i[r++])if((n=o.getAttributeNode("id"))&&n.value===e)return[o]}return[]}}),b.find.TAG=d.getElementsByTagName?function(e,t){return"undefined"!=typeof t.getElementsByTagName?t.getElementsByTagName(e):d.qsa?t.querySelectorAll(e):void 0}:function(e,t){var n,r=[],i=0,o=t.getElementsByTagName(e);if("*"===e){while(n=o[i++])1===n.nodeType&&r.push(n);return r}return o},b.find.CLASS=d.getElementsByClassName&&function(e,t){if("undefined"!=typeof t.getElementsByClassName&&E)return t.getElementsByClassName(e)},s=[],v=[],(d.qsa=K.test(C.querySelectorAll))&&(ce(function(e){a.appendChild(e).innerHTML="<a id='"+k+"'></a><select id='"+k+"-\r\\' msallowcapture=''><option selected=''></option></select>",e.querySelectorAll("[msallowcapture^='']").length&&v.push("[*^$]="+M+"*(?:''|\"\")"),e.querySelectorAll("[selected]").length||v.push("\\["+M+"*(?:value|"+R+")"),e.querySelectorAll("[id~="+k+"-]").length||v.push("~="),e.querySelectorAll(":checked").length||v.push(":checked"),e.querySelectorAll("a#"+k+"+*").length||v.push(".#.+[+~]")}),ce(function(e){e.innerHTML="<a href='' disabled='disabled'></a><select disabled='disabled'><option/></select>";var t=C.createElement("input");t.setAttribute("type","hidden"),e.appendChild(t).setAttribute("name","D"),e.querySelectorAll("[name=d]").length&&v.push("name"+M+"*[*^$|!~]?="),2!==e.querySelectorAll(":enabled").length&&v.push(":enabled",":disabled"),a.appendChild(e).disabled=!0,2!==e.querySelectorAll(":disabled").length&&v.push(":enabled",":disabled"),e.querySelectorAll("*,:x"),v.push(",.*:")})),(d.matchesSelector=K.test(c=a.matches||a.webkitMatchesSelector||a.mozMatchesSelector||a.oMatchesSelector||a.msMatchesSelector))&&ce(function(e){d.disconnectedMatch=c.call(e,"*"),c.call(e,"[s!='']:x"),s.push("!=",$)}),v=v.length&&new RegExp(v.join("|")),s=s.length&&new RegExp(s.join("|")),t=K.test(a.compareDocumentPosition),y=t||K.test(a.contains)?function(e,t){var n=9===e.nodeType?e.documentElement:e,r=t&&t.parentNode;return e===r||!(!r||1!==r.nodeType||!(n.contains?n.contains(r):e.compareDocumentPosition&&16&e.compareDocumentPosition(r)))}:function(e,t){if(t)while(t=t.parentNode)if(t===e)return!0;return!1},D=t?function(e,t){if(e===t)return l=!0,0;var n=!e.compareDocumentPosition-!t.compareDocumentPosition;return n||(1&(n=(e.ownerDocument||e)===(t.ownerDocument||t)?e.compareDocumentPosition(t):1)||!d.sortDetached&&t.compareDocumentPosition(e)===n?e===C||e.ownerDocument===m&&y(m,e)?-1:t===C||t.ownerDocument===m&&y(m,t)?1:u?P(u,e)-P(u,t):0:4&n?-1:1)}:function(e,t){if(e===t)return l=!0,0;var n,r=0,i=e.parentNode,o=t.parentNode,a=[e],s=[t];if(!i||!o)return e===C?-1:t===C?1:i?-1:o?1:u?P(u,e)-P(u,t):0;if(i===o)return pe(e,t);n=e;while(n=n.parentNode)a.unshift(n);n=t;while(n=n.parentNode)s.unshift(n);while(a[r]===s[r])r++;return r?pe(a[r],s[r]):a[r]===m?-1:s[r]===m?1:0}),C},se.matches=function(e,t){return se(e,null,null,t)},se.matchesSelector=function(e,t){if((e.ownerDocument||e)!==C&&T(e),d.matchesSelector&&E&&!A[t+" "]&&(!s||!s.test(t))&&(!v||!v.test(t)))try{var n=c.call(e,t);if(n||d.disconnectedMatch||e.document&&11!==e.document.nodeType)return n}catch(e){A(t,!0)}return 0<se(t,C,null,[e]).length},se.contains=function(e,t){return(e.ownerDocument||e)!==C&&T(e),y(e,t)},se.attr=function(e,t){(e.ownerDocument||e)!==C&&T(e);var n=b.attrHandle[t.toLowerCase()],r=n&&j.call(b.attrHandle,t.toLowerCase())?n(e,t,!E):void 0;return void 0!==r?r:d.attributes||!E?e.getAttribute(t):(r=e.getAttributeNode(t))&&r.specified?r.value:null},se.escape=function(e){return(e+"").replace(re,ie)},se.error=function(e){throw new Error("Syntax error, unrecognized expression: "+e)},se.uniqueSort=function(e){var t,n=[],r=0,i=0;if(l=!d.detectDuplicates,u=!d.sortStable&&e.slice(0),e.sort(D),l){while(t=e[i++])t===e[i]&&(r=n.push(i));while(r--)e.splice(n[r],1)}return u=null,e},o=se.getText=function(e){var t,n="",r=0,i=e.nodeType;if(i){if(1===i||9===i||11===i){if("string"==typeof e.textContent)return e.textContent;for(e=e.firstChild;e;e=e.nextSibling)n+=o(e)}else if(3===i||4===i)return e.nodeValue}else while(t=e[r++])n+=o(t);return n},(b=se.selectors={cacheLength:50,createPseudo:le,match:G,attrHandle:{},find:{},relative:{">":{dir:"parentNode",first:!0}," ":{dir:"parentNode"},"+":{dir:"previousSibling",first:!0},"~":{dir:"previousSibling"}},preFilter:{ATTR:function(e){return e[1]=e[1].replace(te,ne),e[3]=(e[3]||e[4]||e[5]||"").replace(te,ne),"~="===e[2]&&(e[3]=" "+e[3]+" "),e.slice(0,4)},CHILD:function(e){return e[1]=e[1].toLowerCase(),"nth"===e[1].slice(0,3)?(e[3]||se.error(e[0]),e[4]=+(e[4]?e[5]+(e[6]||1):2*("even"===e[3]||"odd"===e[3])),e[5]=+(e[7]+e[8]||"odd"===e[3])):e[3]&&se.error(e[0]),e},PSEUDO:function(e){var t,n=!e[6]&&e[2];return G.CHILD.test(e[0])?null:(e[3]?e[2]=e[4]||e[5]||"":n&&X.test(n)&&(t=h(n,!0))&&(t=n.indexOf(")",n.length-t)-n.length)&&(e[0]=e[0].slice(0,t),e[2]=n.slice(0,t)),e.slice(0,3))}},filter:{TAG:function(e){var t=e.replace(te,ne).toLowerCase();return"*"===e?function(){return!0}:function(e){return e.nodeName&&e.nodeName.toLowerCase()===t}},CLASS:function(e){var t=p[e+" "];return t||(t=new RegExp("(^|"+M+")"+e+"("+M+"|$)"))&&p(e,function(e){return t.test("string"==typeof e.className&&e.className||"undefined"!=typeof e.getAttribute&&e.getAttribute("class")||"")})},ATTR:function(n,r,i){return function(e){var t=se.attr(e,n);return null==t?"!="===r:!r||(t+="","="===r?t===i:"!="===r?t!==i:"^="===r?i&&0===t.indexOf(i):"*="===r?i&&-1<t.indexOf(i):"$="===r?i&&t.slice(-i.length)===i:"~="===r?-1<(" "+t.replace(F," ")+" ").indexOf(i):"|="===r&&(t===i||t.slice(0,i.length+1)===i+"-"))}},CHILD:function(h,e,t,g,v){var y="nth"!==h.slice(0,3),m="last"!==h.slice(-4),x="of-type"===e;return 1===g&&0===v?function(e){return!!e.parentNode}:function(e,t,n){var r,i,o,a,s,u,l=y!==m?"nextSibling":"previousSibling",c=e.parentNode,f=x&&e.nodeName.toLowerCase(),p=!n&&!x,d=!1;if(c){if(y){while(l){a=e;while(a=a[l])if(x?a.nodeName.toLowerCase()===f:1===a.nodeType)return!1;u=l="only"===h&&!u&&"nextSibling"}return!0}if(u=[m?c.firstChild:c.lastChild],m&&p){d=(s=(r=(i=(o=(a=c)[k]||(a[k]={}))[a.uniqueID]||(o[a.uniqueID]={}))[h]||[])[0]===S&&r[1])&&r[2],a=s&&c.childNodes[s];while(a=++s&&a&&a[l]||(d=s=0)||u.pop())if(1===a.nodeType&&++d&&a===e){i[h]=[S,s,d];break}}else if(p&&(d=s=(r=(i=(o=(a=e)[k]||(a[k]={}))[a.uniqueID]||(o[a.uniqueID]={}))[h]||[])[0]===S&&r[1]),!1===d)while(a=++s&&a&&a[l]||(d=s=0)||u.pop())if((x?a.nodeName.toLowerCase()===f:1===a.nodeType)&&++d&&(p&&((i=(o=a[k]||(a[k]={}))[a.uniqueID]||(o[a.uniqueID]={}))[h]=[S,d]),a===e))break;return(d-=v)===g||d%g==0&&0<=d/g}}},PSEUDO:function(e,o){var t,a=b.pseudos[e]||b.setFilters[e.toLowerCase()]||se.error("unsupported pseudo: "+e);return a[k]?a(o):1<a.length?(t=[e,e,"",o],b.setFilters.hasOwnProperty(e.toLowerCase())?le(function(e,t){var n,r=a(e,o),i=r.length;while(i--)e[n=P(e,r[i])]=!(t[n]=r[i])}):function(e){return a(e,0,t)}):a}},pseudos:{not:le(function(e){var r=[],i=[],s=f(e.replace(B,"$1"));return s[k]?le(function(e,t,n,r){var i,o=s(e,null,r,[]),a=e.length;while(a--)(i=o[a])&&(e[a]=!(t[a]=i))}):function(e,t,n){return r[0]=e,s(r,null,n,i),r[0]=null,!i.pop()}}),has:le(function(t){return function(e){return 0<se(t,e).length}}),contains:le(function(t){return t=t.replace(te,ne),function(e){return-1<(e.textContent||o(e)).indexOf(t)}}),lang:le(function(n){return V.test(n||"")||se.error("unsupported lang: "+n),n=n.replace(te,ne).toLowerCase(),function(e){var t;do{if(t=E?e.lang:e.getAttribute("xml:lang")||e.getAttribute("lang"))return(t=t.toLowerCase())===n||0===t.indexOf(n+"-")}while((e=e.parentNode)&&1===e.nodeType);return!1}}),target:function(e){var t=n.location&&n.location.hash;return t&&t.slice(1)===e.id},root:function(e){return e===a},focus:function(e){return e===C.activeElement&&(!C.hasFocus||C.hasFocus())&&!!(e.type||e.href||~e.tabIndex)},enabled:ge(!1),disabled:ge(!0),checked:function(e){var t=e.nodeName.toLowerCase();return"input"===t&&!!e.checked||"option"===t&&!!e.selected},selected:function(e){return e.parentNode&&e.parentNode.selectedIndex,!0===e.selected},empty:function(e){for(e=e.firstChild;e;e=e.nextSibling)if(e.nodeType<6)return!1;return!0},parent:function(e){return!b.pseudos.empty(e)},header:function(e){return J.test(e.nodeName)},input:function(e){return Q.test(e.nodeName)},button:function(e){var t=e.nodeName.toLowerCase();return"input"===t&&"button"===e.type||"button"===t},text:function(e){var t;return"input"===e.nodeName.toLowerCase()&&"text"===e.type&&(null==(t=e.getAttribute("type"))||"text"===t.toLowerCase())},first:ve(function(){return[0]}),last:ve(function(e,t){return[t-1]}),eq:ve(function(e,t,n){return[n<0?n+t:n]}),even:ve(function(e,t){for(var n=0;n<t;n+=2)e.push(n);return e}),odd:ve(function(e,t){for(var n=1;n<t;n+=2)e.push(n);return e}),lt:ve(function(e,t,n){for(var r=n<0?n+t:t<n?t:n;0<=--r;)e.push(r);return e}),gt:ve(function(e,t,n){for(var r=n<0?n+t:n;++r<t;)e.push(r);return e})}}).pseudos.nth=b.pseudos.eq,{radio:!0,checkbox:!0,file:!0,password:!0,image:!0})b.pseudos[e]=de(e);for(e in{submit:!0,reset:!0})b.pseudos[e]=he(e);function me(){}function xe(e){for(var t=0,n=e.length,r="";t<n;t++)r+=e[t].value;return r}function be(s,e,t){var u=e.dir,l=e.next,c=l||u,f=t&&"parentNode"===c,p=r++;return e.first?function(e,t,n){while(e=e[u])if(1===e.nodeType||f)return s(e,t,n);return!1}:function(e,t,n){var r,i,o,a=[S,p];if(n){while(e=e[u])if((1===e.nodeType||f)&&s(e,t,n))return!0}else while(e=e[u])if(1===e.nodeType||f)if(i=(o=e[k]||(e[k]={}))[e.uniqueID]||(o[e.uniqueID]={}),l&&l===e.nodeName.toLowerCase())e=e[u]||e;else{if((r=i[c])&&r[0]===S&&r[1]===p)return a[2]=r[2];if((i[c]=a)[2]=s(e,t,n))return!0}return!1}}function we(i){return 1<i.length?function(e,t,n){var r=i.length;while(r--)if(!i[r](e,t,n))return!1;return!0}:i[0]}function Te(e,t,n,r,i){for(var o,a=[],s=0,u=e.length,l=null!=t;s<u;s++)(o=e[s])&&(n&&!n(o,r,i)||(a.push(o),l&&t.push(s)));return a}function Ce(d,h,g,v,y,e){return v&&!v[k]&&(v=Ce(v)),y&&!y[k]&&(y=Ce(y,e)),le(function(e,t,n,r){var i,o,a,s=[],u=[],l=t.length,c=e||function(e,t,n){for(var r=0,i=t.length;r<i;r++)se(e,t[r],n);return n}(h||"*",n.nodeType?[n]:n,[]),f=!d||!e&&h?c:Te(c,s,d,n,r),p=g?y||(e?d:l||v)?[]:t:f;if(g&&g(f,p,n,r),v){i=Te(p,u),v(i,[],n,r),o=i.length;while(o--)(a=i[o])&&(p[u[o]]=!(f[u[o]]=a))}if(e){if(y||d){if(y){i=[],o=p.length;while(o--)(a=p[o])&&i.push(f[o]=a);y(null,p=[],i,r)}o=p.length;while(o--)(a=p[o])&&-1<(i=y?P(e,a):s[o])&&(e[i]=!(t[i]=a))}}else p=Te(p===t?p.splice(l,p.length):p),y?y(null,t,p,r):H.apply(t,p)})}function Ee(e){for(var i,t,n,r=e.length,o=b.relative[e[0].type],a=o||b.relative[" "],s=o?1:0,u=be(function(e){return e===i},a,!0),l=be(function(e){return-1<P(i,e)},a,!0),c=[function(e,t,n){var r=!o&&(n||t!==w)||((i=t).nodeType?u(e,t,n):l(e,t,n));return i=null,r}];s<r;s++)if(t=b.relative[e[s].type])c=[be(we(c),t)];else{if((t=b.filter[e[s].type].apply(null,e[s].matches))[k]){for(n=++s;n<r;n++)if(b.relative[e[n].type])break;return Ce(1<s&&we(c),1<s&&xe(e.slice(0,s-1).concat({value:" "===e[s-2].type?"*":""})).replace(B,"$1"),t,s<n&&Ee(e.slice(s,n)),n<r&&Ee(e=e.slice(n)),n<r&&xe(e))}c.push(t)}return we(c)}return me.prototype=b.filters=b.pseudos,b.setFilters=new me,h=se.tokenize=function(e,t){var n,r,i,o,a,s,u,l=x[e+" "];if(l)return t?0:l.slice(0);a=e,s=[],u=b.preFilter;while(a){for(o in n&&!(r=_.exec(a))||(r&&(a=a.slice(r[0].length)||a),s.push(i=[])),n=!1,(r=z.exec(a))&&(n=r.shift(),i.push({value:n,type:r[0].replace(B," ")}),a=a.slice(n.length)),b.filter)!(r=G[o].exec(a))||u[o]&&!(r=u[o](r))||(n=r.shift(),i.push({value:n,type:o,matches:r}),a=a.slice(n.length));if(!n)break}return t?a.length:a?se.error(e):x(e,s).slice(0)},f=se.compile=function(e,t){var n,v,y,m,x,r,i=[],o=[],a=N[e+" "];if(!a){t||(t=h(e)),n=t.length;while(n--)(a=Ee(t[n]))[k]?i.push(a):o.push(a);(a=N(e,(v=o,m=0<(y=i).length,x=0<v.length,r=function(e,t,n,r,i){var o,a,s,u=0,l="0",c=e&&[],f=[],p=w,d=e||x&&b.find.TAG("*",i),h=S+=null==p?1:Math.random()||.1,g=d.length;for(i&&(w=t===C||t||i);l!==g&&null!=(o=d[l]);l++){if(x&&o){a=0,t||o.ownerDocument===C||(T(o),n=!E);while(s=v[a++])if(s(o,t||C,n)){r.push(o);break}i&&(S=h)}m&&((o=!s&&o)&&u--,e&&c.push(o))}if(u+=l,m&&l!==u){a=0;while(s=y[a++])s(c,f,t,n);if(e){if(0<u)while(l--)c[l]||f[l]||(f[l]=q.call(r));f=Te(f)}H.apply(r,f),i&&!e&&0<f.length&&1<u+y.length&&se.uniqueSort(r)}return i&&(S=h,w=p),c},m?le(r):r))).selector=e}return a},g=se.select=function(e,t,n,r){var i,o,a,s,u,l="function"==typeof e&&e,c=!r&&h(e=l.selector||e);if(n=n||[],1===c.length){if(2<(o=c[0]=c[0].slice(0)).length&&"ID"===(a=o[0]).type&&9===t.nodeType&&E&&b.relative[o[1].type]){if(!(t=(b.find.ID(a.matches[0].replace(te,ne),t)||[])[0]))return n;l&&(t=t.parentNode),e=e.slice(o.shift().value.length)}i=G.needsContext.test(e)?0:o.length;while(i--){if(a=o[i],b.relative[s=a.type])break;if((u=b.find[s])&&(r=u(a.matches[0].replace(te,ne),ee.test(o[0].type)&&ye(t.parentNode)||t))){if(o.splice(i,1),!(e=r.length&&xe(o)))return H.apply(n,r),n;break}}}return(l||f(e,c))(r,t,!E,n,!t||ee.test(e)&&ye(t.parentNode)||t),n},d.sortStable=k.split("").sort(D).join("")===k,d.detectDuplicates=!!l,T(),d.sortDetached=ce(function(e){return 1&e.compareDocumentPosition(C.createElement("fieldset"))}),ce(function(e){return e.innerHTML="<a href='#'></a>","#"===e.firstChild.getAttribute("href")})||fe("type|href|height|width",function(e,t,n){if(!n)return e.getAttribute(t,"type"===t.toLowerCase()?1:2)}),d.attributes&&ce(function(e){return e.innerHTML="<input/>",e.firstChild.setAttribute("value",""),""===e.firstChild.getAttribute("value")})||fe("value",function(e,t,n){if(!n&&"input"===e.nodeName.toLowerCase())return e.defaultValue}),ce(function(e){return null==e.getAttribute("disabled")})||fe(R,function(e,t,n){var r;if(!n)return!0===e[t]?t.toLowerCase():(r=e.getAttributeNode(t))&&r.specified?r.value:null}),se}(C);k.find=h,k.expr=h.selectors,k.expr[":"]=k.expr.pseudos,k.uniqueSort=k.unique=h.uniqueSort,k.text=h.getText,k.isXMLDoc=h.isXML,k.contains=h.contains,k.escapeSelector=h.escape;var T=function(e,t,n){var r=[],i=void 0!==n;while((e=e[t])&&9!==e.nodeType)if(1===e.nodeType){if(i&&k(e).is(n))break;r.push(e)}return r},S=function(e,t){for(var n=[];e;e=e.nextSibling)1===e.nodeType&&e!==t&&n.push(e);return n},N=k.expr.match.needsContext;function A(e,t){return e.nodeName&&e.nodeName.toLowerCase()===t.toLowerCase()}var D=/^<([a-z][^\/\0>:\x20\t\r\n\f]*)[\x20\t\r\n\f]*\/?>(?:<\/\1>|)$/i;function j(e,n,r){return m(n)?k.grep(e,function(e,t){return!!n.call(e,t,e)!==r}):n.nodeType?k.grep(e,function(e){return e===n!==r}):"string"!=typeof n?k.grep(e,function(e){return-1<i.call(n,e)!==r}):k.filter(n,e,r)}k.filter=function(e,t,n){var r=t[0];return n&&(e=":not("+e+")"),1===t.length&&1===r.nodeType?k.find.matchesSelector(r,e)?[r]:[]:k.find.matches(e,k.grep(t,function(e){return 1===e.nodeType}))},k.fn.extend({find:function(e){var t,n,r=this.length,i=this;if("string"!=typeof e)return this.pushStack(k(e).filter(function(){for(t=0;t<r;t++)if(k.contains(i[t],this))return!0}));for(n=this.pushStack([]),t=0;t<r;t++)k.find(e,i[t],n);return 1<r?k.uniqueSort(n):n},filter:function(e){return this.pushStack(j(this,e||[],!1))},not:function(e){return this.pushStack(j(this,e||[],!0))},is:function(e){return!!j(this,"string"==typeof e&&N.test(e)?k(e):e||[],!1).length}});var q,L=/^(?:\s*(<[\w\W]+>)[^>]*|#([\w-]+))$/;(k.fn.init=function(e,t,n){var r,i;if(!e)return this;if(n=n||q,"string"==typeof e){if(!(r="<"===e[0]&&">"===e[e.length-1]&&3<=e.length?[null,e,null]:L.exec(e))||!r[1]&&t)return!t||t.jquery?(t||n).find(e):this.constructor(t).find(e);if(r[1]){if(t=t instanceof k?t[0]:t,k.merge(this,k.parseHTML(r[1],t&&t.nodeType?t.ownerDocument||t:E,!0)),D.test(r[1])&&k.isPlainObject(t))for(r in t)m(this[r])?this[r](t[r]):this.attr(r,t[r]);return this}return(i=E.getElementById(r[2]))&&(this[0]=i,this.length=1),this}return e.nodeType?(this[0]=e,this.length=1,this):m(e)?void 0!==n.ready?n.ready(e):e(k):k.makeArray(e,this)}).prototype=k.fn,q=k(E);var H=/^(?:parents|prev(?:Until|All))/,O={children:!0,contents:!0,next:!0,prev:!0};function P(e,t){while((e=e[t])&&1!==e.nodeType);return e}k.fn.extend({has:function(e){var t=k(e,this),n=t.length;return this.filter(function(){for(var e=0;e<n;e++)if(k.contains(this,t[e]))return!0})},closest:function(e,t){var n,r=0,i=this.length,o=[],a="string"!=typeof e&&k(e);if(!N.test(e))for(;r<i;r++)for(n=this[r];n&&n!==t;n=n.parentNode)if(n.nodeType<11&&(a?-1<a.index(n):1===n.nodeType&&k.find.matchesSelector(n,e))){o.push(n);break}return this.pushStack(1<o.length?k.uniqueSort(o):o)},index:function(e){return e?"string"==typeof e?i.call(k(e),this[0]):i.call(this,e.jquery?e[0]:e):this[0]&&this[0].parentNode?this.first().prevAll().length:-1},add:function(e,t){return this.pushStack(k.uniqueSort(k.merge(this.get(),k(e,t))))},addBack:function(e){return this.add(null==e?this.prevObject:this.prevObject.filter(e))}}),k.each({parent:function(e){var t=e.parentNode;return t&&11!==t.nodeType?t:null},parents:function(e){return T(e,"parentNode")},parentsUntil:function(e,t,n){return T(e,"parentNode",n)},next:function(e){return P(e,"nextSibling")},prev:function(e){return P(e,"previousSibling")},nextAll:function(e){return T(e,"nextSibling")},prevAll:function(e){return T(e,"previousSibling")},nextUntil:function(e,t,n){return T(e,"nextSibling",n)},prevUntil:function(e,t,n){return T(e,"previousSibling",n)},siblings:function(e){return S((e.parentNode||{}).firstChild,e)},children:function(e){return S(e.firstChild)},contents:function(e){return"undefined"!=typeof e.contentDocument?e.contentDocument:(A(e,"template")&&(e=e.content||e),k.merge([],e.childNodes))}},function(r,i){k.fn[r]=function(e,t){var n=k.map(this,i,e);return"Until"!==r.slice(-5)&&(t=e),t&&"string"==typeof t&&(n=k.filter(t,n)),1<this.length&&(O[r]||k.uniqueSort(n),H.test(r)&&n.reverse()),this.pushStack(n)}});var R=/[^\x20\t\r\n\f]+/g;function M(e){return e}function I(e){throw e}function W(e,t,n,r){var i;try{e&&m(i=e.promise)?i.call(e).done(t).fail(n):e&&m(i=e.then)?i.call(e,t,n):t.apply(void 0,[e].slice(r))}catch(e){n.apply(void 0,[e])}}k.Callbacks=function(r){var e,n;r="string"==typeof r?(e=r,n={},k.each(e.match(R)||[],function(e,t){n[t]=!0}),n):k.extend({},r);var i,t,o,a,s=[],u=[],l=-1,c=function(){for(a=a||r.once,o=i=!0;u.length;l=-1){t=u.shift();while(++l<s.length)!1===s[l].apply(t[0],t[1])&&r.stopOnFalse&&(l=s.length,t=!1)}r.memory||(t=!1),i=!1,a&&(s=t?[]:"")},f={add:function(){return s&&(t&&!i&&(l=s.length-1,u.push(t)),function n(e){k.each(e,function(e,t){m(t)?r.unique&&f.has(t)||s.push(t):t&&t.length&&"string"!==w(t)&&n(t)})}(arguments),t&&!i&&c()),this},remove:function(){return k.each(arguments,function(e,t){var n;while(-1<(n=k.inArray(t,s,n)))s.splice(n,1),n<=l&&l--}),this},has:function(e){return e?-1<k.inArray(e,s):0<s.length},empty:function(){return s&&(s=[]),this},disable:function(){return a=u=[],s=t="",this},disabled:function(){return!s},lock:function(){return a=u=[],t||i||(s=t=""),this},locked:function(){return!!a},fireWith:function(e,t){return a||(t=[e,(t=t||[]).slice?t.slice():t],u.push(t),i||c()),this},fire:function(){return f.fireWith(this,arguments),this},fired:function(){return!!o}};return f},k.extend({Deferred:function(e){var o=[["notify","progress",k.Callbacks("memory"),k.Callbacks("memory"),2],["resolve","done",k.Callbacks("once memory"),k.Callbacks("once memory"),0,"resolved"],["reject","fail",k.Callbacks("once memory"),k.Callbacks("once memory"),1,"rejected"]],i="pending",a={state:function(){return i},always:function(){return s.done(arguments).fail(arguments),this},"catch":function(e){return a.then(null,e)},pipe:function(){var i=arguments;return k.Deferred(function(r){k.each(o,function(e,t){var n=m(i[t[4]])&&i[t[4]];s[t[1]](function(){var e=n&&n.apply(this,arguments);e&&m(e.promise)?e.promise().progress(r.notify).done(r.resolve).fail(r.reject):r[t[0]+"With"](this,n?[e]:arguments)})}),i=null}).promise()},then:function(t,n,r){var u=0;function l(i,o,a,s){return function(){var n=this,r=arguments,e=function(){var e,t;if(!(i<u)){if((e=a.apply(n,r))===o.promise())throw new TypeError("Thenable self-resolution");t=e&&("object"==typeof e||"function"==typeof e)&&e.then,m(t)?s?t.call(e,l(u,o,M,s),l(u,o,I,s)):(u++,t.call(e,l(u,o,M,s),l(u,o,I,s),l(u,o,M,o.notifyWith))):(a!==M&&(n=void 0,r=[e]),(s||o.resolveWith)(n,r))}},t=s?e:function(){try{e()}catch(e){k.Deferred.exceptionHook&&k.Deferred.exceptionHook(e,t.stackTrace),u<=i+1&&(a!==I&&(n=void 0,r=[e]),o.rejectWith(n,r))}};i?t():(k.Deferred.getStackHook&&(t.stackTrace=k.Deferred.getStackHook()),C.setTimeout(t))}}return k.Deferred(function(e){o[0][3].add(l(0,e,m(r)?r:M,e.notifyWith)),o[1][3].add(l(0,e,m(t)?t:M)),o[2][3].add(l(0,e,m(n)?n:I))}).promise()},promise:function(e){return null!=e?k.extend(e,a):a}},s={};return k.each(o,function(e,t){var n=t[2],r=t[5];a[t[1]]=n.add,r&&n.add(function(){i=r},o[3-e][2].disable,o[3-e][3].disable,o[0][2].lock,o[0][3].lock),n.add(t[3].fire),s[t[0]]=function(){return s[t[0]+"With"](this===s?void 0:this,arguments),this},s[t[0]+"With"]=n.fireWith}),a.promise(s),e&&e.call(s,s),s},when:function(e){var n=arguments.length,t=n,r=Array(t),i=s.call(arguments),o=k.Deferred(),a=function(t){return function(e){r[t]=this,i[t]=1<arguments.length?s.call(arguments):e,--n||o.resolveWith(r,i)}};if(n<=1&&(W(e,o.done(a(t)).resolve,o.reject,!n),"pending"===o.state()||m(i[t]&&i[t].then)))return o.then();while(t--)W(i[t],a(t),o.reject);return o.promise()}});var $=/^(Eval|Internal|Range|Reference|Syntax|Type|URI)Error$/;k.Deferred.exceptionHook=function(e,t){C.console&&C.console.warn&&e&&$.test(e.name)&&C.console.warn("jQuery.Deferred exception: "+e.message,e.stack,t)},k.readyException=function(e){C.setTimeout(function(){throw e})};var F=k.Deferred();function B(){E.removeEventListener("DOMContentLoaded",B),C.removeEventListener("load",B),k.ready()}k.fn.ready=function(e){return F.then(e)["catch"](function(e){k.readyException(e)}),this},k.extend({isReady:!1,readyWait:1,ready:function(e){(!0===e?--k.readyWait:k.isReady)||(k.isReady=!0)!==e&&0<--k.readyWait||F.resolveWith(E,[k])}}),k.ready.then=F.then,"complete"===E.readyState||"loading"!==E.readyState&&!E.documentElement.doScroll?C.setTimeout(k.ready):(E.addEventListener("DOMContentLoaded",B),C.addEventListener("load",B));var _=function(e,t,n,r,i,o,a){var s=0,u=e.length,l=null==n;if("object"===w(n))for(s in i=!0,n)_(e,t,s,n[s],!0,o,a);else if(void 0!==r&&(i=!0,m(r)||(a=!0),l&&(a?(t.call(e,r),t=null):(l=t,t=function(e,t,n){return l.call(k(e),n)})),t))for(;s<u;s++)t(e[s],n,a?r:r.call(e[s],s,t(e[s],n)));return i?e:l?t.call(e):u?t(e[0],n):o},z=/^-ms-/,U=/-([a-z])/g;function X(e,t){return t.toUpperCase()}function V(e){return e.replace(z,"ms-").replace(U,X)}var G=function(e){return 1===e.nodeType||9===e.nodeType||!+e.nodeType};function Y(){this.expando=k.expando+Y.uid++}Y.uid=1,Y.prototype={cache:function(e){var t=e[this.expando];return t||(t={},G(e)&&(e.nodeType?e[this.expando]=t:Object.defineProperty(e,this.expando,{value:t,configurable:!0}))),t},set:function(e,t,n){var r,i=this.cache(e);if("string"==typeof t)i[V(t)]=n;else for(r in t)i[V(r)]=t[r];return i},get:function(e,t){return void 0===t?this.cache(e):e[this.expando]&&e[this.expando][V(t)]},access:function(e,t,n){return void 0===t||t&&"string"==typeof t&&void 0===n?this.get(e,t):(this.set(e,t,n),void 0!==n?n:t)},remove:function(e,t){var n,r=e[this.expando];if(void 0!==r){if(void 0!==t){n=(t=Array.isArray(t)?t.map(V):(t=V(t))in r?[t]:t.match(R)||[]).length;while(n--)delete r[t[n]]}(void 0===t||k.isEmptyObject(r))&&(e.nodeType?e[this.expando]=void 0:delete e[this.expando])}},hasData:function(e){var t=e[this.expando];return void 0!==t&&!k.isEmptyObject(t)}};var Q=new Y,J=new Y,K=/^(?:\{[\w\W]*\}|\[[\w\W]*\])$/,Z=/[A-Z]/g;function ee(e,t,n){var r,i;if(void 0===n&&1===e.nodeType)if(r="data-"+t.replace(Z,"-$&").toLowerCase(),"string"==typeof(n=e.getAttribute(r))){try{n="true"===(i=n)||"false"!==i&&("null"===i?null:i===+i+""?+i:K.test(i)?JSON.parse(i):i)}catch(e){}J.set(e,t,n)}else n=void 0;return n}k.extend({hasData:function(e){return J.hasData(e)||Q.hasData(e)},data:function(e,t,n){return J.access(e,t,n)},removeData:function(e,t){J.remove(e,t)},_data:function(e,t,n){return Q.access(e,t,n)},_removeData:function(e,t){Q.remove(e,t)}}),k.fn.extend({data:function(n,e){var t,r,i,o=this[0],a=o&&o.attributes;if(void 0===n){if(this.length&&(i=J.get(o),1===o.nodeType&&!Q.get(o,"hasDataAttrs"))){t=a.length;while(t--)a[t]&&0===(r=a[t].name).indexOf("data-")&&(r=V(r.slice(5)),ee(o,r,i[r]));Q.set(o,"hasDataAttrs",!0)}return i}return"object"==typeof n?this.each(function(){J.set(this,n)}):_(this,function(e){var t;if(o&&void 0===e)return void 0!==(t=J.get(o,n))?t:void 0!==(t=ee(o,n))?t:void 0;this.each(function(){J.set(this,n,e)})},null,e,1<arguments.length,null,!0)},removeData:function(e){return this.each(function(){J.remove(this,e)})}}),k.extend({queue:function(e,t,n){var r;if(e)return t=(t||"fx")+"queue",r=Q.get(e,t),n&&(!r||Array.isArray(n)?r=Q.access(e,t,k.makeArray(n)):r.push(n)),r||[]},dequeue:function(e,t){t=t||"fx";var n=k.queue(e,t),r=n.length,i=n.shift(),o=k._queueHooks(e,t);"inprogress"===i&&(i=n.shift(),r--),i&&("fx"===t&&n.unshift("inprogress"),delete o.stop,i.call(e,function(){k.dequeue(e,t)},o)),!r&&o&&o.empty.fire()},_queueHooks:function(e,t){var n=t+"queueHooks";return Q.get(e,n)||Q.access(e,n,{empty:k.Callbacks("once memory").add(function(){Q.remove(e,[t+"queue",n])})})}}),k.fn.extend({queue:function(t,n){var e=2;return"string"!=typeof t&&(n=t,t="fx",e--),arguments.length<e?k.queue(this[0],t):void 0===n?this:this.each(function(){var e=k.queue(this,t,n);k._queueHooks(this,t),"fx"===t&&"inprogress"!==e[0]&&k.dequeue(this,t)})},dequeue:function(e){return this.each(function(){k.dequeue(this,e)})},clearQueue:function(e){return this.queue(e||"fx",[])},promise:function(e,t){var n,r=1,i=k.Deferred(),o=this,a=this.length,s=function(){--r||i.resolveWith(o,[o])};"string"!=typeof e&&(t=e,e=void 0),e=e||"fx";while(a--)(n=Q.get(o[a],e+"queueHooks"))&&n.empty&&(r++,n.empty.add(s));return s(),i.promise(t)}});var te=/[+-]?(?:\d*\.|)\d+(?:[eE][+-]?\d+|)/.source,ne=new RegExp("^(?:([+-])=|)("+te+")([a-z%]*)$","i"),re=["Top","Right","Bottom","Left"],ie=E.documentElement,oe=function(e){return k.contains(e.ownerDocument,e)},ae={composed:!0};ie.getRootNode&&(oe=function(e){return k.contains(e.ownerDocument,e)||e.getRootNode(ae)===e.ownerDocument});var se=function(e,t){return"none"===(e=t||e).style.display||""===e.style.display&&oe(e)&&"none"===k.css(e,"display")},ue=function(e,t,n,r){var i,o,a={};for(o in t)a[o]=e.style[o],e.style[o]=t[o];for(o in i=n.apply(e,r||[]),t)e.style[o]=a[o];return i};function le(e,t,n,r){var i,o,a=20,s=r?function(){return r.cur()}:function(){return k.css(e,t,"")},u=s(),l=n&&n[3]||(k.cssNumber[t]?"":"px"),c=e.nodeType&&(k.cssNumber[t]||"px"!==l&&+u)&&ne.exec(k.css(e,t));if(c&&c[3]!==l){u/=2,l=l||c[3],c=+u||1;while(a--)k.style(e,t,c+l),(1-o)*(1-(o=s()/u||.5))<=0&&(a=0),c/=o;c*=2,k.style(e,t,c+l),n=n||[]}return n&&(c=+c||+u||0,i=n[1]?c+(n[1]+1)*n[2]:+n[2],r&&(r.unit=l,r.start=c,r.end=i)),i}var ce={};function fe(e,t){for(var n,r,i,o,a,s,u,l=[],c=0,f=e.length;c<f;c++)(r=e[c]).style&&(n=r.style.display,t?("none"===n&&(l[c]=Q.get(r,"display")||null,l[c]||(r.style.display="")),""===r.style.display&&se(r)&&(l[c]=(u=a=o=void 0,a=(i=r).ownerDocument,s=i.nodeName,(u=ce[s])||(o=a.body.appendChild(a.createElement(s)),u=k.css(o,"display"),o.parentNode.removeChild(o),"none"===u&&(u="block"),ce[s]=u)))):"none"!==n&&(l[c]="none",Q.set(r,"display",n)));for(c=0;c<f;c++)null!=l[c]&&(e[c].style.display=l[c]);return e}k.fn.extend({show:function(){return fe(this,!0)},hide:function(){return fe(this)},toggle:function(e){return"boolean"==typeof e?e?this.show():this.hide():this.each(function(){se(this)?k(this).show():k(this).hide()})}});var pe=/^(?:checkbox|radio)$/i,de=/<([a-z][^\/\0>\x20\t\r\n\f]*)/i,he=/^$|^module$|\/(?:java|ecma)script/i,ge={option:[1,"<select multiple='multiple'>","</select>"],thead:[1,"<table>","</table>"],col:[2,"<table><colgroup>","</colgroup></table>"],tr:[2,"<table><tbody>","</tbody></table>"],td:[3,"<table><tbody><tr>","</tr></tbody></table>"],_default:[0,"",""]};function ve(e,t){var n;return n="undefined"!=typeof e.getElementsByTagName?e.getElementsByTagName(t||"*"):"undefined"!=typeof e.querySelectorAll?e.querySelectorAll(t||"*"):[],void 0===t||t&&A(e,t)?k.merge([e],n):n}function ye(e,t){for(var n=0,r=e.length;n<r;n++)Q.set(e[n],"globalEval",!t||Q.get(t[n],"globalEval"))}ge.optgroup=ge.option,ge.tbody=ge.tfoot=ge.colgroup=ge.caption=ge.thead,ge.th=ge.td;var me,xe,be=/<|&#?\w+;/;function we(e,t,n,r,i){for(var o,a,s,u,l,c,f=t.createDocumentFragment(),p=[],d=0,h=e.length;d<h;d++)if((o=e[d])||0===o)if("object"===w(o))k.merge(p,o.nodeType?[o]:o);else if(be.test(o)){a=a||f.appendChild(t.createElement("div")),s=(de.exec(o)||["",""])[1].toLowerCase(),u=ge[s]||ge._default,a.innerHTML=u[1]+k.htmlPrefilter(o)+u[2],c=u[0];while(c--)a=a.lastChild;k.merge(p,a.childNodes),(a=f.firstChild).textContent=""}else p.push(t.createTextNode(o));f.textContent="",d=0;while(o=p[d++])if(r&&-1<k.inArray(o,r))i&&i.push(o);else if(l=oe(o),a=ve(f.appendChild(o),"script"),l&&ye(a),n){c=0;while(o=a[c++])he.test(o.type||"")&&n.push(o)}return f}me=E.createDocumentFragment().appendChild(E.createElement("div")),(xe=E.createElement("input")).setAttribute("type","radio"),xe.setAttribute("checked","checked"),xe.setAttribute("name","t"),me.appendChild(xe),y.checkClone=me.cloneNode(!0).cloneNode(!0).lastChild.checked,me.innerHTML="<textarea>x</textarea>",y.noCloneChecked=!!me.cloneNode(!0).lastChild.defaultValue;var Te=/^key/,Ce=/^(?:mouse|pointer|contextmenu|drag|drop)|click/,Ee=/^([^.]*)(?:\.(.+)|)/;function ke(){return!0}function Se(){return!1}function Ne(e,t){return e===function(){try{return E.activeElement}catch(e){}}()==("focus"===t)}function Ae(e,t,n,r,i,o){var a,s;if("object"==typeof t){for(s in"string"!=typeof n&&(r=r||n,n=void 0),t)Ae(e,s,n,r,t[s],o);return e}if(null==r&&null==i?(i=n,r=n=void 0):null==i&&("string"==typeof n?(i=r,r=void 0):(i=r,r=n,n=void 0)),!1===i)i=Se;else if(!i)return e;return 1===o&&(a=i,(i=function(e){return k().off(e),a.apply(this,arguments)}).guid=a.guid||(a.guid=k.guid++)),e.each(function(){k.event.add(this,t,i,r,n)})}function De(e,i,o){o?(Q.set(e,i,!1),k.event.add(e,i,{namespace:!1,handler:function(e){var t,n,r=Q.get(this,i);if(1&e.isTrigger&&this[i]){if(r.length)(k.event.special[i]||{}).delegateType&&e.stopPropagation();else if(r=s.call(arguments),Q.set(this,i,r),t=o(this,i),this[i](),r!==(n=Q.get(this,i))||t?Q.set(this,i,!1):n={},r!==n)return e.stopImmediatePropagation(),e.preventDefault(),n.value}else r.length&&(Q.set(this,i,{value:k.event.trigger(k.extend(r[0],k.Event.prototype),r.slice(1),this)}),e.stopImmediatePropagation())}})):void 0===Q.get(e,i)&&k.event.add(e,i,ke)}k.event={global:{},add:function(t,e,n,r,i){var o,a,s,u,l,c,f,p,d,h,g,v=Q.get(t);if(v){n.handler&&(n=(o=n).handler,i=o.selector),i&&k.find.matchesSelector(ie,i),n.guid||(n.guid=k.guid++),(u=v.events)||(u=v.events={}),(a=v.handle)||(a=v.handle=function(e){return"undefined"!=typeof k&&k.event.triggered!==e.type?k.event.dispatch.apply(t,arguments):void 0}),l=(e=(e||"").match(R)||[""]).length;while(l--)d=g=(s=Ee.exec(e[l])||[])[1],h=(s[2]||"").split(".").sort(),d&&(f=k.event.special[d]||{},d=(i?f.delegateType:f.bindType)||d,f=k.event.special[d]||{},c=k.extend({type:d,origType:g,data:r,handler:n,guid:n.guid,selector:i,needsContext:i&&k.expr.match.needsContext.test(i),namespace:h.join(".")},o),(p=u[d])||((p=u[d]=[]).delegateCount=0,f.setup&&!1!==f.setup.call(t,r,h,a)||t.addEventListener&&t.addEventListener(d,a)),f.add&&(f.add.call(t,c),c.handler.guid||(c.handler.guid=n.guid)),i?p.splice(p.delegateCount++,0,c):p.push(c),k.event.global[d]=!0)}},remove:function(e,t,n,r,i){var o,a,s,u,l,c,f,p,d,h,g,v=Q.hasData(e)&&Q.get(e);if(v&&(u=v.events)){l=(t=(t||"").match(R)||[""]).length;while(l--)if(d=g=(s=Ee.exec(t[l])||[])[1],h=(s[2]||"").split(".").sort(),d){f=k.event.special[d]||{},p=u[d=(r?f.delegateType:f.bindType)||d]||[],s=s[2]&&new RegExp("(^|\\.)"+h.join("\\.(?:.*\\.|)")+"(\\.|$)"),a=o=p.length;while(o--)c=p[o],!i&&g!==c.origType||n&&n.guid!==c.guid||s&&!s.test(c.namespace)||r&&r!==c.selector&&("**"!==r||!c.selector)||(p.splice(o,1),c.selector&&p.delegateCount--,f.remove&&f.remove.call(e,c));a&&!p.length&&(f.teardown&&!1!==f.teardown.call(e,h,v.handle)||k.removeEvent(e,d,v.handle),delete u[d])}else for(d in u)k.event.remove(e,d+t[l],n,r,!0);k.isEmptyObject(u)&&Q.remove(e,"handle events")}},dispatch:function(e){var t,n,r,i,o,a,s=k.event.fix(e),u=new Array(arguments.length),l=(Q.get(this,"events")||{})[s.type]||[],c=k.event.special[s.type]||{};for(u[0]=s,t=1;t<arguments.length;t++)u[t]=arguments[t];if(s.delegateTarget=this,!c.preDispatch||!1!==c.preDispatch.call(this,s)){a=k.event.handlers.call(this,s,l),t=0;while((i=a[t++])&&!s.isPropagationStopped()){s.currentTarget=i.elem,n=0;while((o=i.handlers[n++])&&!s.isImmediatePropagationStopped())s.rnamespace&&!1!==o.namespace&&!s.rnamespace.test(o.namespace)||(s.handleObj=o,s.data=o.data,void 0!==(r=((k.event.special[o.origType]||{}).handle||o.handler).apply(i.elem,u))&&!1===(s.result=r)&&(s.preventDefault(),s.stopPropagation()))}return c.postDispatch&&c.postDispatch.call(this,s),s.result}},handlers:function(e,t){var n,r,i,o,a,s=[],u=t.delegateCount,l=e.target;if(u&&l.nodeType&&!("click"===e.type&&1<=e.button))for(;l!==this;l=l.parentNode||this)if(1===l.nodeType&&("click"!==e.type||!0!==l.disabled)){for(o=[],a={},n=0;n<u;n++)void 0===a[i=(r=t[n]).selector+" "]&&(a[i]=r.needsContext?-1<k(i,this).index(l):k.find(i,this,null,[l]).length),a[i]&&o.push(r);o.length&&s.push({elem:l,handlers:o})}return l=this,u<t.length&&s.push({elem:l,handlers:t.slice(u)}),s},addProp:function(t,e){Object.defineProperty(k.Event.prototype,t,{enumerable:!0,configurable:!0,get:m(e)?function(){if(this.originalEvent)return e(this.originalEvent)}:function(){if(this.originalEvent)return this.originalEvent[t]},set:function(e){Object.defineProperty(this,t,{enumerable:!0,configurable:!0,writable:!0,value:e})}})},fix:function(e){return e[k.expando]?e:new k.Event(e)},special:{load:{noBubble:!0},click:{setup:function(e){var t=this||e;return pe.test(t.type)&&t.click&&A(t,"input")&&De(t,"click",ke),!1},trigger:function(e){var t=this||e;return pe.test(t.type)&&t.click&&A(t,"input")&&De(t,"click"),!0},_default:function(e){var t=e.target;return pe.test(t.type)&&t.click&&A(t,"input")&&Q.get(t,"click")||A(t,"a")}},beforeunload:{postDispatch:function(e){void 0!==e.result&&e.originalEvent&&(e.originalEvent.returnValue=e.result)}}}},k.removeEvent=function(e,t,n){e.removeEventListener&&e.removeEventListener(t,n)},k.Event=function(e,t){if(!(this instanceof k.Event))return new k.Event(e,t);e&&e.type?(this.originalEvent=e,this.type=e.type,this.isDefaultPrevented=e.defaultPrevented||void 0===e.defaultPrevented&&!1===e.returnValue?ke:Se,this.target=e.target&&3===e.target.nodeType?e.target.parentNode:e.target,this.currentTarget=e.currentTarget,this.relatedTarget=e.relatedTarget):this.type=e,t&&k.extend(this,t),this.timeStamp=e&&e.timeStamp||Date.now(),this[k.expando]=!0},k.Event.prototype={constructor:k.Event,isDefaultPrevented:Se,isPropagationStopped:Se,isImmediatePropagationStopped:Se,isSimulated:!1,preventDefault:function(){var e=this.originalEvent;this.isDefaultPrevented=ke,e&&!this.isSimulated&&e.preventDefault()},stopPropagation:function(){var e=this.originalEvent;this.isPropagationStopped=ke,e&&!this.isSimulated&&e.stopPropagation()},stopImmediatePropagation:function(){var e=this.originalEvent;this.isImmediatePropagationStopped=ke,e&&!this.isSimulated&&e.stopImmediatePropagation(),this.stopPropagation()}},k.each({altKey:!0,bubbles:!0,cancelable:!0,changedTouches:!0,ctrlKey:!0,detail:!0,eventPhase:!0,metaKey:!0,pageX:!0,pageY:!0,shiftKey:!0,view:!0,"char":!0,code:!0,charCode:!0,key:!0,keyCode:!0,button:!0,buttons:!0,clientX:!0,clientY:!0,offsetX:!0,offsetY:!0,pointerId:!0,pointerType:!0,screenX:!0,screenY:!0,targetTouches:!0,toElement:!0,touches:!0,which:function(e){var t=e.button;return null==e.which&&Te.test(e.type)?null!=e.charCode?e.charCode:e.keyCode:!e.which&&void 0!==t&&Ce.test(e.type)?1&t?1:2&t?3:4&t?2:0:e.which}},k.event.addProp),k.each({focus:"focusin",blur:"focusout"},function(e,t){k.event.special[e]={setup:function(){return De(this,e,Ne),!1},trigger:function(){return De(this,e),!0},delegateType:t}}),k.each({mouseenter:"mouseover",mouseleave:"mouseout",pointerenter:"pointerover",pointerleave:"pointerout"},function(e,i){k.event.special[e]={delegateType:i,bindType:i,handle:function(e){var t,n=e.relatedTarget,r=e.handleObj;return n&&(n===this||k.contains(this,n))||(e.type=r.origType,t=r.handler.apply(this,arguments),e.type=i),t}}}),k.fn.extend({on:function(e,t,n,r){return Ae(this,e,t,n,r)},one:function(e,t,n,r){return Ae(this,e,t,n,r,1)},off:function(e,t,n){var r,i;if(e&&e.preventDefault&&e.handleObj)return r=e.handleObj,k(e.delegateTarget).off(r.namespace?r.origType+"."+r.namespace:r.origType,r.selector,r.handler),this;if("object"==typeof e){for(i in e)this.off(i,t,e[i]);return this}return!1!==t&&"function"!=typeof t||(n=t,t=void 0),!1===n&&(n=Se),this.each(function(){k.event.remove(this,e,n,t)})}});var je=/<(?!area|br|col|embed|hr|img|input|link|meta|param)(([a-z][^\/\0>\x20\t\r\n\f]*)[^>]*)\/>/gi,qe=/<script|<style|<link/i,Le=/checked\s*(?:[^=]|=\s*.checked.)/i,He=/^\s*<!(?:\[CDATA\[|--)|(?:\]\]|--)>\s*$/g;function Oe(e,t){return A(e,"table")&&A(11!==t.nodeType?t:t.firstChild,"tr")&&k(e).children("tbody")[0]||e}function Pe(e){return e.type=(null!==e.getAttribute("type"))+"/"+e.type,e}function Re(e){return"true/"===(e.type||"").slice(0,5)?e.type=e.type.slice(5):e.removeAttribute("type"),e}function Me(e,t){var n,r,i,o,a,s,u,l;if(1===t.nodeType){if(Q.hasData(e)&&(o=Q.access(e),a=Q.set(t,o),l=o.events))for(i in delete a.handle,a.events={},l)for(n=0,r=l[i].length;n<r;n++)k.event.add(t,i,l[i][n]);J.hasData(e)&&(s=J.access(e),u=k.extend({},s),J.set(t,u))}}function Ie(n,r,i,o){r=g.apply([],r);var e,t,a,s,u,l,c=0,f=n.length,p=f-1,d=r[0],h=m(d);if(h||1<f&&"string"==typeof d&&!y.checkClone&&Le.test(d))return n.each(function(e){var t=n.eq(e);h&&(r[0]=d.call(this,e,t.html())),Ie(t,r,i,o)});if(f&&(t=(e=we(r,n[0].ownerDocument,!1,n,o)).firstChild,1===e.childNodes.length&&(e=t),t||o)){for(s=(a=k.map(ve(e,"script"),Pe)).length;c<f;c++)u=e,c!==p&&(u=k.clone(u,!0,!0),s&&k.merge(a,ve(u,"script"))),i.call(n[c],u,c);if(s)for(l=a[a.length-1].ownerDocument,k.map(a,Re),c=0;c<s;c++)u=a[c],he.test(u.type||"")&&!Q.access(u,"globalEval")&&k.contains(l,u)&&(u.src&&"module"!==(u.type||"").toLowerCase()?k._evalUrl&&!u.noModule&&k._evalUrl(u.src,{nonce:u.nonce||u.getAttribute("nonce")}):b(u.textContent.replace(He,""),u,l))}return n}function We(e,t,n){for(var r,i=t?k.filter(t,e):e,o=0;null!=(r=i[o]);o++)n||1!==r.nodeType||k.cleanData(ve(r)),r.parentNode&&(n&&oe(r)&&ye(ve(r,"script")),r.parentNode.removeChild(r));return e}k.extend({htmlPrefilter:function(e){return e.replace(je,"<$1></$2>")},clone:function(e,t,n){var r,i,o,a,s,u,l,c=e.cloneNode(!0),f=oe(e);if(!(y.noCloneChecked||1!==e.nodeType&&11!==e.nodeType||k.isXMLDoc(e)))for(a=ve(c),r=0,i=(o=ve(e)).length;r<i;r++)s=o[r],u=a[r],void 0,"input"===(l=u.nodeName.toLowerCase())&&pe.test(s.type)?u.checked=s.checked:"input"!==l&&"textarea"!==l||(u.defaultValue=s.defaultValue);if(t)if(n)for(o=o||ve(e),a=a||ve(c),r=0,i=o.length;r<i;r++)Me(o[r],a[r]);else Me(e,c);return 0<(a=ve(c,"script")).length&&ye(a,!f&&ve(e,"script")),c},cleanData:function(e){for(var t,n,r,i=k.event.special,o=0;void 0!==(n=e[o]);o++)if(G(n)){if(t=n[Q.expando]){if(t.events)for(r in t.events)i[r]?k.event.remove(n,r):k.removeEvent(n,r,t.handle);n[Q.expando]=void 0}n[J.expando]&&(n[J.expando]=void 0)}}}),k.fn.extend({detach:function(e){return We(this,e,!0)},remove:function(e){return We(this,e)},text:function(e){return _(this,function(e){return void 0===e?k.text(this):this.empty().each(function(){1!==this.nodeType&&11!==this.nodeType&&9!==this.nodeType||(this.textContent=e)})},null,e,arguments.length)},append:function(){return Ie(this,arguments,function(e){1!==this.nodeType&&11!==this.nodeType&&9!==this.nodeType||Oe(this,e).appendChild(e)})},prepend:function(){return Ie(this,arguments,function(e){if(1===this.nodeType||11===this.nodeType||9===this.nodeType){var t=Oe(this,e);t.insertBefore(e,t.firstChild)}})},before:function(){return Ie(this,arguments,function(e){this.parentNode&&this.parentNode.insertBefore(e,this)})},after:function(){return Ie(this,arguments,function(e){this.parentNode&&this.parentNode.insertBefore(e,this.nextSibling)})},empty:function(){for(var e,t=0;null!=(e=this[t]);t++)1===e.nodeType&&(k.cleanData(ve(e,!1)),e.textContent="");return this},clone:function(e,t){return e=null!=e&&e,t=null==t?e:t,this.map(function(){return k.clone(this,e,t)})},html:function(e){return _(this,function(e){var t=this[0]||{},n=0,r=this.length;if(void 0===e&&1===t.nodeType)return t.innerHTML;if("string"==typeof e&&!qe.test(e)&&!ge[(de.exec(e)||["",""])[1].toLowerCase()]){e=k.htmlPrefilter(e);try{for(;n<r;n++)1===(t=this[n]||{}).nodeType&&(k.cleanData(ve(t,!1)),t.innerHTML=e);t=0}catch(e){}}t&&this.empty().append(e)},null,e,arguments.length)},replaceWith:function(){var n=[];return Ie(this,arguments,function(e){var t=this.parentNode;k.inArray(this,n)<0&&(k.cleanData(ve(this)),t&&t.replaceChild(e,this))},n)}}),k.each({appendTo:"append",prependTo:"prepend",insertBefore:"before",insertAfter:"after",replaceAll:"replaceWith"},function(e,a){k.fn[e]=function(e){for(var t,n=[],r=k(e),i=r.length-1,o=0;o<=i;o++)t=o===i?this:this.clone(!0),k(r[o])[a](t),u.apply(n,t.get());return this.pushStack(n)}});var $e=new RegExp("^("+te+")(?!px)[a-z%]+$","i"),Fe=function(e){var t=e.ownerDocument.defaultView;return t&&t.opener||(t=C),t.getComputedStyle(e)},Be=new RegExp(re.join("|"),"i");function _e(e,t,n){var r,i,o,a,s=e.style;return(n=n||Fe(e))&&(""!==(a=n.getPropertyValue(t)||n[t])||oe(e)||(a=k.style(e,t)),!y.pixelBoxStyles()&&$e.test(a)&&Be.test(t)&&(r=s.width,i=s.minWidth,o=s.maxWidth,s.minWidth=s.maxWidth=s.width=a,a=n.width,s.width=r,s.minWidth=i,s.maxWidth=o)),void 0!==a?a+"":a}function ze(e,t){return{get:function(){if(!e())return(this.get=t).apply(this,arguments);delete this.get}}}!function(){function e(){if(u){s.style.cssText="position:absolute;left:-11111px;width:60px;margin-top:1px;padding:0;border:0",u.style.cssText="position:relative;display:block;box-sizing:border-box;overflow:scroll;margin:auto;border:1px;padding:1px;width:60%;top:1%",ie.appendChild(s).appendChild(u);var e=C.getComputedStyle(u);n="1%"!==e.top,a=12===t(e.marginLeft),u.style.right="60%",o=36===t(e.right),r=36===t(e.width),u.style.position="absolute",i=12===t(u.offsetWidth/3),ie.removeChild(s),u=null}}function t(e){return Math.round(parseFloat(e))}var n,r,i,o,a,s=E.createElement("div"),u=E.createElement("div");u.style&&(u.style.backgroundClip="content-box",u.cloneNode(!0).style.backgroundClip="",y.clearCloneStyle="content-box"===u.style.backgroundClip,k.extend(y,{boxSizingReliable:function(){return e(),r},pixelBoxStyles:function(){return e(),o},pixelPosition:function(){return e(),n},reliableMarginLeft:function(){return e(),a},scrollboxSize:function(){return e(),i}}))}();var Ue=["Webkit","Moz","ms"],Xe=E.createElement("div").style,Ve={};function Ge(e){var t=k.cssProps[e]||Ve[e];return t||(e in Xe?e:Ve[e]=function(e){var t=e[0].toUpperCase()+e.slice(1),n=Ue.length;while(n--)if((e=Ue[n]+t)in Xe)return e}(e)||e)}var Ye=/^(none|table(?!-c[ea]).+)/,Qe=/^--/,Je={position:"absolute",visibility:"hidden",display:"block"},Ke={letterSpacing:"0",fontWeight:"400"};function Ze(e,t,n){var r=ne.exec(t);return r?Math.max(0,r[2]-(n||0))+(r[3]||"px"):t}function et(e,t,n,r,i,o){var a="width"===t?1:0,s=0,u=0;if(n===(r?"border":"content"))return 0;for(;a<4;a+=2)"margin"===n&&(u+=k.css(e,n+re[a],!0,i)),r?("content"===n&&(u-=k.css(e,"padding"+re[a],!0,i)),"margin"!==n&&(u-=k.css(e,"border"+re[a]+"Width",!0,i))):(u+=k.css(e,"padding"+re[a],!0,i),"padding"!==n?u+=k.css(e,"border"+re[a]+"Width",!0,i):s+=k.css(e,"border"+re[a]+"Width",!0,i));return!r&&0<=o&&(u+=Math.max(0,Math.ceil(e["offset"+t[0].toUpperCase()+t.slice(1)]-o-u-s-.5))||0),u}function tt(e,t,n){var r=Fe(e),i=(!y.boxSizingReliable()||n)&&"border-box"===k.css(e,"boxSizing",!1,r),o=i,a=_e(e,t,r),s="offset"+t[0].toUpperCase()+t.slice(1);if($e.test(a)){if(!n)return a;a="auto"}return(!y.boxSizingReliable()&&i||"auto"===a||!parseFloat(a)&&"inline"===k.css(e,"display",!1,r))&&e.getClientRects().length&&(i="border-box"===k.css(e,"boxSizing",!1,r),(o=s in e)&&(a=e[s])),(a=parseFloat(a)||0)+et(e,t,n||(i?"border":"content"),o,r,a)+"px"}function nt(e,t,n,r,i){return new nt.prototype.init(e,t,n,r,i)}k.extend({cssHooks:{opacity:{get:function(e,t){if(t){var n=_e(e,"opacity");return""===n?"1":n}}}},cssNumber:{animationIterationCount:!0,columnCount:!0,fillOpacity:!0,flexGrow:!0,flexShrink:!0,fontWeight:!0,gridArea:!0,gridColumn:!0,gridColumnEnd:!0,gridColumnStart:!0,gridRow:!0,gridRowEnd:!0,gridRowStart:!0,lineHeight:!0,opacity:!0,order:!0,orphans:!0,widows:!0,zIndex:!0,zoom:!0},cssProps:{},style:function(e,t,n,r){if(e&&3!==e.nodeType&&8!==e.nodeType&&e.style){var i,o,a,s=V(t),u=Qe.test(t),l=e.style;if(u||(t=Ge(s)),a=k.cssHooks[t]||k.cssHooks[s],void 0===n)return a&&"get"in a&&void 0!==(i=a.get(e,!1,r))?i:l[t];"string"===(o=typeof n)&&(i=ne.exec(n))&&i[1]&&(n=le(e,t,i),o="number"),null!=n&&n==n&&("number"!==o||u||(n+=i&&i[3]||(k.cssNumber[s]?"":"px")),y.clearCloneStyle||""!==n||0!==t.indexOf("background")||(l[t]="inherit"),a&&"set"in a&&void 0===(n=a.set(e,n,r))||(u?l.setProperty(t,n):l[t]=n))}},css:function(e,t,n,r){var i,o,a,s=V(t);return Qe.test(t)||(t=Ge(s)),(a=k.cssHooks[t]||k.cssHooks[s])&&"get"in a&&(i=a.get(e,!0,n)),void 0===i&&(i=_e(e,t,r)),"normal"===i&&t in Ke&&(i=Ke[t]),""===n||n?(o=parseFloat(i),!0===n||isFinite(o)?o||0:i):i}}),k.each(["height","width"],function(e,u){k.cssHooks[u]={get:function(e,t,n){if(t)return!Ye.test(k.css(e,"display"))||e.getClientRects().length&&e.getBoundingClientRect().width?tt(e,u,n):ue(e,Je,function(){return tt(e,u,n)})},set:function(e,t,n){var r,i=Fe(e),o=!y.scrollboxSize()&&"absolute"===i.position,a=(o||n)&&"border-box"===k.css(e,"boxSizing",!1,i),s=n?et(e,u,n,a,i):0;return a&&o&&(s-=Math.ceil(e["offset"+u[0].toUpperCase()+u.slice(1)]-parseFloat(i[u])-et(e,u,"border",!1,i)-.5)),s&&(r=ne.exec(t))&&"px"!==(r[3]||"px")&&(e.style[u]=t,t=k.css(e,u)),Ze(0,t,s)}}}),k.cssHooks.marginLeft=ze(y.reliableMarginLeft,function(e,t){if(t)return(parseFloat(_e(e,"marginLeft"))||e.getBoundingClientRect().left-ue(e,{marginLeft:0},function(){return e.getBoundingClientRect().left}))+"px"}),k.each({margin:"",padding:"",border:"Width"},function(i,o){k.cssHooks[i+o]={expand:function(e){for(var t=0,n={},r="string"==typeof e?e.split(" "):[e];t<4;t++)n[i+re[t]+o]=r[t]||r[t-2]||r[0];return n}},"margin"!==i&&(k.cssHooks[i+o].set=Ze)}),k.fn.extend({css:function(e,t){return _(this,function(e,t,n){var r,i,o={},a=0;if(Array.isArray(t)){for(r=Fe(e),i=t.length;a<i;a++)o[t[a]]=k.css(e,t[a],!1,r);return o}return void 0!==n?k.style(e,t,n):k.css(e,t)},e,t,1<arguments.length)}}),((k.Tween=nt).prototype={constructor:nt,init:function(e,t,n,r,i,o){this.elem=e,this.prop=n,this.easing=i||k.easing._default,this.options=t,this.start=this.now=this.cur(),this.end=r,this.unit=o||(k.cssNumber[n]?"":"px")},cur:function(){var e=nt.propHooks[this.prop];return e&&e.get?e.get(this):nt.propHooks._default.get(this)},run:function(e){var t,n=nt.propHooks[this.prop];return this.options.duration?this.pos=t=k.easing[this.easing](e,this.options.duration*e,0,1,this.options.duration):this.pos=t=e,this.now=(this.end-this.start)*t+this.start,this.options.step&&this.options.step.call(this.elem,this.now,this),n&&n.set?n.set(this):nt.propHooks._default.set(this),this}}).init.prototype=nt.prototype,(nt.propHooks={_default:{get:function(e){var t;return 1!==e.elem.nodeType||null!=e.elem[e.prop]&&null==e.elem.style[e.prop]?e.elem[e.prop]:(t=k.css(e.elem,e.prop,""))&&"auto"!==t?t:0},set:function(e){k.fx.step[e.prop]?k.fx.step[e.prop](e):1!==e.elem.nodeType||!k.cssHooks[e.prop]&&null==e.elem.style[Ge(e.prop)]?e.elem[e.prop]=e.now:k.style(e.elem,e.prop,e.now+e.unit)}}}).scrollTop=nt.propHooks.scrollLeft={set:function(e){e.elem.nodeType&&e.elem.parentNode&&(e.elem[e.prop]=e.now)}},k.easing={linear:function(e){return e},swing:function(e){return.5-Math.cos(e*Math.PI)/2},_default:"swing"},k.fx=nt.prototype.init,k.fx.step={};var rt,it,ot,at,st=/^(?:toggle|show|hide)$/,ut=/queueHooks$/;function lt(){it&&(!1===E.hidden&&C.requestAnimationFrame?C.requestAnimationFrame(lt):C.setTimeout(lt,k.fx.interval),k.fx.tick())}function ct(){return C.setTimeout(function(){rt=void 0}),rt=Date.now()}function ft(e,t){var n,r=0,i={height:e};for(t=t?1:0;r<4;r+=2-t)i["margin"+(n=re[r])]=i["padding"+n]=e;return t&&(i.opacity=i.width=e),i}function pt(e,t,n){for(var r,i=(dt.tweeners[t]||[]).concat(dt.tweeners["*"]),o=0,a=i.length;o<a;o++)if(r=i[o].call(n,t,e))return r}function dt(o,e,t){var n,a,r=0,i=dt.prefilters.length,s=k.Deferred().always(function(){delete u.elem}),u=function(){if(a)return!1;for(var e=rt||ct(),t=Math.max(0,l.startTime+l.duration-e),n=1-(t/l.duration||0),r=0,i=l.tweens.length;r<i;r++)l.tweens[r].run(n);return s.notifyWith(o,[l,n,t]),n<1&&i?t:(i||s.notifyWith(o,[l,1,0]),s.resolveWith(o,[l]),!1)},l=s.promise({elem:o,props:k.extend({},e),opts:k.extend(!0,{specialEasing:{},easing:k.easing._default},t),originalProperties:e,originalOptions:t,startTime:rt||ct(),duration:t.duration,tweens:[],createTween:function(e,t){var n=k.Tween(o,l.opts,e,t,l.opts.specialEasing[e]||l.opts.easing);return l.tweens.push(n),n},stop:function(e){var t=0,n=e?l.tweens.length:0;if(a)return this;for(a=!0;t<n;t++)l.tweens[t].run(1);return e?(s.notifyWith(o,[l,1,0]),s.resolveWith(o,[l,e])):s.rejectWith(o,[l,e]),this}}),c=l.props;for(!function(e,t){var n,r,i,o,a;for(n in e)if(i=t[r=V(n)],o=e[n],Array.isArray(o)&&(i=o[1],o=e[n]=o[0]),n!==r&&(e[r]=o,delete e[n]),(a=k.cssHooks[r])&&"expand"in a)for(n in o=a.expand(o),delete e[r],o)n in e||(e[n]=o[n],t[n]=i);else t[r]=i}(c,l.opts.specialEasing);r<i;r++)if(n=dt.prefilters[r].call(l,o,c,l.opts))return m(n.stop)&&(k._queueHooks(l.elem,l.opts.queue).stop=n.stop.bind(n)),n;return k.map(c,pt,l),m(l.opts.start)&&l.opts.start.call(o,l),l.progress(l.opts.progress).done(l.opts.done,l.opts.complete).fail(l.opts.fail).always(l.opts.always),k.fx.timer(k.extend(u,{elem:o,anim:l,queue:l.opts.queue})),l}k.Animation=k.extend(dt,{tweeners:{"*":[function(e,t){var n=this.createTween(e,t);return le(n.elem,e,ne.exec(t),n),n}]},tweener:function(e,t){m(e)?(t=e,e=["*"]):e=e.match(R);for(var n,r=0,i=e.length;r<i;r++)n=e[r],dt.tweeners[n]=dt.tweeners[n]||[],dt.tweeners[n].unshift(t)},prefilters:[function(e,t,n){var r,i,o,a,s,u,l,c,f="width"in t||"height"in t,p=this,d={},h=e.style,g=e.nodeType&&se(e),v=Q.get(e,"fxshow");for(r in n.queue||(null==(a=k._queueHooks(e,"fx")).unqueued&&(a.unqueued=0,s=a.empty.fire,a.empty.fire=function(){a.unqueued||s()}),a.unqueued++,p.always(function(){p.always(function(){a.unqueued--,k.queue(e,"fx").length||a.empty.fire()})})),t)if(i=t[r],st.test(i)){if(delete t[r],o=o||"toggle"===i,i===(g?"hide":"show")){if("show"!==i||!v||void 0===v[r])continue;g=!0}d[r]=v&&v[r]||k.style(e,r)}if((u=!k.isEmptyObject(t))||!k.isEmptyObject(d))for(r in f&&1===e.nodeType&&(n.overflow=[h.overflow,h.overflowX,h.overflowY],null==(l=v&&v.display)&&(l=Q.get(e,"display")),"none"===(c=k.css(e,"display"))&&(l?c=l:(fe([e],!0),l=e.style.display||l,c=k.css(e,"display"),fe([e]))),("inline"===c||"inline-block"===c&&null!=l)&&"none"===k.css(e,"float")&&(u||(p.done(function(){h.display=l}),null==l&&(c=h.display,l="none"===c?"":c)),h.display="inline-block")),n.overflow&&(h.overflow="hidden",p.always(function(){h.overflow=n.overflow[0],h.overflowX=n.overflow[1],h.overflowY=n.overflow[2]})),u=!1,d)u||(v?"hidden"in v&&(g=v.hidden):v=Q.access(e,"fxshow",{display:l}),o&&(v.hidden=!g),g&&fe([e],!0),p.done(function(){for(r in g||fe([e]),Q.remove(e,"fxshow"),d)k.style(e,r,d[r])})),u=pt(g?v[r]:0,r,p),r in v||(v[r]=u.start,g&&(u.end=u.start,u.start=0))}],prefilter:function(e,t){t?dt.prefilters.unshift(e):dt.prefilters.push(e)}}),k.speed=function(e,t,n){var r=e&&"object"==typeof e?k.extend({},e):{complete:n||!n&&t||m(e)&&e,duration:e,easing:n&&t||t&&!m(t)&&t};return k.fx.off?r.duration=0:"number"!=typeof r.duration&&(r.duration in k.fx.speeds?r.duration=k.fx.speeds[r.duration]:r.duration=k.fx.speeds._default),null!=r.queue&&!0!==r.queue||(r.queue="fx"),r.old=r.complete,r.complete=function(){m(r.old)&&r.old.call(this),r.queue&&k.dequeue(this,r.queue)},r},k.fn.extend({fadeTo:function(e,t,n,r){return this.filter(se).css("opacity",0).show().end().animate({opacity:t},e,n,r)},animate:function(t,e,n,r){var i=k.isEmptyObject(t),o=k.speed(e,n,r),a=function(){var e=dt(this,k.extend({},t),o);(i||Q.get(this,"finish"))&&e.stop(!0)};return a.finish=a,i||!1===o.queue?this.each(a):this.queue(o.queue,a)},stop:function(i,e,o){var a=function(e){var t=e.stop;delete e.stop,t(o)};return"string"!=typeof i&&(o=e,e=i,i=void 0),e&&!1!==i&&this.queue(i||"fx",[]),this.each(function(){var e=!0,t=null!=i&&i+"queueHooks",n=k.timers,r=Q.get(this);if(t)r[t]&&r[t].stop&&a(r[t]);else for(t in r)r[t]&&r[t].stop&&ut.test(t)&&a(r[t]);for(t=n.length;t--;)n[t].elem!==this||null!=i&&n[t].queue!==i||(n[t].anim.stop(o),e=!1,n.splice(t,1));!e&&o||k.dequeue(this,i)})},finish:function(a){return!1!==a&&(a=a||"fx"),this.each(function(){var e,t=Q.get(this),n=t[a+"queue"],r=t[a+"queueHooks"],i=k.timers,o=n?n.length:0;for(t.finish=!0,k.queue(this,a,[]),r&&r.stop&&r.stop.call(this,!0),e=i.length;e--;)i[e].elem===this&&i[e].queue===a&&(i[e].anim.stop(!0),i.splice(e,1));for(e=0;e<o;e++)n[e]&&n[e].finish&&n[e].finish.call(this);delete t.finish})}}),k.each(["toggle","show","hide"],function(e,r){var i=k.fn[r];k.fn[r]=function(e,t,n){return null==e||"boolean"==typeof e?i.apply(this,arguments):this.animate(ft(r,!0),e,t,n)}}),k.each({slideDown:ft("show"),slideUp:ft("hide"),slideToggle:ft("toggle"),fadeIn:{opacity:"show"},fadeOut:{opacity:"hide"},fadeToggle:{opacity:"toggle"}},function(e,r){k.fn[e]=function(e,t,n){return this.animate(r,e,t,n)}}),k.timers=[],k.fx.tick=function(){var e,t=0,n=k.timers;for(rt=Date.now();t<n.length;t++)(e=n[t])()||n[t]!==e||n.splice(t--,1);n.length||k.fx.stop(),rt=void 0},k.fx.timer=function(e){k.timers.push(e),k.fx.start()},k.fx.interval=13,k.fx.start=function(){it||(it=!0,lt())},k.fx.stop=function(){it=null},k.fx.speeds={slow:600,fast:200,_default:400},k.fn.delay=function(r,e){return r=k.fx&&k.fx.speeds[r]||r,e=e||"fx",this.queue(e,function(e,t){var n=C.setTimeout(e,r);t.stop=function(){C.clearTimeout(n)}})},ot=E.createElement("input"),at=E.createElement("select").appendChild(E.createElement("option")),ot.type="checkbox",y.checkOn=""!==ot.value,y.optSelected=at.selected,(ot=E.createElement("input")).value="t",ot.type="radio",y.radioValue="t"===ot.value;var ht,gt=k.expr.attrHandle;k.fn.extend({attr:function(e,t){return _(this,k.attr,e,t,1<arguments.length)},removeAttr:function(e){return this.each(function(){k.removeAttr(this,e)})}}),k.extend({attr:function(e,t,n){var r,i,o=e.nodeType;if(3!==o&&8!==o&&2!==o)return"undefined"==typeof e.getAttribute?k.prop(e,t,n):(1===o&&k.isXMLDoc(e)||(i=k.attrHooks[t.toLowerCase()]||(k.expr.match.bool.test(t)?ht:void 0)),void 0!==n?null===n?void k.removeAttr(e,t):i&&"set"in i&&void 0!==(r=i.set(e,n,t))?r:(e.setAttribute(t,n+""),n):i&&"get"in i&&null!==(r=i.get(e,t))?r:null==(r=k.find.attr(e,t))?void 0:r)},attrHooks:{type:{set:function(e,t){if(!y.radioValue&&"radio"===t&&A(e,"input")){var n=e.value;return e.setAttribute("type",t),n&&(e.value=n),t}}}},removeAttr:function(e,t){var n,r=0,i=t&&t.match(R);if(i&&1===e.nodeType)while(n=i[r++])e.removeAttribute(n)}}),ht={set:function(e,t,n){return!1===t?k.removeAttr(e,n):e.setAttribute(n,n),n}},k.each(k.expr.match.bool.source.match(/\w+/g),function(e,t){var a=gt[t]||k.find.attr;gt[t]=function(e,t,n){var r,i,o=t.toLowerCase();return n||(i=gt[o],gt[o]=r,r=null!=a(e,t,n)?o:null,gt[o]=i),r}});var vt=/^(?:input|select|textarea|button)$/i,yt=/^(?:a|area)$/i;function mt(e){return(e.match(R)||[]).join(" ")}function xt(e){return e.getAttribute&&e.getAttribute("class")||""}function bt(e){return Array.isArray(e)?e:"string"==typeof e&&e.match(R)||[]}k.fn.extend({prop:function(e,t){return _(this,k.prop,e,t,1<arguments.length)},removeProp:function(e){return this.each(function(){delete this[k.propFix[e]||e]})}}),k.extend({prop:function(e,t,n){var r,i,o=e.nodeType;if(3!==o&&8!==o&&2!==o)return 1===o&&k.isXMLDoc(e)||(t=k.propFix[t]||t,i=k.propHooks[t]),void 0!==n?i&&"set"in i&&void 0!==(r=i.set(e,n,t))?r:e[t]=n:i&&"get"in i&&null!==(r=i.get(e,t))?r:e[t]},propHooks:{tabIndex:{get:function(e){var t=k.find.attr(e,"tabindex");return t?parseInt(t,10):vt.test(e.nodeName)||yt.test(e.nodeName)&&e.href?0:-1}}},propFix:{"for":"htmlFor","class":"className"}}),y.optSelected||(k.propHooks.selected={get:function(e){var t=e.parentNode;return t&&t.parentNode&&t.parentNode.selectedIndex,null},set:function(e){var t=e.parentNode;t&&(t.selectedIndex,t.parentNode&&t.parentNode.selectedIndex)}}),k.each(["tabIndex","readOnly","maxLength","cellSpacing","cellPadding","rowSpan","colSpan","useMap","frameBorder","contentEditable"],function(){k.propFix[this.toLowerCase()]=this}),k.fn.extend({addClass:function(t){var e,n,r,i,o,a,s,u=0;if(m(t))return this.each(function(e){k(this).addClass(t.call(this,e,xt(this)))});if((e=bt(t)).length)while(n=this[u++])if(i=xt(n),r=1===n.nodeType&&" "+mt(i)+" "){a=0;while(o=e[a++])r.indexOf(" "+o+" ")<0&&(r+=o+" ");i!==(s=mt(r))&&n.setAttribute("class",s)}return this},removeClass:function(t){var e,n,r,i,o,a,s,u=0;if(m(t))return this.each(function(e){k(this).removeClass(t.call(this,e,xt(this)))});if(!arguments.length)return this.attr("class","");if((e=bt(t)).length)while(n=this[u++])if(i=xt(n),r=1===n.nodeType&&" "+mt(i)+" "){a=0;while(o=e[a++])while(-1<r.indexOf(" "+o+" "))r=r.replace(" "+o+" "," ");i!==(s=mt(r))&&n.setAttribute("class",s)}return this},toggleClass:function(i,t){var o=typeof i,a="string"===o||Array.isArray(i);return"boolean"==typeof t&&a?t?this.addClass(i):this.removeClass(i):m(i)?this.each(function(e){k(this).toggleClass(i.call(this,e,xt(this),t),t)}):this.each(function(){var e,t,n,r;if(a){t=0,n=k(this),r=bt(i);while(e=r[t++])n.hasClass(e)?n.removeClass(e):n.addClass(e)}else void 0!==i&&"boolean"!==o||((e=xt(this))&&Q.set(this,"__className__",e),this.setAttribute&&this.setAttribute("class",e||!1===i?"":Q.get(this,"__className__")||""))})},hasClass:function(e){var t,n,r=0;t=" "+e+" ";while(n=this[r++])if(1===n.nodeType&&-1<(" "+mt(xt(n))+" ").indexOf(t))return!0;return!1}});var wt=/\r/g;k.fn.extend({val:function(n){var r,e,i,t=this[0];return arguments.length?(i=m(n),this.each(function(e){var t;1===this.nodeType&&(null==(t=i?n.call(this,e,k(this).val()):n)?t="":"number"==typeof t?t+="":Array.isArray(t)&&(t=k.map(t,function(e){return null==e?"":e+""})),(r=k.valHooks[this.type]||k.valHooks[this.nodeName.toLowerCase()])&&"set"in r&&void 0!==r.set(this,t,"value")||(this.value=t))})):t?(r=k.valHooks[t.type]||k.valHooks[t.nodeName.toLowerCase()])&&"get"in r&&void 0!==(e=r.get(t,"value"))?e:"string"==typeof(e=t.value)?e.replace(wt,""):null==e?"":e:void 0}}),k.extend({valHooks:{option:{get:function(e){var t=k.find.attr(e,"value");return null!=t?t:mt(k.text(e))}},select:{get:function(e){var t,n,r,i=e.options,o=e.selectedIndex,a="select-one"===e.type,s=a?null:[],u=a?o+1:i.length;for(r=o<0?u:a?o:0;r<u;r++)if(((n=i[r]).selected||r===o)&&!n.disabled&&(!n.parentNode.disabled||!A(n.parentNode,"optgroup"))){if(t=k(n).val(),a)return t;s.push(t)}return s},set:function(e,t){var n,r,i=e.options,o=k.makeArray(t),a=i.length;while(a--)((r=i[a]).selected=-1<k.inArray(k.valHooks.option.get(r),o))&&(n=!0);return n||(e.selectedIndex=-1),o}}}}),k.each(["radio","checkbox"],function(){k.valHooks[this]={set:function(e,t){if(Array.isArray(t))return e.checked=-1<k.inArray(k(e).val(),t)}},y.checkOn||(k.valHooks[this].get=function(e){return null===e.getAttribute("value")?"on":e.value})}),y.focusin="onfocusin"in C;var Tt=/^(?:focusinfocus|focusoutblur)$/,Ct=function(e){e.stopPropagation()};k.extend(k.event,{trigger:function(e,t,n,r){var i,o,a,s,u,l,c,f,p=[n||E],d=v.call(e,"type")?e.type:e,h=v.call(e,"namespace")?e.namespace.split("."):[];if(o=f=a=n=n||E,3!==n.nodeType&&8!==n.nodeType&&!Tt.test(d+k.event.triggered)&&(-1<d.indexOf(".")&&(d=(h=d.split(".")).shift(),h.sort()),u=d.indexOf(":")<0&&"on"+d,(e=e[k.expando]?e:new k.Event(d,"object"==typeof e&&e)).isTrigger=r?2:3,e.namespace=h.join("."),e.rnamespace=e.namespace?new RegExp("(^|\\.)"+h.join("\\.(?:.*\\.|)")+"(\\.|$)"):null,e.result=void 0,e.target||(e.target=n),t=null==t?[e]:k.makeArray(t,[e]),c=k.event.special[d]||{},r||!c.trigger||!1!==c.trigger.apply(n,t))){if(!r&&!c.noBubble&&!x(n)){for(s=c.delegateType||d,Tt.test(s+d)||(o=o.parentNode);o;o=o.parentNode)p.push(o),a=o;a===(n.ownerDocument||E)&&p.push(a.defaultView||a.parentWindow||C)}i=0;while((o=p[i++])&&!e.isPropagationStopped())f=o,e.type=1<i?s:c.bindType||d,(l=(Q.get(o,"events")||{})[e.type]&&Q.get(o,"handle"))&&l.apply(o,t),(l=u&&o[u])&&l.apply&&G(o)&&(e.result=l.apply(o,t),!1===e.result&&e.preventDefault());return e.type=d,r||e.isDefaultPrevented()||c._default&&!1!==c._default.apply(p.pop(),t)||!G(n)||u&&m(n[d])&&!x(n)&&((a=n[u])&&(n[u]=null),k.event.triggered=d,e.isPropagationStopped()&&f.addEventListener(d,Ct),n[d](),e.isPropagationStopped()&&f.removeEventListener(d,Ct),k.event.triggered=void 0,a&&(n[u]=a)),e.result}},simulate:function(e,t,n){var r=k.extend(new k.Event,n,{type:e,isSimulated:!0});k.event.trigger(r,null,t)}}),k.fn.extend({trigger:function(e,t){return this.each(function(){k.event.trigger(e,t,this)})},triggerHandler:function(e,t){var n=this[0];if(n)return k.event.trigger(e,t,n,!0)}}),y.focusin||k.each({focus:"focusin",blur:"focusout"},function(n,r){var i=function(e){k.event.simulate(r,e.target,k.event.fix(e))};k.event.special[r]={setup:function(){var e=this.ownerDocument||this,t=Q.access(e,r);t||e.addEventListener(n,i,!0),Q.access(e,r,(t||0)+1)},teardown:function(){var e=this.ownerDocument||this,t=Q.access(e,r)-1;t?Q.access(e,r,t):(e.removeEventListener(n,i,!0),Q.remove(e,r))}}});var Et=C.location,kt=Date.now(),St=/\?/;k.parseXML=function(e){var t;if(!e||"string"!=typeof e)return null;try{t=(new C.DOMParser).parseFromString(e,"text/xml")}catch(e){t=void 0}return t&&!t.getElementsByTagName("parsererror").length||k.error("Invalid XML: "+e),t};var Nt=/\[\]$/,At=/\r?\n/g,Dt=/^(?:submit|button|image|reset|file)$/i,jt=/^(?:input|select|textarea|keygen)/i;function qt(n,e,r,i){var t;if(Array.isArray(e))k.each(e,function(e,t){r||Nt.test(n)?i(n,t):qt(n+"["+("object"==typeof t&&null!=t?e:"")+"]",t,r,i)});else if(r||"object"!==w(e))i(n,e);else for(t in e)qt(n+"["+t+"]",e[t],r,i)}k.param=function(e,t){var n,r=[],i=function(e,t){var n=m(t)?t():t;r[r.length]=encodeURIComponent(e)+"="+encodeURIComponent(null==n?"":n)};if(null==e)return"";if(Array.isArray(e)||e.jquery&&!k.isPlainObject(e))k.each(e,function(){i(this.name,this.value)});else for(n in e)qt(n,e[n],t,i);return r.join("&")},k.fn.extend({serialize:function(){return k.param(this.serializeArray())},serializeArray:function(){return this.map(function(){var e=k.prop(this,"elements");return e?k.makeArray(e):this}).filter(function(){var e=this.type;return this.name&&!k(this).is(":disabled")&&jt.test(this.nodeName)&&!Dt.test(e)&&(this.checked||!pe.test(e))}).map(function(e,t){var n=k(this).val();return null==n?null:Array.isArray(n)?k.map(n,function(e){return{name:t.name,value:e.replace(At,"\r\n")}}):{name:t.name,value:n.replace(At,"\r\n")}}).get()}});var Lt=/%20/g,Ht=/#.*$/,Ot=/([?&])_=[^&]*/,Pt=/^(.*?):[ \t]*([^\r\n]*)$/gm,Rt=/^(?:GET|HEAD)$/,Mt=/^\/\//,It={},Wt={},$t="*/".concat("*"),Ft=E.createElement("a");function Bt(o){return function(e,t){"string"!=typeof e&&(t=e,e="*");var n,r=0,i=e.toLowerCase().match(R)||[];if(m(t))while(n=i[r++])"+"===n[0]?(n=n.slice(1)||"*",(o[n]=o[n]||[]).unshift(t)):(o[n]=o[n]||[]).push(t)}}function _t(t,i,o,a){var s={},u=t===Wt;function l(e){var r;return s[e]=!0,k.each(t[e]||[],function(e,t){var n=t(i,o,a);return"string"!=typeof n||u||s[n]?u?!(r=n):void 0:(i.dataTypes.unshift(n),l(n),!1)}),r}return l(i.dataTypes[0])||!s["*"]&&l("*")}function zt(e,t){var n,r,i=k.ajaxSettings.flatOptions||{};for(n in t)void 0!==t[n]&&((i[n]?e:r||(r={}))[n]=t[n]);return r&&k.extend(!0,e,r),e}Ft.href=Et.href,k.extend({active:0,lastModified:{},etag:{},ajaxSettings:{url:Et.href,type:"GET",isLocal:/^(?:about|app|app-storage|.+-extension|file|res|widget):$/.test(Et.protocol),global:!0,processData:!0,async:!0,contentType:"application/x-www-form-urlencoded; charset=UTF-8",accepts:{"*":$t,text:"text/plain",html:"text/html",xml:"application/xml, text/xml",json:"application/json, text/javascript"},contents:{xml:/\bxml\b/,html:/\bhtml/,json:/\bjson\b/},responseFields:{xml:"responseXML",text:"responseText",json:"responseJSON"},converters:{"* text":String,"text html":!0,"text json":JSON.parse,"text xml":k.parseXML},flatOptions:{url:!0,context:!0}},ajaxSetup:function(e,t){return t?zt(zt(e,k.ajaxSettings),t):zt(k.ajaxSettings,e)},ajaxPrefilter:Bt(It),ajaxTransport:Bt(Wt),ajax:function(e,t){"object"==typeof e&&(t=e,e=void 0),t=t||{};var c,f,p,n,d,r,h,g,i,o,v=k.ajaxSetup({},t),y=v.context||v,m=v.context&&(y.nodeType||y.jquery)?k(y):k.event,x=k.Deferred(),b=k.Callbacks("once memory"),w=v.statusCode||{},a={},s={},u="canceled",T={readyState:0,getResponseHeader:function(e){var t;if(h){if(!n){n={};while(t=Pt.exec(p))n[t[1].toLowerCase()+" "]=(n[t[1].toLowerCase()+" "]||[]).concat(t[2])}t=n[e.toLowerCase()+" "]}return null==t?null:t.join(", ")},getAllResponseHeaders:function(){return h?p:null},setRequestHeader:function(e,t){return null==h&&(e=s[e.toLowerCase()]=s[e.toLowerCase()]||e,a[e]=t),this},overrideMimeType:function(e){return null==h&&(v.mimeType=e),this},statusCode:function(e){var t;if(e)if(h)T.always(e[T.status]);else for(t in e)w[t]=[w[t],e[t]];return this},abort:function(e){var t=e||u;return c&&c.abort(t),l(0,t),this}};if(x.promise(T),v.url=((e||v.url||Et.href)+"").replace(Mt,Et.protocol+"//"),v.type=t.method||t.type||v.method||v.type,v.dataTypes=(v.dataType||"*").toLowerCase().match(R)||[""],null==v.crossDomain){r=E.createElement("a");try{r.href=v.url,r.href=r.href,v.crossDomain=Ft.protocol+"//"+Ft.host!=r.protocol+"//"+r.host}catch(e){v.crossDomain=!0}}if(v.data&&v.processData&&"string"!=typeof v.data&&(v.data=k.param(v.data,v.traditional)),_t(It,v,t,T),h)return T;for(i in(g=k.event&&v.global)&&0==k.active++&&k.event.trigger("ajaxStart"),v.type=v.type.toUpperCase(),v.hasContent=!Rt.test(v.type),f=v.url.replace(Ht,""),v.hasContent?v.data&&v.processData&&0===(v.contentType||"").indexOf("application/x-www-form-urlencoded")&&(v.data=v.data.replace(Lt,"+")):(o=v.url.slice(f.length),v.data&&(v.processData||"string"==typeof v.data)&&(f+=(St.test(f)?"&":"?")+v.data,delete v.data),!1===v.cache&&(f=f.replace(Ot,"$1"),o=(St.test(f)?"&":"?")+"_="+kt+++o),v.url=f+o),v.ifModified&&(k.lastModified[f]&&T.setRequestHeader("If-Modified-Since",k.lastModified[f]),k.etag[f]&&T.setRequestHeader("If-None-Match",k.etag[f])),(v.data&&v.hasContent&&!1!==v.contentType||t.contentType)&&T.setRequestHeader("Content-Type",v.contentType),T.setRequestHeader("Accept",v.dataTypes[0]&&v.accepts[v.dataTypes[0]]?v.accepts[v.dataTypes[0]]+("*"!==v.dataTypes[0]?", "+$t+"; q=0.01":""):v.accepts["*"]),v.headers)T.setRequestHeader(i,v.headers[i]);if(v.beforeSend&&(!1===v.beforeSend.call(y,T,v)||h))return T.abort();if(u="abort",b.add(v.complete),T.done(v.success),T.fail(v.error),c=_t(Wt,v,t,T)){if(T.readyState=1,g&&m.trigger("ajaxSend",[T,v]),h)return T;v.async&&0<v.timeout&&(d=C.setTimeout(function(){T.abort("timeout")},v.timeout));try{h=!1,c.send(a,l)}catch(e){if(h)throw e;l(-1,e)}}else l(-1,"No Transport");function l(e,t,n,r){var i,o,a,s,u,l=t;h||(h=!0,d&&C.clearTimeout(d),c=void 0,p=r||"",T.readyState=0<e?4:0,i=200<=e&&e<300||304===e,n&&(s=function(e,t,n){var r,i,o,a,s=e.contents,u=e.dataTypes;while("*"===u[0])u.shift(),void 0===r&&(r=e.mimeType||t.getResponseHeader("Content-Type"));if(r)for(i in s)if(s[i]&&s[i].test(r)){u.unshift(i);break}if(u[0]in n)o=u[0];else{for(i in n){if(!u[0]||e.converters[i+" "+u[0]]){o=i;break}a||(a=i)}o=o||a}if(o)return o!==u[0]&&u.unshift(o),n[o]}(v,T,n)),s=function(e,t,n,r){var i,o,a,s,u,l={},c=e.dataTypes.slice();if(c[1])for(a in e.converters)l[a.toLowerCase()]=e.converters[a];o=c.shift();while(o)if(e.responseFields[o]&&(n[e.responseFields[o]]=t),!u&&r&&e.dataFilter&&(t=e.dataFilter(t,e.dataType)),u=o,o=c.shift())if("*"===o)o=u;else if("*"!==u&&u!==o){if(!(a=l[u+" "+o]||l["* "+o]))for(i in l)if((s=i.split(" "))[1]===o&&(a=l[u+" "+s[0]]||l["* "+s[0]])){!0===a?a=l[i]:!0!==l[i]&&(o=s[0],c.unshift(s[1]));break}if(!0!==a)if(a&&e["throws"])t=a(t);else try{t=a(t)}catch(e){return{state:"parsererror",error:a?e:"No conversion from "+u+" to "+o}}}return{state:"success",data:t}}(v,s,T,i),i?(v.ifModified&&((u=T.getResponseHeader("Last-Modified"))&&(k.lastModified[f]=u),(u=T.getResponseHeader("etag"))&&(k.etag[f]=u)),204===e||"HEAD"===v.type?l="nocontent":304===e?l="notmodified":(l=s.state,o=s.data,i=!(a=s.error))):(a=l,!e&&l||(l="error",e<0&&(e=0))),T.status=e,T.statusText=(t||l)+"",i?x.resolveWith(y,[o,l,T]):x.rejectWith(y,[T,l,a]),T.statusCode(w),w=void 0,g&&m.trigger(i?"ajaxSuccess":"ajaxError",[T,v,i?o:a]),b.fireWith(y,[T,l]),g&&(m.trigger("ajaxComplete",[T,v]),--k.active||k.event.trigger("ajaxStop")))}return T},getJSON:function(e,t,n){return k.get(e,t,n,"json")},getScript:function(e,t){return k.get(e,void 0,t,"script")}}),k.each(["get","post"],function(e,i){k[i]=function(e,t,n,r){return m(t)&&(r=r||n,n=t,t=void 0),k.ajax(k.extend({url:e,type:i,dataType:r,data:t,success:n},k.isPlainObject(e)&&e))}}),k._evalUrl=function(e,t){return k.ajax({url:e,type:"GET",dataType:"script",cache:!0,async:!1,global:!1,converters:{"text script":function(){}},dataFilter:function(e){k.globalEval(e,t)}})},k.fn.extend({wrapAll:function(e){var t;return this[0]&&(m(e)&&(e=e.call(this[0])),t=k(e,this[0].ownerDocument).eq(0).clone(!0),this[0].parentNode&&t.insertBefore(this[0]),t.map(function(){var e=this;while(e.firstElementChild)e=e.firstElementChild;return e}).append(this)),this},wrapInner:function(n){return m(n)?this.each(function(e){k(this).wrapInner(n.call(this,e))}):this.each(function(){var e=k(this),t=e.contents();t.length?t.wrapAll(n):e.append(n)})},wrap:function(t){var n=m(t);return this.each(function(e){k(this).wrapAll(n?t.call(this,e):t)})},unwrap:function(e){return this.parent(e).not("body").each(function(){k(this).replaceWith(this.childNodes)}),this}}),k.expr.pseudos.hidden=function(e){return!k.expr.pseudos.visible(e)},k.expr.pseudos.visible=function(e){return!!(e.offsetWidth||e.offsetHeight||e.getClientRects().length)},k.ajaxSettings.xhr=function(){try{return new C.XMLHttpRequest}catch(e){}};var Ut={0:200,1223:204},Xt=k.ajaxSettings.xhr();y.cors=!!Xt&&"withCredentials"in Xt,y.ajax=Xt=!!Xt,k.ajaxTransport(function(i){var o,a;if(y.cors||Xt&&!i.crossDomain)return{send:function(e,t){var n,r=i.xhr();if(r.open(i.type,i.url,i.async,i.username,i.password),i.xhrFields)for(n in i.xhrFields)r[n]=i.xhrFields[n];for(n in i.mimeType&&r.overrideMimeType&&r.overrideMimeType(i.mimeType),i.crossDomain||e["X-Requested-With"]||(e["X-Requested-With"]="XMLHttpRequest"),e)r.setRequestHeader(n,e[n]);o=function(e){return function(){o&&(o=a=r.onload=r.onerror=r.onabort=r.ontimeout=r.onreadystatechange=null,"abort"===e?r.abort():"error"===e?"number"!=typeof r.status?t(0,"error"):t(r.status,r.statusText):t(Ut[r.status]||r.status,r.statusText,"text"!==(r.responseType||"text")||"string"!=typeof r.responseText?{binary:r.response}:{text:r.responseText},r.getAllResponseHeaders()))}},r.onload=o(),a=r.onerror=r.ontimeout=o("error"),void 0!==r.onabort?r.onabort=a:r.onreadystatechange=function(){4===r.readyState&&C.setTimeout(function(){o&&a()})},o=o("abort");try{r.send(i.hasContent&&i.data||null)}catch(e){if(o)throw e}},abort:function(){o&&o()}}}),k.ajaxPrefilter(function(e){e.crossDomain&&(e.contents.script=!1)}),k.ajaxSetup({accepts:{script:"text/javascript, application/javascript, application/ecmascript, application/x-ecmascript"},contents:{script:/\b(?:java|ecma)script\b/},converters:{"text script":function(e){return k.globalEval(e),e}}}),k.ajaxPrefilter("script",function(e){void 0===e.cache&&(e.cache=!1),e.crossDomain&&(e.type="GET")}),k.ajaxTransport("script",function(n){var r,i;if(n.crossDomain||n.scriptAttrs)return{send:function(e,t){r=k("<script>").attr(n.scriptAttrs||{}).prop({charset:n.scriptCharset,src:n.url}).on("load error",i=function(e){r.remove(),i=null,e&&t("error"===e.type?404:200,e.type)}),E.head.appendChild(r[0])},abort:function(){i&&i()}}});var Vt,Gt=[],Yt=/(=)\?(?=&|$)|\?\?/;k.ajaxSetup({jsonp:"callback",jsonpCallback:function(){var e=Gt.pop()||k.expando+"_"+kt++;return this[e]=!0,e}}),k.ajaxPrefilter("json jsonp",function(e,t,n){var r,i,o,a=!1!==e.jsonp&&(Yt.test(e.url)?"url":"string"==typeof e.data&&0===(e.contentType||"").indexOf("application/x-www-form-urlencoded")&&Yt.test(e.data)&&"data");if(a||"jsonp"===e.dataTypes[0])return r=e.jsonpCallback=m(e.jsonpCallback)?e.jsonpCallback():e.jsonpCallback,a?e[a]=e[a].replace(Yt,"$1"+r):!1!==e.jsonp&&(e.url+=(St.test(e.url)?"&":"?")+e.jsonp+"="+r),e.converters["script json"]=function(){return o||k.error(r+" was not called"),o[0]},e.dataTypes[0]="json",i=C[r],C[r]=function(){o=arguments},n.always(function(){void 0===i?k(C).removeProp(r):C[r]=i,e[r]&&(e.jsonpCallback=t.jsonpCallback,Gt.push(r)),o&&m(i)&&i(o[0]),o=i=void 0}),"script"}),y.createHTMLDocument=((Vt=E.implementation.createHTMLDocument("").body).innerHTML="<form></form><form></form>",2===Vt.childNodes.length),k.parseHTML=function(e,t,n){return"string"!=typeof e?[]:("boolean"==typeof t&&(n=t,t=!1),t||(y.createHTMLDocument?((r=(t=E.implementation.createHTMLDocument("")).createElement("base")).href=E.location.href,t.head.appendChild(r)):t=E),o=!n&&[],(i=D.exec(e))?[t.createElement(i[1])]:(i=we([e],t,o),o&&o.length&&k(o).remove(),k.merge([],i.childNodes)));var r,i,o},k.fn.load=function(e,t,n){var r,i,o,a=this,s=e.indexOf(" ");return-1<s&&(r=mt(e.slice(s)),e=e.slice(0,s)),m(t)?(n=t,t=void 0):t&&"object"==typeof t&&(i="POST"),0<a.length&&k.ajax({url:e,type:i||"GET",dataType:"html",data:t}).done(function(e){o=arguments,a.html(r?k("<div>").append(k.parseHTML(e)).find(r):e)}).always(n&&function(e,t){a.each(function(){n.apply(this,o||[e.responseText,t,e])})}),this},k.each(["ajaxStart","ajaxStop","ajaxComplete","ajaxError","ajaxSuccess","ajaxSend"],function(e,t){k.fn[t]=function(e){return this.on(t,e)}}),k.expr.pseudos.animated=function(t){return k.grep(k.timers,function(e){return t===e.elem}).length},k.offset={setOffset:function(e,t,n){var r,i,o,a,s,u,l=k.css(e,"position"),c=k(e),f={};"static"===l&&(e.style.position="relative"),s=c.offset(),o=k.css(e,"top"),u=k.css(e,"left"),("absolute"===l||"fixed"===l)&&-1<(o+u).indexOf("auto")?(a=(r=c.position()).top,i=r.left):(a=parseFloat(o)||0,i=parseFloat(u)||0),m(t)&&(t=t.call(e,n,k.extend({},s))),null!=t.top&&(f.top=t.top-s.top+a),null!=t.left&&(f.left=t.left-s.left+i),"using"in t?t.using.call(e,f):c.css(f)}},k.fn.extend({offset:function(t){if(arguments.length)return void 0===t?this:this.each(function(e){k.offset.setOffset(this,t,e)});var e,n,r=this[0];return r?r.getClientRects().length?(e=r.getBoundingClientRect(),n=r.ownerDocument.defaultView,{top:e.top+n.pageYOffset,left:e.left+n.pageXOffset}):{top:0,left:0}:void 0},position:function(){if(this[0]){var e,t,n,r=this[0],i={top:0,left:0};if("fixed"===k.css(r,"position"))t=r.getBoundingClientRect();else{t=this.offset(),n=r.ownerDocument,e=r.offsetParent||n.documentElement;while(e&&(e===n.body||e===n.documentElement)&&"static"===k.css(e,"position"))e=e.parentNode;e&&e!==r&&1===e.nodeType&&((i=k(e).offset()).top+=k.css(e,"borderTopWidth",!0),i.left+=k.css(e,"borderLeftWidth",!0))}return{top:t.top-i.top-k.css(r,"marginTop",!0),left:t.left-i.left-k.css(r,"marginLeft",!0)}}},offsetParent:function(){return this.map(function(){var e=this.offsetParent;while(e&&"static"===k.css(e,"position"))e=e.offsetParent;return e||ie})}}),k.each({scrollLeft:"pageXOffset",scrollTop:"pageYOffset"},function(t,i){var o="pageYOffset"===i;k.fn[t]=function(e){return _(this,function(e,t,n){var r;if(x(e)?r=e:9===e.nodeType&&(r=e.defaultView),void 0===n)return r?r[i]:e[t];r?r.scrollTo(o?r.pageXOffset:n,o?n:r.pageYOffset):e[t]=n},t,e,arguments.length)}}),k.each(["top","left"],function(e,n){k.cssHooks[n]=ze(y.pixelPosition,function(e,t){if(t)return t=_e(e,n),$e.test(t)?k(e).position()[n]+"px":t})}),k.each({Height:"height",Width:"width"},function(a,s){k.each({padding:"inner"+a,content:s,"":"outer"+a},function(r,o){k.fn[o]=function(e,t){var n=arguments.length&&(r||"boolean"!=typeof e),i=r||(!0===e||!0===t?"margin":"border");return _(this,function(e,t,n){var r;return x(e)?0===o.indexOf("outer")?e["inner"+a]:e.document.documentElement["client"+a]:9===e.nodeType?(r=e.documentElement,Math.max(e.body["scroll"+a],r["scroll"+a],e.body["offset"+a],r["offset"+a],r["client"+a])):void 0===n?k.css(e,t,i):k.style(e,t,n,i)},s,n?e:void 0,n)}})}),k.each("blur focus focusin focusout resize scroll click dblclick mousedown mouseup mousemove mouseover mouseout mouseenter mouseleave change select submit keydown keypress keyup contextmenu".split(" "),function(e,n){k.fn[n]=function(e,t){return 0<arguments.length?this.on(n,null,e,t):this.trigger(n)}}),k.fn.extend({hover:function(e,t){return this.mouseenter(e).mouseleave(t||e)}}),k.fn.extend({bind:function(e,t,n){return this.on(e,null,t,n)},unbind:function(e,t){return this.off(e,null,t)},delegate:function(e,t,n,r){return this.on(t,e,n,r)},undelegate:function(e,t,n){return 1===arguments.length?this.off(e,"**"):this.off(t,e||"**",n)}}),k.proxy=function(e,t){var n,r,i;if("string"==typeof t&&(n=e[t],t=e,e=n),m(e))return r=s.call(arguments,2),(i=function(){return e.apply(t||this,r.concat(s.call(arguments)))}).guid=e.guid=e.guid||k.guid++,i},k.holdReady=function(e){e?k.readyWait++:k.ready(!0)},k.isArray=Array.isArray,k.parseJSON=JSON.parse,k.nodeName=A,k.isFunction=m,k.isWindow=x,k.camelCase=V,k.type=w,k.now=Date.now,k.isNumeric=function(e){var t=k.type(e);return("number"===t||"string"===t)&&!isNaN(e-parseFloat(e))},"function"==typeof define&&define.amd&&define("jquery",[],function(){return k});var Qt=C.jQuery,Jt=C.$;return k.noConflict=function(e){return C.$===k&&(C.$=Jt),e&&C.jQuery===k&&(C.jQuery=Qt),k},e||(C.jQuery=C.$=k),k});

// Source: https://github.com/devongovett/jquery.event.drag/blob/451d90e1a737f49f613d0966082ce67582b0afd1/drag/jquery.event.drag.js
//
//	Warning! Make sure the hijack() is patch to work with any jquery version:
//
//   ($.event.dispatch || $.event.handle).call( elem, event );
//

/*!
jquery.event.drag.js ~ v1.6 ~ Copyright (c) 2008, Three Dub Media (http://threedubmedia.com)
Liscensed under the MIT License ~ http://threedubmedia.googlecode.com/files/MIT-LICENSE.txt
*/
;(function($){ // secure $ jQuery alias
/*******************************************************************************************/
// Created: 2008-06-04 | Updated: 2009-04-21
/*******************************************************************************************/
// Events: drag, dragstart, dragend
/*******************************************************************************************/

// jquery method
$.fn.drag = function( fn1, fn2, fn3 ){
	if ( fn2 ) this.bind('dragstart', fn1 ); // 2+ args
	if ( fn3 ) this.bind('dragend', fn3 ); // 3 args
	return !fn1 ? this.trigger('drag') // 0 args
		: this.bind('drag', fn2 ? fn2 : fn1 ); // 1+ args
	};

// local refs
var $event = $.event, $special = $event.special,

// special event configuration
drag = $special.drag = {
	not: ':input', // don't begin to drag on event.targets that match this selector
	distance: 0, // distance dragged before dragstart
	which: 1, // mouse button pressed to start drag sequence
	drop: false, // false to suppress drop events
	dragging: false, // hold the active target element
	setup: function( data ){
		data = $.extend({
			distance: drag.distance,
			which: drag.which,
			not: drag.not,
			drop: drag.drop
			}, data || {});
		data.distance = squared( data.distance ); //  x² + y² = distance²
		$event.add( this, "mousedown", handler, data );
		if ( this.attachEvent ) this.attachEvent("ondragstart", dontStart ); // prevent image dragging in IE...
		},
	teardown: function(){
		$event.remove( this, "mousedown", handler );
		if ( this === drag.dragging ) drag.dragging = drag.proxy = false; // deactivate element
		selectable( this, true ); // enable text selection
		if ( this.detachEvent ) this.detachEvent("ondragstart", dontStart ); // prevent image dragging in IE...
		}
	};

// prevent normal event binding...
$special.dragstart = $special.dragend = { setup:function(){}, teardown:function(){} };

// handle drag-releatd DOM events
function handler ( event ){
	var elem = this, returned, data = event.data || {};
	// mousemove or mouseup
	if ( data.elem ){
		// update event properties...
		elem = event.dragTarget = data.elem; // drag source element
		event.dragProxy = drag.proxy || elem; // proxy element or source
		event.cursorOffsetX = data.pageX - data.left; // mousedown offset
		event.cursorOffsetY = data.pageY - data.top; // mousedown offset
		event.offsetX = event.pageX - event.cursorOffsetX; // element offset
		event.offsetY = event.pageY - event.cursorOffsetY; // element offset
		}
	// mousedown, check some initial props to avoid the switch statement
	else if ( drag.dragging || ( data.which>0 && event.which!=data.which ) ||
		$( event.target ).is( data.not ) ) return;
	// handle various events
	switch ( event.type ){
		// mousedown, left click, event.target is not restricted, init dragging
		case 'mousedown':
			$.extend( data, $( elem ).offset(), {
				elem: elem, target: event.target,
				pageX: event.pageX, pageY: event.pageY
				}); // store some initial attributes
			$event.add( document, "mousemove mouseup", handler, data );
			selectable( elem, false ); // disable text selection
			drag.dragging = null; // pending state
			break; // prevents text selection in safari
		// mousemove, check distance, start dragging
		case !drag.dragging && 'mousemove':
			if ( squared( event.pageX-data.pageX )
				+ squared( event.pageY-data.pageY ) //  x² + y² = distance²
				< data.distance ) break; // distance tolerance not reached
			event.target = data.target; // force target from "mousedown" event (fix distance issue)
			returned = hijack( event, "dragstart", elem ); // trigger "dragstart", return proxy element
			if ( returned !== false ){ // "dragstart" not rejected
				drag.dragging = elem; // activate element
				drag.proxy = event.dragProxy = $( returned || elem )[0]; // set proxy
				}
		// mousemove, dragging
		case 'mousemove':
			if ( drag.dragging ){
				returned = hijack( event, "drag", elem ); // trigger "drag"
				if ( data.drop && $special.drop ){ // manage drop events
					$special.drop.allowed = ( returned !== false ); // prevent drop
					$special.drop.handler( event ); // "dropstart", "dropend"
					}
				if ( returned !== false ) break; // "drag" not rejected, stop
				event.type = "mouseup"; // helps "drop" handler behave
				}
		// mouseup, stop dragging
		case 'mouseup':
			$event.remove( document, "mousemove mouseup", handler ); // remove page events
			if ( drag.dragging ){
				if ( data.drop && $special.drop ) $special.drop.handler( event ); // "drop"
				hijack( event, "dragend", elem ); // trigger "dragend"
				}
			selectable( elem, true ); // enable text selection
			drag.dragging = drag.proxy = data.elem = false; // deactivate element
			break;
		}
	};

// set event type to custom value, and handle it
function hijack ( event, type, elem ){
	event.type = type; // force the event type
	var result = ($.event.dispatch || $.event.handle).call( elem, event );
	return result===false ? false : result || event.result;
	};

// return the value squared
function squared ( value ){ return Math.pow( value, 2 ); };

// suppress default dragstart IE events...
function dontStart(){ return ( drag.dragging === false ); };

// toggles text selection attributes
function selectable ( elem, bool ){
	if ( !elem ) return; // maybe element was removed ?
	elem = elem.ownerDocument ? elem.ownerDocument : elem;
	elem.unselectable = bool ? "off" : "on"; // IE
	if ( elem.style ) elem.style.MozUserSelect = bool ? "" : "none"; // FF
	$.event[ bool ? "remove" : "add" ]( elem, "selectstart mousedown", dontStart ); // IE/Opera
	};

/*******************************************************************************************/
})( jQuery ); // confine scope

// Source: https://github.com/jquery/jquery-mousewheel/blob/a06ef4e1a127795606642c55e22d4f2945edc061/jquery.mousewheel.js

/*! Copyright (c) 2011 Brandon Aaron (http://brandonaaron.net)
 * Licensed under the MIT License (LICENSE.txt).
 *
 * Thanks to: http://adomas.org/javascript-mouse-wheel/ for some pointers.
 * Thanks to: Mathias Bank(http://www.mathias-bank.de) for a scope bug fix.
 * Thanks to: Seamus Leahy for adding deltaX and deltaY
 *
 * Version: 3.0.6
 *
 * Requires: 1.2.2+
 */

(function($) {

var types = ['DOMMouseScroll', 'mousewheel'];

if ($.event.fixHooks) {
    for ( var i=types.length; i; ) {
        $.event.fixHooks[ types[--i] ] = $.event.mouseHooks;
    }
}

$.event.special.mousewheel = {
    setup: function() {
        if ( this.addEventListener ) {
            for ( var i=types.length; i; ) {
                this.addEventListener( types[--i], handler, false );
            }
        } else {
            this.onmousewheel = handler;
        }
    },

    teardown: function() {
        if ( this.removeEventListener ) {
            for ( var i=types.length; i; ) {
                this.removeEventListener( types[--i], handler, false );
            }
        } else {
            this.onmousewheel = null;
        }
    }
};

$.fn.extend({
    mousewheel: function(fn) {
        return fn ? this.bind("mousewheel", fn) : this.trigger("mousewheel");
    },

    unmousewheel: function(fn) {
        return this.unbind("mousewheel", fn);
    }
});


function handler(event) {
    var orgEvent = event || window.event, args = [].slice.call( arguments, 1 ), delta = 0, returnValue = true, deltaX = 0, deltaY = 0;
    event = $.event.fix(orgEvent);
    event.type = "mousewheel";

    // Old school scrollwheel delta
    if ( orgEvent.wheelDelta ) { delta = orgEvent.wheelDelta/120; }
    if ( orgEvent.detail     ) { delta = -orgEvent.detail/3; }

    // New school multidimensional scroll (touchpads) deltas
    deltaY = delta;

    // Gecko
    if ( orgEvent.axis !== undefined && orgEvent.axis === orgEvent.HORIZONTAL_AXIS ) {
        deltaY = 0;
        deltaX = -1*delta;
    }

    // Webkit
    if ( orgEvent.wheelDeltaY !== undefined ) { deltaY = orgEvent.wheelDeltaY/120; }
    if ( orgEvent.wheelDeltaX !== undefined ) { deltaX = -1*orgEvent.wheelDeltaX/120; }

    // Add event and delta to the front of the arguments
    args.unshift(event, delta, deltaX, deltaY);

    return ($.event.dispatch || $.event.handle).apply(this, args);
}

})(jQuery);

"use strict";function _typeof(t){return(_typeof="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(t){return typeof t}:function(t){return t&&"function"==typeof Symbol&&t.constructor===Symbol&&t!==Symbol.prototype?"symbol":typeof t})(t)}function _typeof(t){return(_typeof="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(t){return typeof t}:function(t){return t&&"function"==typeof Symbol&&t.constructor===Symbol&&t!==Symbol.prototype?"symbol":typeof t})(t)}!function(r){var t=function(t,e){var n=e.getElementsByClassName(t)[0];if(!n&&((n=document.createElement("canvas")).className=t,n.style.direction="ltr",n.style.position="absolute",n.style.left="0px",n.style.top="0px",e.appendChild(n),!n.getContext))throw new Error("Canvas is not available.");this.element=n;var o=this.context=n.getContext("2d");this.pixelRatio=r.plot.browser.getPixelRatio(o);var i=r(e).width(),a=r(e).height();this.resize(i,a),this.SVGContainer=null,this.SVG={},this._textCache={}};function d(e,t){e.transform.baseVal.clear(),t&&t.forEach(function(t){e.transform.baseVal.appendItem(t)})}t.prototype.resize=function(t,e){t=t<10?10:t,e=e<10?10:e;var n=this.element,o=this.context,i=this.pixelRatio;this.width!==t&&(n.width=t*i,n.style.width=t+"px",this.width=t),this.height!==e&&(n.height=e*i,n.style.height=e+"px",this.height=e),o.restore(),o.save(),o.scale(i,i)},t.prototype.clear=function(){this.context.clearRect(0,0,this.width,this.height)},t.prototype.render=function(){var t=this._textCache;for(var e in t)if(hasOwnProperty.call(t,e)){var n=this.getSVGLayer(e),o=t[e],i=n.style.display;for(var a in n.style.display="none",o)if(hasOwnProperty.call(o,a)){var r=o[a];for(var s in r)if(hasOwnProperty.call(r,s)){for(var l,c=r[s],u=c.positions,p=0;u[p];p++)if((l=u[p]).active)l.rendered||(n.appendChild(l.element),l.rendered=!0);else if(u.splice(p--,1),l.rendered){for(;l.element.firstChild;)l.element.removeChild(l.element.firstChild);l.element.parentNode.removeChild(l.element)}0===u.length&&(c.measured?c.measured=!1:delete r[s])}}n.style.display=i}},t.prototype.getSVGLayer=function(t){var e,n=this.SVG[t];n||(this.SVGContainer?e=this.SVGContainer.firstChild:(this.SVGContainer=document.createElement("div"),this.SVGContainer.className="flot-svg",this.SVGContainer.style.position="absolute",this.SVGContainer.style.top="0px",this.SVGContainer.style.left="0px",this.SVGContainer.style.height="100%",this.SVGContainer.style.width="100%",this.SVGContainer.style.pointerEvents="none",this.element.parentNode.appendChild(this.SVGContainer),(e=document.createElementNS("http://www.w3.org/2000/svg","svg")).style.width="100%",e.style.height="100%",this.SVGContainer.appendChild(e)),(n=document.createElementNS("http://www.w3.org/2000/svg","g")).setAttribute("class",t),n.style.position="absolute",n.style.top="0px",n.style.left="0px",n.style.bottom="0px",n.style.right="0px",e.appendChild(n),this.SVG[t]=n);return n},t.prototype.getTextInfo=function(t,e,n,o,i){var a,r,s,l;e=""+e,a="object"===_typeof(n)?n.style+" "+n.variant+" "+n.weight+" "+n.size+"px/"+n.lineHeight+"px "+n.family:n,null==(r=this._textCache[t])&&(r=this._textCache[t]={}),null==(s=r[a])&&(s=r[a]={});var c=e.replace(/0|1|2|3|4|5|6|7|8|9/g,"0");if(!(l=s[c])){var u=document.createElementNS("http://www.w3.org/2000/svg","text");if(-1!==e.indexOf("<br>"))m(e,u,-9999);else{var p=document.createTextNode(e);u.appendChild(p)}u.style.position="absolute",u.style.maxWidth=i,u.setAttributeNS(null,"x",-9999),u.setAttributeNS(null,"y",-9999),"object"===_typeof(n)?(u.style.font=a,u.style.fill=n.fill):"string"==typeof n&&u.setAttribute("class",n),this.getSVGLayer(t).appendChild(u);var h=u.getBBox();for(l=s[c]={width:h.width,height:h.height,measured:!0,element:u,positions:[]};u.firstChild;)u.removeChild(u.firstChild);u.parentNode.removeChild(u)}return l.measured=!0,l},t.prototype.addText=function(t,e,n,o,i,a,r,s,l,c){var u=this.getTextInfo(t,o,i,a,r),p=u.positions;"center"===s?e-=u.width/2:"right"===s&&(e-=u.width),"middle"===l?n-=u.height/2:"bottom"===l&&(n-=u.height),n+=.75*u.height;for(var h,f=0;p[f];f++){if((h=p[f]).x===e&&h.y===n&&h.text===o)return h.active=!0,void d(h.element,c);if(!1===h.active)return h.active=!0,-1!==(h.text=o).indexOf("<br>")?(n-=.25*u.height,m(o,h.element,e)):h.element.textContent=o,h.element.setAttributeNS(null,"x",e),h.element.setAttributeNS(null,"y",n),h.x=e,h.y=n,void d(h.element,c)}h={active:!0,rendered:!1,element:p.length?u.element.cloneNode():u.element,text:o,x:e,y:n},p.push(h),-1!==o.indexOf("<br>")?(n-=.25*u.height,m(o,h.element,e)):h.element.textContent=o,h.element.setAttributeNS(null,"x",e),h.element.setAttributeNS(null,"y",n),h.element.style.textAlign=s,d(h.element,c)};var m=function(t,e,n){var o,i,a,r=t.split("<br>");for(i=0;i<r.length;i++)e.childNodes[i]?o=e.childNodes[i]:(o=document.createElementNS("http://www.w3.org/2000/svg","tspan"),e.appendChild(o)),o.textContent=r[i],a=1*i+"em",o.setAttributeNS(null,"dy",a),o.setAttributeNS(null,"x",n)};t.prototype.removeText=function(t,e,n,o,i,a){var r,s;if(null==o){var l=this._textCache[t];if(null!=l)for(var c in l)if(hasOwnProperty.call(l,c)){var u=l[c];for(var p in u)if(hasOwnProperty.call(u,p)){var h=u[p].positions;h.forEach(function(t){t.active=!1})}}}else(h=(r=this.getTextInfo(t,o,i,a)).positions).forEach(function(t){s=n+.75*r.height,t.x===e&&t.y===s&&t.text===o&&(t.active=!1)})},t.prototype.clearCache=function(){var t=this._textCache;for(var e in t)if(hasOwnProperty.call(t,e))for(var n=this.getSVGLayer(e);n.firstChild;)n.removeChild(n.firstChild);this._textCache={}},window.Flot||(window.Flot={}),window.Flot.Canvas=t}(jQuery),function(a){a.color={},a.color.make=function(t,e,n,o){var i={};return i.r=t||0,i.g=e||0,i.b=n||0,i.a=null!=o?o:1,i.add=function(t,e){for(var n=0;n<t.length;++n)i[t.charAt(n)]+=e;return i.normalize()},i.scale=function(t,e){for(var n=0;n<t.length;++n)i[t.charAt(n)]*=e;return i.normalize()},i.toString=function(){return 1<=i.a?"rgb("+[i.r,i.g,i.b].join(",")+")":"rgba("+[i.r,i.g,i.b,i.a].join(",")+")"},i.normalize=function(){function t(t,e,n){return e<t?t:n<e?n:e}return i.r=t(0,parseInt(i.r),255),i.g=t(0,parseInt(i.g),255),i.b=t(0,parseInt(i.b),255),i.a=t(0,i.a,1),i},i.clone=function(){return a.color.make(i.r,i.b,i.g,i.a)},i.normalize()},a.color.extract=function(t,e){var n;do{if(""!==(n=t.css(e).toLowerCase())&&"transparent"!==n)break;t=t.parent()}while(t.length&&!a.nodeName(t.get(0),"body"));return"rgba(0, 0, 0, 0)"===n&&(n="transparent"),a.color.parse(n)},a.color.parse=function(t){var e,n=a.color.make;if(e=/rgb\(\s*([0-9]{1,3})\s*,\s*([0-9]{1,3})\s*,\s*([0-9]{1,3})\s*\)/.exec(t))return n(parseInt(e[1],10),parseInt(e[2],10),parseInt(e[3],10));if(e=/rgba\(\s*([0-9]{1,3})\s*,\s*([0-9]{1,3})\s*,\s*([0-9]{1,3})\s*,\s*([0-9]+(?:\.[0-9]+)?)\s*\)/.exec(t))return n(parseInt(e[1],10),parseInt(e[2],10),parseInt(e[3],10),parseFloat(e[4]));if(e=/rgb\(\s*([0-9]+(?:\.[0-9]+)?)%\s*,\s*([0-9]+(?:\.[0-9]+)?)%\s*,\s*([0-9]+(?:\.[0-9]+)?)%\s*\)/.exec(t))return n(2.55*parseFloat(e[1]),2.55*parseFloat(e[2]),2.55*parseFloat(e[3]));if(e=/rgba\(\s*([0-9]+(?:\.[0-9]+)?)%\s*,\s*([0-9]+(?:\.[0-9]+)?)%\s*,\s*([0-9]+(?:\.[0-9]+)?)%\s*,\s*([0-9]+(?:\.[0-9]+)?)\s*\)/.exec(t))return n(2.55*parseFloat(e[1]),2.55*parseFloat(e[2]),2.55*parseFloat(e[3]),parseFloat(e[4]));if(e=/#([a-fA-F0-9]{2})([a-fA-F0-9]{2})([a-fA-F0-9]{2})/.exec(t))return n(parseInt(e[1],16),parseInt(e[2],16),parseInt(e[3],16));if(e=/#([a-fA-F0-9])([a-fA-F0-9])([a-fA-F0-9])/.exec(t))return n(parseInt(e[1]+e[1],16),parseInt(e[2]+e[2],16),parseInt(e[3]+e[3],16));var o=a.trim(t).toLowerCase();return"transparent"===o?n(255,255,255,0):n((e=i[o]||[0,0,0])[0],e[1],e[2])};var i={aqua:[0,255,255],azure:[240,255,255],beige:[245,245,220],black:[0,0,0],blue:[0,0,255],brown:[165,42,42],cyan:[0,255,255],darkblue:[0,0,139],darkcyan:[0,139,139],darkgrey:[169,169,169],darkgreen:[0,100,0],darkkhaki:[189,183,107],darkmagenta:[139,0,139],darkolivegreen:[85,107,47],darkorange:[255,140,0],darkorchid:[153,50,204],darkred:[139,0,0],darksalmon:[233,150,122],darkviolet:[148,0,211],fuchsia:[255,0,255],gold:[255,215,0],green:[0,128,0],indigo:[75,0,130],khaki:[240,230,140],lightblue:[173,216,230],lightcyan:[224,255,255],lightgreen:[144,238,144],lightgrey:[211,211,211],lightpink:[255,182,193],lightyellow:[255,255,224],lime:[0,255,0],magenta:[255,0,255],maroon:[128,0,0],navy:[0,0,128],olive:[128,128,0],orange:[255,165,0],pink:[255,192,203],purple:[128,0,128],violet:[128,0,128],red:[255,0,0],silver:[192,192,192],white:[255,255,255],yellow:[255,255,0]}}(jQuery),function(J){var K=window.Flot.Canvas;function $(t){var e,n=[],o=J.plot.saturated.saturate(J.plot.saturated.floorInBase(t.min,t.tickSize)),i=0,a=Number.NaN;for(o===-Number.MAX_VALUE&&(n.push(o),o=J.plot.saturated.floorInBase(t.min+t.tickSize,t.tickSize));e=a,a=J.plot.saturated.multiplyAdd(t.tickSize,i,o),n.push(a),++i,a<t.max&&a!==e;);return n}function tt(t,e,n){var o=e.tickDecimals;if(-1!==(""+t).indexOf("e"))return l(t,e,n);0<n&&(e.tickDecimals=n);var i=e.tickDecimals?parseFloat("1e"+e.tickDecimals):1,a=""+Math.round(t*i)/i;if(null!=e.tickDecimals){var r=a.indexOf("."),s=-1===r?0:a.length-r-1;if(s<e.tickDecimals)a=(s?a:a+".")+(""+i).substr(1,e.tickDecimals-s)}return e.tickDecimals=o,a}function l(t,e,n){var o=(""+t).indexOf("e"),i=parseInt((""+t).substr(o+1)),a=-1!==o?i:0<t?Math.floor(Math.log(t)/Math.LN10):0,r=parseFloat("1e"+a),s=t/r;if(n){var l=c(t,n);return(t/r).toFixed(l)+"e"+a}return 0<e.tickDecimals?s.toFixed(c(t,e.tickDecimals))+"e"+a:s.toFixed()+"e"+a}function c(t,e){var n=Math.log(Math.abs(t))*Math.LOG10E,o=Math.abs(n+e);return o<=20?Math.floor(o):20}function o(l,t,e,o){var y=[],d={colors:["#edc240","#afd8f8","#cb4b4b","#4da74d","#9440ed"],xaxis:{show:null,position:"bottom",mode:null,font:null,color:null,tickColor:null,transform:null,inverseTransform:null,min:null,max:null,autoScaleMargin:null,autoScale:"exact",windowSize:null,growOnly:null,ticks:null,tickFormatter:null,showTickLabels:"major",labelWidth:null,labelHeight:null,reserveSpace:null,tickLength:null,showMinorTicks:null,showTicks:null,gridLines:null,alignTicksWithAxis:null,tickDecimals:null,tickSize:null,minTickSize:null,offset:{below:0,above:0},boxPosition:{centerX:0,centerY:0}},yaxis:{autoScaleMargin:.02,autoScale:"loose",growOnly:null,position:"left",showTickLabels:"major",offset:{below:0,above:0},boxPosition:{centerX:0,centerY:0}},xaxes:[],yaxes:[],series:{points:{show:!1,radius:3,lineWidth:2,fill:!0,fillColor:"#ffffff",symbol:"circle"},lines:{lineWidth:1,fill:!1,fillColor:null,steps:!1},bars:{show:!1,lineWidth:2,horizontal:!1,barWidth:.8,fill:!0,fillColor:null,align:"left",zero:!0},shadowSize:3,highlightColor:null},grid:{show:!0,aboveData:!1,color:"#545454",backgroundColor:null,borderColor:null,tickColor:null,margin:0,labelMargin:5,axisMargin:8,borderWidth:1,minBorderMargin:null,markings:null,markingsColor:"#f4f4f4",markingsLineWidth:2,clickable:!1,hoverable:!1,autoHighlight:!0,mouseActiveRadius:15},interaction:{redrawOverlayInterval:1e3/60},hooks:{}},x=null,n=null,i=null,g=null,a=null,m=[],v=[],b={left:0,right:0,top:0,bottom:0},w=0,T=0,k={processOptions:[],processRawData:[],processDatapoints:[],processOffset:[],setupGrid:[],adjustSeriesDataRange:[],setRange:[],drawBackground:[],drawSeries:[],drawAxis:[],draw:[],axisReserveSpace:[],bindEvents:[],drawOverlay:[],resize:[],shutdown:[]},M=this,r={},s=null;M.setData=c,M.setupGrid=z,M.draw=W,M.getPlaceholder=function(){return l},M.getCanvas=function(){return x.element},M.getSurface=function(){return x},M.getEventHolder=function(){return i[0]},M.getPlotOffset=function(){return b},M.width=function(){return w},M.height=function(){return T},M.offset=function(){var t=i.offset();return t.left+=b.left,t.top+=b.top,t},M.getData=function(){return y},M.getAxes=function(){var n={};return J.each(m.concat(v),function(t,e){e&&(n[e.direction+(1!==e.n?e.n:"")+"axis"]=e)}),n},M.getXAxes=function(){return m},M.getYAxes=function(){return v},M.c2p=function(t){var e,n,o={};for(e=0;e<m.length;++e)(n=m[e])&&n.used&&(o["x"+n.n]=n.c2p(t.left));for(e=0;e<v.length;++e)(n=v[e])&&n.used&&(o["y"+n.n]=n.c2p(t.top));void 0!==o.x1&&(o.x=o.x1);void 0!==o.y1&&(o.y=o.y1);return o},M.p2c=function(t){var e,n,o,i={};for(e=0;e<m.length;++e)if((n=m[e])&&n.used&&(o="x"+n.n,null==t[o]&&1===n.n&&(o="x"),null!=t[o])){i.left=n.p2c(t[o]);break}for(e=0;e<v.length;++e)if((n=v[e])&&n.used&&(o="y"+n.n,null==t[o]&&1===n.n&&(o="y"),null!=t[o])){i.top=n.p2c(t[o]);break}return i},M.getOptions=function(){return d},M.triggerRedrawOverlay=U,M.pointOffset=function(t){return{left:parseInt(m[N(t,"x")-1].p2c(+t.x)+b.left,10),top:parseInt(v[N(t,"y")-1].p2c(+t.y)+b.top,10)}},M.shutdown=u,M.destroy=function(){u(),l.removeData("plot").empty(),y=[],m=[],v=[],M=k=a=g=i=n=x=d=null},M.resize=function(){var t=l.width(),e=l.height();x.resize(t,e),n.resize(t,e),P(k.resize,[t,e])},M.clearTextCache=function(){x.clearCache(),n.clearCache()},M.autoScaleAxis=E,M.computeRangeForDataSeries=function(t,e,n){for(var o=t.datapoints.points,i=t.datapoints.pointsize,a=t.datapoints.format,r=Number.POSITIVE_INFINITY,s=Number.NEGATIVE_INFINITY,l={xmin:r,ymin:r,xmax:s,ymax:s},c=0;c<o.length;c+=i)if(null!==o[c]&&("function"!=typeof n||n(o[c])))for(var u=0;u<i;++u){var p=o[c+u],h=a[u];null!=h&&(("function"!=typeof n||n(p))&&(e||h.computeRange)&&p!==1/0&&p!==-1/0&&(!0===h.x&&(p<l.xmin&&(l.xmin=p),p>l.xmax&&(l.xmax=p)),!0===h.y&&(p<l.ymin&&(l.ymin=p),p>l.ymax&&(l.ymax=p))))}return l},M.adjustSeriesDataRange=function(t,e){if(t.bars.show){var n,o=t.bars.barWidth[1];t.datapoints&&t.datapoints.points&&!o&&function(t){var e=[],n=t.datapoints.pointsize,o=Number.MAX_VALUE;t.datapoints.points.length<=n&&(o=1);for(var i=t.bars.horizontal?1:0;i<t.datapoints.points.length;i+=n)isFinite(t.datapoints.points[i])&&null!==t.datapoints.points[i]&&e.push(t.datapoints.points[i]);(e=e.filter(function(t,e,n){return n.indexOf(t)===e})).sort(function(t,e){return t-e});for(var i=1;i<e.length;i++){var a=Math.abs(e[i]-e[i-1]);a<o&&isFinite(a)&&(o=a)}"number"==typeof t.bars.barWidth?t.bars.barWidth=t.bars.barWidth*o:t.bars.barWidth[0]=t.bars.barWidth[0]*o}(t);var i=t.bars.barWidth[0]||t.bars.barWidth;switch(t.bars.align){case"left":n=0;break;case"right":n=-i;break;default:n=-i/2}t.bars.horizontal?(e.ymin+=n,e.ymax+=n+i):(e.xmin+=n,e.xmax+=n+i)}if(t.bars.show&&t.bars.zero||t.lines.show&&t.lines.zero){var a=t.datapoints.pointsize;a<=2&&(e.ymin=Math.min(0,e.ymin),e.ymax=Math.max(0,e.ymax))}return e},M.findNearbyItem=function(t,e,n,o,i){for(var a,r=null,s=o*o+1,l=y.length-1;0<=l;--l)if(n(l)){var c=y[l];if(!c.datapoints)return;if(c.lines.show||c.points.show){var u=H(c,t,e,o,s,i);u&&(s=u.distance,r=[l,u.dataIndex])}if(c.bars.show&&!r){var p=q(c,t,e);0<=p&&(r=[l,p])}}if(r){l=r[0],a=r[1];var h=y[l].datapoints.pointsize;return{datapoint:y[l].datapoints.points.slice(a*h,(a+1)*h),dataIndex:a,series:y[l],seriesIndex:l}}return null},M.findNearbyInterpolationPoint=function(t,e,n){var o,i,a,r,s,l,c,u=Number.MAX_VALUE;for(o=0;o<y.length;++o)if(n(o)){var p=y[o].datapoints.points;l=y[o].datapoints.pointsize;var h=p[p.length-l]<p[0]?function(t,e){return e<t}:function(t,e){return t<e};if(!h(t,p[0])){for(i=l;i<p.length&&!h(t,p[i]);i+=l);var f=p[i-l],d=p[i-l+1],m=p[i],g=p[i+1];void 0!==f&&void 0!==m&&void 0!==d&&void 0!==g&&(e=f===m?g:d+(g-d)*(t-f)/(m-f),r=Math.abs(y[o].xaxis.p2c(m)-t),s=Math.abs(y[o].yaxis.p2c(g)-e),(a=r*r+s*s)<u&&(u=a,c=[t,e,o,i]))}}if(c)return o=c[2],i=c[3],l=y[o].datapoints.pointsize,p=y[o].datapoints.points,f=p[i-l],d=p[i-l+1],m=p[i],g=p[i+1],{datapoint:[c[0],c[1]],leftPoint:[f,d],rightPoint:[m,g],seriesIndex:o};return null},M.computeValuePrecision=O,M.computeTickSize=I,M.addEventHandler=function(t,e,n,o){var i=n+t,a=r[i]||[];a.push({event:t,handler:e,eventHolder:n,priority:o}),a.sort(function(t,e){return e.priority-t.priority}),a.forEach(function(t){t.eventHolder.unbind(t.event,t.handler),t.eventHolder.bind(t.event,t.handler)}),r[i]=a},M.hooks=k;var S=J.plot.uiConstants.MINOR_TICKS_COUNT_CONSTANT,C=J.plot.uiConstants.TICK_LENGTH_CONSTANT;function P(t,e){e=[M].concat(e);for(var n=0;n<t.length;++n)t[n].apply(this,e)}function c(t){var e=y;y=function(t){for(var e=[],n=0;n<t.length;++n){var o=J.extend(!0,{},d.series);null!=t[n].data?(o.data=t[n].data,delete t[n].data,J.extend(!0,o,t[n]),t[n].data=o.data):o.data=t[n],e.push(o)}return e}(t),function(){var t,e=y.length,n=-1;for(t=0;t<y.length;++t){var o=y[t].color;null!=o&&(e--,"number"==typeof o&&n<o&&(n=o))}e<=n&&(e=n+1);var i,a=[],r=d.colors,s=r.length,l=0,c=Math.max(0,y.length-e);for(t=0;t<e;t++)i=J.color.parse(r[(c+t)%s]||"#666"),t%s==0&&t&&(l=0<=l?l<.5?-l-.2:0:-l),a[t]=i.scale("rgb",1+l);var u,p=0;for(t=0;t<y.length;++t){if(null==(u=y[t]).color?(u.color=a[p].toString(),++p):"number"==typeof u.color&&(u.color=a[u.color].toString()),null==u.lines.show){var h,f=!0;for(h in u)if(u[h]&&u[h].show){f=!1;break}f&&(u.lines.show=!0)}null==u.lines.zero&&(u.lines.zero=!!u.lines.fill),u.xaxis=A(m,N(u,"x")),u.yaxis=A(v,N(u,"y"))}}(),function(t){var e,n,o,i,a,r,s,l,c,u,p,h,f=Number.POSITIVE_INFINITY,d=Number.NEGATIVE_INFINITY;function m(t,e,n){e<t.datamin&&e!==-1/0&&(t.datamin=e),n>t.datamax&&n!==1/0&&(t.datamax=n)}function g(t,e){return t&&t[e]&&t[e].datapoints&&t[e].datapoints.points?t[e].datapoints.points:[]}for(J.each(L(),function(t,e){!0!==e.options.growOnly?(e.datamin=f,e.datamax=d):(void 0===e.datamin&&(e.datamin=f),void 0===e.datamax&&(e.datamax=d)),e.used=!1}),e=0;e<y.length;++e)(a=y[e]).datapoints={points:[]},0===a.datapoints.points.length&&(a.datapoints.points=g(t,e)),P(k.processRawData,[a,a.data,a.datapoints]);for(e=0;e<y.length;++e){if(a=y[e],p=a.data,!(h=a.datapoints.format)){if((h=[]).push({x:!0,y:!1,number:!0,required:!0,computeRange:"none"!==a.xaxis.options.autoScale,defaultValue:null}),h.push({x:!1,y:!0,number:!0,required:!0,computeRange:"none"!==a.yaxis.options.autoScale,defaultValue:null}),a.stack||a.bars.show||a.lines.show&&a.lines.fill){var x=null!=a.datapoints.pointsize?a.datapoints.pointsize:a.data&&a.data[0]&&a.data[0].length?a.data[0].length:3;2<x&&h.push({x:!1,y:!0,number:!0,required:!1,computeRange:"none"!==a.yaxis.options.autoScale,defaultValue:0})}a.datapoints.format=h}if(a.xaxis.used=a.yaxis.used=!0,null==a.datapoints.pointsize){a.datapoints.pointsize=h.length,s=a.datapoints.pointsize,r=a.datapoints.points;a.lines.show&&a.lines.steps;for(n=o=0;n<p.length;++n,o+=s){var v=null==(u=p[n]);if(!v)for(i=0;i<s;++i)l=u[i],(c=h[i])&&(c.number&&null!=l&&(l=+l,isNaN(l)&&(l=null)),null==l&&(c.required&&(v=!0),null!=c.defaultValue&&(l=c.defaultValue))),r[o+i]=l;if(v)for(i=0;i<s;++i)null!=(l=r[o+i])&&(c=h[i]).computeRange&&(c.x&&m(a.xaxis,l,l),c.y&&m(a.yaxis,l,l)),r[o+i]=null}r.length=o}}for(e=0;e<y.length;++e)a=y[e],P(k.processDatapoints,[a,a.datapoints]);for(e=0;e<y.length;++e)if(a=y[e],!(h=a.datapoints.format).every(function(t){return!t.computeRange})){var b=M.adjustSeriesDataRange(a,M.computeRangeForDataSeries(a));P(k.adjustSeriesDataRange,[a,b]),m(a.xaxis,b.xmin,b.xmax),m(a.yaxis,b.ymin,b.ymax)}J.each(L(),function(t,e){e.datamin===f&&(e.datamin=null),e.datamax===d&&(e.datamax=null)})}(e)}function N(t,e){var n=t[e+"axis"];return"object"===_typeof(n)&&(n=n.n),"number"!=typeof n&&(n=1),n}function L(){return m.concat(v).filter(function(t){return t})}function A(t,e){return t[e-1]||(t[e-1]={n:e,direction:t===m?"x":"y",options:J.extend(!0,{},t===m?d.xaxis:d.yaxis)}),t[e-1]}function u(){s&&clearTimeout(s),P(k.shutdown,[i])}function p(t){function e(t){return t}var n,o,i=t.options.transform||e,a=t.options.inverseTransform;o="x"===t.direction?(n=isFinite(i(t.max)-i(t.min))?t.scale=w/Math.abs(i(t.max)-i(t.min)):t.scale=1/Math.abs(J.plot.saturated.delta(i(t.min),i(t.max),w)),Math.min(i(t.max),i(t.min))):(n=-(n=isFinite(i(t.max)-i(t.min))?t.scale=T/Math.abs(i(t.max)-i(t.min)):t.scale=1/Math.abs(J.plot.saturated.delta(i(t.min),i(t.max),T))),Math.max(i(t.max),i(t.min))),t.p2c=i===e?function(t){return isFinite(t-o)?(t-o)*n:(t/4-o/4)*n*4}:function(t){var e=i(t);return isFinite(e-o)?(e-o)*n:(e/4-o/4)*n*4},t.c2p=a?function(t){return a(o+t/n)}:function(t){return o+t/n}}function h(n){P(k.axisReserveSpace,[n]);var t=n.labelWidth,e=n.labelHeight,o=n.options.position,i="x"===n.direction,a=n.options.tickLength,r=n.options.showTicks,s=n.options.showMinorTicks,l=n.options.gridLines,c=d.grid.axisMargin,u=d.grid.labelMargin,p=!0,h=!0,f=!1;J.each(i?m:v,function(t,e){e&&(e.show||e.reserveSpace)&&(e===n?f=!0:e.options.position===o&&(f?h=!1:p=!1))}),h&&(c=0),null==a&&(a=C),null==r&&(r=!0),null==s&&(s=!0),null==l&&(l=!!p),isNaN(+a)||(u+=r?+a:0),i?(e+=u,"bottom"===o?(b.bottom+=e+c,n.box={top:x.height-b.bottom,height:e}):(n.box={top:b.top+c,height:e},b.top+=e+c)):(t+=u,"left"===o?(n.box={left:b.left+c,width:t},b.left+=t+c):(b.right+=t+c,n.box={left:x.width-b.right,width:t})),n.position=o,n.tickLength=a,n.showMinorTicks=s,n.showTicks=r,n.gridLines=l,n.box.padding=u,n.innermost=p}function f(t,e,n){"x"===t.direction?("bottom"===t.position&&n(e.bottom)&&(t.box.top-=Math.ceil(e.bottom)),"top"===t.position&&n(e.top)&&(t.box.top+=Math.ceil(e.top))):("left"===t.position&&n(e.left)&&(t.box.left+=Math.ceil(e.left)),"right"===t.position&&n(e.right)&&(t.box.left-=Math.ceil(e.right)))}function z(a){var t,e,n=L(),o=d.grid.show;for(e in b)b[e]=0;for(e in P(k.processOffset,[b]),b)"object"===_typeof(d.grid.borderWidth)?b[e]+=o?d.grid.borderWidth[e]:0:b[e]+=o?d.grid.borderWidth:0;if(J.each(n,function(t,e){var n,o,i=e.options;e.show=null==i.show?e.used:i.show,e.reserveSpace=null==i.reserveSpace?e.show:i.reserveSpace,o=(n=e).options,n.tickFormatter||("function"==typeof o.tickFormatter?n.tickFormatter=function(){var t=Array.prototype.slice.call(arguments);return""+o.tickFormatter.apply(null,t)}:n.tickFormatter=tt),P(k.setRange,[e,a]),function(t,e){var n="number"==typeof t.options.min?t.options.min:t.min,o="number"==typeof t.options.max?t.options.max:t.max,i=t.options.offset;e&&(E(t),n=t.autoScaledMin,o=t.autoScaledMax);if(n=(null!=n?n:-1)+(i.below||0),(o=(null!=o?o:1)+(i.above||0))<n){var a=n;n=o,o=a,t.options.offset={above:0,below:0}}t.min=J.plot.saturated.saturate(n),t.max=J.plot.saturated.saturate(o)}(e,a)}),o){w=x.width-b.left-b.right,T=x.height-b.bottom-b.top;var i=J.grep(n,function(t){return t.show||t.reserveSpace});for(J.each(i,function(t,e){var n,o,i,a;!function(t){var e,n=t.options;e=D(t.direction,x,n.ticks),t.delta=J.plot.saturated.delta(t.min,t.max,e);var o=M.computeValuePrecision(t.min,t.max,t.direction,e,n.tickDecimals);t.tickDecimals=Math.max(0,null!=n.tickDecimals?n.tickDecimals:o),t.tickSize=function(t,e,n,o,i){var a;a="number"==typeof o.ticks&&0<o.ticks?o.ticks:.3*Math.sqrt("x"===n?x.width:x.height);var r=I(t,e,a,i);return null!=o.minTickSize&&r<o.minTickSize&&(r=o.minTickSize),o.tickSize||r}(t.min,t.max,t.direction,n,n.tickDecimals),t.tickGenerator||("function"==typeof n.tickGenerator?t.tickGenerator=n.tickGenerator:t.tickGenerator=$);if(null!=n.alignTicksWithAxis){var i=("x"===t.direction?m:v)[n.alignTicksWithAxis-1];if(i&&i.used&&i!==t){var a=t.tickGenerator(t,M);if(0<a.length&&(null==n.min&&(t.min=Math.min(t.min,a[0])),null==n.max&&1<a.length&&(t.max=Math.max(t.max,a[a.length-1]))),t.tickGenerator=function(t){var e,n,o=[];for(n=0;n<i.ticks.length;++n)e=(i.ticks[n].v-i.min)/(i.max-i.min),e=t.min+e*(t.max-t.min),o.push(e);return o},!t.mode&&null==n.tickDecimals){var r=Math.max(0,1-Math.floor(Math.log(t.delta)/Math.LN10)),s=t.tickGenerator(t,M);1<s.length&&/\..*0$/.test((s[1]-s[0]).toFixed(r))||(t.tickDecimals=r)}}}}(e),function(t){var e,n,o=t.options.ticks,i=[];null==o||"number"==typeof o&&0<o?i=t.tickGenerator(t,M):o&&(i=J.isFunction(o)?o(t):o);for(t.ticks=[],e=0;e<i.length;++e){var a=null,r=i[e];"object"===_typeof(r)?(n=+r[0],1<r.length&&(a=r[1])):n=+r,isNaN(n)||t.ticks.push(R(n,a,t,"major"))}}(e),o=(n=e).ticks,i=y,"loose"===n.options.autoScale&&0<o.length&&i.some(function(t){return 0<t.datapoints.points.length})&&(n.min=Math.min(n.min,o[0].v),n.max=Math.max(n.max,o[o.length-1].v)),p(e),function(e,t){if("endpoints"===e.options.showTickLabels)return!0;if("all"!==e.options.showTickLabels)return"major"!==e.options.showTickLabels&&"none"!==e.options.showTickLabels&&void 0;var n=t.filter(function(t){return t.xaxis===e}),o=n.some(function(t){return!t.bars.show});return 0===n.length||o}(a=e,y)&&(a.ticks.unshift(R(a.min,null,a,"min")),a.ticks.push(R(a.max,null,a,"max"))),function(t){for(var e=t.options,n="none"!==e.showTickLabels&&t.ticks?t.ticks:[],o="major"===e.showTickLabels||"all"===e.showTickLabels,i="endpoints"===e.showTickLabels||"all"===e.showTickLabels,a=e.labelWidth||0,r=e.labelHeight||0,s=t.direction+"Axis "+t.direction+t.n+"Axis",l="flot-"+t.direction+"-axis flot-"+t.direction+t.n+"-axis "+s,c=e.font||"flot-tick-label tickLabel",u=0;u<n.length;++u){var p=n[u],h=p.label;if(p.label&&!(!1===o&&0<u&&u<n.length-1)&&(!1!==i||0!==u&&u!==n.length-1)){"object"===_typeof(p.label)&&(h=p.label.name);var f=x.getTextInfo(l,h,c);a=Math.max(a,f.width),r=Math.max(r,f.height)}}t.labelWidth=e.labelWidth||a,t.labelHeight=e.labelHeight||r}(e)}),t=i.length-1;0<=t;--t)h(i[t]);!function(){var t,e=d.grid.minBorderMargin;if(null==e)for(t=e=0;t<y.length;++t)e=Math.max(e,2*(y[t].points.radius+y[t].points.lineWidth/2));var n,o={},i={left:e,right:e,top:e,bottom:e};for(n in J.each(L(),function(t,e){e.reserveSpace&&e.ticks&&e.ticks.length&&("x"===e.direction?(i.left=Math.max(i.left,e.labelWidth/2),i.right=Math.max(i.right,e.labelWidth/2)):(i.bottom=Math.max(i.bottom,e.labelHeight/2),i.top=Math.max(i.top,e.labelHeight/2)))}),i)o[n]=i[n]-b[n];J.each(m.concat(v),function(t,e){f(e,o,function(t){return 0<t})}),b.left=Math.ceil(Math.max(i.left,b.left)),b.right=Math.ceil(Math.max(i.right,b.right)),b.top=Math.ceil(Math.max(i.top,b.top)),b.bottom=Math.ceil(Math.max(i.bottom,b.bottom))}(),J.each(i,function(t,e){var n;"x"===(n=e).direction?(n.box.left=b.left-n.labelWidth/2,n.box.width=x.width-b.left-b.right+n.labelWidth):(n.box.top=b.top-n.labelHeight/2,n.box.height=x.height-b.bottom-b.top+n.labelHeight)})}if(d.grid.margin){for(e in b){var r=d.grid.margin||0;b[e]+="number"==typeof r?r:r[e]||0}J.each(m.concat(v),function(t,e){f(e,d.grid.margin,function(t){return null!=t})})}w=x.width-b.left-b.right,T=x.height-b.bottom-b.top,J.each(n,function(t,e){p(e)}),o&&J.each(L(),function(t,o){var e,i,a,r,s,l,c,u=o.box,n=o.direction+"Axis "+o.direction+o.n+"Axis",p="flot-"+o.direction+"-axis flot-"+o.direction+o.n+"-axis "+n,h=o.options.font||"flot-tick-label tickLabel",f={x:NaN,y:NaN,width:NaN,height:NaN},d=[],m=function(t,e,n,o,i,a,r,s){return(t<=i&&i<=n||i<=t&&t<=r)&&(e<=a&&a<=o||a<=e&&e<=s)},g=function(t,e){return!t||!t.label||t.v<o.min||t.v>o.max?f:(l=x.getTextInfo(p,t.label,h),"x"===o.direction?(r="center",i=b.left+o.p2c(t.v),"bottom"===o.position?a=u.top+u.padding-o.boxPosition.centerY:(a=u.top+u.height-u.padding+o.boxPosition.centerY,s="bottom")):(s="middle",a=b.top+o.p2c(t.v),"left"===o.position?(i=u.left+u.width-u.padding-o.boxPosition.centerX,r="right"):i=u.left+u.padding+o.boxPosition.centerX),c={x:i-l.width/2-3,y:a-3,width:l.width+6,height:l.height+6},n=c,e.some(function(t){return m(n.x,n.y,n.x+n.width,n.y+n.height,t.x,t.y,t.x+t.width,t.y+t.height)})?f:(x.addText(p,i,a,t.label,h,null,null,r,s),c));var n};if(x.removeText(p),P(k.drawAxis,[o,x]),o.show)switch(o.options.showTickLabels){case"none":break;case"endpoints":d.push(g(o.ticks[0],d)),d.push(g(o.ticks[o.ticks.length-1],d));break;case"major":for(d.push(g(o.ticks[0],d)),d.push(g(o.ticks[o.ticks.length-1],d)),e=1;e<o.ticks.length-1;++e)d.push(g(o.ticks[e],d));break;case"all":for(d.push(g(o.ticks[0],[])),d.push(g(o.ticks[o.ticks.length-1],d)),e=1;e<o.ticks.length-1;++e)d.push(g(o.ticks[e],d))}}),P(k.setupGrid,[])}function E(t){var e,n=t.options,o=n.min,i=n.max,a=t.datamin,r=t.datamax;switch(n.autoScale){case"none":o=+(null!=n.min?n.min:a),i=+(null!=n.max?n.max:r);break;case"loose":if(null!=a&&null!=r){o=a,i=r,e=J.plot.saturated.saturate(i-o);var s="number"==typeof n.autoScaleMargin?n.autoScaleMargin:.02;o=J.plot.saturated.saturate(o-e*s),i=J.plot.saturated.saturate(i+e*s),o<0&&0<=a&&(o=0)}else o=n.min,i=n.max;break;case"exact":o=null!=a?a:n.min,i=null!=r?r:n.max;break;case"sliding-window":i<r&&(i=r,o=Math.max(r-(n.windowSize||100),o))}var l=function(t,e){var n=void 0===t?null:t,o=void 0===e?null:e;if(0==o-n){var i=0===o?1:.01,a=null;null==n&&(a-=i),null!=o&&null==n||(o+=i),null!=a&&(n=a)}return{min:n,max:o}}(o,i);o=l.min,i=l.max,!0===n.growOnly&&"none"!==n.autoScale&&"sliding-window"!==n.autoScale&&(o=o<a?o:null!==a?a:o,i=r<i?i:null!==r?r:i),t.autoScaledMin=o,t.autoScaledMax=i}function O(t,e,n,o,i){var a=D(n,x,o),r=J.plot.saturated.delta(t,e,a),s=-Math.floor(Math.log(r)/Math.LN10);i&&i<s&&(s=i);var l=r/parseFloat("1e"+-s);return 2.25<l&&l<3&&s+1<=i&&++s,isFinite(s)?s:0}function I(t,e,n,o){var i=J.plot.saturated.delta(t,e,n),a=-Math.floor(Math.log(i)/Math.LN10);o&&o<a&&(a=o);var r,s=parseFloat("1e"+-a),l=i/s;return l<1.5?r=1:l<3?(r=2,2.25<l&&(null==o||a+1<=o)&&(r=2.5)):r=l<7.5?5:10,r*=s}function D(t,e,n){return"number"==typeof n&&0<n?n:.3*Math.sqrt("x"===t?e.width:e.height)}function R(t,e,n,o){if(null===e)switch(o){case"min":case"max":var i=(a=t,r=n,s=Math.floor(r.p2c(a)),l="x"===r.direction?s+1:s-1,c=r.c2p(s),u=r.c2p(l),O(c,u,r.direction,1));isFinite(i),e=n.tickFormatter(t,n,i,M);break;case"major":e=n.tickFormatter(t,n,void 0,M)}var a,r,s,l,c,u;return{v:t,label:e}}function W(){x.clear(),P(k.drawBackground,[g]);var t=d.grid;t.show&&t.backgroundColor&&(g.save(),g.translate(b.left,b.top),g.fillStyle=Z(d.grid.backgroundColor,T,0,"rgba(255, 255, 255, 0)"),g.fillRect(0,0,w,T),g.restore()),t.show&&!t.aboveData&&V();for(var e=0;e<y.length;++e)P(k.drawSeries,[g,y[e],e,Z]),_(y[e]);P(k.draw,[g]),t.show&&t.aboveData&&V(),x.render(),U()}function F(t,e){for(var n,o,i,a,r=L(),s=0;s<r.length;++s)if((n=r[s]).direction===e&&(t[a=e+n.n+"axis"]||1!==n.n||(a=e+"axis"),t[a])){o=t[a].from,i=t[a].to;break}if(t[a]||(n="x"===e?m[0]:v[0],o=t[e+"1"],i=t[e+"2"]),null!=o&&null!=i&&i<o){var l=o;o=i,i=l}return{from:o,to:i,axis:n}}function Y(t){var e=t.box,n=0,o=0;return"x"===t.direction?(n=0,o=e.top-b.top+("top"===t.position?e.height:0)):(o=0,n=e.left-b.left+("left"===t.position?e.width:0)+t.boxPosition.centerX),{x:n,y:o}}function X(t,e){return t%2!=0?Math.floor(e)+.5:e}function G(t){g.lineWidth=1;var e=Y(t),n=e.x,o=e.y;if(t.show){var i=0,a=0;g.strokeStyle=t.options.color,g.beginPath(),"x"===t.direction?i=w+1:a=T+1,"x"===t.direction?o=X(g.lineWidth,o):n=X(g.lineWidth,n),g.moveTo(n,o),g.lineTo(n+i,o+a),g.stroke()}}function B(t){var e=t.tickLength,n=t.showMinorTicks,o=S,i=Y(t),a=i.x,r=i.y,s=0;for(g.strokeStyle=t.options.color,g.beginPath(),s=0;s<t.ticks.length;++s){var l,c=t.ticks[s].v,u=0,p=0,h=0,f=0;if(!isNaN(c)&&c>=t.min&&c<=t.max&&("x"===t.direction?(a=t.p2c(c),p=e,"top"===t.position&&(p=-p)):(r=t.p2c(c),u=e,"left"===t.position&&(u=-u)),"x"===t.direction?a=X(g.lineWidth,a):r=X(g.lineWidth,r),g.moveTo(a,r),g.lineTo(a+u,r+p)),!0===n&&s<t.ticks.length-1){var d=t.ticks[s].v,m=(t.ticks[s+1].v-d)/(o+1);for(l=1;l<=o;l++){if("x"===t.direction){if(f=e/2,a=X(g.lineWidth,t.p2c(d+l*m)),"top"===t.position&&(f=-f),a<0||w<a)continue}else if(h=e/2,r=X(g.lineWidth,t.p2c(d+l*m)),"left"===t.position&&(h=-h),r<0||T<r)continue;g.moveTo(a,r),g.lineTo(a+h,r+f)}}}g.stroke()}function j(t){var e,n,o;for(g.strokeStyle=d.grid.tickColor,g.beginPath(),e=0;e<t.ticks.length;++e){var i=t.ticks[e].v,a=0,r=0,s=0,l=0;isNaN(i)||i<t.min||i>t.max||(n=i,void 0,o=d.grid.borderWidth,(!("object"===_typeof(o)&&0<o[t.position]||0<o)||n!==t.min&&n!==t.max)&&("x"===t.direction?(s=t.p2c(i),r=-(l=T)):(s=0,l=t.p2c(i),a=w),"x"===t.direction?s=X(g.lineWidth,s):l=X(g.lineWidth,l),g.moveTo(s,l),g.lineTo(s+a,l+r)))}g.stroke()}function V(){var t,e,n,o;g.save(),g.translate(b.left,b.top),function(){var t,e,n=d.grid.markings;if(n)for(J.isFunction(n)&&((t=M.getAxes()).xmin=t.xaxis.min,t.xmax=t.xaxis.max,t.ymin=t.yaxis.min,t.ymax=t.yaxis.max,n=n(t)),e=0;e<n.length;++e){var o=n[e],i=F(o,"x"),a=F(o,"y");if(null==i.from&&(i.from=i.axis.min),null==i.to&&(i.to=i.axis.max),null==a.from&&(a.from=a.axis.min),null==a.to&&(a.to=a.axis.max),!(i.to<i.axis.min||i.from>i.axis.max||a.to<a.axis.min||a.from>a.axis.max)){i.from=Math.max(i.from,i.axis.min),i.to=Math.min(i.to,i.axis.max),a.from=Math.max(a.from,a.axis.min),a.to=Math.min(a.to,a.axis.max);var r=i.from===i.to,s=a.from===a.to;if(!r||!s)if(i.from=Math.floor(i.axis.p2c(i.from)),i.to=Math.floor(i.axis.p2c(i.to)),a.from=Math.floor(a.axis.p2c(a.from)),a.to=Math.floor(a.axis.p2c(a.to)),r||s){var l=o.lineWidth||d.grid.markingsLineWidth,c=l%2?.5:0;g.beginPath(),g.strokeStyle=o.color||d.grid.markingsColor,g.lineWidth=l,r?(g.moveTo(i.to+c,a.from),g.lineTo(i.to+c,a.to)):(g.moveTo(i.from,a.to+c),g.lineTo(i.to,a.to+c)),g.stroke()}else g.fillStyle=o.color||d.grid.markingsColor,g.fillRect(i.from,a.to,i.to-i.from,a.from-a.to)}}}(),t=L(),e=d.grid.borderWidth;for(var i=0;i<t.length;++i){var a=t[i];a.show&&(G(a),!0===a.showTicks&&B(a),!0===a.gridLines&&j(a))}e&&(n=d.grid.borderWidth,o=d.grid.borderColor,"object"===_typeof(n)||"object"===_typeof(o)?("object"!==_typeof(n)&&(n={top:n,right:n,bottom:n,left:n}),"object"!==_typeof(o)&&(o={top:o,right:o,bottom:o,left:o}),0<n.top&&(g.strokeStyle=o.top,g.lineWidth=n.top,g.beginPath(),g.moveTo(0-n.left,0-n.top/2),g.lineTo(w,0-n.top/2),g.stroke()),0<n.right&&(g.strokeStyle=o.right,g.lineWidth=n.right,g.beginPath(),g.moveTo(w+n.right/2,0-n.top),g.lineTo(w+n.right/2,T),g.stroke()),0<n.bottom&&(g.strokeStyle=o.bottom,g.lineWidth=n.bottom,g.beginPath(),g.moveTo(w+n.right,T+n.bottom/2),g.lineTo(0,T+n.bottom/2),g.stroke()),0<n.left&&(g.strokeStyle=o.left,g.lineWidth=n.left,g.beginPath(),g.moveTo(0-n.left/2,T+n.bottom),g.lineTo(0-n.left/2,0),g.stroke())):(g.lineWidth=n,g.strokeStyle=d.grid.borderColor,g.strokeRect(-n/2,-n/2,w+n,T+n))),g.restore()}function _(t){t.lines.show&&J.plot.drawSeries.drawSeriesLines(t,g,b,w,T,M.drawSymbol,Z),t.bars.show&&J.plot.drawSeries.drawSeriesBars(t,g,b,w,T,M.drawSymbol,Z),t.points.show&&J.plot.drawSeries.drawSeriesPoints(t,g,b,w,T,M.drawSymbol,Z)}function H(t,e,n,o,i,a){var r=t.xaxis.c2p(e),s=t.yaxis.c2p(n),l=o/t.xaxis.scale,c=o/t.yaxis.scale,u=t.datapoints.points,p=t.datapoints.pointsize;t.xaxis.options.inverseTransform&&(l=Number.MAX_VALUE),t.yaxis.options.inverseTransform&&(c=Number.MAX_VALUE);for(var h=null,f=0;f<u.length;f+=p){var d=u[f],m=u[f+1];if(null!=d&&!(l<d-r||d-r<-l||c<m-s||m-s<-c)){var g=Math.abs(t.xaxis.p2c(d)-e),x=Math.abs(t.yaxis.p2c(m)-n),v=a?a(g,x):g*g+x*x;v<i&&(h={dataIndex:f/p,distance:i=v})}}return h}function q(t,e,n){var o,i,a=t.bars.barWidth[0]||t.bars.barWidth,r=t.xaxis.c2p(e),s=t.yaxis.c2p(n),l=t.datapoints.points,c=t.datapoints.pointsize;switch(t.bars.align){case"left":o=0;break;case"right":o=-a;break;default:o=-a/2}i=o+a;for(var u=t.bars.fillTowards||0,p=u>t.yaxis.min?Math.min(t.yaxis.max,u):t.yaxis.min,h=-1,f=0;f<l.length;f+=c){var d=l[f],m=l[f+1];null!=d&&((t.bars.horizontal?r<=Math.max(p,d)&&r>=Math.min(p,d)&&m+o<=s&&s<=m+i:d+o<=r&&r<=d+i&&s>=Math.min(p,m)&&s<=Math.max(p,m))&&(h=f/c))}return h}function U(){var t=d.interaction.redrawOverlayInterval;-1!==t?s||(s=setTimeout(function(){Q(M)},t)):Q()}function Q(t){if(s=null,a){n.clear(),P(k.drawOverlay,[a,n]);var e=new CustomEvent("onDrawingDone");t.getEventHolder().dispatchEvent(e),t.getPlaceholder().trigger("drawingdone")}}function Z(t,e,n,o){if("string"==typeof t)return t;for(var i=g.createLinearGradient(0,n,0,e),a=0,r=t.colors.length;a<r;++a){var s=t.colors[a];if("string"!=typeof s){var l=J.color.parse(o);null!=s.brightness&&(l=l.scale("rgb",s.brightness)),null!=s.opacity&&(l.a*=s.opacity),s=l.toString()}i.addColorStop(a/(r-1),s)}return i}!function(){for(var t={Canvas:K},e=0;e<o.length;++e){var n=o[e];n.init(M,t),n.options&&J.extend(!0,d,n.options)}}(),function(){l.css("padding",0).children().filter(function(){return!J(this).hasClass("flot-overlay")&&!J(this).hasClass("flot-base")}).remove(),"static"===l.css("position")&&l.css("position","relative");x=new K("flot-base",l[0]),n=new K("flot-overlay",l[0]),g=x.context,a=n.context,i=J(n.element).unbind();var t=l.data("plot");t&&(t.shutdown(),n.clear());l.data("plot",M)}(),function(t){J.extend(!0,d,t),t&&t.colors&&(d.colors=t.colors);null==d.xaxis.color&&(d.xaxis.color=J.color.parse(d.grid.color).scale("a",.22).toString());null==d.yaxis.color&&(d.yaxis.color=J.color.parse(d.grid.color).scale("a",.22).toString());null==d.xaxis.tickColor&&(d.xaxis.tickColor=d.grid.tickColor||d.xaxis.color);null==d.yaxis.tickColor&&(d.yaxis.tickColor=d.grid.tickColor||d.yaxis.color);null==d.grid.borderColor&&(d.grid.borderColor=d.grid.color);null==d.grid.tickColor&&(d.grid.tickColor=J.color.parse(d.grid.color).scale("a",.22).toString());var e,n,o,i=l.css("font-size"),a=i?+i.replace("px",""):13,r={style:l.css("font-style"),size:Math.round(.8*a),variant:l.css("font-variant"),weight:l.css("font-weight"),family:l.css("font-family")};for(o=d.xaxes.length||1,e=0;e<o;++e)(n=d.xaxes[e])&&!n.tickColor&&(n.tickColor=n.color),n=J.extend(!0,{},d.xaxis,n),(d.xaxes[e]=n).font&&(n.font=J.extend({},r,n.font),n.font.color||(n.font.color=n.color),n.font.lineHeight||(n.font.lineHeight=Math.round(1.15*n.font.size)));for(o=d.yaxes.length||1,e=0;e<o;++e)(n=d.yaxes[e])&&!n.tickColor&&(n.tickColor=n.color),n=J.extend(!0,{},d.yaxis,n),(d.yaxes[e]=n).font&&(n.font=J.extend({},r,n.font),n.font.color||(n.font.color=n.color),n.font.lineHeight||(n.font.lineHeight=Math.round(1.15*n.font.size)));for(e=0;e<d.xaxes.length;++e)A(m,e+1).options=d.xaxes[e];for(e=0;e<d.yaxes.length;++e)A(v,e+1).options=d.yaxes[e];for(var s in J.each(L(),function(t,e){e.boxPosition=e.options.boxPosition||{centerX:0,centerY:0}}),k)d.hooks[s]&&d.hooks[s].length&&(k[s]=k[s].concat(d.hooks[s]));P(k.processOptions,[d])}(e),c(t),z(!0),W(),P(k.bindEvents,[i])}J.plot=function(t,e,n){return new o(J(t),e,n,J.plot.plugins)},J.plot.version="3.0.0",J.plot.plugins=[],J.fn.plot=function(t,e){return this.each(function(){J.plot(this,t,e)})},J.plot.linearTickGenerator=$,J.plot.defaultTickFormatter=tt,J.plot.expRepTickFormatter=l}(jQuery),function(t){var a={saturate:function(t){return t===1/0?Number.MAX_VALUE:t===-1/0?-Number.MAX_VALUE:t},delta:function(t,e,n){return(e-t)/n==1/0?e/n-t/n:(e-t)/n},multiply:function(t,e){return a.saturate(t*e)},multiplyAdd:function(t,e,n){if(isFinite(t*e))return a.saturate(t*e+n);for(var o=n,i=0;i<e;i++)o+=t;return a.saturate(o)},floorInBase:function(t,e){return e*Math.floor(t/e)}};t.plot.saturated=a}(jQuery),function(t){var e={getPageXY:function(t){var e=document.documentElement;return{X:t.clientX+(window.pageXOffset||e.scrollLeft)-(e.clientLeft||0),Y:t.clientY+(window.pageYOffset||e.scrollTop)-(e.clientTop||0)}},getPixelRatio:function(t){return(window.devicePixelRatio||1)/(t.webkitBackingStorePixelRatio||t.mozBackingStorePixelRatio||t.msBackingStorePixelRatio||t.oBackingStorePixelRatio||t.backingStorePixelRatio||1)},isSafari:function(){return/constructor/i.test(window.top.HTMLElement)||"[object SafariRemoteNotification]"===(!window.top.safari||void 0!==window.top.safari&&window.top.safari.pushNotification).toString()},isMobileSafari:function(){return navigator.userAgent.match(/(iPod|iPhone|iPad)/)&&navigator.userAgent.match(/AppleWebKit/)},isOpera:function(){return!!window.opr&&!!opr.addons||!!window.opera||0<=navigator.userAgent.indexOf(" OPR/")},isFirefox:function(){return"undefined"!=typeof InstallTrigger},isIE:function(){return!!document.documentMode},isEdge:function(){return!e.isIE()&&!!window.StyleMedia},isChrome:function(){return!!window.chrome&&!!window.chrome.webstore},isBlink:function(){return(e.isChrome()||e.isOpera())&&!!window.CSS}};t.plot.browser=e}(jQuery),function(s){s.plot.drawSeries=new function(){function d(t,e,n,o,i,a,r,s,l,c,u){var p,h,f,d,m=t+o,g=t+i,x=n,v=e,b=!1;p=h=f=!0,c?(b=h=f=!0,p=!1,v=e+o,x=e+i,(g=t)<(m=n)&&(d=g,g=m,m=d,h=!(p=!0))):(p=h=f=!0,b=!1,m=t+o,g=t+i,(v=e)<(x=n)&&(d=v,v=x,x=d,f=!(b=!0))),g<r.min||m>r.max||v<s.min||x>s.max||(m<r.min&&(m=r.min,p=!1),g>r.max&&(g=r.max,h=!1),x<s.min&&(x=s.min,b=!1),v>s.max&&(v=s.max,f=!1),m=r.p2c(m),x=s.p2c(x),g=r.p2c(g),v=s.p2c(v),a&&(l.fillStyle=a(x,v),l.fillRect(m,v,g-m,x-v)),0<u&&(p||h||f||b)&&(l.beginPath(),l.moveTo(m,x),p?l.lineTo(m,v):l.moveTo(m,v),f?l.lineTo(g,v):l.moveTo(g,v),h?l.lineTo(g,x):l.moveTo(g,x),b?l.lineTo(m,x):l.moveTo(m,x),l.stroke()))}function m(t,e,n,o,i){var a=t.fill;if(!a)return null;if(t.fillColor)return i(t.fillColor,n,o,e);var r=s.color.parse(e);return r.a="number"==typeof a?a:.4,r.normalize(),r.toString()}this.drawSeriesLines=function(t,e,n,o,i,a,r){e.save(),e.translate(n.left,n.top),e.lineJoin="round",t.lines.dashes&&e.setLineDash&&e.setLineDash(t.lines.dashes);var s={format:t.datapoints.format,points:t.datapoints.points,pointsize:t.datapoints.pointsize};t.decimate&&(s.points=t.decimate(t,t.xaxis.min,t.xaxis.max,o,t.yaxis.min,t.yaxis.max,i));var l=t.lines.lineWidth;e.lineWidth=l,e.strokeStyle=t.color;var c=m(t.lines,t.color,0,i,r);c&&(e.fillStyle=c,function(t,e,n,o,i,a){for(var r=t.points,s=t.pointsize,l=o>n.min?Math.min(n.max,o):n.min,c=0,u=1,p=!1,h=0,f=0,d=null,m=null;!(0<s&&c>r.length+s);){var g=r[(c+=s)-s],x=r[c-s+u],v=r[c],b=r[c+u];if(-2===s&&(x=b=l),p){if(0<s&&null!=g&&null==v){f=c,s=-s,u=2;continue}if(s<0&&c===h+s){i.fill(),p=!1,u=1,c=h=f+(s=-s);continue}}if(null!=g&&null!=v){if(a&&(null!==d&&null!==m?(v=g,b=x,g=d,x=m,m=d=null,c-=s):x!==b&&g!==v&&(d=v,m=b=x)),g<=v&&g<e.min){if(v<e.min)continue;x=(e.min-g)/(v-g)*(b-x)+x,g=e.min}else if(v<=g&&v<e.min){if(g<e.min)continue;b=(e.min-g)/(v-g)*(b-x)+x,v=e.min}if(v<=g&&g>e.max){if(v>e.max)continue;x=(e.max-g)/(v-g)*(b-x)+x,g=e.max}else if(g<=v&&v>e.max){if(g>e.max)continue;b=(e.max-g)/(v-g)*(b-x)+x,v=e.max}if(p||(i.beginPath(),i.moveTo(e.p2c(g),n.p2c(l)),p=!0),x>=n.max&&b>=n.max)i.lineTo(e.p2c(g),n.p2c(n.max)),i.lineTo(e.p2c(v),n.p2c(n.max));else if(x<=n.min&&b<=n.min)i.lineTo(e.p2c(g),n.p2c(n.min)),i.lineTo(e.p2c(v),n.p2c(n.min));else{var y=g,w=v;x<=b&&x<n.min&&b>=n.min?(g=(n.min-x)/(b-x)*(v-g)+g,x=n.min):b<=x&&b<n.min&&x>=n.min&&(v=(n.min-x)/(b-x)*(v-g)+g,b=n.min),b<=x&&x>n.max&&b<=n.max?(g=(n.max-x)/(b-x)*(v-g)+g,x=n.max):x<=b&&b>n.max&&x<=n.max&&(v=(n.max-x)/(b-x)*(v-g)+g,b=n.max),g!==y&&i.lineTo(e.p2c(y),n.p2c(x)),i.lineTo(e.p2c(g),n.p2c(x)),i.lineTo(e.p2c(v),n.p2c(b)),v!==w&&(i.lineTo(e.p2c(v),n.p2c(b)),i.lineTo(e.p2c(w),n.p2c(b)))}}else m=d=null}}(s,t.xaxis,t.yaxis,t.lines.fillTowards||0,e,t.lines.steps)),0<l&&function(t,e,n,o,i,a,r){var s=t.points,l=t.pointsize,c=null,u=null,p=0,h=0,f=0,d=0,m=null,g=null,x=0;for(a.beginPath(),x=l;x<s.length;x+=l)if(p=s[x-l],h=s[x-l+1],f=s[x],d=s[x+1],null!==p&&null!==f)if(isNaN(p)||isNaN(f)||isNaN(h)||isNaN(d))u=c=null;else{if(r&&(null!==m&&null!==g?(f=p,d=h,p=m,h=g,g=m=null,x-=l):h!==d&&p!==f&&(m=f,g=d=h)),h<=d&&h<i.min){if(d<i.min)continue;p=(i.min-h)/(d-h)*(f-p)+p,h=i.min}else if(d<=h&&d<i.min){if(h<i.min)continue;f=(i.min-h)/(d-h)*(f-p)+p,d=i.min}if(d<=h&&h>i.max){if(d>i.max)continue;p=(i.max-h)/(d-h)*(f-p)+p,h=i.max}else if(h<=d&&d>i.max){if(h>i.max)continue;f=(i.max-h)/(d-h)*(f-p)+p,d=i.max}if(p<=f&&p<o.min){if(f<o.min)continue;h=(o.min-p)/(f-p)*(d-h)+h,p=o.min}else if(f<=p&&f<o.min){if(p<o.min)continue;d=(o.min-p)/(f-p)*(d-h)+h,f=o.min}if(f<=p&&p>o.max){if(f>o.max)continue;h=(o.max-p)/(f-p)*(d-h)+h,p=o.max}else if(p<=f&&f>o.max){if(p>o.max)continue;d=(o.max-p)/(f-p)*(d-h)+h,f=o.max}p===c&&h===u||a.moveTo(o.p2c(p)+e,i.p2c(h)+n),c=f,u=d,a.lineTo(o.p2c(f)+e,i.p2c(d)+n)}else g=m=null;a.stroke()}(s,0,0,t.xaxis,t.yaxis,e,t.lines.steps),e.restore()},this.drawSeriesPoints=function(t,f,e,n,o,i,a){function r(t,e,n,o,i,a){t.moveTo(e+o,n),t.arc(e,n,o,0,i?Math.PI:2*Math.PI,!1)}r.fill=!0,f.save(),f.translate(e.left,e.top);var s={format:t.datapoints.format,points:t.datapoints.points,pointsize:t.datapoints.pointsize};t.decimatePoints&&(s.points=t.decimatePoints(t,t.xaxis.min,t.xaxis.max,n,t.yaxis.min,t.yaxis.max,o));var l,c=t.points.lineWidth,u=t.points.radius,p=t.points.symbol;"circle"===p?l=r:"string"==typeof p&&i&&i[p]?l=i[p]:"function"==typeof i&&(l=i),0===c&&(c=1e-4),f.lineWidth=c,f.fillStyle=m(t.points,t.color,null,null,a),f.strokeStyle=t.color,function(t,e,n,o,i,a,r,s){var l=t.points,c=t.pointsize;f.beginPath();for(var u=0;u<l.length;u+=c){var p=l[u],h=l[u+1];null==p||p<a.min||p>a.max||h<r.min||h>r.max||(p=a.p2c(p),h=r.p2c(h)+o,s(f,p,h,e,i,n))}s.fill&&!i&&f.fill(),f.stroke()}(s,u,!0,0,!1,t.xaxis,t.yaxis,l),f.restore()},this.drawSeriesBars=function(h,f,t,e,n,o,i){f.save(),f.translate(t.left,t.top);var a,r={format:h.datapoints.format,points:h.datapoints.points,pointsize:h.datapoints.pointsize};h.decimate&&(r.points=h.decimate(h,h.xaxis.min,h.xaxis.max,e)),f.lineWidth=h.bars.lineWidth,f.strokeStyle=h.color;var s=h.bars.barWidth[0]||h.bars.barWidth;switch(h.bars.align){case"left":a=0;break;case"right":a=-s;break;default:a=-s/2}!function(t,e,n,o,i,a){for(var r=t.points,s=t.pointsize,l=h.bars.fillTowards||0,c=l>a.min?Math.min(a.max,l):a.min,u=0;u<r.length;u+=s)if(null!=r[u]){var p=3===s?r[u+2]:c;d(r[u],r[u+1],p,e,n,o,i,a,f,h.bars.horizontal,h.bars.lineWidth)}}(r,a,a+s,h.bars.fill?function(t,e){return m(h.bars,h.color,t,e,i)}:null,h.xaxis,h.yaxis),f.restore()},this.drawBar=d}}(jQuery),function(p){function e(t,e,n,o){if(e.points.errorbars){var i=[{x:!0,number:!0,required:!0},{y:!0,number:!0,required:!0}],a=e.points.errorbars;"x"!==a&&"xy"!==a||(e.points.xerr.asymmetric&&i.push({x:!0,number:!0,required:!0}),i.push({x:!0,number:!0,required:!0})),"y"!==a&&"xy"!==a||(e.points.yerr.asymmetric&&i.push({y:!0,number:!0,required:!0}),i.push({y:!0,number:!0,required:!0})),o.format=i}}function M(t,e){var n=t.datapoints.points,o=null,i=null,a=null,r=null,s=t.points.xerr,l=t.points.yerr,c=t.points.errorbars;"x"===c||"xy"===c?s.asymmetric?(o=n[e+2],i=n[e+3],"xy"===c&&(l.asymmetric?(a=n[e+4],r=n[e+5]):a=n[e+4])):(o=n[e+2],"xy"===c&&(l.asymmetric?(a=n[e+3],r=n[e+4]):a=n[e+3])):"y"===c&&(l.asymmetric?(a=n[e+2],r=n[e+3]):a=n[e+2]),null==i&&(i=o),null==r&&(r=a);var u=[o,i,a,r];return s.show||(u[0]=null,u[1]=null),l.show||(u[2]=null,u[3]=null),u}function S(t,e,n,o,i,a,r,s,l,c,u){o+=c,i+=c,a+=c,"x"===e.err?(n+l<i?h(t,[[i,o],[Math.max(n+l,u[0]),o]]):r=!1,a<n-l?h(t,[[Math.min(n-l,u[1]),o],[a,o]]):s=!1):(i<o-l?h(t,[[n,i],[n,Math.min(o-l,u[0])]]):r=!1,o+l<a?h(t,[[n,Math.max(o+l,u[1])],[n,a]]):s=!1),l=null!=e.radius?e.radius:l,r&&("-"===e.upperCap?"x"===e.err?h(t,[[i,o-l],[i,o+l]]):h(t,[[n-l,i],[n+l,i]]):p.isFunction(e.upperCap)&&("x"===e.err?e.upperCap(t,i,o,l):e.upperCap(t,n,i,l))),s&&("-"===e.lowerCap?"x"===e.err?h(t,[[a,o-l],[a,o+l]]):h(t,[[n-l,a],[n+l,a]]):p.isFunction(e.lowerCap)&&("x"===e.err?e.lowerCap(t,a,o,l):e.lowerCap(t,n,a,l)))}function h(t,e){t.beginPath(),t.moveTo(e[0][0],e[0][1]);for(var n=1;n<e.length;n++)t.lineTo(e[n][0],e[n][1]);t.stroke()}function n(t,n){var e=t.getPlotOffset();n.save(),n.translate(e.left,e.top),p.each(t.getData(),function(t,e){e.points.errorbars&&(e.points.xerr.show||e.points.yerr.show)&&function(t,e,n){var o,i=n.datapoints.points,a=n.datapoints.pointsize,r=[n.xaxis,n.yaxis],s=n.points.radius,l=[n.points.xerr,n.points.yerr],c=!1;r[0].p2c(r[0].max)<r[0].p2c(r[0].min)&&(c=!0,o=l[0].lowerCap,l[0].lowerCap=l[0].upperCap,l[0].upperCap=o);var u=!1;r[1].p2c(r[1].min)<r[1].p2c(r[1].max)&&(u=!0,o=l[1].lowerCap,l[1].lowerCap=l[1].upperCap,l[1].upperCap=o);for(var p=0;p<n.datapoints.points.length;p+=a)for(var h=M(n,p),f=0;f<l.length;f++){var d=[r[f].min,r[f].max];if(h[f*l.length]){var m=i[p],g=i[p+1],x=[m,g][f]+h[f*l.length+1],v=[m,g][f]-h[f*l.length];if("x"===l[f].err&&(g>r[1].max||g<r[1].min||x<r[0].min||v>r[0].max))continue;if("y"===l[f].err&&(m>r[0].max||m<r[0].min||x<r[1].min||v>r[1].max))continue;var b=!0,y=!0;x>d[1]&&(b=!1,x=d[1]),v<d[0]&&(y=!1,v=d[0]),("x"===l[f].err&&c||"y"===l[f].err&&u)&&(o=v,v=x,x=o,o=y,y=b,b=o,o=d[0],d[0]=d[1],d[1]=o),m=r[0].p2c(m),g=r[1].p2c(g),x=r[f].p2c(x),v=r[f].p2c(v),d[0]=r[f].p2c(d[0]),d[1]=r[f].p2c(d[1]);var w=l[f].lineWidth?l[f].lineWidth:n.points.lineWidth,T=null!=n.points.shadowSize?n.points.shadowSize:n.shadowSize;if(0<w&&0<T){var k=T/2;e.lineWidth=k,e.strokeStyle="rgba(0,0,0,0.1)",S(e,l[f],m,g,x,v,b,y,s,k+k/2,d),e.strokeStyle="rgba(0,0,0,0.2)",S(e,l[f],m,g,x,v,b,y,s,k/2,d)}e.strokeStyle=l[f].color?l[f].color:n.color,e.lineWidth=w,S(e,l[f],m,g,x,v,b,y,s,0,d)}}}(0,n,e)}),n.restore()}p.plot.plugins.push({init:function(t){t.hooks.processRawData.push(e),t.hooks.draw.push(n)},options:{series:{points:{errorbars:null,xerr:{err:"x",show:null,asymmetric:null,upperCap:null,lowerCap:null,color:null,radius:null},yerr:{err:"y",show:null,asymmetric:null,upperCap:null,lowerCap:null,color:null,radius:null}}}},name:"errorbars",version:"1.0"})}(jQuery),jQuery.plot.uiConstants={SNAPPING_CONSTANT:20,PANHINT_LENGTH_CONSTANT:10,MINOR_TICKS_COUNT_CONSTANT:4,TICK_LENGTH_CONSTANT:10,ZOOM_DISTANCE_MARGIN:25},function(v){var b=t(Number.MAX_VALUE,10),y=t(Number.MAX_VALUE,4);function t(t,e){for(var n,o,i=Math.floor(Math.log(t)*Math.LOG10E)-1,a=[],r=-i;r<=i;r++){o=parseFloat("1e"+r);for(var s=1;s<9;s+=e)n=o*s,a.push(n)}return a}var i=function(t,e,n){var o=[],i=-1,a=-1,r=t.getCanvas(),s=b,l=w(e,t),c=e.max;n||(n=.3*Math.sqrt("x"===e.direction?r.width:r.height)),b.some(function(t,e){return l<=t&&(i=e,!0)}),b.some(function(t,e){return c<=t&&(a=e,!0)}),-1===a&&(a=b.length-1),a-i<=n/4&&s.length!==y.length&&(s=y,i*=2,a*=2);var u,p,h,f=null,d=1/n;if(n/4<=a-i){for(var m=a;i<=m;m--)u=s[m],p=(Math.log(u)-Math.log(l))/(Math.log(c)-Math.log(l)),h=u,null===f?f={pixelCoord:p,idealPixelCoord:p}:Math.abs(p-f.pixelCoord)>=d?f={pixelCoord:p,idealPixelCoord:f.idealPixelCoord-d}:h=null,h&&o.push(h);o.reverse()}else{var g=t.computeTickSize(l,c,n),x={min:l,max:c,tickSize:g};o=v.plot.linearTickGenerator(x)}return o},w=function(t,e){var n=t.min,o=t.max;return n<=0&&o<(n=null===t.datamin?t.min=.1:h(e,t))&&(t.max=null!==t.datamax?t.datamax:t.options.max,t.options.offset.below=0,t.options.offset.above=0),n},a=function(t,e,n){var o=0<t?Math.floor(Math.log(t)/Math.LN10):0;if(n)return-4<=o&&o<=7?v.plot.defaultTickFormatter(t,e,n):v.plot.expRepTickFormatter(t,e,n);if(-4<=o&&o<=7){var i=o<0?t.toFixed(-o):t.toFixed(o+2);if(-1!==i.indexOf(".")){for(var a=i.lastIndexOf("0");a===i.length-1;)a=(i=i.slice(0,-1)).lastIndexOf("0");i.indexOf(".")===i.length-1&&(i=i.slice(0,-1))}return i}return v.plot.expRepTickFormatter(t,e)},r=function(t){return t<b[0]&&(t=b[0]),Math.log(t)},s=function(t){return Math.exp(t)},l=function(t){return-t},c=function(t){return-r(t)},u=function(t){return s(-t)};function p(t,e){"log"===e.options.mode&&e.datamin<=0&&(null===e.datamin?e.datamin=.1:e.datamin=h(t,e))}function h(e,n){var t=e.getData().filter(function(t){return t.xaxis===n||t.yaxis===n}).map(function(t){return e.computeRangeForDataSeries(t,null,f)}),o="x"===n.direction?Math.min(.1,t&&t[0]?t[0].xmin:.1):Math.min(.1,t&&t[0]?t[0].ymin:.1);return n.min=o}function f(t){return 0<t}v.plot.plugins.push({init:function(t){t.hooks.processOptions.push(function(o){v.each(o.getAxes(),function(t,e){var n=e.options;"log"===n.mode?(e.tickGenerator=function(t){return i(o,t,11)},"function"!=typeof e.options.tickFormatter&&(e.options.tickFormatter=a),e.options.transform=n.inverted?c:r,e.options.inverseTransform=n.inverted?u:s,e.options.autoScaleMargin=0,o.hooks.setRange.push(p)):n.inverted&&(e.options.transform=l,e.options.inverseTransform=l)})})},options:{xaxis:{}},name:"log",version:"0.1"}),v.plot.logTicksGenerator=i,v.plot.logTickFormatter=a}(jQuery),function(t){var e=function(t,e,n,o,i){var a=o*Math.sqrt(Math.PI)/2;t.rect(e-a,n-a,a+a,a+a)},n=function(t,e,n,o,i){var a=o*Math.sqrt(Math.PI)/2;t.rect(e-a,n-a,a+a,a+a)},o=function(t,e,n,o,i){var a=o*Math.sqrt(Math.PI/2);t.moveTo(e-a,n),t.lineTo(e,n-a),t.lineTo(e+a,n),t.lineTo(e,n+a),t.lineTo(e-a,n),t.lineTo(e,n-a)},i=function(t,e,n,o,i){var a=o*Math.sqrt(2*Math.PI/Math.sin(Math.PI/3)),r=a*Math.sin(Math.PI/3);t.moveTo(e-a/2,n+r/2),t.lineTo(e+a/2,n+r/2),i||(t.lineTo(e,n-r/2),t.lineTo(e-a/2,n+r/2),t.lineTo(e+a/2,n+r/2))},a=function(t,e,n,o,i,a){i||(t.moveTo(e+o,n),t.arc(e,n,o,0,2*Math.PI,!1))},r={square:e,rectangle:n,diamond:o,triangle:i,cross:function(t,e,n,o,i){var a=o*Math.sqrt(Math.PI)/2;t.moveTo(e-a,n-a),t.lineTo(e+a,n+a),t.moveTo(e-a,n+a),t.lineTo(e+a,n-a)},ellipse:a,plus:function(t,e,n,o,i){var a=o*Math.sqrt(Math.PI/2);t.moveTo(e-a,n),t.lineTo(e+a,n),t.moveTo(e,n+a),t.lineTo(e,n-a)}};a.fill=i.fill=o.fill=n.fill=e.fill=!0,t.plot.plugins.push({init:function(t){t.drawSymbol=r},name:"symbols",version:"1.0"})}(jQuery),function(t){function e(t,e,n,o){if(!0===e.flatdata){var i=e.start||0,a="number"==typeof e.step?e.step:1;o.pointsize=2;for(var r=0,s=0;r<n.length;r++,s+=2)o.points[s]=i+r*a,o.points[s+1]=n[r];void 0!==o.points?o.points.length=2*n.length:o.points=[]}}jQuery.plot.plugins.push({init:function(t){t.hooks.processRawData.push(e)},name:"flatdata",version:"0.0.2"})}(),function(S){var C=S.plot.saturated,P=S.plot.browser,N=S.plot.uiConstants.SNAPPING_CONSTANT,L=S.plot.uiConstants.PANHINT_LENGTH_CONSTANT;function e(y,t){var s=null,i=!1,a="manual"===t.pan.mode,o="smartLock"===t.pan.mode,r=o||"smart"===t.pan.mode;var l,c="default",w=null,u=null,p={x:0,y:0},h=!1;function f(t,e){var n=Math.abs(t.originalEvent.deltaY)<=1?1+Math.abs(t.originalEvent.deltaY)/50:null;if(h&&v(t),y.getOptions().zoom.active)return t.preventDefault(),function(t,e,n){var o=P.getPageXY(t),i=y.offset();i.left=o.X-i.left,i.top=o.Y-i.top;var a=y.getPlaceholder().offset();a.left=o.X-a.left,a.top=o.Y-a.top;var r=y.getXAxes().concat(y.getYAxes()).filter(function(t){var e=t.box;if(void 0!==e)return a.left>e.left&&a.left<e.left+e.width&&a.top>e.top&&a.top<e.top+e.height});0===r.length&&(r=void 0),e?y.zoomOut({center:i,axes:r,amount:n}):y.zoom({center:i,axes:r,amount:n})}(t,e<0,n),!1}function d(t){i=!0}function m(t){i=!1}function g(t){if(!i||0!==t.button)return!1;h=!0;var e=P.getPageXY(t),n=y.getPlaceholder().offset();n.left=e.X-n.left,n.top=e.Y-n.top,0===(s=y.getXAxes().concat(y.getYAxes()).filter(function(t){var e=t.box;if(void 0!==e)return n.left>e.left&&n.left<e.left+e.width&&n.top>e.top&&n.top<e.top+e.height})).length&&(s=void 0);var o=y.getPlaceholder().css("cursor");o&&(c=o),y.getPlaceholder().css("cursor",y.getOptions().pan.cursor),r?l=y.navigationState(e.X,e.Y):a&&(p.x=e.X,p.y=e.Y)}function x(t){if(h){var e=P.getPageXY(t),n=y.getOptions().pan.frameRate;-1!==n?!u&&n&&(u=setTimeout(function(){r?y.smartPan({x:l.startPageX-e.X,y:l.startPageY-e.Y},l,s,!1,o):a&&(y.pan({left:p.x-e.X,top:p.y-e.Y,axes:s}),p.x=e.X,p.y=e.Y),u=null},1/n*1e3)):r?y.smartPan({x:l.startPageX-e.X,y:l.startPageY-e.Y},l,s,!1,o):a&&(y.pan({left:p.x-e.X,top:p.y-e.Y,axes:s}),p.x=e.X,p.y=e.Y)}}function v(t){if(h){u&&(clearTimeout(u),u=null),h=!1;var e=P.getPageXY(t);y.getPlaceholder().css("cursor",c),r?(y.smartPan({x:l.startPageX-e.X,y:l.startPageY-e.Y},l,s,!1,o),y.smartPan.end()):a&&(y.pan({left:p.x-e.X,top:p.y-e.Y,axes:s}),p.x=0,p.y=0)}}function b(t){if(y.activate(),y.getOptions().recenter.interactive){var e,n=y.getTouchedAxis(t.clientX,t.clientY);y.recenter({axes:n[0]?n:null}),e=n[0]?new S.Event("re-center",{detail:{axisTouched:n[0]}}):new S.Event("re-center",{detail:t}),y.getPlaceholder().trigger(e)}}function T(t){return y.activate(),h&&v(t),!1}y.navigationState=function(t,e){var n=this.getAxes(),o={};return Object.keys(n).forEach(function(t){var e=n[t];o[t]={navigationOffset:{below:e.options.offset.below||0,above:e.options.offset.above||0},axisMin:e.min,axisMax:e.max,diagMode:!1}}),o.startPageX=t||0,o.startPageY=e||0,o},y.activate=function(){var t=y.getOptions();t.pan.active&&t.zoom.active||(t.pan.active=!0,t.zoom.active=!0,y.getPlaceholder().trigger("plotactivated",[y]))},y.zoomOut=function(t){t||(t={}),t.amount||(t.amount=y.getOptions().zoom.amount),t.amount=1/t.amount,y.zoom(t)},y.zoom=function(t){t||(t={});var e=t.center,n=t.amount||y.getOptions().zoom.amount,o=y.width(),i=y.height(),a=t.axes||y.getAxes();e||(e={left:o/2,top:i/2});var r=e.left/o,s=e.top/i,l={x:{min:e.left-r*o/n,max:e.left+(1-r)*o/n},y:{min:e.top-s*i/n,max:e.top+(1-s)*i/n}};for(var c in a)if(a.hasOwnProperty(c)){var u=a[c],p=u.options,h=l[u.direction].min,f=l[u.direction].max,d=u.options.offset;if((p.axisZoom||!t.axes)&&(t.axes||p.plotZoom)){if(h=S.plot.saturated.saturate(u.c2p(h)),(f=S.plot.saturated.saturate(u.c2p(f)))<h){var m=h;h=f,f=m}var g=S.plot.saturated.saturate(d.below-(u.min-h)),x=S.plot.saturated.saturate(d.above-(u.max-f));p.offset={below:g,above:x}}}y.setupGrid(!0),y.draw(),t.preventEvent||y.getPlaceholder().trigger("plotzoom",[y,t])},y.pan=function(r){var s={x:+r.left,y:+r.top};isNaN(s.x)&&(s.x=0),isNaN(s.y)&&(s.y=0),S.each(r.axes||y.getAxes(),function(t,e){var n=e.options,o=s[e.direction];if((n.axisPan||!r.axes)&&(n.plotPan||r.axes)&&0!==o){var i=C.saturate(e.c2p(e.p2c(e.min)+o)-e.c2p(e.p2c(e.min))),a=C.saturate(e.c2p(e.p2c(e.max)+o)-e.c2p(e.p2c(e.max)));isFinite(i)||(i=0),isFinite(a)||(a=0),n.offset={below:C.saturate(i+(n.offset.below||0)),above:C.saturate(a+(n.offset.above||0))}}}),y.setupGrid(!0),y.draw(),r.preventEvent||y.getPlaceholder().trigger("plotpan",[y,r])},y.recenter=function(n){S.each(n.axes||y.getAxes(),function(t,e){n.axes?"x"===this.direction?e.options.offset={below:0}:"y"===this.direction&&(e.options.offset={above:0}):e.options.offset={below:0,above:0}}),y.setupGrid(!0),y.draw()};var k=null,M={x:0,y:0};y.smartPan=function(o,t,i,e,n){var a,r,s,l,c,u,p,h,f,d,m,g,x,v=!!n||(r=o,Math.abs(r.y)<N&&Math.abs(r.x)>=N||Math.abs(r.x)<N&&Math.abs(r.y)>=N),b=y.getAxes();o=n?function(t){switch(!k&&Math.max(Math.abs(t.x),Math.abs(t.y))>=N&&(k=Math.abs(t.x)<Math.abs(t.y)?"y":"x"),k){case"x":return{x:t.x,y:0};case"y":return{x:0,y:t.y};default:return{x:0,y:0}}}(o):(s=o,Math.abs(s.x)<N&&Math.abs(s.y)>=N?{x:0,y:s.y}:Math.abs(s.y)<N&&Math.abs(s.x)>=N?{x:s.x,y:0}:s),l=o,0<Math.abs(l.x)&&0<Math.abs(l.y)&&(t.diagMode=!0),v&&!0===t.diagMode&&(t.diagMode=!1,c=b,u=t,p=o,Object.keys(c).forEach(function(t){h=c[t],0===p[h.direction]&&(h.options.offset.below=u[t].navigationOffset.below,h.options.offset.above=u[t].navigationOffset.above)})),w=v?{start:{x:t.startPageX-y.offset().left+y.getPlotOffset().left,y:t.startPageY-y.offset().top+y.getPlotOffset().top},end:{x:t.startPageX-o.x-y.offset().left+y.getPlotOffset().left,y:t.startPageY-o.y-y.offset().top+y.getPlotOffset().top}}:{start:{x:t.startPageX-y.offset().left+y.getPlotOffset().left,y:t.startPageY-y.offset().top+y.getPlotOffset().top},end:!1},isNaN(o.x)&&(o.x=0),isNaN(o.y)&&(o.y=0),i&&(b=i),Object.keys(b).forEach(function(t){if(f=b[t],d=f.min,m=f.max,a=f.options,x=o[f.direction],g=M[f.direction],(a.axisPan||!i)&&(i||a.plotPan)&&0!==x){var e=C.saturate(f.c2p(f.p2c(d)-(g-x))-f.c2p(f.p2c(d))),n=C.saturate(f.c2p(f.p2c(m)-(g-x))-f.c2p(f.p2c(m)));isFinite(e)||(e=0),isFinite(n)||(n=0),f.options.offset.below=C.saturate(e+(f.options.offset.below||0)),f.options.offset.above=C.saturate(n+(f.options.offset.above||0))}}),M=o,y.setupGrid(!0),y.draw(),e||y.getPlaceholder().trigger("plotpan",[y,o,i,t])},y.smartPan.end=function(){k=w=null,M={x:0,y:0},y.triggerRedrawOverlay()},y.getTouchedAxis=function(t,e){var n=y.getPlaceholder().offset();return n.left=t-n.left,n.top=e-n.top,y.getXAxes().concat(y.getYAxes()).filter(function(t){var e=t.box;if(void 0!==e)return n.left>e.left&&n.left<e.left+e.width&&n.top>e.top&&n.top<e.top+e.height})},y.hooks.drawOverlay.push(function(t,e){if(w){e.strokeStyle="rgba(96, 160, 208, 0.7)",e.lineWidth=2,e.lineJoin="round";var n,o,i=Math.round(w.start.x),a=Math.round(w.start.y);if(s?"x"===s[0].direction?(o=Math.round(w.start.y),n=Math.round(w.end.x)):"y"===s[0].direction&&(n=Math.round(w.start.x),o=Math.round(w.end.y)):(n=Math.round(w.end.x),o=Math.round(w.end.y)),e.beginPath(),!1===w.end)e.moveTo(i,a-L),e.lineTo(i,a+L),e.moveTo(i+L,a),e.lineTo(i-L,a);else{var r=a===o;e.moveTo(i-(r?0:L),a-(r?L:0)),e.lineTo(i+(r?0:L),a+(r?L:0)),e.moveTo(i,a),e.lineTo(n,o),e.moveTo(n-(r?0:L),o-(r?L:0)),e.lineTo(n+(r?0:L),o+(r?L:0))}e.stroke()}}),y.hooks.bindEvents.push(function(t,e){var n=t.getOptions();n.zoom.interactive&&e.mousewheel(f),n.pan.interactive&&(t.addEventHandler("dragstart",g,e,0),t.addEventHandler("drag",x,e,0),t.addEventHandler("dragend",v,e,0),e.bind("mousedown",d),e.bind("mouseup",m)),e.dblclick(b),e.click(T)}),y.hooks.shutdown.push(function(t,e){e.unbind("mousewheel",f),e.unbind("mousedown",d),e.unbind("mouseup",m),e.unbind("dragstart",g),e.unbind("drag",x),e.unbind("dragend",v),e.unbind("dblclick",b),e.unbind("click",T),u&&clearTimeout(u)})}S.plot.plugins.push({init:function(t){t.hooks.processOptions.push(e)},options:{zoom:{interactive:!1,active:!1,amount:1.5},pan:{interactive:!1,active:!1,cursor:"move",frameRate:60,mode:"smart"},recenter:{interactive:!0},xaxis:{axisZoom:!0,plotZoom:!0,axisPan:!0,plotPan:!0},yaxis:{axisZoom:!0,plotZoom:!0,axisPan:!0,plotPan:!0}},name:"navigate",version:"1.3"})}(jQuery),jQuery.plot.plugins.push({init:function(t){t.hooks.processRawData.push(function(n,t,e,o){null!=t.fillBetween&&(format=o.format,format||(format=[],format.push({x:!0,number:!0,computeRange:"none"!==t.xaxis.options.autoScale,required:!0}),format.push({y:!0,number:!0,computeRange:"none"!==t.yaxis.options.autoScale,required:!0}),void 0!==t.fillBetween&&""!==t.fillBetween&&function(t){var e=n.getData();for(i=0;i<e.length;i++)if(e[i].id===t)return!0;return!1}(t.fillBetween)&&t.fillBetween!==t.id&&format.push({x:!1,y:!0,number:!0,required:!1,computeRange:"none"!==t.yaxis.options.autoScale,defaultValue:0}),o.format=format))}),t.hooks.processDatapoints.push(function(t,e,n){if(null!=e.fillBetween){var o=function(t,e){var n;for(n=0;n<e.length;++n)if(e[n].id===t.fillBetween)return e[n];return"number"==typeof t.fillBetween?t.fillBetween<0||t.fillBetween>=e.length?null:e[t.fillBetween]:null}(e,t.getData());if(o){for(var i,a,r,s,l,c,u,p,h=n.pointsize,f=n.points,d=o.datapoints.pointsize,m=o.datapoints.points,g=[],x=e.lines.show,v=2<h&&n.format[2].y,b=x&&e.lines.steps,y=!0,w=0,T=0;!(w>=f.length);){if(u=g.length,null==f[w]){for(p=0;p<h;++p)g.push(f[w+p]);w+=h}else if(T>=m.length){if(!x)for(p=0;p<h;++p)g.push(f[w+p]);w+=h}else if(null==m[T]){for(p=0;p<h;++p)g.push(null);y=!0,T+=d}else{if(i=f[w],a=f[w+1],s=m[T],l=m[T+1],c=0,i===s){for(p=0;p<h;++p)g.push(f[w+p]);c=l,w+=h,T+=d}else if(s<i){if(x&&0<w&&null!=f[w-h]){for(r=a+(f[w-h+1]-a)*(s-i)/(f[w-h]-i),g.push(s),g.push(r),p=2;p<h;++p)g.push(f[w+p]);c=l}T+=d}else{if(y&&x){w+=h;continue}for(p=0;p<h;++p)g.push(f[w+p]);x&&0<T&&null!=m[T-d]&&(c=l+(m[T-d+1]-l)*(i-s)/(m[T-d]-s)),w+=h}y=!1,u!==g.length&&v&&(g[u+2]=c)}if(b&&u!==g.length&&0<u&&null!==g[u]&&g[u]!==g[u-h]&&g[u+1]!==g[u-h+1]){for(p=0;p<h;++p)g[u+h+p]=g[u+p];g[u+1]=g[u-h+1]}}n.points=g}}})},options:{series:{fillBetween:null}},name:"fillbetween",version:"1.0"}),function(s){function e(t,e,n,o){var i="categories"===e.xaxis.options.mode,a="categories"===e.yaxis.options.mode;if(i||a){var r=o.format;if(!r){var s=e;if((r=[]).push({x:!0,number:!0,required:!0,computeRange:!0}),r.push({y:!0,number:!0,required:!0,computeRange:!0}),s.bars.show||s.lines.show&&s.lines.fill){var l=!!(s.bars.show&&s.bars.zero||s.lines.show&&s.lines.zero);r.push({y:!0,number:!0,required:!1,defaultValue:0,computeRange:l}),s.bars.horizontal&&(delete r[r.length-1].y,r[r.length-1].x=!0)}o.format=r}for(var c=0;c<r.length;++c)r[c].x&&i&&(r[c].number=!1),r[c].y&&a&&(r[c].number=!1,r[c].computeRange=!1)}}function l(t){var e=[];for(var n in t.categories){var o=t.categories[n];o>=t.min&&o<=t.max&&e.push([o,n])}return e.sort(function(t,e){return t[0]-e[0]}),e}function o(t,e,n){if("categories"===t[e].options.mode){if(!t[e].categories){var o={},i=t[e].options.categories||{};if(s.isArray(i))for(var a=0;a<i.length;++a)o[i[a]]=a;else for(var r in i)o[r]=i[r];t[e].categories=o}t[e].options.ticks||(t[e].options.ticks=l),function(t,e,n){for(var o=t.points,i=t.pointsize,a=t.format,r=e.charAt(0),s=function(t){var e=-1;for(var n in t)t[n]>e&&(e=t[n]);return e+1}(n),l=0;l<o.length;l+=i)if(null!=o[l])for(var c=0;c<i;++c){var u=o[l+c];null!=u&&a[c][r]&&(u in n||(n[u]=s,++s),o[l+c]=n[u])}}(n,e,t[e].categories)}}function n(t,e,n){o(e,"xaxis",n),o(e,"yaxis",n)}s.plot.plugins.push({init:function(t){t.hooks.processRawData.push(e),t.hooks.processDatapoints.push(n)},options:{xaxis:{categories:null},yaxis:{categories:null}},name:"categories",version:"1.0"})}(jQuery),jQuery.plot.plugins.push({init:function(t){t.hooks.processDatapoints.push(function(t,e,n){if(null!=e.stack&&!1!==e.stack){var o=e.bars.show||e.lines.show&&e.lines.fill,i=2<n.pointsize&&(y?n.format[2].x:n.format[2].y);o&&!i&&function(t,e){for(var n=[],o=0;o<e.points.length;o+=2)n.push(e.points[o]),n.push(e.points[o+1]),n.push(0);e.format.push({x:!1,y:!0,number:!0,required:!1,computeRange:"none"!==t.yaxis.options.autoScale,defaultValue:0}),e.points=n,e.pointsize=3}(e,n);var a=function(t,e){for(var n=null,o=0;o<e.length&&t!==e[o];++o)e[o].stack===t.stack&&(n=e[o]);return n}(e,t.getData());if(a){for(var r,s,l,c,u,p,h,f,d=n.pointsize,m=n.points,g=a.datapoints.pointsize,x=a.datapoints.points,v=[],b=e.lines.show,y=e.bars.horizontal,w=b&&e.lines.steps,T=!0,k=y?1:0,M=y?0:1,S=0,C=0;!(S>=m.length);){if(h=v.length,null==m[S]){for(f=0;f<d;++f)v.push(m[S+f]);S+=d}else if(C>=x.length){if(!b)for(f=0;f<d;++f)v.push(m[S+f]);S+=d}else if(null==x[C]){for(f=0;f<d;++f)v.push(null);T=!0,C+=g}else{if(r=m[S+k],s=m[S+M],c=x[C+k],u=x[C+M],p=0,r===c){for(f=0;f<d;++f)v.push(m[S+f]);v[h+M]+=u,p=u,S+=d,C+=g}else if(c<r){if(b&&0<S&&null!=m[S-d]){for(l=s+(m[S-d+M]-s)*(c-r)/(m[S-d+k]-r),v.push(c),v.push(l+u),f=2;f<d;++f)v.push(m[S+f]);p=u}C+=g}else{if(T&&b){S+=d;continue}for(f=0;f<d;++f)v.push(m[S+f]);b&&0<C&&null!=x[C-g]&&(p=u+(x[C-g+M]-u)*(r-c)/(x[C-g+k]-c)),v[h+M]+=p,S+=d}T=!1,h!==v.length&&o&&(v[h+2]+=p)}if(w&&h!==v.length&&0<h&&null!==v[h]&&v[h]!==v[h-d]&&v[h+1]!==v[h-d+1]){for(f=0;f<d;++f)v[h+d+f]=v[h+f];v[h+1]=v[h-d+1]}}n.points=v}}})},options:{series:{stack:null}},name:"stack",version:"1.2"}),function(c){var m=c.plot.uiConstants.ZOOM_DISTANCE_MARGIN;function e(u,t){var o,i,a,p,h={zoomEnable:!1,prevDistance:null,prevTapTime:0,prevPanPosition:{x:0,y:0},prevTapPosition:{x:0,y:0}},f={prevTouchedAxis:"none",currentTouchedAxis:"none",touchedAxis:null,navigationConstraint:"unconstrained",initialState:null},n=t.pan.interactive&&"manual"===t.pan.touchMode,r="smartLock"===t.pan.touchMode,s=t.pan.interactive&&(r||"smart"===t.pan.touchMode);function d(t,e,n){f.touchedAxis=function(t,e,n,o){{if("pinchstart"!==e.type)return"panstart"===e.type?t.getTouchedAxis(e.detail.touches[0].pageX,e.detail.touches[0].pageY):"pinchend"===e.type?t.getTouchedAxis(e.detail.touches[0].pageX,e.detail.touches[0].pageY):o.touchedAxis;var i=t.getTouchedAxis(e.detail.touches[0].pageX,e.detail.touches[0].pageY),a=t.getTouchedAxis(e.detail.touches[1].pageX,e.detail.touches[1].pageY);if(i.length===a.length&&i.toString()===a.toString())return i}}(u,t,0,f),g(f)?f.navigationConstraint="unconstrained":f.navigationConstraint="axisConstrained"}o={start:function(t){if(d(t,"pan",h),l(t,"pan",h,f),s){var e=y(t,"pan");f.initialState=u.navigationState(e.x,e.y)}},drag:function(t){if(d(t,"pan",h),s){var e=y(t,"pan");u.smartPan({x:f.initialState.startPageX-e.x,y:f.initialState.startPageY-e.y},f.initialState,f.touchedAxis,!1,r)}else n&&(u.pan({left:-b(t,"pan",h).x,top:-b(t,"pan",h).y,axes:f.touchedAxis}),v(t,"pan",h,f))},end:function(t){var e;d(t,"pan",h),s&&u.smartPan.end(),e=t,h.zoomEnable&&1===e.detail.touches.length&&updateprevPanPosition(t,"pan",h,f)}},i={start:function(t){var e;p&&(clearTimeout(p),p=null),d(t,"pinch",h),e=t,h.prevDistance=x(e),l(t,"pinch",h,f)},drag:function(c){p||(p=setTimeout(function(){d(c,"pinch",h),u.pan({left:-b(c,"pinch",h).x,top:-b(c,"pinch",h).y,axes:f.touchedAxis}),v(c,"pinch",h,f);var t,e,n,o,i,a,r,s,l=x(c);(h.zoomEnable||Math.abs(l-h.prevDistance)>m)&&(e=c,n=h,o=f,i=(t=u).offset(),a={left:0,top:0},r=x(e)/n.prevDistance,s=x(e),a.left=y(e,"pinch").x-i.left,a.top=y(e,"pinch").y-i.top,t.zoom({center:a,amount:r,axes:o.touchedAxis}),n.prevDistance=s,h.zoomEnable=!0),p=null},1e3/60))},end:function(t){p&&(clearTimeout(p),p=null),d(t,"pinch",h),h.prevDistance=null}},a={recenterPlot:function(t){t&&t.detail&&"touchstart"===t.detail.type&&function(t,e,n,o){if(a=t,r=e,s=o,l=a.getTouchedAxis(r.detail.firstTouch.x,r.detail.firstTouch.y),void 0!==l[0]&&(s.prevTouchedAxis=l[0].direction),void 0!==(l=a.getTouchedAxis(r.detail.secondTouch.x,r.detail.secondTouch.y))[0]&&(s.touchedAxis=l,s.currentTouchedAxis=l[0].direction),g(s)&&(s.touchedAxis=null,s.prevTouchedAxis="none",s.currentTouchedAxis="none"),"x"===o.currentTouchedAxis&&"x"===o.prevTouchedAxis||"y"===o.currentTouchedAxis&&"y"===o.prevTouchedAxis||"none"===o.currentTouchedAxis&&"none"===o.prevTouchedAxis){var i;t.recenter({axes:o.touchedAxis}),i=o.touchedAxis?new c.Event("re-center",{detail:{axisTouched:o.touchedAxis}}):new c.Event("re-center",{detail:e}),t.getPlaceholder().trigger(i)}var a,r,s,l}(u,t,0,f)}},!0!==t.pan.enableTouch&&!0!==t.zoom.enableTouch||(u.hooks.bindEvents.push(function(t,e){var n=t.getOptions();n.zoom.interactive&&n.zoom.enableTouch&&(e[0].addEventListener("pinchstart",i.start,!1),e[0].addEventListener("pinchdrag",i.drag,!1),e[0].addEventListener("pinchend",i.end,!1)),n.pan.interactive&&n.pan.enableTouch&&(e[0].addEventListener("panstart",o.start,!1),e[0].addEventListener("pandrag",o.drag,!1),e[0].addEventListener("panend",o.end,!1)),n.recenter.interactive&&n.recenter.enableTouch&&e[0].addEventListener("doubletap",a.recenterPlot,!1)}),u.hooks.shutdown.push(function(t,e){e[0].removeEventListener("panstart",o.start),e[0].removeEventListener("pandrag",o.drag),e[0].removeEventListener("panend",o.end),e[0].removeEventListener("pinchstart",i.start),e[0].removeEventListener("pinchdrag",i.drag),e[0].removeEventListener("pinchend",i.end),e[0].removeEventListener("doubletap",a.recenterPlot)}))}function g(t){return!t.touchedAxis||0===t.touchedAxis.length}function l(t,e,n,o){var i,a=y(t,e);switch(o.navigationConstraint){case"unconstrained":o.touchedAxis=null,n.prevTapPosition={x:n.prevPanPosition.x,y:n.prevPanPosition.y},n.prevPanPosition={x:a.x,y:a.y};break;case"axisConstrained":i=o.touchedAxis[0].direction,o.currentTouchedAxis=i,n.prevTapPosition[i]=n.prevPanPosition[i],n.prevPanPosition[i]=a[i]}}function x(t){var e,n,o,i,a=t.detail.touches[0],r=t.detail.touches[1];return e=a.pageX,n=a.pageY,o=r.pageX,i=r.pageY,Math.sqrt((e-o)*(e-o)+(n-i)*(n-i))}function v(t,e,n,o){var i=y(t,e);switch(o.navigationConstraint){case"unconstrained":n.prevPanPosition.x=i.x,n.prevPanPosition.y=i.y;break;case"axisConstrained":n.prevPanPosition[o.currentTouchedAxis]=i[o.currentTouchedAxis]}}function b(t,e,n){var o=y(t,e);return{x:o.x-n.prevPanPosition.x,y:o.y-n.prevPanPosition.y}}function y(t,e){return"pinch"===e?{x:(t.detail.touches[0].pageX+t.detail.touches[1].pageX)/2,y:(t.detail.touches[0].pageY+t.detail.touches[1].pageY)/2}:{x:t.detail.touches[0].pageX,y:t.detail.touches[0].pageY}}c.plot.plugins.push({init:function(t){t.hooks.processOptions.push(e)},options:{zoom:{enableTouch:!1},pan:{enableTouch:!1,touchMode:"manual"},recenter:{enableTouch:!0}},name:"navigateTouch",version:"0.3"})}(jQuery),function(y){var w=y.plot.browser,e="click",T="hover";y.plot.plugins.push({init:function(d){var n,m=[];function o(t){var e=d.getOptions(),n=new CustomEvent("mouseevent");return n.pageX=t.detail.changedTouches[0].pageX,n.pageY=t.detail.changedTouches[0].pageY,n.clientX=t.detail.changedTouches[0].clientX,n.clientY=t.detail.changedTouches[0].clientY,e.grid.hoverable&&i(n,T,30),!1}function i(t,e,n){var o=d.getData();if(void 0!==t&&0<o.length&&void 0!==o[0].xaxis.c2p&&void 0!==o[0].yaxis.c2p){var i=e+"able";c("plot"+e,t,function(t){return!1!==o[t][i]},n)}}function a(t){n=t,i(d.getPlaceholder()[0].lastMouseMoveEvent=t,T)}function r(t){n=void 0,d.getPlaceholder()[0].lastMouseMoveEvent=void 0,c("plothover",t,function(t){return!1})}function s(t){i(t,e)}function l(){d.unhighlight(),d.getPlaceholder().trigger("plothovercleanup")}function c(t,e,n,o){var i=d.getOptions(),a=d.offset(),r=w.getPageXY(e),s=r.X-a.left,l=r.Y-a.top,c=d.c2p({left:s,top:l}),u=void 0!==o?o:i.grid.mouseActiveRadius;c.pageX=r.X,c.pageY=r.Y;var p=d.findNearbyItem(s,l,n,u);if(p&&(p.pageX=parseInt(p.series.xaxis.p2c(p.datapoint[0])+a.left,10),p.pageY=parseInt(p.series.yaxis.p2c(p.datapoint[1])+a.top,10)),i.grid.autoHighlight){for(var h=0;h<m.length;++h){var f=m[h];(f.auto!==t||p&&f.series===p.series&&f.point[0]===p.datapoint[0]&&f.point[1]===p.datapoint[1])&&p||x(f.series,f.point)}p&&g(p.series,p.datapoint,t)}d.getPlaceholder().trigger(t,[c,p])}function g(t,e,n){if("number"==typeof t&&(t=d.getData()[t]),"number"==typeof e){var o=t.datapoints.pointsize;e=t.datapoints.points.slice(o*e,o*(e+1))}var i=u(t,e);-1===i?(m.push({series:t,point:e,auto:n}),d.triggerRedrawOverlay()):n||(m[i].auto=!1)}function x(t,e){if(null==t&&null==e)return m=[],void d.triggerRedrawOverlay();if("number"==typeof t&&(t=d.getData()[t]),"number"==typeof e){var n=t.datapoints.pointsize;e=t.datapoints.points.slice(n*e,n*(e+1))}var o=u(t,e);-1!==o&&(m.splice(o,1),d.triggerRedrawOverlay())}function u(t,e){for(var n=0;n<m.length;++n){var o=m[n];if(o.series===t&&o.point[0]===e[0]&&o.point[1]===e[1])return n}return-1}function p(){l(),i(n,T)}function h(){i(n,T)}function f(t,e,n){var o,i,a=t.getPlotOffset();for(e.save(),e.translate(a.left,a.top),o=0;o<m.length;++o)(i=m[o]).series.bars.show?b(i.series,i.point,e):v(i.series,i.point,e,t);e.restore()}function v(t,e,n,o){var i=e[0],a=e[1],r=t.xaxis,s=t.yaxis,l="string"==typeof t.highlightColor?t.highlightColor:y.color.parse(t.color).scale("a",.5).toString();if(!(i<r.min||i>r.max||a<s.min||a>s.max)){var c=t.points.radius+t.points.lineWidth/2;n.lineWidth=c,n.strokeStyle=l;var u=1.5*c;i=r.p2c(i),a=s.p2c(a),n.beginPath();var p=t.points.symbol;"circle"===p?n.arc(i,a,u,0,2*Math.PI,!1):"string"==typeof p&&o.drawSymbol&&o.drawSymbol[p]&&o.drawSymbol[p](n,i,a,u,!1),n.closePath(),n.stroke()}}function b(t,e,n){var o,i="string"==typeof t.highlightColor?t.highlightColor:y.color.parse(t.color).scale("a",.5).toString(),a=i,r=t.bars.barWidth[0]||t.bars.barWidth;switch(t.bars.align){case"left":o=0;break;case"right":o=-r;break;default:o=-r/2}n.lineWidth=t.bars.lineWidth,n.strokeStyle=i;var s=t.bars.fillTowards||0,l=s>t.yaxis.min?Math.min(t.yaxis.max,s):t.yaxis.min;y.plot.drawSeries.drawBar(e[0],e[1],e[2]||l,o,o+r,function(){return a},t.xaxis,t.yaxis,n,t.bars.horizontal,t.bars.lineWidth)}d.hooks.bindEvents.push(function(t,e){var n=t.getOptions();(n.grid.hoverable||n.grid.clickable)&&(e[0].addEventListener("touchevent",l,!1),e[0].addEventListener("tap",o,!1)),n.grid.clickable&&e.bind("click",s),n.grid.hoverable&&(e.bind("mousemove",a),e.bind("mouseleave",r))}),d.hooks.shutdown.push(function(t,e){e[0].removeEventListener("tap",o),e[0].removeEventListener("touchevent",l),e.unbind("mousemove",a),e.unbind("mouseleave",r),e.unbind("click",s),m=[]}),d.hooks.processOptions.push(function(t,e){t.highlight=g,t.unhighlight=x,(e.grid.hoverable||e.grid.clickable)&&(t.hooks.drawOverlay.push(f),t.hooks.processDatapoints.push(p),t.hooks.setupGrid.push(h)),n=t.getPlaceholder()[0].lastMouseMoveEvent})},options:{grid:{hoverable:!1,clickable:!1}},name:"hover",version:"0.1"})}(jQuery),function(t){function e(n,t){var o,i={twoTouches:!1,currentTapStart:{x:0,y:0},currentTapEnd:{x:0,y:0},prevTap:{x:0,y:0},currentTap:{x:0,y:0},interceptedLongTap:!1,isUnsupportedGesture:!1,prevTapTime:null,tapStartTime:null,longTapTriggerId:null},a=20,r=500;function s(t){var e=n.getOptions();(e.pan.active||e.zoom.active)&&(3<=t.touches.length?i.isUnsupportedGesture=!0:i.isUnsupportedGesture=!1,o.dispatchEvent(new CustomEvent("touchevent",{detail:t})),v(t)?l(t,"pinch"):(l(t,"pan"),x(t)||(function(t){var e=(new Date).getTime(),n=e-i.prevTapTime;if(0<=n&&n<r&&g(i.prevTap.x,i.prevTap.y,i.currentTap.x,i.currentTap.y)<a)return t.firstTouch=i.prevTap,t.secondTouch=i.currentTap,!0;return i.prevTapTime=e,!1}(t)&&l(t,"doubleTap"),l(t,"tap"),l(t,"longTap"))))}function l(t,e){switch(e){case"pan":c[t.type](t);break;case"pinch":u[t.type](t);break;case"doubleTap":p.onDoubleTap(t);break;case"longTap":h[t.type](t);break;case"tap":f[t.type](t)}}var c={touchstart:function(t){var e;i.prevTap={x:i.currentTap.x,y:i.currentTap.y},d(t),e=t,i.tapStartTime=(new Date).getTime(),i.interceptedLongTap=!1,i.currentTapStart={x:e.touches[0].pageX,y:e.touches[0].pageY},i.currentTapEnd={x:e.touches[0].pageX,y:e.touches[0].pageY},o.dispatchEvent(new CustomEvent("panstart",{detail:t}))},touchmove:function(t){var e;m(t),d(t),e=t,i.currentTapEnd={x:e.touches[0].pageX,y:e.touches[0].pageY},i.isUnsupportedGesture||o.dispatchEvent(new CustomEvent("pandrag",{detail:t}))},touchend:function(t){var e;m(t),x(t)?(o.dispatchEvent(new CustomEvent("pinchend",{detail:t})),o.dispatchEvent(new CustomEvent("panstart",{detail:t}))):(e=t).touches&&0===e.touches.length&&o.dispatchEvent(new CustomEvent("panend",{detail:t}))}},u={touchstart:function(t){o.dispatchEvent(new CustomEvent("pinchstart",{detail:t}))},touchmove:function(t){m(t),i.twoTouches=v(t),i.isUnsupportedGesture||o.dispatchEvent(new CustomEvent("pinchdrag",{detail:t}))},touchend:function(t){m(t)}},p={onDoubleTap:function(t){m(t),o.dispatchEvent(new CustomEvent("doubletap",{detail:t}))}},h={touchstart:function(t){h.waitForLongTap(t)},touchmove:function(t){},touchend:function(t){i.longTapTriggerId&&(clearTimeout(i.longTapTriggerId),i.longTapTriggerId=null)},isLongTap:function(t){return 1500<=(new Date).getTime()-i.tapStartTime&&!i.interceptedLongTap&&g(i.currentTapStart.x,i.currentTapStart.y,i.currentTapEnd.x,i.currentTapEnd.y)<20&&(i.interceptedLongTap=!0)},waitForLongTap:function(t){i.longTapTriggerId||(i.longTapTriggerId=setTimeout(function(){h.isLongTap(t)&&o.dispatchEvent(new CustomEvent("longtap",{detail:t})),i.longTapTriggerId=null},1500))}},f={touchstart:function(t){i.tapStartTime=(new Date).getTime()},touchmove:function(t){},touchend:function(t){f.isTap(t)&&(o.dispatchEvent(new CustomEvent("tap",{detail:t})),m(t))},isTap:function(t){return(new Date).getTime()-i.tapStartTime<=125&&g(i.currentTapStart.x,i.currentTapStart.y,i.currentTapEnd.x,i.currentTapEnd.y)<20}};function d(t){i.currentTap={x:t.touches[0].pageX,y:t.touches[0].pageY}}function m(t){i.isUnsupportedGesture||(t.preventDefault(),n.getOptions().propagateSupportedGesture||t.stopPropagation())}function g(t,e,n,o){return Math.sqrt((t-n)*(t-n)+(e-o)*(e-o))}function x(t){return i.twoTouches&&1===t.touches.length}function v(t){return!!(t.touches&&2<=t.touches.length&&t.touches[0].target===n.getEventHolder()&&t.touches[1].target===n.getEventHolder())}(!0===t.pan.enableTouch||t.zoom.enableTouch)&&(n.hooks.bindEvents.push(function(t,e){o=e[0],e[0].addEventListener("touchstart",s,!1),e[0].addEventListener("touchmove",s,!1),e[0].addEventListener("touchend",s,!1)}),n.hooks.shutdown.push(function(t,e){e[0].removeEventListener("touchstart",s),e[0].removeEventListener("touchmove",s),e[0].removeEventListener("touchend",s),i.longTapTriggerId&&(clearTimeout(i.longTapTriggerId),i.longTapTriggerId=null)}))}jQuery.plot.plugins.push({init:function(t){t.hooks.processOptions.push(e)},options:{propagateSupportedGesture:!1},name:"navigateTouch",version:"0.3"})}(),function(e){var y=e.plot.saturated.floorInBase,i=function(t,e){var n=new t(e),o=n.setTime.bind(n);n.update=function(t){o(t);var e=(t=Math.round(1e3*t)/1e3)/1e3;this.microseconds=1e6*(e-Math.floor(e))};var i=n.getTime.bind(n);return n.getTime=function(){return i()+this.microseconds/1e3},n.setTime=function(t){this.update(t)},n.getMicroseconds=function(){return this.microseconds},n.setMicroseconds=function(t){var e=i()+t/1e3;this.update(e)},n.setUTCMicroseconds=function(t){this.setMicroseconds(t)},n.getUTCMicroseconds=function(){return this.getMicroseconds()},n.microseconds=null,n.microEpoch=null,n.update(e),n};function f(t,e,n,o){if("function"==typeof t.strftime)return t.strftime(e);var i,a=function(t,e){return e=""+(null==e?"0":e),1==(t=""+t).length?e+t:t},r=function(t,e){if(e<6&&0<e){var n=parseFloat("1e"+(e-6));t=("00000"+(t=Math.round(Math.round(t*n)/n))).slice(-6,-(6-e))}else t=("00000"+(t=Math.round(t))).slice(-6);return t},s=[],l=!1,c=t.getHours(),u=c<12;n||(n=["Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec"]),o||(o=["Sun","Mon","Tue","Wed","Thu","Fri","Sat"]),i=12<c?c-12:0==c?12:c;for(var p=-1,h=0;h<e.length;++h){var f=e.charAt(h);if(!isNaN(Number(f))&&0<Number(f))p=Number(f);else if(l){switch(f){case"a":f=""+o[t.getDay()];break;case"b":f=""+n[t.getMonth()];break;case"d":f=a(t.getDate());break;case"e":f=a(t.getDate()," ");break;case"h":case"H":f=a(c);break;case"I":f=a(i);break;case"l":f=a(i," ");break;case"m":f=a(t.getMonth()+1);break;case"M":f=a(t.getMinutes());break;case"q":f=""+(Math.floor(t.getMonth()/3)+1);break;case"S":f=a(t.getSeconds());break;case"s":f=""+r(t.getMicroseconds(),p);break;case"y":f=a(t.getFullYear()%100);break;case"Y":f=""+t.getFullYear();break;case"p":f=u?"am":"pm";break;case"P":f=u?"AM":"PM";break;case"w":f=""+t.getDay()}s.push(f),l=!1}else"%"==f?l=!0:s.push(f)}return s.join("")}function a(t){function e(t,e,n,o){t[e]=function(){return n[o].apply(n,arguments)}}var n={date:t};void 0!==t.strftime&&e(n,"strftime",t,"strftime"),e(n,"getTime",t,"getTime"),e(n,"setTime",t,"setTime");for(var o=["Date","Day","FullYear","Hours","Minutes","Month","Seconds","Milliseconds","Microseconds"],i=0;i<o.length;i++)e(n,"get"+o[i],t,"getUTC"+o[i]),e(n,"set"+o[i],t,"setUTC"+o[i]);return n}function w(t,e){var n=864e13;if(e&&"seconds"===e.timeBase?t*=1e3:"microseconds"===e.timeBase&&(t/=1e3),n<t?t=n:t<-n&&(t=-n),"browser"===e.timezone)return i(Date,t);if(e.timezone&&"utc"!==e.timezone){if("undefined"==typeof timezoneJS||void 0===timezoneJS.Date)return a(i(Date,t));var o=i(timezoneJS.Date,t);return o.setTimezone(e.timezone),o.setTime(t),o}return a(i(Date,t))}var T={microsecond:1e-6,millisecond:.001,second:1,minute:60,hour:3600,day:86400,month:2592e3,quarter:7776e3,year:525949.2*60},k={microsecond:.001,millisecond:1,second:1e3,minute:6e4,hour:36e5,day:864e5,month:2592e6,quarter:7776e6,year:525949.2*60*1e3},M={microsecond:1,millisecond:1e3,second:1e6,minute:6e7,hour:36e8,day:864e8,month:2592e9,quarter:7776e9,year:525949.2*60*1e6},t=[[1,"microsecond"],[2,"microsecond"],[5,"microsecond"],[10,"microsecond"],[25,"microsecond"],[50,"microsecond"],[100,"microsecond"],[250,"microsecond"],[500,"microsecond"],[1,"millisecond"],[2,"millisecond"],[5,"millisecond"],[10,"millisecond"],[25,"millisecond"],[50,"millisecond"],[100,"millisecond"],[250,"millisecond"],[500,"millisecond"],[1,"second"],[2,"second"],[5,"second"],[10,"second"],[30,"second"],[1,"minute"],[2,"minute"],[5,"minute"],[10,"minute"],[30,"minute"],[1,"hour"],[2,"hour"],[4,"hour"],[8,"hour"],[12,"hour"],[1,"day"],[2,"day"],[3,"day"],[.25,"month"],[.5,"month"],[1,"month"],[2,"month"]],S=t.concat([[3,"month"],[6,"month"],[1,"year"]]),C=t.concat([[1,"quarter"],[2,"quarter"],[1,"year"]]);function n(t){var e,n=t.options,o=[],i=w(t.min,n),a=0,r=n.tickSize&&"quarter"===n.tickSize[1]||n.minTickSize&&"quarter"===n.minTickSize[1]?C:S;e="seconds"===n.timeBase?T:"microseconds"===n.timeBase?M:k,null!==n.minTickSize&&void 0!==n.minTickSize&&(a="number"==typeof n.tickSize?n.tickSize:n.minTickSize[0]*e[n.minTickSize[1]]);for(var s=0;s<r.length-1&&!(t.delta<(r[s][0]*e[r[s][1]]+r[s+1][0]*e[r[s+1][1]])/2&&r[s][0]*e[r[s][1]]>=a);++s);var l=r[s][0],c=r[s][1];if("year"===c){if(null!==n.minTickSize&&void 0!==n.minTickSize&&"year"===n.minTickSize[1])l=Math.floor(n.minTickSize[0]);else{var u=parseFloat("1e"+Math.floor(Math.log(t.delta/e.year)/Math.LN10)),p=t.delta/e.year/u;l=p<1.5?1:p<3?2:p<7.5?5:10,l*=u}l<1&&(l=1)}t.tickSize=n.tickSize||[l,c];var h=t.tickSize[0],f=h*e[c=t.tickSize[1]];"microsecond"===c?i.setMicroseconds(y(i.getMicroseconds(),h)):"millisecond"===c?i.setMilliseconds(y(i.getMilliseconds(),h)):"second"===c?i.setSeconds(y(i.getSeconds(),h)):"minute"===c?i.setMinutes(y(i.getMinutes(),h)):"hour"===c?i.setHours(y(i.getHours(),h)):"month"===c?i.setMonth(y(i.getMonth(),h)):"quarter"===c?i.setMonth(3*y(i.getMonth()/3,h)):"year"===c&&i.setFullYear(y(i.getFullYear(),h)),f>=e.millisecond&&(f>=e.second?i.setMicroseconds(0):i.setMicroseconds(1e3*i.getMilliseconds())),f>=e.minute&&i.setSeconds(0),f>=e.hour&&i.setMinutes(0),f>=e.day&&i.setHours(0),f>=4*e.day&&i.setDate(1),f>=2*e.month&&i.setMonth(y(i.getMonth(),3)),f>=2*e.quarter&&i.setMonth(y(i.getMonth(),6)),f>=e.year&&i.setMonth(0);var d,m,g=0,x=Number.NaN;do{if(m=x,d=i.getTime(),x=n&&"seconds"===n.timeBase?d/1e3:n&&"microseconds"===n.timeBase?1e3*d:d,o.push(x),"month"===c||"quarter"===c)if(h<1){i.setDate(1);var v=i.getTime();i.setMonth(i.getMonth()+("quarter"===c?3:1));var b=i.getTime();i.setTime(x+g*e.hour+(b-v)*h),g=i.getHours(),i.setHours(0)}else i.setMonth(i.getMonth()+h*("quarter"===c?3:1));else"year"===c?i.setFullYear(i.getFullYear()+h):"seconds"===n.timeBase?i.setTime(1e3*(x+f)):"microseconds"===n.timeBase?i.setTime((x+f)/1e3):i.setTime(x+f)}while(x<t.max&&x!==m);return o}e.plot.plugins.push({init:function(t){t.hooks.processOptions.push(function(t){e.each(t.getAxes(),function(t,e){var h=e.options;"time"===h.mode&&(e.tickGenerator=n,e.tickFormatter=function(t,e){var n=w(t,e.options);if(null!=h.timeformat)return f(n,h.timeformat,h.monthNames,h.dayNames);var o,i=e.options.tickSize&&"quarter"==e.options.tickSize[1]||e.options.minTickSize&&"quarter"==e.options.minTickSize[1];o="seconds"===h.timeBase?T:"microseconds"===h.timeBase?M:k;var a,r,s=e.tickSize[0]*o[e.tickSize[1]],l=e.max-e.min,c=h.twelveHourClock?" %p":"",u=h.twelveHourClock?"%I":"%H";if(a="seconds"===h.timeBase?1:"microseconds"===h.timeBase?1e6:1e3,s<o.second){var p=-Math.floor(Math.log10(s/a));-1<String(s).indexOf("25")&&p++,r="%S.%"+p+"s"}else r=s<o.minute?u+":%M:%S"+c:s<o.day?l<2*o.day?u+":%M"+c:"%b %d "+u+":%M"+c:s<o.month?"%b %d":i&&s<o.quarter||!i&&s<o.year?l<o.year?"%b":"%b %Y":i&&s<o.year?l<o.year?"Q%q":"Q%q %Y":"%Y";return f(n,r,h.monthNames,h.dayNames)})})})},options:{xaxis:{timezone:null,timeformat:null,twelveHourClock:!1,monthNames:null,timeBase:"seconds"},yaxis:{timeBase:"seconds"}},name:"time",version:"1.0"}),e.plot.formatDate=f,e.plot.dateGenerator=w,e.plot.dateTickGenerator=n,e.plot.makeUtcWrapper=a}(jQuery),function(n){function s(t,e,n,o,i,a){this.axisName=t,this.position=e,this.padding=n,this.placeholder=o,this.axisLabel=i,this.surface=a,this.width=0,this.height=0,this.elem=null}s.prototype.calculateSize=function(){var t=this.axisName+"Label",e=t+"Layer",n=t+" axisLabels",o=this.surface.getTextInfo(e,this.axisLabel,n);this.labelWidth=o.width,this.labelHeight=o.height,"left"===this.position||"right"===this.position?(this.width=this.labelHeight+this.padding,this.height=0):(this.width=0,this.height=this.labelHeight+this.padding)},s.prototype.transforms=function(t,e,n,o){var i,a,r=[];if(0===e&&0===n||((i=o.createSVGTransform()).setTranslate(e,n),r.push(i)),0!==t){a=o.createSVGTransform();var s=Math.round(this.labelWidth/2);a.setRotate(t,s,0),r.push(a)}return r},s.prototype.calculateOffsets=function(t){var e={x:0,y:0,degrees:0};return"bottom"===this.position?(e.x=t.left+t.width/2-this.labelWidth/2,e.y=t.top+t.height-this.labelHeight):"top"===this.position?(e.x=t.left+t.width/2-this.labelWidth/2,e.y=t.top):"left"===this.position?(e.degrees=-90,e.x=t.left-this.labelWidth/2,e.y=t.height/2+t.top):"right"===this.position&&(e.degrees=90,e.x=t.left+t.width-this.labelWidth/2,e.y=t.height/2+t.top),e.x=Math.round(e.x),e.y=Math.round(e.y),e},s.prototype.cleanup=function(){var t=this.axisName+"Label",e=t+"Layer",n=t+" axisLabels";this.surface.removeText(e,0,0,this.axisLabel,n)},s.prototype.draw=function(t){var e=this.axisName+"Label",n=e+"Layer",o=e+" axisLabels",i=this.calculateOffsets(t),a={position:"absolute",bottom:"",right:"",display:"inline-block","white-space":"nowrap"},r=this.surface.getSVGLayer(n),s=this.transforms(i.degrees,i.x,i.y,r.parentNode);this.surface.addText(n,0,0,this.axisLabel,o,void 0,void 0,void 0,void 0,s),this.surface.render(),Object.keys(a).forEach(function(t){r.style[t]=a[t]})},n.plot.plugins.push({init:function(t){t.hooks.processOptions.push(function(t,e){if(e.axisLabels.show){var r={};t.hooks.axisReserveSpace.push(function(t,e){var n=e.options,o=e.direction+e.n;if(e.labelHeight+=e.boxPosition.centerY,e.labelWidth+=e.boxPosition.centerX,n&&n.axisLabel&&e.show){var i=void 0===n.axisLabelPadding?2:n.axisLabelPadding,a=r[o];a||(a=new s(o,n.position,i,t.getPlaceholder()[0],n.axisLabel,t.getSurface()),r[o]=a),a.calculateSize(),e.labelHeight+=a.height,e.labelWidth+=a.width}}),t.hooks.draw.push(function(t,e){n.each(t.getAxes(),function(t,e){var n=e.options;if(n&&n.axisLabel&&e.show){var o=e.direction+e.n;r[o].draw(e.box)}})}),t.hooks.shutdown.push(function(t,e){for(var n in r)r[n].cleanup()})}})},options:{axisLabels:{show:!0}},name:"axisLabels",version:"3.0"})}(jQuery),function(S){S.plot.plugins.push({init:function(c){var T={first:{x:-1,y:-1},second:{x:-1,y:-1},show:!1,currentMode:"xy",active:!1},i=S.plot.uiConstants.SNAPPING_CONSTANT,n={},o=null;function a(t){T.active&&(p(t),c.getPlaceholder().trigger("plotselecting",[e()]))}function r(t){var e=c.getOptions();1===t.which&&null!==e.selection.mode&&(T.currentMode="xy",document.body.focus(),void 0!==document.onselectstart&&null==n.onselectstart&&(n.onselectstart=document.onselectstart,document.onselectstart=function(){return!1}),void 0!==document.ondrag&&null==n.ondrag&&(n.ondrag=document.ondrag,document.ondrag=function(){return!1}),u(T.first,t),T.active=!0,o=function(t){var e;e=t,o=null,void 0!==document.onselectstart&&(document.onselectstart=n.onselectstart),void 0!==document.ondrag&&(document.ondrag=n.ondrag),T.active=!1,p(e),M()?s():(c.getPlaceholder().trigger("plotunselected",[]),c.getPlaceholder().trigger("plotselecting",[null]))},S(document).one("mouseup",o))}function e(){if(!M())return null;if(!T.show)return null;var i={},a={x:T.first.x,y:T.first.y},r={x:T.second.x,y:T.second.y};return"x"===k(c)&&(a.y=0,r.y=c.height()),"y"===k(c)&&(a.x=0,r.x=c.width()),S.each(c.getAxes(),function(t,e){if(e.used){var n=e.c2p(a[e.direction]),o=e.c2p(r[e.direction]);i[t]={from:Math.min(n,o),to:Math.max(n,o)}}}),i}function s(){var t=e();c.getPlaceholder().trigger("plotselected",[t]),t.xaxis&&t.yaxis&&c.getPlaceholder().trigger("selected",[{x1:t.xaxis.from,y1:t.yaxis.from,x2:t.xaxis.to,y2:t.yaxis.to}])}function l(t,e,n){return e<t?t:n<e?n:e}function k(t){var e=t.getOptions();return"smart"===e.selection.mode?T.currentMode:e.selection.mode}function u(t,e){var n=c.getPlaceholder().offset(),o=c.getPlotOffset();t.x=l(0,e.pageX-n.left-o.left,c.width()),t.y=l(0,e.pageY-n.top-o.top,c.height()),t!==T.first&&function(t){if(T.first){var e={x:t.x-T.first.x,y:t.y-T.first.y};Math.abs(e.x)<i?T.currentMode="y":Math.abs(e.y)<i?T.currentMode="x":T.currentMode="xy"}}(t),"y"===k(c)&&(t.x=t===T.first?0:c.width()),"x"===k(c)&&(t.y=t===T.first?0:c.height())}function p(t){null!=t.pageX&&(u(T.second,t),M()?(T.show=!0,c.triggerRedrawOverlay()):h(!0))}function h(t){T.show&&(T.show=!1,T.currentMode="",c.triggerRedrawOverlay(),t||c.getPlaceholder().trigger("plotunselected",[]))}function f(t,e){var n,o,i,a,r=c.getAxes();for(var s in r)if((n=r[s]).direction===e&&(t[a=e+n.n+"axis"]||1!==n.n||(a=e+"axis"),t[a])){o=t[a].from,i=t[a].to;break}if(t[a]||(n="x"===e?c.getXAxes()[0]:c.getYAxes()[0],o=t[e+"1"],i=t[e+"2"]),null!=o&&null!=i&&i<o){var l=o;o=i,i=l}return{from:o,to:i,axis:n}}function M(){var t=c.getOptions().selection.minSize;return Math.abs(T.second.x-T.first.x)>=t&&Math.abs(T.second.y-T.first.y)>=t}c.clearSelection=h,c.setSelection=function(t,e){var n;"y"===k(c)?(T.first.x=0,T.second.x=c.width()):(n=f(t,"x"),T.first.x=n.axis.p2c(n.from),T.second.x=n.axis.p2c(n.to)),"x"===k(c)?(T.first.y=0,T.second.y=c.height()):(n=f(t,"y"),T.first.y=n.axis.p2c(n.from),T.second.y=n.axis.p2c(n.to)),T.show=!0,c.triggerRedrawOverlay(),!e&&M()&&s()},c.getSelection=e,c.hooks.bindEvents.push(function(t,e){null!=t.getOptions().selection.mode&&(e.mousemove(a),e.mousedown(r))}),c.hooks.drawOverlay.push(function(t,e){if(T.show&&M()){var n=t.getPlotOffset(),o=t.getOptions();e.save(),e.translate(n.left,n.top);var i=S.color.parse(o.selection.color),a=o.selection.visualization,r=1;"fill"===a&&(r=.8),e.strokeStyle=i.scale("a",r).toString(),e.lineWidth=1,e.lineJoin=o.selection.shape,e.fillStyle=i.scale("a",.4).toString();var s=Math.min(T.first.x,T.second.x)+.5,l=s,c=Math.min(T.first.y,T.second.y)+.5,u=c,p=Math.abs(T.second.x-T.first.x)-1,h=Math.abs(T.second.y-T.first.y)-1;"x"===k(t)&&(h+=c,c=0),"y"===k(t)&&(p+=s,s=0),"fill"===a?(e.fillRect(s,c,p,h),e.strokeRect(s,c,p,h)):(e.fillRect(0,0,t.width(),t.height()),e.clearRect(s,c,p,h),f=e,d=s,m=c,g=p,x=h,v=l,b=u,y=k(t),w=Math.max(0,Math.min(15,g/2-2,x/2-2)),f.fillStyle="#ffffff","xy"===y&&(f.beginPath(),f.moveTo(d,m+w),f.lineTo(d-3,m+w),f.lineTo(d-3,m-3),f.lineTo(d+w,m-3),f.lineTo(d+w,m),f.lineTo(d,m),f.closePath(),f.moveTo(d,m+x-w),f.lineTo(d-3,m+x-w),f.lineTo(d-3,m+x+3),f.lineTo(d+w,m+x+3),f.lineTo(d+w,m+x),f.lineTo(d,m+x),f.closePath(),f.moveTo(d+g,m+w),f.lineTo(d+g+3,m+w),f.lineTo(d+g+3,m-3),f.lineTo(d+g-w,m-3),f.lineTo(d+g-w,m),f.lineTo(d+g,m),f.closePath(),f.moveTo(d+g,m+x-w),f.lineTo(d+g+3,m+x-w),f.lineTo(d+g+3,m+x+3),f.lineTo(d+g-w,m+x+3),f.lineTo(d+g-w,m+x),f.lineTo(d+g,m+x),f.closePath(),f.stroke(),f.fill()),d=v,m=b,"x"===y&&(f.beginPath(),f.moveTo(d,m+15),f.lineTo(d,m-15),f.lineTo(d-3,m-15),f.lineTo(d-3,m+15),f.closePath(),f.moveTo(d+g,m+15),f.lineTo(d+g,m-15),f.lineTo(d+g+3,m-15),f.lineTo(d+g+3,m+15),f.closePath(),f.stroke(),f.fill()),"y"===y&&(f.beginPath(),f.moveTo(d-15,m),f.lineTo(d+15,m),f.lineTo(d+15,m-3),f.lineTo(d-15,m-3),f.closePath(),f.moveTo(d-15,m+x),f.lineTo(d+15,m+x),f.lineTo(d+15,m+x+3),f.lineTo(d-15,m+x+3),f.closePath(),f.stroke(),f.fill())),e.restore()}var f,d,m,g,x,v,b,y,w}),c.hooks.shutdown.push(function(t,e){e.unbind("mousemove",a),e.unbind("mousedown",r),o&&S(document).unbind("mouseup",o)})},options:{selection:{mode:null,visualization:"focus",color:"#888888",shape:"round",minSize:5}},name:"selection",version:"1.1"})}(jQuery),function(t){var e=-100,c=0,u=-1,p=-2,h=1,g=t.plot.browser,a=g.getPixelRatio;function n(t,e){var n=t.filter(r);h=a(e.getContext("2d"));var o,i=n.map(function(t){var d,m,e=new Image;return new Promise((m=t,(d=e).sourceDescription='<info className="'+m.className+'" tagName="'+m.tagName+'" id="'+m.id+'">',d.sourceComponent=m,function(e,t){var n,o,i,a,r,s,l,c,u,p,h,f;d.onload=function(t){d.successfullyLoaded=!0,e(d)},d.onabort=function(t){d.successfullyLoaded=!1,console.log("Can't generate temp image from "+d.sourceDescription+". It is possible that it is missing some properties or its content is not supported by this browser. Source component:",d.sourceComponent),e(d)},d.onerror=function(t){d.successfullyLoaded=!1,console.log("Can't generate temp image from "+d.sourceDescription+". It is possible that it is missing some properties or its content is not supported by this browser. Source component:",d.sourceComponent),e(d)},o=d,"CANVAS"===(n=m).tagName&&(i=n,o.src=i.toDataURL("image/png")),"svg"===n.tagName&&(a=n,r=o,g.isSafari()||g.isMobileSafari()?(s=a,l=r,p=b(p=v(x(document),s)),u=function(t){for(var e="",n=new Uint8Array(t),o=0;o<n.length;o+=16384){var i=String.fromCharCode.apply(null,n.subarray(o,o+16384));e+=i}return e}(new(TextEncoder||TextEncoderLite)("utf-8").encode(p)),c="data:image/svg+xml;base64,"+btoa(u),l.src=c):function(t,e){var n=v(x(document),t);n=b(n);var o=new Blob([n],{type:"image/svg+xml;charset=utf-8"}),i=(self.URL||self.webkitURL||self).createObjectURL(o);e.src=i}(a,r)),o.srcImgTagName=n.tagName,h=n,(f=o).genLeft=h.getBoundingClientRect().left,f.genTop=h.getBoundingClientRect().top,"CANVAS"===h.tagName&&(f.genRight=f.genLeft+h.width,f.genBottom=f.genTop+h.height),"svg"===h.tagName&&(f.genRight=h.getBoundingClientRect().right,f.genBottom=h.getBoundingClientRect().bottom)}))});return Promise.all(i).then((o=e,function(t){var e=function(t,e){var n=function(t,e){var n,o=c;if(0===t.length)o=u;else{var i=t[0].genLeft,a=t[0].genTop,r=t[0].genRight,s=t[0].genBottom,l=0;for(l=1;l<t.length;l++)i>t[l].genLeft&&(i=t[l].genLeft),a>t[l].genTop&&(a=t[l].genTop);for(l=1;l<t.length;l++)r<t[l].genRight&&(r=t[l].genRight),s<t[l].genBottom&&(s=t[l].genBottom);if(r-i<=0||s-a<=0)o=p;else{for(e.width=Math.round(r-i),e.height=Math.round(s-a),l=0;l<t.length;l++)t[l].xCompOffset=t[l].genLeft-i,t[l].yCompOffset=t[l].genTop-a;n=e,void 0!==t.find(function(t){return"svg"===t.srcImgTagName})&&h<1&&(n.width=n.width*h,n.height=n.height*h)}}return o}(t,e);if(n===c)for(var o=e.getContext("2d"),i=0;i<t.length;i++)!0===t[i].successfullyLoaded&&o.drawImage(t[i],t[i].xCompOffset*h,t[i].yCompOffset*h);return n}(t,o);return e}),s)}function r(t){var e=!0,n=!0;return null==t?n=!1:"CANVAS"===t.tagName&&(t.getBoundingClientRect().right!==t.getBoundingClientRect().left&&t.getBoundingClientRect().bottom!==t.getBoundingClientRect().top||(e=!1)),n&&e&&"visible"===window.getComputedStyle(t).visibility}function x(t){for(var e=t.styleSheets,n=[],o=0;o<e.length;o++)try{for(var i=e[o].cssRules||[],a=0;a<i.length;a++){var r=i[a];n.push(r.cssText)}}catch(t){console.log("Failed to get some css rules")}return n}function v(t,e){return['<svg class="snapshot '+e.classList+'" width="'+e.width.baseVal.value*h+'" height="'+e.height.baseVal.value*h+'" viewBox="0 0 '+e.width.baseVal.value+" "+e.height.baseVal.value+'" xmlns="http://www.w3.org/2000/svg">',"<style>","/* <![CDATA[ */",t.join("\n"),"/* ]]> */","</style>",e.innerHTML,"</svg>"].join("\n")}function b(t){var e="";return t.match(/^<svg[^>]+xmlns="http:\/\/www\.w3\.org\/2000\/svg"/)||(e=t.replace(/^<svg/,'<svg xmlns="http://www.w3.org/2000/svg"')),t.match(/^<svg[^>]+"http:\/\/www\.w3\.org\/1999\/xlink"/)||(e=t.replace(/^<svg/,'<svg xmlns:xlink="http://www.w3.org/1999/xlink"')),'<?xml version="1.0" standalone="no"?>\r\n'+e}function s(){return e}t.plot.composeImages=n,t.plot.plugins.push({init:function(t){t.composeImages=n},name:"composeImages",version:"1.0"})}(jQuery),function(M){function S(t){var e="",n=t.name,o=t.xPos,i=t.yPos,a=t.fillColor,r=t.strokeColor,s=t.strokeWidth;switch(n){case"circle":e='<use xlink:href="#circle" class="legendIcon" x="'+o+'" y="'+i+'" fill="'+a+'" stroke="'+r+'" stroke-width="'+s+'" width="1.5em" height="1.5em"/>';break;case"diamond":e='<use xlink:href="#diamond" class="legendIcon" x="'+o+'" y="'+i+'" fill="'+a+'" stroke="'+r+'" stroke-width="'+s+'" width="1.5em" height="1.5em"/>';break;case"cross":e='<use xlink:href="#cross" class="legendIcon" x="'+o+'" y="'+i+'" stroke="'+r+'" stroke-width="'+s+'" width="1.5em" height="1.5em"/>';break;case"rectangle":e='<use xlink:href="#rectangle" class="legendIcon" x="'+o+'" y="'+i+'" fill="'+a+'" stroke="'+r+'" stroke-width="'+s+'" width="1.5em" height="1.5em"/>';break;case"plus":e='<use xlink:href="#plus" class="legendIcon" x="'+o+'" y="'+i+'" stroke="'+r+'" stroke-width="'+s+'" width="1.5em" height="1.5em"/>';break;case"bar":e='<use xlink:href="#bars" class="legendIcon" x="'+o+'" y="'+i+'" fill="'+a+'" width="1.5em" height="1.5em"/>';break;case"area":e='<use xlink:href="#area" class="legendIcon" x="'+o+'" y="'+i+'" fill="'+a+'" width="1.5em" height="1.5em"/>';break;case"line":e='<use xlink:href="#line" class="legendIcon" x="'+o+'" y="'+i+'" stroke="'+r+'" stroke-width="'+s+'" width="1.5em" height="1.5em"/>';break;default:e='<use xlink:href="#circle" class="legendIcon" x="'+o+'" y="'+i+'" fill="'+a+'" stroke="'+r+'" stroke-width="'+s+'" width="1.5em" height="1.5em"/>'}return e}var C='<defs><symbol id="line" fill="none" viewBox="-5 -5 25 25"><polyline points="0,15 5,5 10,10 15,0"/></symbol><symbol id="area" stroke-width="1" viewBox="-5 -5 25 25"><polyline points="0,15 5,5 10,10 15,0, 15,15, 0,15"/></symbol><symbol id="bars" stroke-width="1" viewBox="-5 -5 25 25"><polyline points="1.5,15.5 1.5,12.5, 4.5,12.5 4.5,15.5 6.5,15.5 6.5,3.5, 9.5,3.5 9.5,15.5 11.5,15.5 11.5,7.5 14.5,7.5 14.5,15.5 1.5,15.5"/></symbol><symbol id="circle" viewBox="-5 -5 25 25"><circle cx="0" cy="15" r="2.5"/><circle cx="5" cy="5" r="2.5"/><circle cx="10" cy="10" r="2.5"/><circle cx="15" cy="0" r="2.5"/></symbol><symbol id="rectangle" viewBox="-5 -5 25 25"><rect x="-2.1" y="12.9" width="4.2" height="4.2"/><rect x="2.9" y="2.9" width="4.2" height="4.2"/><rect x="7.9" y="7.9" width="4.2" height="4.2"/><rect x="12.9" y="-2.1" width="4.2" height="4.2"/></symbol><symbol id="diamond" viewBox="-5 -5 25 25"><path d="M-3,15 L0,12 L3,15, L0,18 Z"/><path d="M2,5 L5,2 L8,5, L5,8 Z"/><path d="M7,10 L10,7 L13,10, L10,13 Z"/><path d="M12,0 L15,-3 L18,0, L15,3 Z"/></symbol><symbol id="cross" fill="none" viewBox="-5 -5 25 25"><path d="M-2.1,12.9 L2.1,17.1, M2.1,12.9 L-2.1,17.1 Z"/><path d="M2.9,2.9 L7.1,7.1 M7.1,2.9 L2.9,7.1 Z"/><path d="M7.9,7.9 L12.1,12.1 M12.1,7.9 L7.9,12.1 Z"/><path d="M12.9,-2.1 L17.1,2.1 M17.1,-2.1 L12.9,2.1 Z"/></symbol><symbol id="plus" fill="none" viewBox="-5 -5 25 25"><path d="M0,12 L0,18, M-3,15 L3,15 Z"/><path d="M5,2 L5,8 M2,5 L8,5 Z"/><path d="M10,7 L10,13 M7,10 L13,10 Z"/><path d="M15,-3 L15,3 M12,0 L18,0 Z"/></symbol></defs>';function l(t,e){for(var n in t)if(t.hasOwnProperty(n)&&t[n]!==e[n])return!0;return!1}M.plot.plugins.push({init:function(t){t.hooks.setupGrid.push(function(t){var e=t.getOptions(),n=t.getData(),o=e.legend.labelFormatter,i=e.legend.legendEntries,a=e.legend.plotOffset,r=function(t,e,n){var a=e,o=t.reduce(function(t,e,n){var o=a?a(e.label,e):e.label;if(!e.hasOwnProperty("label")||o){var i={label:o||"Plot "+(n+1),color:e.color,options:{lines:e.lines,points:e.points,bars:e.bars}};t.push(i)}return t},[]);if(n)if(M.isFunction(n))o.sort(n);else if("reverse"===n)o.reverse();else{var i="descending"!==n;o.sort(function(t,e){return t.label===e.label?0:t.label<e.label!==i?1:-1})}return o}(n,o,e.legend.sorted),s=t.getPlotOffset();(function(t,e){if(!t||!e)return!0;if(t.length!==e.length)return!0;var n,o,i;for(n=0;n<e.length;n++){if(o=e[n],i=t[n],o.label!==i.label)return!0;if(o.color!==i.color)return!0;if(l(o.options.lines,i.options.lines))return!0;if(l(o.options.points,i.options.points))return!0;if(l(o.options.bars,i.options.bars))return!0}return!1}(i,r)||l(a,s))&&function(t,e,n,o){if(null!=e.legend.container?M(e.legend.container).html(""):n.find(".legend").remove(),e.legend.show){var i,a,r,s,l=e.legend.legendEntries=o,c=e.legend.plotOffset=t.getPlotOffset(),u=[],p=0,h="",f=e.legend.position,d=e.legend.margin,m={name:"",label:"",xPos:"",yPos:""};u[p++]='<svg class="legendLayer" style="width:inherit;height:inherit;">',u[p++]='<rect class="background" width="100%" height="100%"/>',u[p++]=C;var g=0,x=[],v=window.getComputedStyle(document.querySelector("body"));for(s=0;s<l.length;++s){var b=s%e.legend.noColumns;i=l[s],m.label=i.label;var y=t.getSurface().getTextInfo("",m.label,{style:v.fontStyle,variant:v.fontVariant,weight:v.fontWeight,size:parseInt(v.fontSize),lineHeight:parseInt(v.lineHeight),family:v.fontFamily}).width;x[b]?y>x[b]&&(x[b]=y+48):x[b]=y+48}for(s=0;s<l.length;++s)b=s%e.legend.noColumns,i=l[s],r="",m.label=i.label,m.xPos=g+3+"px",g+=x[b],(s+1)%e.legend.noColumns==0&&(g=0),m.yPos=1.5*Math.floor(s/e.legend.noColumns)+"em",i.options.lines.show&&i.options.lines.fill&&(m.name="area",m.fillColor=i.color,r+=S(m)),i.options.bars.show&&(m.name="bar",m.fillColor=i.color,r+=S(m)),i.options.lines.show&&!i.options.lines.fill&&(m.name="line",m.strokeColor=i.color,m.strokeWidth=i.options.lines.lineWidth,r+=S(m)),i.options.points.show&&(m.name=i.options.points.symbol,m.strokeColor=i.color,m.fillColor=i.options.points.fillColor,m.strokeWidth=i.options.points.lineWidth,r+=S(m)),a='<text x="'+m.xPos+'" y="'+m.yPos+'" text-anchor="start"><tspan dx="2em" dy="1.2em">'+m.label+"</tspan></text>",u[p++]="<g>"+r+a+"</g>";u[p++]="</svg>",null==d[0]&&(d=[d,d]),"n"===f.charAt(0)?h+="top:"+(d[1]+c.top)+"px;":"s"===f.charAt(0)&&(h+="bottom:"+(d[1]+c.bottom)+"px;"),"e"===f.charAt(1)?h+="right:"+(d[0]+c.right)+"px;":"w"===f.charAt(1)&&(h+="left:"+(d[0]+c.left)+"px;");var w=6;for(s=0;s<x.length;++s)w+=x[s];var T,k=1.6*Math.ceil(l.length/e.legend.noColumns);e.legend.container?(T=M(u.join("")).appendTo(e.legend.container)[0],e.legend.container.style.width=w+"px",e.legend.container.style.height=k+"em"):((T=M('<div class="legend" style="position:absolute;'+h+'">'+u.join("")+"</div>").appendTo(n)).css("width",w+"px"),T.css("height",k+"em"),T.css("pointerEvents","none"))}}(t,e,t.getPlaceholder(),r)})},options:{legend:{show:!1,noColumns:1,labelFormatter:null,container:null,position:"ne",margin:5,sorted:null}},name:"legend",version:"1.0"})}(jQuery);
//# sourceMappingURL=jquery.flot.js.map

"use strict";function _typeof(t){return(_typeof="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(t){return typeof t}:function(t){return t&&"function"==typeof Symbol&&t.constructor===Symbol&&t!==Symbol.prototype?"symbol":typeof t})(t)}function _slicedToArray(t,e){return _arrayWithHoles(t)||_iterableToArrayLimit(t,e)||_nonIterableRest()}function _nonIterableRest(){throw new TypeError("Invalid attempt to destructure non-iterable instance")}function _iterableToArrayLimit(t,e){var i=[],o=!0,n=!1,r=void 0;try{for(var a,s=t[Symbol.iterator]();!(o=(a=s.next()).done)&&(i.push(a.value),!e||i.length!==e);o=!0);}catch(t){n=!0,r=t}finally{try{o||null==s.return||s.return()}finally{if(n)throw r}}return i}function _arrayWithHoles(t){if(Array.isArray(t))return t}function _typeof(t){return(_typeof="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(t){return typeof t}:function(t){return t&&"function"==typeof Symbol&&t.constructor===Symbol&&t!==Symbol.prototype?"symbol":typeof t})(t)}function _slicedToArray(t,e){return _arrayWithHoles(t)||_iterableToArrayLimit(t,e)||_nonIterableRest()}function _nonIterableRest(){throw new TypeError("Invalid attempt to destructure non-iterable instance")}function _iterableToArrayLimit(t,e){var i=[],o=!0,n=!1,r=void 0;try{for(var a,s=t[Symbol.iterator]();!(o=(a=s.next()).done)&&(i.push(a.value),!e||i.length!==e);o=!0);}catch(t){n=!0,r=t}finally{try{o||null==s.return||s.return()}finally{if(n)throw r}}return i}function _arrayWithHoles(t){if(Array.isArray(t))return t}function _slicedToArray(t,e){return _arrayWithHoles(t)||_iterableToArrayLimit(t,e)||_nonIterableRest()}function _nonIterableRest(){throw new TypeError("Invalid attempt to destructure non-iterable instance")}function _iterableToArrayLimit(t,e){var i=[],o=!0,n=!1,r=void 0;try{for(var a,s=t[Symbol.iterator]();!(o=(a=s.next()).done)&&(i.push(a.value),!e||i.length!==e);o=!0);}catch(t){n=!0,r=t}finally{try{o||null==s.return||s.return()}finally{if(n)throw r}}return i}function _arrayWithHoles(t){if(Array.isArray(t))return t}function _typeof(t){return(_typeof="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(t){return typeof t}:function(t){return t&&"function"==typeof Symbol&&t.constructor===Symbol&&t!==Symbol.prototype?"symbol":typeof t})(t)}function _slicedToArray(t,e){return _arrayWithHoles(t)||_iterableToArrayLimit(t,e)||_nonIterableRest()}function _nonIterableRest(){throw new TypeError("Invalid attempt to destructure non-iterable instance")}function _iterableToArrayLimit(t,e){var i=[],o=!0,n=!1,r=void 0;try{for(var a,s=t[Symbol.iterator]();!(o=(a=s.next()).done)&&(i.push(a.value),!e||i.length!==e);o=!0);}catch(t){n=!0,r=t}finally{try{o||null==s.return||s.return()}finally{if(n)throw r}}return i}function _arrayWithHoles(t){if(Array.isArray(t))return t}function _classCallCheck(t,e){if(!(t instanceof e))throw new TypeError("Cannot call a class as a function")}function _defineProperties(t,e){for(var i=0;i<e.length;i++){var o=e[i];o.enumerable=o.enumerable||!1,o.configurable=!0,"value"in o&&(o.writable=!0),Object.defineProperty(t,o.key,o)}}function _createClass(t,e,i){return e&&_defineProperties(t.prototype,e),i&&_defineProperties(t,i),t}function _possibleConstructorReturn(t,e){return!e||"object"!==_typeof(e)&&"function"!=typeof e?_assertThisInitialized(t):e}function _assertThisInitialized(t){if(void 0===t)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return t}function _get(t,e,i){return(_get="undefined"!=typeof Reflect&&Reflect.get?Reflect.get:function(t,e,i){var o=_superPropBase(t,e);if(o){var n=Object.getOwnPropertyDescriptor(o,e);return n.get?n.get.call(i):n.value}})(t,e,i||t)}function _superPropBase(t,e){for(;!Object.prototype.hasOwnProperty.call(t,e)&&null!==(t=_getPrototypeOf(t)););return t}function _inherits(t,e){if("function"!=typeof e&&null!==e)throw new TypeError("Super expression must either be null or a function");t.prototype=Object.create(e&&e.prototype,{constructor:{value:t,writable:!0,configurable:!0}}),e&&_setPrototypeOf(t,e)}function _wrapNativeSuper(t){var e="function"==typeof Map?new Map:void 0;return(_wrapNativeSuper=function(t){function i(){return _construct(t,arguments,_getPrototypeOf(this).constructor)}if(null===t||!_isNativeFunction(t))return t;if("function"!=typeof t)throw new TypeError("Super expression must either be null or a function");if(void 0!==e){if(e.has(t))return e.get(t);e.set(t,i)}return i.prototype=Object.create(t.prototype,{constructor:{value:i,enumerable:!1,writable:!0,configurable:!0}}),_setPrototypeOf(i,t)})(t)}function isNativeReflectConstruct(){if("undefined"==typeof Reflect||!Reflect.construct)return!1;if(Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Date.prototype.toString.call(Reflect.construct(Date,[],function(){})),!0}catch(t){return!1}}function _construct(t,e,i){return _construct=isNativeReflectConstruct()?Reflect.construct:function(t,e,i){var o=[null];o.push.apply(o,e);var n=Function.bind.apply(t,o),r=new n;return i&&_setPrototypeOf(r,i.prototype),r},_construct.apply(null,arguments)}function _isNativeFunction(t){return-1!==Function.toString.call(t).indexOf("[native code]")}function _setPrototypeOf(t,e){return(_setPrototypeOf=Object.setPrototypeOf||function(t,e){return t.__proto__=e,t})(t,e)}function _getPrototypeOf(t){return(_getPrototypeOf=Object.setPrototypeOf?Object.getPrototypeOf:function(t){return t.__proto__||Object.getPrototypeOf(t)})(t)}function _toConsumableArray(t){return _arrayWithoutHoles(t)||_iterableToArray(t)||_nonIterableSpread()}function _nonIterableSpread(){throw new TypeError("Invalid attempt to spread non-iterable instance")}function _iterableToArray(t){if(Symbol.iterator in Object(t)||"[object Arguments]"===Object.prototype.toString.call(t))return Array.from(t)}function _arrayWithoutHoles(t){if(Array.isArray(t)){for(var e=0,i=new Array(t.length);e<t.length;e++)i[e]=t[e];return i}}function _classCallCheck(t,e){if(!(t instanceof e))throw new TypeError("Cannot call a class as a function")}function _defineProperties(t,e){for(var i=0;i<e.length;i++){var o=e[i];o.enumerable=o.enumerable||!1,o.configurable=!0,"value"in o&&(o.writable=!0),Object.defineProperty(t,o.key,o)}}function _createClass(t,e,i){return e&&_defineProperties(t.prototype,e),i&&_defineProperties(t,i),t}function _toConsumableArray(t){return _arrayWithoutHoles(t)||_iterableToArray(t)||_nonIterableSpread()}function _nonIterableSpread(){throw new TypeError("Invalid attempt to spread non-iterable instance")}function _iterableToArray(t){if(Symbol.iterator in Object(t)||"[object Arguments]"===Object.prototype.toString.call(t))return Array.from(t)}function _arrayWithoutHoles(t){if(Array.isArray(t)){for(var e=0,i=new Array(t.length);e<t.length;e++)i[e]=t[e];return i}}function _classCallCheck(t,e){if(!(t instanceof e))throw new TypeError("Cannot call a class as a function")}function _defineProperties(t,e){for(var i=0;i<e.length;i++){var o=e[i];o.enumerable=o.enumerable||!1,o.configurable=!0,"value"in o&&(o.writable=!0),Object.defineProperty(t,o.key,o)}}function _createClass(t,e,i){return e&&_defineProperties(t.prototype,e),i&&_defineProperties(t,i),t}function _typeof(t){return(_typeof="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(t){return typeof t}:function(t){return t&&"function"==typeof Symbol&&t.constructor===Symbol&&t!==Symbol.prototype?"symbol":typeof t})(t)}!function(t,e){function i(){this.pluginName="scattergraph",this.pluginVersion="1.0",this.defaultOptions={series:{scattergraph:{data:[],show:!1,lineWidth:2,filled:!1,drawLines:!1,color:"black",shape:"circle",size:5}}};var t=new Map([[0,"red"],[1,"green"],[2,"blue"],[3,"cyan"],[4,"yellow"],[5,"magenta"],[6,"salmon"],[7,"teal"],[8,"grey"],[9,"black"]]),e=new Map([[0,"circle"],[1,"square"],[2,"triangle_n"],[3,"triangle_s"],[4,"triangle_e"],[5,"triangle_w"],[6,"cross_v"],[7,"cross_d"],[8,"diamond"],[9,"asterisk"]]),i=new Map([[0,1],[1,2],[2,3],[3,4],[4,5],[5,9],[6,14],[7,23],[8,37],[9,60]]);this.init=function(o){function n(t,e,i,o){if(!0===t.getOptions().series.scattergraph.show&&i[0]){if(!Array.isArray(i[0])&&Array.isArray(i[0].x))E=!0,R=i[0].x.length;else if(Array.isArray(i[0])&&Array.isArray(i[0][0])&&!Array.isArray(i[0][0][0]))z=!0,R=i[0].length;else{if(!Array.isArray(i[0])||"object"!==_typeof(i[0][0]))return void console.log("unknown data type for scatter graph");P=!0,R=i[0].length}for(var n,r,a=Number.NEGATIVE_INFINITY,s=Number.NEGATIVE_INFINITY,h=Number.POSITIVE_INFINITY,l=Number.POSITIVE_INFINITY,u=0;u<R;u++)P?(n=i[0][u].x,r=i[0][u].y):E?(n=i[0].x[u],r=i[0].y[u]):z&&(n=i[0][u][0],r=i[0][u][1]),n>a&&(a=n),r>s&&(s=r),n<l&&(l=n),r<h&&(h=r);o.pointsize=2,o.points.length=0,o.points.push(l,h),o.points.push(a,s),o.format=[{x:!0,y:!1,number:!0,computeRange:!0},{x:!1,y:!0,number:!0,computeRange:!0}]}}function r(o,r){r.series.scattergraph.show&&(r.series.scattergraph.colors?"string"==typeof r.series.scattergraph.colors?r.series.scattergraph.colors=a(JSON.parse(r.series.scattergraph.colors)):Array.isArray(r.series.scattergraph.colors)?r.series.scattergraph.colors=a(r.series.scattergraph.colors):"function"!=typeof r.series.scattergraph.colors&&console.log("colors is unknown type"):r.series.scattergraph.colors=t,r.series.scattergraph.sizes?"string"==typeof r.series.scattergraph.sizes?r.series.scattergraph.sizes=u(JSON.parse(r.series.scattergraph.sizes)):Array.isArray(r.series.scattergraph.sizes)?r.series.scattergraph.sizes=u(r.series.scattergraph.sizes):"function"!=typeof r.series.scattergraph.sizes&&console.log("sizes is unknown type"):r.series.scattergraph.sizes=i,r.series.scattergraph.shapes?"string"==typeof r.series.scattergraph.shapes?r.series.scattergraph.shapes=h(JSON.parse(r.series.scattergraph.shapes)):Array.isArray(r.series.scattergraph.shapes)?r.series.scattergraph.shapes=h(r.series.scattergraph.shapes):"function"!=typeof r.series.scattergraph.shapes&&console.log("sizes is unknown type"):r.series.scattergraph.shapes=e,o.hooks.drawSeries.push(S),o.hooks.processRawData.push(n),L=r)}function a(t){var e,i=new Map;for(e=0;e<t.length;e++)i.set(t[e].value,t[e].color);return i}function s(t){var e;return void 0!==t&&("function"==typeof L.series.scattergraph.colors?e=L.series.scattergraph.colors(t):L.series.scattergraph.colors&&(e=L.series.scattergraph.colors.get(t))),e||L.series.scattergraph.color}function h(t){var e,i=new Map;for(e=0;e<t.length;e++)i.set(t[e].value,t[e].shape);return i}function l(t){var e;return void 0!==t&&("function"==typeof L.series.scattergraph.shapes?e=L.series.scattergraph.shapes(t):L.series.scattergraph.shapes&&(e=L.series.scattergraph.shapes.get(t))),e||L.series.scattergraph.shape}function u(t){var e,i=new Map;for(e=0;e<t.length;e++)i.set(t[e].value,parseFloat(t[e].size));return i}function d(t){var e;return void 0!==t&&("function"==typeof L.series.scattergraph.sizes?e=L.series.scattergraph.sizes(t):L.series.scattergraph.sizes&&(e=L.series.scattergraph.sizes.get(t))),void 0===e?L.series.scattergraph.size:e}function c(t,e,i,o,n,r,a,s){t.save(),t.strokeStyle=s,t.beginPath(),t.moveTo(e.p2c(o),i.p2c(n)),t.lineTo(e.p2c(r),i.p2c(a)),t.stroke(),t.restore()}function f(t,e,i,o,n){t.beginPath(),t.arc(e,i,o/2,0,2*Math.PI),n?t.fill():t.stroke()}function p(t,e,i,o,n){n?t.fillRect(e-o/2,i-o/2,o,o):t.strokeRect(e-o/2,i-o/2,o,o)}function g(t,e,i,o,n){var r=o*(Math.sqrt(3)/2);t.beginPath(),t.moveTo(e,i-r/2),t.lineTo(e-o/2,i+r/2),t.lineTo(e+o/2,i+r/2),t.lineTo(e,i-r/2),t.lineTo(e-o/2,i+r/2),n?t.fill():t.stroke()}function m(t,e,i,o,n){var r=o*(Math.sqrt(3)/2);t.beginPath(),t.moveTo(e,i+r/2),t.lineTo(e-o/2,i-r/2),t.lineTo(e+o/2,i-r/2),t.lineTo(e,i+r/2),t.lineTo(e-o/2,i-r/2),n?t.fill():t.stroke()}function v(t,e,i,o,n){var r=o*(Math.sqrt(3)/2);t.beginPath(),t.moveTo(e+r/2,i),t.lineTo(e-r/2,i+r/2),t.lineTo(e-r/2,i-r/2),t.lineTo(e+r/2,i),t.lineTo(e-r/2,i+r/2),n?t.fill():t.stroke()}function b(t,e,i,o,n){var r=o*(Math.sqrt(3)/2);t.beginPath(),t.moveTo(e-r/2,i),t.lineTo(e+r/2,i+r/2),t.lineTo(e+r/2,i-r/2),t.lineTo(e-r/2,i),t.lineTo(e+r/2,i+r/2),n?t.fill():t.stroke()}function y(t,e,i,o){var n=o;t.beginPath(),t.moveTo(e,i-n/2),t.lineTo(e,i+n/2),t.moveTo(e-n/2,i),t.lineTo(e+n/2,i),t.stroke()}function x(t,e,i,o){var n=o;t.beginPath(),t.moveTo(e-n/2,i-n/2),t.lineTo(e+n/2,i+n/2),t.moveTo(e-n/2,i+n/2),t.lineTo(e+n/2,i-n/2),t.stroke()}function w(t,e,i,o,n){var r=o;t.beginPath(),t.moveTo(e,i-r/2),t.lineTo(e+r/2,i),t.lineTo(e,i+r/2),t.lineTo(e-r/2,i),t.lineTo(e,i-r/2),t.lineTo(e+r/2,i),n?t.fill():t.stroke()}function _(t,e,i,o){var n=o,r=n/(2*Math.sqrt(2));t.beginPath(),t.moveTo(e-r,i-r),t.lineTo(e+r,i+r),t.moveTo(e-r,i+r),t.lineTo(e+r,i-r),t.moveTo(e,i-n/2),t.lineTo(e,i+n/2),t.moveTo(e-n/2,i),t.lineTo(e+n/2,i),t.stroke()}function k(t,e,i,o,n,r,a,s,h,l,u,d){if(void 0!==e&&void 0!==i)switch(t.strokeStyle=s,t.fillStyle=s,t.lineWidth=u,t.moveTo(o.p2c(e)+r,n.p2c(i)+a),h){case"circle":f(t,o.p2c(e),n.p2c(i),l,d);break;case"square":p(t,o.p2c(e),n.p2c(i),l,d);break;case"triangle_n":g(t,o.p2c(e),n.p2c(i),l,d);break;case"triangle_s":m(t,o.p2c(e),n.p2c(i),l,d);break;case"triangle_e":v(t,o.p2c(e),n.p2c(i),l,d);break;case"triangle_w":b(t,o.p2c(e),n.p2c(i),l,d);break;case"cross_v":y(t,o.p2c(e),n.p2c(i),l,d);break;case"cross_d":x(t,o.p2c(e),n.p2c(i),l);break;case"diamond":w(t,o.p2c(e),n.p2c(i),l,d);break;case"asterisk":_(t,o.p2c(e),n.p2c(i),l)}}function T(t,e,i,o,n,r,a){var s=!1,h=Math.round(t.xaxis.p2c(e)),l=Math.round(t.yaxis.p2c(i)),u={x:h,y:l},d=a.get(u);if(d){for(var c=0;c<d.length;c++)d[c].color===o&&d[c].shape===n&&d[c].size===r&&(s=!0);d.push({color:o,size:r,shape:n}),a.set(u,d)}else a.set(u,[{color:o,size:r,shape:n}]);return s}function S(t,e,i){var o,n;if(i.data&&Array.isArray(i.data)&&0!==i.data.length){var r=new Map,a=t.getPlotOffset();e.save(),e.translate(a.left,a.top);for(var h=0;h<R;h++){var u,f,p,g,m;P?(u=i.data[0][h].x,f=i.data[0][h].y,p=s(i.data[0][h].color),g=l(i.data[0][h].shape),m=d(i.data[0][h].size)):E?(u=i.data[0].x[h],f=i.data[0].y[h],p=s(i.data[0].color?i.data[0].color[h]:void 0),g=l(i.data[0].shape?i.data[0].shape[h]:void 0),m=d(i.data[0].size?i.data[0].size[h]:void 0)):z&&(u=i.data[0][h][0],f=i.data[0][h][1],p=s(i.data[0][h][2]),g=l(i.data[0][h][3]),m=d(i.data[0][h][4])),"transparent"===p.toLowerCase()||"none"===g.toLowerCase()||0===m||!L.series.scattergraph.drawLines&&T(i,u,f,p,g,m,r)||(k(e,u,f,i.xaxis,i.yaxis,0,0,p,g,m,L.series.scattergraph.lineWidth,L.series.scattergraph.filled),h>0&&L.series.scattergraph.drawLines&&c(e,i.xaxis,i.yaxis,o,n,u,f,i.color),o=u,n=f)}e.restore()}}var R,L=null,P=!1,z=!1,E=!1;o.hooks.processOptions.push(r)}}var o=new i;e.plot.plugins.push({init:o.init,options:o.defaultOptions,name:o.pluginName,version:o.pluginVersion}),e.plot.scattergraph=o}(0,jQuery),function(t){function e(t){t.addEventListener("mousemove",i,!1),t.addEventListener("touchmove",i,!1),t.addEventListener("mouseup",o,!1),t.addEventListener("touchend",o,!1)}function i(t){if(g){if(0===t.buttons)return void o(t);var e=c(t),i={x:e.X-g.deltaHandlingX,y:e.Y-g.deltaHandlingY},n=r(t),s=a(n),l=s.eventHolder,d=!1;if(g.selectedElement.constraintFunction){var f=g.selectedElement.constraintFunction(e.X,e.Y,g.x,g.y,i.x,i.y),p=_slicedToArray(f,3);e.X=p[0],e.Y=p[1],d=p[2]}if(!d){var m=g.selectedElement.getCTM(),v=e.X-g.x,b=e.Y-g.y;m.e+=v,m.f+=b,g.selectedElement.transform.baseVal.getItem(0).setMatrix(m)}g.x=e.X,g.y=e.Y,h(g.selectedElement),t.preventDefault(),t.stopPropagation(),u("thumbmove",t,l)}}function o(t){var e=r(t),i=a(e),o=i.eventHolder;g&&(g=null,i.style.pointerEvents="none",o.dispatchEvent(new CustomEvent("thumbmoveend",{detail:t})))}function n(t){var e=r(t),i=a(e),o=i.eventHolder;if(g=null,e&&-1!==e.getAttribute("class").indexOf("draggable")){var n=c(t),s=e.getBoundingClientRect(),h=document.documentElement,l=(window.pageXOffset||h.scrollLeft)-(h.clientLeft||0),d=(window.pageYOffset||h.scrollTop)-(h.clientTop||0);g={selectedElement:e,x:n.X,y:n.Y,deltaHandlingX:n.X-(s.left+s.right)/2-l,deltaHandlingY:n.Y-(s.top+s.bottom)/2-d},i.style.pointerEvents="all"}g&&u("thumbmovestart",t,o)}function r(t){var e=t.target,i=e.getAttribute("class");return i&&i.includes("interactionLayer")?e.parentNode:e}function a(t){return"svg"===t.tagName?t:"g"===t.tagName?t.parentNode:null}function s(t){var e=r(t),i=[];e&&-1!==e.getAttribute("class").indexOf("thumb")&&(i=l(e),i.length>0&&h(i[0]))}function h(t){t.parentNode.appendChild(t)}function l(t){var e=t.getBoundingClientRect(),i=e.left,o=e.right,n=e.top,r=e.bottom,a=t.parentNode;return Array.prototype.slice.call(a.childNodes,0).filter(function(t){var e=t.getBoundingClientRect(),a=e.left,s=e.right,h=e.top,l=e.bottom;return e.width>0&&e.height>0&&(i<s&&o>a&&n<l&&r>h)})}function u(t,e,i){var o=c(e),n=new CustomEvent(t,{detail:e});n.pageX=o.X-g.deltaHandlingX,n.pageY=o.Y-g.deltaHandlingY,n.selectedThumb=g.selectedElement,i.dispatchEvent(n)}function d(t){var e=document.documentElement;return{X:t.clientX+(window.pageXOffset||e.scrollLeft)-(e.clientLeft||0),Y:t.clientY+(window.pageYOffset||e.scrollTop)-(e.clientTop||0)}}function c(t){return t.touches?{X:t.touches[0].pageX,Y:t.touches[0].pageY}:d(t)}function f(t){Array.prototype.forEach.call(t.childNodes,function(t){t.classList.contains("thumb")&&(t.removeEventListener("mousedown",n),t.removeEventListener("touchstart",n))}),t.removeEventListener("mousemove",i),t.removeEventListener("touchmove",i),t.removeEventListener("mouseup",o),t.removeEventListener("touchend",o)}function p(t,e){var i=e-8,o=window.getComputedStyle(t).fontSize.replace("px",""),n=t.textContent,r=n.trim().split(/\s+/);if(r.length>1){t.textContent="";var a=document.createElementNS("http://www.w3.org/2000/svg","tspan");a.setAttribute("x",t.getAttribute("x")),a.setAttribute("y",t.getAttribute("y")),a.setAttribute("pointer-events","none"),a.setAttribute("font-size",o),a.textContent=r[0],t.appendChild(a);for(var s=1;s<r.length;s++){var h=a.firstChild.textContent.length;a.firstChild.textContent+=" "+r[s],a.getComputedTextLength()>i&&(a.firstChild.textContent=a.firstChild.textContent.slice(0,h),a=a.cloneNode(!0),t.appendChild(a),a.textContent=r[s])}for(var l=0;l<t.children.length;l++){var u=-(o*(t.children.length/2-l)-o/2);t.children[l].setAttribute("dy",u)}}}t.thumb={};var g;t.thumb.createSVGLayer=function(t,i){if(t&&t.find(".flot-thumbs")[0])return t.find(".flot-thumbs")[0].firstChild;var o=document.createElement("div");o.className="flot-thumbs",o.style.position="absolute",o.style.top="0px",o.style.left="0px",o.style.width="100%",o.style.height="100%",o.style.pointerEvents="none",t?t.append(o):document.body.appendChild(o);var n=document.createElementNS("http://www.w3.org/2000/svg","svg");n.setAttributeNS(null,"width","100%"),n.setAttributeNS(null,"height","100%");var r=window.getComputedStyle(o).getPropertyValue("--customIcon");r=(r||"").trim();var a=window.getComputedStyle(o).getPropertyValue("--customIconTextBoundary");a=(a||"").trim();var s=r||'<symbol id="round" viewBox="0 0 50 50"><polyline points="25,0 40,20 10,20 25,0"></polyline><circle cx="25" cy="25" r="20"/></symbol>',h=a;""===a&&""===r&&(h='<symbol id="round" viewBox="0 0 50 50"><circle cx="25" cy="25" r="20"/></symbol>'),""===h&&(h=s);var l='<defs xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">'+s+h+'<symbol id="l_round" viewBox="0 0 50 50"><use xlink:href="#round" x="0" y="0" width="50" height="50" transform="rotate(90 25 25)"/></symbol><symbol id="r_round" viewBox="0 0 50 50"><use xlink:href="#round" x="0" y="0" width="50" height="50" transform="rotate(270 25 25)"/></symbol><symbol id="b_round" viewBox="0 0 50 50"><use xlink:href="#round" x="0" y="0" width="50" height="50" transform="rotate(0 25 25)"/></symbol><symbol id="t_round" viewBox="0 0 50 50"><use xlink:href="#round" x="0" y="0" width="50" height="50" transform="rotate(180 25 25)"/></symbol><symbol id="l_tb" viewBox="0 0 50 50"><use xlink:href="#tb" x="0" y="0" width="50" height="50" transform="rotate(90 25 25)" /></symbol><symbol id="r_tb" viewBox="0 0 50 50"><use xlink:href="#tb" x="0" y="0" width="50" height="50" transform="rotate(270 25 25)" /></symbol><symbol id="b_tb" viewBox="0 0 50 50"><use xlink:href="#tb" x="0" y="0" width="50" height="50" transform="rotate(0 25 25)" /></symbol><symbol id="t_tb" viewBox="0 0 50 50"><use xlink:href="#tb" x="0" y="0" width="50" height="50" transform="rotate(180 25 25)" /></symbol></defs>',u=(new DOMParser).parseFromString(l,"image/svg+xml"),d=document.importNode(u.documentElement,!0);return d.children[0].setAttribute("id","round"),d.children[1].setAttribute("id","tb"),n.appendChild(d),o.appendChild(n),n.eventHolder=i||document,e(n),n},t.thumb.createThumb=function(e){function i(t,e){t.setAttributeNS("http://www.w3.org/1999/xlink","xlink:href",e),t.setAttributeNS("http://www.w3.org/1999/xlink","href",e)}var o={size:e.size||20,x:e.x||0,y:e.y||0,svgRoot:e.svgRoot,shape:e.shape||"bottom",abbreviation:e.abbreviation||"",constraintFunction:e.constraintFunction,classList:e.classList?e.classList.slice():["draggable"],offset:e.offset||"0",fill:e.fill},r=document.createElementNS("http://www.w3.org/2000/svg","use"),a=document.createElementNS("http://www.w3.org/2000/svg","text"),h=document.createElementNS("http://www.w3.org/2000/svg","use"),l=document.createElementNS("http://www.w3.org/2000/svg","g"),u=document.createElementNS("http://www.w3.org/2000/svg","rect"),d=o.svgRoot,c=o.size,f=o.x,g=o.y,m="",v=0,b=0;switch(o.shape){case"left":m="y",o.classList.push("left"),l.shape="left",i(r,"#l_round"),i(h,"#l_tb"),v="-"===o.offset[0]?o.offset.substr(1):"-"+o.offset;break;case"right":m="y",o.classList.push("right"),l.shape="right",i(r,"#r_round"),i(h,"#r_tb"),v=o.offset;break;case"bottom":m="x",o.classList.push("bottom"),l.shape="bottom",i(r,"#b_round"),i(h,"#b_tb"),b=o.offset;break;case"top":m="x",o.classList.push("top"),l.shape="top",i(r,"#t_round"),i(h,"#t_tb"),b="-"===o.offset[0]?o.offset.substr(1):"-"+o.offset}if(r.setAttributeNS(null,"width",2*c),r.setAttributeNS(null,"height",2*c),r.setAttributeNS(null,"transform","translate("+-c+" "+-c+")"),r.setAttributeNS(null,"x",v),r.setAttributeNS(null,"y",b),r.setAttribute("class","thumbIcon"),r.style.fill=o.fill,h.setAttributeNS(null,"width",2*c),h.setAttributeNS(null,"height",2*c),h.setAttributeNS(null,"transform","translate("+-c+" "+-c+")"),h.setAttributeNS(null,"x",v),h.setAttributeNS(null,"y",b),a.setAttributeNS(null,"text-anchor","middle"),a.setAttributeNS(null,"dominant-baseline","middle"),a.setAttributeNS(null,"lengthAdjust","spacingAndGlyphs"),a.setAttribute("class","thumbLabel"),a.textContent=o.abbreviation,a.style.pointerEvents="none",l.appendChild(r),l.appendChild(h),l.appendChild(a),l.setAttributeNS(null,"transform","translate("+f+" "+g+")"),l.setAttribute("class","thumb"),l.classList.add(m),o.classList)for(var y=0;y<o.classList.length;y++)""!==o.classList[y]&&l.classList.add(o.classList[y]);l.style.pointerEvents="all",l.addEventListener("mousedown",n,!1),l.addEventListener("touchstart",n,!1),t(l).click(s),l.constraintFunction=o.constraintFunction,d.appendChild(l);var x=r.getBBox();u.setAttributeNS(null,"width",x.width),u.setAttributeNS(null,"height",x.height),u.setAttributeNS(null,"x",x.x),u.setAttributeNS(null,"y",x.y),u.setAttributeNS(null,"transform","translate("+-c+" "+-c+")"),u.setAttribute("pointer-events","all"),u.classList.add("interactionLayer"),u.style.fill="transparent",u.style.stroke="transparent",l.appendChild(u);var w=h.getBBox(),_=w.x+w.width/2,k=w.y+w.height/2;return l.removeChild(h),a.setAttributeNS(null,"x",_),a.setAttributeNS(null,"y",k),a.setAttributeNS(null,"transform","translate("+-c+" "+-c+")"),/word/.test(window.getComputedStyle(a).getPropertyValue("--wrap"))?p(a,2*c):a.setAttributeNS(null,"textLength",c),l},t.thumb.updateComputedXPosition=function(t,e){var i=t.getCTM(),o="matrix("+i.a+" "+i.b+" "+i.c+" "+i.d+" "+e+" "+i.f+")";t.setAttribute("transform",o)},t.thumb.updateComputedYPosition=function(t,e){var i=t.getCTM(),o="matrix("+i.a+" "+i.b+" "+i.c+" "+i.d+" "+i.e+" "+e+")";t.setAttribute("transform",o)},t.thumb.setHidden=function(t,e){t.style.display=e?"none":"inline"},t.thumb.shutdown=function(t){g=null,f(t)}}(jQuery),function(t){function e(e){function s(t){var e=h();return l(e,t),i(t,e)}function h(){return{name:"unnamed "+ot.length,position:{relativeX:.5,relativeY:.5,x:void 0,y:void 0},mousePosition:{relativeX:void 0,relativeY:void 0},x:0,y:0,valign:"below",halign:"right",show:!0,selected:!1,highlighted:!1,mode:"xy",showIntersections:!1,showLabel:!1,showValues:!0,color:"gray",fontSize:"10px",fontFamily:"sans-serif",fontStyle:"",fontWeight:"",lineWidth:1,movable:!0,dashes:[],intersectionColor:"darkgray",intersectionLabelPosition:"bottom-right",snapToPlot:void 0,interpolate:!1,defaultxaxis:1,defaultyaxis:1,symbolSize:8,showThumbs:"none",thumbAbbreviation:"C"+ot.length,thumbClassList:["draggable"],thumbs:[],thumbColor:void 0,horizontalThumbConstrain:void 0,verticalThumbConstrain:void 0}}function l(t,e){g(t,e),v(t,e)}function u(t,e){return"x"===t&&-1!==e.search(/[lr]/)||("y"===t&&-1!==e.search(/[tb]/)||"xy"===t&&-1!==e.search(/l\s*r|r\s*l|t\s*b|b\s*t/))}function f(t,e){if(e.mode&&e.showThumbs){if(u(e.mode,e.showThumbs)){switch(console.log("showThumbs ".concat(e.showThumbs," doesn't match mode ").concat(e.mode,".")),e.mode){case"x":e.showThumbs="t";break;case"y":e.showThumbs="r";break;case"xy":e.showThumbs="tr"}console.log("showThumbs is coerced to ".concat(e.showThumbs))}}else e.mode?u(e.mode,t.showThumbs)&&(console.log("mode doesn't match the existing showThumbs. It will be ignored"),delete e.mode):e.showThumbs&&u(t.mode,e.showThumbs)&&(console.log("showThumbs doesn't match the existing mode. It will be ignored"),delete e.showThumbs)}function g(t,e){if("none"!==e.showThumbs&&(f(t,e),e.showThumbs))for(var i,o=e.showThumbs.split("").map(function(t){return A[t]}),n=0;n<t.thumbs.length;n++)o.includes(t.thumbs[n].shape)||(i=t.thumbs[n],t.thumbs[n]=null,t._createThumbs=!0,T("thumbWillBeRemoved",{current:i}),it.removeChild(i),st.delete(i))}function v(t,e){if(0!==t.thumbs.length){var i=void 0!==e.show?e.show:t.show,o=void 0!==e.showThumbs?e.showThumbs:t.showThumbs,n=void 0!==e.show&&e.show!==t.show,r=void 0!==e.showThumbs&&(e.showThumbs!==t.showThumbs&&("none"===e.showThumbs||"none"===t.showThumbs));t.triggerThumbVisibilityChanged=n&&"none"!==o||r&&i}}function T(t,i){var o=new CustomEvent(t,{detail:i});e.getPlaceholder()[0].dispatchEvent(o)}function S(t,e){t.triggerThumbVisibilityChanged&&t.thumbs.forEach(function(t){T("thumbVisibilityChanged",{visible:e,current:t})})}function z(){rt=O.relative,ot.forEach(function(t){if(!isNaN(t.x)&&!isNaN(t.y)){var i={relativeX:t.position.relativeX||t.x/e.width(),relativeY:t.position.relativeY||t.y/e.height(),x:void 0,y:void 0};isNaN(i.relativeX)||isNaN(i.relativeY)||(t.position=i)}})}function M(){rt=O.axis,ot.forEach(function(t){if(t.mousePosition={},void 0===t.position.x){var i=b(e,t);t.position.x=i.c2p?i.c2p(t.x):void 0}if(void 0===t.position.y){var o=y(e,t);t.position.y=o.c2p?o.c2p(t.y):void 0}t.position.relativeX=void 0,t.position.relativeY=void 0})}function I(t,e){var i={cursor:e.name,points:[]};return e.interpolate?N(t,e,i):H(t,e,i),i}function H(t,e,i){var o,n;rt===O.axis?(o=e.x,n=e.y):(o=e.mousePosition.relativeX*t.width(),n=e.mousePosition.relativeY*t.height());var r=t.findNearbyItem(o,n,function(t){return-1===e.snapToPlot||t===e.snapToPlot},Number.MAX_VALUE,function(t,e){return at===C.x?t:t*t+e*e*.025});if(r){var a=t.getData(),s=a[r.seriesIndex].datapoints.pointsize,h=r.dataIndex*s;i.points.push({x:r.datapoint[0],y:r.datapoint[1],leftPoint:[h-s,h-s+1],rightPoint:[h,h+1],seriesIndex:r.seriesIndex})}}function N(t,e,i){var o=t.c2p({left:e.x,top:e.y}),n=t.getAxes();if(!(o.x<n.xaxis.min||o.x>n.xaxis.max||o.y<n.yaxis.min||o.y>n.yaxis.max)){var r=t.findNearbyInterpolationPoint(o.x,o.y,function(t){return-1===e.snapToPlot||t===e.snapToPlot});r&&i.points.push({x:r.datapoint[0],y:r.datapoint[1],leftPoint:r.leftPoint,rightPoint:r.rightPoint,seriesIndex:r.seriesIndex})}}function D(t){function i(t){return t.getAttribute("class").includes("draggable")}function o(t){var e=t,i=t.getAttribute("class");return i.includes("interactionLayer")&&(e=t.parentNode,i=e.getAttribute("class")),i.includes("thumb")?e:null}lt(ot)||ut(ot).filter(function(t){return!0===t.movable}).forEach(function(n){n.thumbs.filter(i).filter(function(e){return e===o(t.detail.target)}).forEach(function(i){var o=n;o&&(i.classList.contains("x")?o.dragmode="x":o.dragmode="y",o.selected=!0,o.thumbmove=!0,"x"===o.mode?e.getPlaceholder().css("cursor","ew-resize"):"y"===o.mode&&e.getPlaceholder().css("cursor","ns-resize"),e.getPlaceholder().css("cursor","move"),e.getPlaceholder().trigger("cursordragstart",o),e.triggerRedrawOverlay(),t.stopImmediatePropagation(),t.preventDefault())})})}function B(t,i,o){var n=lt(ot);if(n){j(n,i,o);var r,a=t.selectedThumb;r=a.classList.contains("x")?n.x+e.getPlotOffset().left:n.y+e.getPlotOffset().top,st.set(a,r),e.getPlaceholder().trigger("cursordrag",n),e.triggerRedrawOverlay(),t.stopImmediatePropagation(),t.preventDefault()}}function Y(t,i,o,n,r){var a=lt(ot);a&&(j(a,i,o),e.getPlaceholder().trigger("cursordrag",a),e.triggerRedrawOverlay(),t.stopImmediatePropagation(),t.preventDefault())}function X(t,i,o,n,r){var a=lt(ot);a&&0===t.buttons&&(a.selected=!1,e.triggerRedrawOverlay()),ut(ot).forEach(function(t){W(n,r,e,t)})}function W(t,e,i,o){o.movable&&(R(t,e,i,o)?(o.highlighted||(o.highlighted=!0,i.triggerRedrawOverlay()),i.getPlaceholder().css("cursor","pointer")):L(t,e,i,o)?(o.highlighted||(o.highlighted=!0,i.triggerRedrawOverlay()),i.getPlaceholder().css("cursor","col-resize")):P(t,e,i,o)?(o.highlighted||(o.highlighted=!0,i.triggerRedrawOverlay()),i.getPlaceholder().css("cursor","row-resize")):o.highlighted&&(o.highlighted=!1,i.getPlaceholder().css("cursor","default"),i.triggerRedrawOverlay()))}function V(t,i,o,n,r){var a=lt(ot);if(at=C.xy,a)e.getPlaceholder().css("cursor","default"),a.x=i,a.y=o,a.position.relativeX=i/e.width(),a.position.relativeY=o/e.height(),e.triggerRedrawOverlay();else{var s,h;ut(ot).forEach(function(t){t.movable&&(R(n,r,e,t)?(s=t,h="xy"):P(n,r,e,t)?(s=t,h="y"):L(n,r,e,t)&&(s=t,h="x"),W(n,r,e,t))}),s&&(s.thumbmove=!1,s.selected=!0,s.dragmode=h,"x"===s.mode?e.getPlaceholder().css("cursor","ew-resize"):"y"===s.mode?e.getPlaceholder().css("cursor","ns-resize"):e.getPlaceholder().css("cursor","move"),e.getPlaceholder().css("cursor","move"),e.getPlaceholder().trigger("cursordragstart",s),e.triggerRedrawOverlay(),t.stopImmediatePropagation(),t.preventDefault())}a=lt(ot)}function F(t,i,o,n,r){var a=lt(ot);a&&(isFinite(i)&&isFinite(o)&&j(a,i,o),a.selected=!1,a.thumbmove=!1,e.getPlaceholder().css("cursor","default"),e.getPlaceholder().trigger("cursordragend",a),e.triggerRedrawOverlay(),t.stopImmediatePropagation(),t.preventDefault())}function j(t,i,o){var n=b(e,t),r=y(e,t);-1!==t.dragmode.indexOf("x")&&(t.x=i,t.position.x=n.c2p?n.c2p(i):void 0,t.position.relativeX=i/e.width(),t.mousePosition.relativeX=i/e.width()),-1!==t.dragmode.indexOf("y")&&(t.y=o,t.position.y=r.c2p?r.c2p(o):void 0,t.position.relativeY=o/e.height(),t.mousePosition.relativeY=o/e.height())}function G(t,i){if(et)return et(t,i);var o=e.offset();return[Math.max(0,Math.min(t-o.left,e.width())),Math.max(0,Math.min(i-o.top,e.height()))]}function q(e){e.thumbs.forEach(function(e){t.thumb.setHidden(e,!0)})}function U(e,i,o){it=t.thumb.createSVGLayer(i.getPlaceholder(),i.getEventHolder());var n,r,a,s,h=0,l={size:E.thumbRadius,svgRoot:it,abbreviation:e.thumbAbbreviation||e.name[0],classList:e.thumbClassList,offset:e.thumbOffset,fill:e.thumbColor};$(e)&&!e.thumbs[0]&&(h=1,r=e.x+o.left,a=-1!==e.showThumbs.indexOf("b")?i.height()+o.top+E.thumbRadius:o.top-E.thumbRadius,s=e.horizontalThumbConstrain?e.horizontalThumbConstrain:function(t,e,o,n,r,a){var s=i.offset().left;return[Math.max(s,Math.min(r,i.width()+s))-r+t,n]},l.shape=-1!==e.showThumbs.indexOf("b")?"bottom":"top",l.x=r,l.y=a,l.constraintFunction=s,n=t.thumb.createThumb(l),
e.thumbs[0]=n,st.set(n,r),T("thumbCreated",{current:n})),tt(e)&&!e.thumbs[h]&&(r=-1!==e.showThumbs.indexOf("l")?o.left-E.thumbRadius:o.left+i.width()+E.thumbRadius,a=e.y+o.top,s=e.verticalThumbConstrain?e.verticalThumbConstrain:function(t,e,o,n,r,a){var s=i.offset();return[o,Math.max(s.top,Math.min(a,i.height()+s.top))-a+e]},l.shape=-1!==e.showThumbs.indexOf("l")?"left":"right",l.x=r,l.y=a,l.constraintFunction=s,n=t.thumb.createThumb(l),e.thumbs[h]=n,st.set(n,a),T("thumbCreated",{current:n}))}function J(e,i,o){var n;if($(i)){n=i.thumbs[0];var r=i.x+o.left,a=st.get(n),s=Z(n);d(e,i.x)?(a<o.left?Q("thumbIntoRange",{target:n,edge:s?"topleft":"bottomleft",orientation:"horizontal",position:r},e.getEventHolder()):a>o.left+e.width()&&Q("thumbIntoRange",{target:n,edge:s?"topright":"bottomright",orientation:"horizontal",position:r},e.getEventHolder()),t.thumb.setHidden(n,!1),t.thumb.updateComputedXPosition(n,r)):(d(e,a-o.left)&&i.x<0?Q("thumbOutOfRange",{target:n,edge:s?"topleft":"bottomleft",orientation:"horizontal"},e.getEventHolder()):d(e,a-o.left)&&i.x>e.width()&&Q("thumbOutOfRange",{target:n,edge:s?"topright":"bottomright",orientation:"horizontal"},e.getEventHolder()),t.thumb.setHidden(n,!0)),st.set(n,r)}if(tt(i)){var h=$(i)?1:0;n=i.thumbs[h];var l=i.y+o.top,u=st.get(n),f=K(n);c(e,i.y)?(u<o.top?Q("thumbIntoRange",{target:n,edge:f?"topleft":"topright",orientation:"vertical",position:l},e.getEventHolder()):u>o.top+e.height()&&Q("thumbIntoRange",{target:n,edge:f?"bottomleft":"bottomright",orientation:"vertical",position:l},e.getEventHolder()),t.thumb.setHidden(n,!1),t.thumb.updateComputedYPosition(n,l)):(c(e,u-o.top)&&(i.y<0?Q("thumbOutOfRange",{target:n,edge:f?"topleft":"topright",orientation:"vertical"},e.getEventHolder()):i.y>e.height()&&Q("thumbOutOfRange",{target:n,edge:f?"bottomleft":"bottomright",orientation:"vertical"},e.getEventHolder())),t.thumb.setHidden(n,!0)),st.set(n,l)}}function Q(t,e,i){var o=new CustomEvent(t,{detail:e});i.dispatchEvent(o)}function Z(t){return t.classList.contains("top")}function K(t){return t.classList.contains("left")}function $(t){return-1!==t.showThumbs.indexOf("b")||-1!==t.showThumbs.indexOf("t")}function tt(t){return-1!==t.showThumbs.indexOf("l")||-1!==t.showThumbs.indexOf("r")}var et,it,ot=[],nt=[],rt=O.axis,at=C.xy,st=new Map;e.hooks.processOptions.push(function(t){t.getOptions().cursors.forEach(function(e){t.addCursor(e)})}),e.hooks.processOffset.push(function(t,e){ht(ot,t,e)}),e.getCursors=function(){return ot},e.addCursor=function(t){var i=s(t);n(e,i,i.position,rt),ot.push(i),e.triggerRedrawOverlay()},e.removeCursor=function(t){var i=ot.indexOf(t);-1!==i&&(t.thumbs.forEach(function(t){T("thumbWillBeRemoved",{current:t}),it.removeChild(t),st.delete(t)}),ot.splice(i,1)),e.triggerRedrawOverlay()},e.setCursor=function(t,o){var r=ot.indexOf(t);-1!==r&&(l(t,o),i(o,ot[r]),n(e,ot[r],ot[r].position),t._createThumbs?(e.setupGrid(),e.draw()):e.triggerRedrawOverlay())},e.getIntersections=function(t){var e=ot.indexOf(t);return-1!==e?ot[e].intersections:[]},e.formatCursorPosition=x,e.setPlotPositionConstrain=function(t){if("function"!=typeof t)throw new Error("plot position constrain should be a function");et=t};var ht=function(t,e,i){var o,n,r,a,s=["left","right","top","bottom"],h=[],l=0,u=2*E.thumbRadius;h=s.map(function(i,a){return o=t.some(function(t){return-1!==t.showThumbs.indexOf(i[0])}),r=a>1?e.getXAxes():e.getYAxes(),n=r.some(function(t){return t.options.position===i}),o&&!n?u:0});for(a in i)i[a]+=h[l++]},lt=function(t){var e;return t.forEach(function(t){t.selected&&(e||(e=t))}),e},ut=function(t){return t.filter(function(t){return t.show})},dt={start:function(t){var e=G(t.detail.touches[0].pageX,t.detail.touches[0].pageY),i=_slicedToArray(e,2);V(t,i[0],i[1],t.detail.touches[0].pageX,t.detail.touches[0].pageY)},drag:function(t){var e=G(t.detail.touches[0].pageX,t.detail.touches[0].pageY),i=_slicedToArray(e,2);Y(t,i[0],i[1],t.detail.touches[0].pageX,t.detail.touches[0].pageY)},end:function(t){F(t)}},ct={start:function(t){var e=G(t.detail.touches[0].pageX,t.detail.touches[0].pageY),i=_slicedToArray(e,2);V(t,i[0],i[1],t.detail.touches[0].pageX,t.detail.touches[0].pageY)},drag:function(t){var e=G(t.detail.touches[0].pageX,t.detail.touches[0].pageY),i=_slicedToArray(e,2);Y(t,i[0],i[1],t.detail.touches[0].pageX,t.detail.touches[0].pageY)},end:function(t){F(t)}},ft={start:function(t){D(t)},drag:function(t){var e=G(t.pageX,t.pageY),i=_slicedToArray(e,2);B(t,i[0],i[1])},end:function(t){F(t)}},pt={start:function(e){var i=t.plot.browser.getPageXY(e),o=G(i.X,i.Y),n=_slicedToArray(o,2);V(e,n[0],n[1],i.X,i.Y)},drag:function(e){var i=t.plot.browser.getPageXY(e),o=G(i.X,i.Y),n=_slicedToArray(o,2);Y(e,n[0],n[1],i.X,i.Y)},mouseover:function(e){var i=t.plot.browser.getPageXY(e),o=G(i.X,i.Y),n=_slicedToArray(o,2);X(e,n[0],n[1],i.X,i.Y)},end:function(e){var i=t.plot.browser.getPageXY(e),o=G(i.X,i.Y),n=_slicedToArray(o,2);F(e,n[0],n[1],i.X,i.Y)}};e.hooks.bindEvents.push(function(t,e){e[0].addEventListener("panstart",dt.start,!1),e[0].addEventListener("pandrag",dt.drag,!1),e[0].addEventListener("panend",dt.end,!1),e[0].addEventListener("pinchstart",ct.start,!1),e[0].addEventListener("pinchdrag",ct.drag,!1),e[0].addEventListener("pinchend",ct.end,!1),t.getPlaceholder().bind("plotpan",M),t.getPlaceholder().bind("plotzoom",M),e[0].addEventListener("thumbmovestart",ft.start,!1),e[0].addEventListener("thumbmove",ft.drag,!1),e[0].addEventListener("thumbmoveend",ft.end,!1),t.addEventHandler("dragstart",pt.start,e,10),t.addEventHandler("drag",pt.drag,e,10),t.addEventHandler("dragend",pt.end,e,10),e.bind("mousemove",pt.mouseover)}),e.hooks.processRawData.push(function(t,e,i,o){e.historyBuffer&&(z(),at=C.x)}),e.hooks.drawOverlay.push(function(t,e){var i=function(t){return void 0!==t.relativeX&&void 0!==t.relativeY};nt=[],ot.forEach(function(s){var h;if(o(t,s),n(t,s,s.position),i(s.mousePosition)||(s.mousePosition.relativeX=s.x/t.width(),s.mousePosition.relativeY=s.y/t.height()),h=I(t,s),r(t,s,h),s.intersections=h,h.target=s,nt.push(h),s.show){var l=t.getPlotOffset();e.save(),e.translate(l.left,l.top),a(t,e,s),_(t,e,s),p(t,e,s),m(t,e,s),w(t,e,s),"none"!==s.symbol&&k(t,e,s),e.restore(),"none"!==s.showThumbs?0===s.thumbs.length||s._createThumbs?(U(s,t,l),s._createThumbs=!1):s.thumbmove||(J(t,s,l),S(s,!0)):(q(s),S(s,!1))}else q(s),S(s,!1)}),nt.length>0&&t.getPlaceholder().trigger("cursorupdates",[nt])}),e.hooks.resize.push(function(e,i,o){ot.forEach(function(n){var r=e.getPlotOffset(),a=0,s=n.thumbs[0];if($(n)&&s&&(a=1,-1!==n.showThumbs.indexOf("b"))){var h=o-r.bottom+E.thumbRadius;t.thumb.updateComputedYPosition(s,h)}var l=n.thumbs[a];if(tt(n)&&l&&-1!==n.showThumbs.indexOf("r")){var u=i-r.right+E.thumbRadius;t.thumb.updateComputedXPosition(l,u)}})}),e.hooks.shutdown.push(function(e,i){i[0].removeEventListener("panstart",dt.start),i[0].removeEventListener("pandrag",dt.drag),i[0].removeEventListener("panend",dt.end),i[0].removeEventListener("pinchstart",ct.start),i[0].removeEventListener("pinchdrag",ct.drag),i[0].removeEventListener("pinchend",ct.end),i[0].removeEventListener("thumbmovestart",ft.start),i[0].removeEventListener("thumbmove",ft.drag),i[0].removeEventListener("thumbmoveend",ft.end),i.unbind("dragstart",pt.start),i.unbind("drag",pt.drag),i.unbind("dragend",pt.end),i.unbind("mousemove",pt.mouseover),i.unbind("cursorupdates");var o=e.getPlaceholder();o.unbind("plotpan",M),o.unbind("plotzoom",M),o.css("cursor","default"),o.find(".flot-thumbs")[0]&&t.thumb.shutdown(o.find(".flot-thumbs")[0].firstChild),ot=[],st.clear(),nt=[]})}function i(t,e){return Object.keys(t).forEach(function(i){e[i]=t[i]}),e}function o(t,e){var i=b(t,e),o=y(t,e),n=e.position;void 0!==n.x&&void 0!==n.y||!i.c2p||!o.c2p||0===i.min&&1===i.max&&0===o.min&&1===o.max||(n.x=i.c2p(n.relativeX*t.width()),n.y=o.c2p(n.relativeY*t.height())),(void 0===n.relativeX||void 0===n.relativeY)&&i.p2c&&o.p2c&&void 0!==n.x&&void 0!==n.y&&(n.relativeX=i.p2c(n.x)/t.width(),n.relativeY=o.p2c(n.y)/t.height())}function n(t,e,i){var o,n,r=b(t,e),a=y(t,e);o=void 0!==i.x&&r.p2c?r.p2c(i.x):i.relativeX*t.width(),n=void 0!==i.y&&a.p2c?a.p2c(i.y):i.relativeY*t.height(),e.x=o,e.y=n}function r(t,e,i){if(e.snapToPlot>=-1){var o=i.points[0];if(o){var r=t.getData()[o.seriesIndex],a=r.xaxis.p2c(o.x)/t.width(),s=r.yaxis.p2c(o.y)/t.height();n(t,e,{x:o.x,y:o.y}),e.position.x=o.x,e.position.y=o.y,e.position.relativeX=a,e.position.relativeY=s,i.x=o.x,i.y=o.y}}}function a(t,e,i){var o=t.width(),n=t.height(),r=i.y,a=i.x,s=0,l=0,u=h(i),d=Number(i.fontSize.substring(0,i.fontSize.length-2));if(e.font=i.fontStyle+" "+i.fontWeight+" "+i.fontSize+" "+i.fontFamily,i.showLabel&&(s=Math.max(s,e.measureText(i.name).width)),i.showValues){var c=x(t,i),f=c.xTextValue+", "+c.yTextValue;s=Math.max(s,e.measureText(f).width)}"right"===i.halign&&a+s>.95*o?i.halign="left":"left"===i.halign&&a-s<.05*o&&(i.halign="right"),l=u*(d+E.labelPadding),"below"===i.valign&&r+l>.95*n?i.valign="above":"above"===i.valign&&r-l<.05*n&&(i.valign="below")}function s(t,e,i,o){var n="left",r=Number(e.fontSize.substring(0,e.fontSize.length-2)),a=e.y,s=e.x;return"left"===e.halign?(s-=E.labelPadding,n="right"):s+=E.labelPadding,"above"===e.valign?a-=E.labelPadding*(o-i)+r*(o-1-i):a+=E.labelPadding*(i+1)+r*(i+1),{x:s,y:a,textAlign:n}}function h(t){return(t.showLabel?1:0)+(t.showValues?1:0)}function l(t){return 0}function u(t){return t.showLabel?1:0}function d(t,e){return e>=0&&Math.round(e)<=t.width()}function c(t,e){return e>=0&&Math.round(e)<=t.height()}function f(t,e){return d(t,e.x)&&c(t,e.y)}function p(t,e,i){if(i.showLabel&&f(t,i)){e.beginPath();var o=s(t,i,l(i),h(i));e.fillStyle=i.color,e.textAlign=o.textAlign,e.font=i.fontStyle+" "+i.fontWeight+" "+i.fontSize+" "+i.fontFamily,e.fillText(i.name,o.x,o.y),e.textAlign="left",e.stroke()}}function g(t,e,i,o,n,r,a,s,h){var l,u=Number(s.substring(0,s.length-2));switch(n){case"left":l=t.measureText(e).width,i=i-l-E.iRectSize;break;case"bottom-left":l=t.measureText(e).width,i=i-l-E.iRectSize,o+=u;break;case"top-left":l=t.measureText(e).width,i=i-l-E.iRectSize,o-=E.iRectSize;break;case"top-right":i+=E.iRectSize,o-=E.iRectSize;break;case"right":i+=E.iRectSize;break;case"bottom-right":default:i+=E.iRectSize,o+=u}t.textBaseline="middle",t.font=r+" "+a+" "+s+" "+h,t.fillText(e,i,o)}function m(t,e,i){if(i.showIntersections&&T(i)){if(e.beginPath(),void 0===i.intersections)return;i.intersections.points.forEach(function(o,n){if("object"!==_typeof(i.showIntersections)||-1!==i.showIntersections.indexOf(n)){var r=t.p2c(o);e.fillStyle=i.intersectionColor,e.fillRect(Math.floor(r.left)-E.iRectSize/2,Math.floor(r.top)-E.iRectSize/2,E.iRectSize,E.iRectSize);var a;a="function"==typeof i.formatIntersectionData?i.formatIntersectionData(o):o.y.toFixed(2),g(e,a,r.left,r.top,i.intersectionLabelPosition,i.fontStyle,i.fontWeight,i.fontSize,i.fontFamily)}}),e.stroke()}}function v(t,e,i){var o="x"===e.direction?i+1:i-1,n=e.c2p(i),r=e.c2p(o);return t.computeValuePrecision(n,r,e.direction,1)}function b(t,e){var i=t.getData(),o=t.getXAxes(),n=e.defaultxaxis-1;if(e.snapToPlot>=-1){if(e.intersections&&e.intersections.points[0]){var r=i[e.intersections.points[0].seriesIndex];return r?r.xaxis:o[n]}return o[n]}return o[n]}function y(t,e){var i=t.getData(),o=t.getYAxes(),n=e.defaultyaxis-1;if(e.snapToPlot>=-1){if(e.intersections&&e.intersections.points[0]){var r=i[e.intersections.points[0].seriesIndex];return r?r.yaxis:o[n]}return o[n]}return o[n]}function x(t,e){var i=b(t,e),o=y(t,e),n=v(t,i,e.x),r=i.tickFormatter(i.c2p(e.x),i,n,t),a=v(t,o,e.y),s=o.tickFormatter(o.c2p(e.y),o,a,t);return r=r.replace("<br>"," "),r=r.replace("&nbsp;"," "),s=s.replace("<br>"," "),s=s.replace("&nbsp;"," "),{xTextValue:r,yTextValue:s}}function w(t,e,i){if(i.showValues&&f(t,i)){var o=x(t,i),n=o.xTextValue+", "+o.yTextValue,r=s(t,i,u(i),h(i));e.fillStyle=i.color,e.textAlign=r.textAlign,e.font=i.fontStyle+" "+i.fontWeight+" "+i.fontSize+" "+i.fontFamily,e.fillText(n,r.x,r.y)}}function _(t,e,i){if(0!==i.lineWidth){var o=i.lineWidth%2?.5:0;if(e.strokeStyle=i.color,e.lineWidth=i.lineWidth,e.lineJoin="round",e.beginPath(),e.setLineDash(i.dashes),-1!==i.mode.indexOf("x")&&d(t,i.x)){var n=Math.floor(i.x)+o;e.moveTo(n,Math.min(t.height(),Math.max(0,i.y-i.symbolSize/2))),e.lineTo(n,0),e.moveTo(n,Math.min(t.height(),Math.max(0,i.y+i.symbolSize/2))),e.lineTo(n,t.height())}if(-1!==i.mode.indexOf("y")&&c(t,i.y)){var r=Math.floor(i.y)+o;e.moveTo(Math.min(t.width(),Math.max(0,i.x-i.symbolSize/2)),r),e.lineTo(0,r),e.moveTo(Math.min(t.width(),Math.max(0,i.x+i.symbolSize/2)),r),e.lineTo(t.width(),r)}e.stroke(),e.setLineDash([])}}function k(t,e,i){if(f(t,i)){var o=i.lineWidth%2?.5:0;e.beginPath(),i.highlighted?e.strokeStyle="orange":e.strokeStyle=i.color,i.symbol&&t.drawSymbol&&t.drawSymbol[i.symbol]?(e.fillStyle=i.color,t.drawSymbol[i.symbol](e,Math.floor(i.x)+o,Math.floor(i.y)+o,i.symbolSize/2,0)):e.fillRect(Math.floor(i.x)+o-i.symbolSize/2,Math.floor(i.y)+o-i.symbolSize/2,i.symbolSize,i.symbolSize),e.stroke()}}function T(t){return-1!==t.mode.indexOf("x")}function S(t){return-1!==t.mode.indexOf("y")}function R(t,e,i,o){var n=i.offset(),r=Math.max(0,Math.min(t-n.left,i.width())),a=Math.max(0,Math.min(e-n.top,i.height())),s=o.symbolSize+E.mouseGrabMargin;return r>o.x-s&&r<o.x+s&&a>o.y-s&&a<o.y+s&&"none"!==o.symbol}function L(t,e,i,o){var n=i.offset(),r=Math.max(0,Math.min(t-n.left,i.width())),a=Math.max(0,Math.min(e-n.top,i.height()));return T(o)&&r>o.x-E.mouseGrabMargin&&r<o.x+E.mouseGrabMargin&&a>0&&a<i.height()}function P(t,e,i,o){var n=i.offset(),r=Math.max(0,Math.min(t-n.left,i.width())),a=Math.max(0,Math.min(e-n.top,i.height()));return S(o)&&a>o.y-E.mouseGrabMargin&&a<o.y+E.mouseGrabMargin&&r>0&&r<i.width()}var z={cursors:[]},E={iRectSize:8,mouseGrabMargin:12,textHeight:10,labelPadding:10,thumbRadius:17},O=Object.freeze({axis:0,relative:1}),C=Object.freeze({xy:0,x:1}),A=Object.freeze({t:"top",b:"bottom",l:"left",r:"right"});t.plot.plugins.push({init:e,options:z,name:"cursors",version:"0.2"})}(jQuery),function(t){function e(e){function i(){return{position:.5,absolutePosition:void 0,show:!0,orientation:"vertical",location:"far",axisIndex:0,radius:o,handleLabel:M.length.toString(),handleClassList:["draggable"],fill:void 0,horizontalHandleConstrain:void 0,verticalHandleConstrain:void 0,positionInPixel:void 0,selected:!1,thumbmove:!1,thumb:void 0}}function a(t){"vertical"!==t.orientation&&"horizontal"!==t.orientation&&(console.log("orientation is invalid. it will be coerced to vertical"),t.orientation="vertical");var i="vertical"===t.orientation?e.getYAxes():e.getXAxes();(t.axisIndex<0||t.axisIndex>i.length-1)&&(console.log("axisIndex is invalid. it will be coerced to 0"),t.axisIndex=0)}function s(t,e,i){var o=t.filter(function(t){return"far"===t.location}),r={},a=e.getXAxes(),s=e.getYAxes();o.forEach(function(t){S(t)?r[n[a[t.axisIndex].options.position]]=2*t.radius:r[n[s[t.axisIndex].options.position]]=2*t.radius}),Object.keys(r).forEach(function(t){i[t]+=Math.max(0,r[t]-i[t])})}function h(t){var e=t.filter(function(t){return t.selected});return e.length>0?e[0]:void 0}function l(t){return t.filter(function(t){return t.show})}function u(t){return 0===t.button||t.touches}function d(t,i){var o=L(e,i);Number.isNaN(t.x)&&(t.x=0),Number.isNaN(t.y)&&(t.y=0);var n=o.options,a=t[o.direction],s=B.previousDelta[o.direction]-t[o.direction];if(0!==a){var h=r.saturate(o.c2p(o.p2c(o.min)-s)-o.c2p(o.p2c(o.min))),l=r.saturate(o.c2p(o.p2c(o.max)-s)-o.c2p(o.p2c(o.max)));isFinite(h)||(h=0),isFinite(l)||(l=0),n.offset={below:r.saturate(h+(n.offset.below||0)),above:r.saturate(l+(n.offset.above||0))}}B.previousDelta=t,e.setupGrid(!0),e.draw(),e.getPlaceholder().trigger("axisHandlePan",[t,o,B,i])}function c(t,i){if(A)return A(t,i);var o=e.offset();return[Math.max(0,Math.min(t-o.left,e.width())),Math.max(0,Math.min(i-o.top,e.height()))]}function f(t){function i(t){var e=t,i=t.getAttribute("class");return i.includes("interactionLayer")&&(e=t.parentNode,i=e.getAttribute("class")),i.includes("thumb")?e:null}if(u(t.detail)){var o=c(t.pageX,t.pageY),n=_slicedToArray(o,2);B.startX=n[0],B.startY=n[1];if(!h(M)){var r=l(M).find(function(e){return e.thumb===i(t.detail.target)});r.selected=!0,r.thumbmove=!0,t.stopImmediatePropagation(),t.preventDefault(),e.getPlaceholder().trigger("axisHandlePanStart",[r])}}}function p(t){if(!O){var i=h(M);if(i){var o=c(t.pageX,t.pageY),n=_slicedToArray(o,2),r=n[0],a=n[1];O=window.requestAnimationFrame(function(){d({x:B.startX-r,y:B.startY-a},i),O=void 0});var s=i.positionInPixel+(S(i)?e.getPlotOffset().left:e.getPlotOffset().top);N.set(t.selectedThumb,s),t.stopImmediatePropagation(),t.preventDefault()}}}function g(t){O&&(window.cancelAnimationFrame(O),O=void 0);var i=h(M);i&&(B.previousDelta={x:0,y:0},i.selected=!1,i.thumbmove=!1,y(i,e.getPlotOffset()),e.triggerRedrawOverlay(),t.stopImmediatePropagation(),t.preventDefault(),e.getPlaceholder().trigger("axisHandlePanEnd",[i]))}function m(e,i,o){C=t.thumb.createSVGLayer(i.getPlaceholder(),i.getEventHolder());var n,r,a,s,h={size:e.radius,svgRoot:C,abbreviation:e.handleLabel,classList:e.handleClassList.slice(),fill:e.fill};S(e)?(r=e.positionInPixel+o.left,a="near"===e.location?i.height()+o.top+e.radius:o.top-e.radius,s=e.horizontalHandleConstrain?e.horizontalHandleConstrain:function(t,e,o,n){var r=i.offset().left;return[Math.max(r,Math.min(t,i.width()+r)),n]},h.shape="near"===e.location?"bottom":"top",h.x=r,h.y=a,h.constraintFunction=s,n=t.thumb.createThumb(h),N.set(n,r)):(r="near"===e.location?o.left-e.radius:o.left+i.width()+e.radius,a=e.positionInPixel+o.top,s=e.verticalHandleConstrain?e.verticalHandleConstrain:function(t,e,o,n){var r=i.offset();return[o,Math.max(r.top,Math.min(e,i.height()+r.top))]},h.shape="near"===e.location?"left":"right",h.x=r,h.y=a,h.constraintFunction=s,n=t.thumb.createThumb(h),N.set(n,a)),e.thumb=n,T("thumbCreated",{current:n})}function v(t){var i=Math.round(t);return i>=0&&i<=e.width()}function b(t){var i=Math.round(t);return i>=0&&i<=e.height()}function y(i,o){var n;if(S(i)){n=i.thumb;var r=i.positionInPixel+o.left,a=N.get(n),s=w(n);v(i.positionInPixel)?(a<o.left?k("thumbIntoRange",{target:n,edge:s?"topleft":"bottomleft",orientation:"horizontal",position:r},e.getEventHolder()):a>o.left+e.width()&&k("thumbIntoRange",{target:n,edge:s?"topright":"bottomright",orientation:"horizontal",position:r},e.getEventHolder()),t.thumb.setHidden(n,!1),t.thumb.updateComputedXPosition(n,r)):(v(a-o.left)&&r<o.left?k("thumbOutOfRange",{target:n,edge:s?"topleft":"bottomleft",orientation:"horizontal"},e.getEventHolder()):v(a-o.left)&&r>e.width()+o.left&&k("thumbOutOfRange",{target:n,edge:s?"topright":"bottomright",orientation:"horizontal"},e.getEventHolder()),t.thumb.setHidden(n,!0)),N.set(n,r)}else{n=i.thumb;var h=i.positionInPixel+o.top,l=N.get(n),u=_(n);b(i.positionInPixel)?(l<o.top?k("thumbIntoRange",{target:n,edge:u?"topleft":"topright",orientation:"vertical",position:h},e.getEventHolder()):l>o.top+e.height()&&k("thumbIntoRange",{target:n,edge:u?"bottomleft":"bottomright",orientation:"vertical",position:h},e.getEventHolder()),t.thumb.setHidden(n,!1),t.thumb.updateComputedYPosition(n,h)):(b(l-o.top)&&(h<o.top?k("thumbOutOfRange",{target:n,edge:u?"topleft":"topright",orientation:"vertical"},e.getEventHolder()):h>e.height()+o.top&&k("thumbOutOfRange",{target:n,edge:u?"bottomleft":"bottomright",orientation:"vertical"},e.getEventHolder())),t.thumb.setHidden(n,!0)),N.set(n,h)}}function x(e,i,o,n){if(e.thumb){var r=i.getPlotOffset();if(S(e)){var a="near"===e.location?n-r.bottom+e.radius:r.top-e.radius;t.thumb.updateComputedYPosition(e.thumb,a)}else{var s="near"===e.location?r.left-e.radius:o-r.right+e.radius;t.thumb.updateComputedXPosition(e.thumb,s)}}}function w(t){return"top"===t.shape}function _(t){return"left"===t.shape}function k(t,e,i){var o=new CustomEvent(t,{detail:e});i.dispatchEvent(o)}function T(t,i){var o=new CustomEvent(t,{detail:i});e.getPlaceholder()[0].dispatchEvent(o)}function S(t){return"horizontal"===t.orientation}function R(t,e){var i=L(t,e),o=S(e)?t.width():t.height();if(isFinite(e.absolutePosition)&&i.p2c)return e.positionInPixel=i.p2c(e.absolutePosition),void(e.position=e.positionInPixel/o);e.positionInPixel=void 0!==e.position?e.position*o:void 0,!isFinite(e.absolutePosition)&&isFinite(e.positionInPixel)&&i.c2p&&(e.absolutePosition=i.c2p(e.positionInPixel))}function L(t,e){return S(e)?t.getXAxes()[e.axisIndex]:t.getYAxes()[e.axisIndex]}function P(t,e){return t.filter(function(t){return!e.includes(t)})}function z(t,i){var o=Object.keys(t),n=P(o,I),r=!1,a=isFinite(t.absolutePosition),s=isFinite(t.position)||t.orientation;if(!a&&s&&(i.absolutePosition=void 0),n.forEach(function(e){!r&&H.includes(e)&&i[e]!==t[e]&&(r=!0),"show"===e&&i[e]!==t[e]&&(i.triggerThumbVisibilityChanged=!0),i[e]=t[e]}),i.thumb)if(i.thumb.classList.toggle("draggable",i.handleClassList.includes("draggable")),r)T("thumbWillBeRemoved",{current:i.thumb}),N.delete(i.thumb),C.removeChild(i.thumb),i.thumb=null,e.setupGrid(),e.draw();else{var h=i.thumb.getElementsByClassName("thumbLabel")[0];h.textContent=i.handleLabel;var l=i.thumb.getElementsByClassName("thumbIcon")[0];l.style.fill=i.fill}return i}function E(t){t.triggerThumbVisibilityChanged&&T("thumbVisibilityChanged",{current:t.thumb,visible:t.show})}var O,C,A,M=[],I=["positionInPixel","selected","thumbmove","thumb"],H=["orientation","location","radius"],N=new Map,D={start:function(t){f(t)},drag:function(t){p(t)},end:function(t){g(t)}},B={startX:void 0,startY:void 0,previousDelta:{x:0,y:0}};e.getAxisHandles=function(){return M},e.addAxisHandle=function(t){var o=z(t,i());a(o),R(e,o),M.push(o),e.triggerRedrawOverlay()},e.removeAxisHandle=function(t){var i=M.indexOf(t);-1!==i&&(t.thumb&&(T("thumbWillBeRemoved",{current:t.thumb}),C.removeChild(t.thumb),N.delete(t.thumb),t.thumb=null),M.splice(i,1)),e.triggerRedrawOverlay()},e.setAxisHandle=function(t,i){var o=M.indexOf(t);-1!==o&&(z(i,M[o]),a(M[o]),R(e,M[o]),e.triggerRedrawOverlay())},e.setAxisHandlePlotPositionConstrain=function(t){if("function"!=typeof t)throw new Error("constrain should be a function");A=t},e.hooks.processOptions.push(function(t){t.getOptions().axisHandles.forEach(function(e){t.addAxisHandle(e)})}),e.hooks.processOffset.push(function(t,e){s(M,t,e)}),e.hooks.drawOverlay.push(function(e,i){var o=e.getPlotOffset();M.forEach(function(i){R(e,i),i.show?i.thumb?i.thumbmove||(y(i,o),E(i)):m(i,e,o):i.thumb&&(t.thumb.setHidden(i.thumb,!0),E(i))}),e.getPlaceholder().trigger("axisHandleUpdates",[M])}),e.hooks.resize.push(function(t,e,i){M.forEach(function(o){x(o,t,e,i)})}),e.hooks.bindEvents.push(function(t,e){e[0].addEventListener("thumbmovestart",D.start,!1),e[0].addEventListener("thumbmove",D.drag,!1),e[0].addEventListener("thumbmoveend",D.end,!1)}),e.hooks.shutdown.push(function(e,i){i[0].removeEventListener("thumbmovestart",D.start),i[0].removeEventListener("thumbmove",D.drag),i[0].removeEventListener("thumbmoveend",D.end),C=void 0,M=[],N.clear();var o=e.getPlaceholder();o.find(".flot-thumbs")[0]&&t.thumb.shutdown(o.find(".flot-thumbs")[0].firstChild)})}var i={axisHandles:[]},o=17,n=Object.freeze({left:"right",right:"left",bottom:"top",top:"bottom"}),r=t.plot.saturated;t.plot.plugins.push({init:e,options:i,name:"axis-handle",version:"2.0.3"})}(jQuery),function(t){function e(t){var e;t.hooks.processOptions.push(function(t){t.getOptions().parkingLot&&(e=new n(t,{offset:t.getOptions().parkingLot.offset,show:t.getOptions().parkingLot.show}))}),t.hooks.processOffset.push(function(t,i){if(e&&e._show){var o=e.reserveSpace();Object.keys(i).forEach(function(t){i[t]+=o[t]})}}),t.hooks.drawOverlay.push(function(t,i){e&&e.render(t)}),t.hooks.bindEvents.push(function(t,i){e&&e.bindEvents(t)}),t.hooks.shutdown.push(function(t,i){e&&e.dispose(t)}),t.getParkingLot=function(){return e}}var i=function(t){function e(){var t,i;_classCallCheck(this,e);for(var o=arguments.length,n=new Array(o),r=0;r<o;r++)n[r]=arguments[r];return i=_possibleConstructorReturn(this,(t=_getPrototypeOf(e)).call.apply(t,[this].concat(n))),i.setChangedListeners=[],i}return _inherits(e,t),_createClass(e,[{key:"add",value:function(t){var i=this.size,o=_get(_getPrototypeOf(e.prototype),"add",this).call(this,t);return this.size!==i&&this.onSetChanged("add"),o}},{key:"delete",value:function(t){var i=_get(_getPrototypeOf(e.prototype),"delete",this).call(this,t);return i&&this.onSetChanged("remove"),i}},{key:"clear",value:function(){var t=this.size;_get(_getPrototypeOf(e.prototype),"clear",this).call(this),t>0&&this.onSetChanged("reset")}},{key:"onSetChanged",value:function(t){if(void 0!==this.setChangedListeners){this.setChangedListeners.slice().forEach(function(e){e(t)})}}},{key:"addSetChangedListener",value:function(t){if("function"!=typeof t)throw new Error("listener is not a callable object");this.setChangedListeners.push(t)}},{key:"removeSetChangedListener",value:function(t){var e=this.setChangedListeners.findIndex(t);-1!==e&&this.setChangedListeners.splice(e,1)}}],[{key:Symbol.species,get:function(){return Set}}]),e}(_wrapNativeSuper(Set)),o=Object.freeze({topLeft:"topleft",topRight:"topright",bottomLeft:"bottomleft",bottomRight:"bottomright"}),n=function(){function e(t,i){_classCallCheck(this,e),this._offset=i.offset||35,this._thumbRadius=i.thumbRadius||17,this._show=!1!==i.show,this._initialize(t)}return _createClass(e,[{key:"_initialize",value:function(t){this.thumbs=new Set;var e=function(e){"reset"!==e&&t.triggerRedrawOverlay()};this.topLeftHorizontalDocker=new i,this.topLeftHorizontalDocker.addSetChangedListener(e),this.topLeftVerticalDocker=new i,this.topLeftVerticalDocker.addSetChangedListener(e),this.topRightHorizontalDocker=new i,this.topRightHorizontalDocker.addSetChangedListener(e),this.topRightVerticalDocker=new i,this.topRightVerticalDocker.addSetChangedListener(e),this.bottomRightHorizontalDocker=new i,this.bottomRightHorizontalDocker.addSetChangedListener(e),this.bottomRightVerticalDocker=new i,this.bottomRightVerticalDocker.addSetChangedListener(e),this.bottomLeftHorizontalDocker=new i,this.bottomLeftHorizontalDocker.addSetChangedListener(e),this.bottomLeftVerticalDocker=new i,this.bottomLeftVerticalDocker.addSetChangedListener(e),this._attachConstrains(t),this._onThumbMoveStart=this._onThumbMoveStart.bind(this),this._onThumbCreated=this._onThumbCreated.bind(this,t),this._onThumbWillBeRemoved=this._onThumbWillBeRemoved.bind(this,t),this._onThumbVisibilityChanged=this._onThumbVisibilityChanged.bind(this,t),this._onThumbIntoRange=this._onThumbIntoRange.bind(this,t),this._onThumbOutOfRange=this._onThumbOutOfRange.bind(this)}},{key:"dispose",value:function(t){this.topLeftHorizontalDocker.clear(),this.bottomLeftHorizontalDocker.clear(),this.topRightHorizontalDocker.clear(),this.bottomRightHorizontalDocker.clear(),this.topLeftVerticalDocker.clear(),this.bottomLeftVerticalDocker.clear(),this.topRightVerticalDocker.clear(),this.bottomRightVerticalDocker.clear(),this._unbindEvents(t)}},{key:"reserveSpace",value:function(){var t=this;return["left","right","bottom","top"].reduce(function(e,i){return e[i]=t._offset,e},{})}},{key:"_createThumbConstrain",value:function(e){var i=this;return{horizontal:function(o,n,r,a,s,h){var l=i.thumbMoveState.selectedElement,u=e.getPlotOffset(),d=!1;if(i.thumbMoveState.inParkingLot){var c=e.offset();if(s>=c.left&&s<=c.left+e.width()){t.thumb.setHidden(l,!1);var f={target:l,edge:i.thumbMoveState.parkingLotLocation,orientation:"horizontal",position:s-c.left+u.left};i.thumbMoveState.axisHandle&&(f.axisHandle=i.thumbMoveState.axisHandle),i._dispatchThumbEvent("thumbIntoRange",f,e.getEventHolder()),d=!0,i.thumbMoveState.inParkingLot=!1}}else{var p=i._willHorizontalThumbBeMovedOffGraph(l,s,e),g=_slicedToArray(p,2);i.thumbMoveState.inParkingLot=g[0],i.thumbMoveState.parkingLotLocation=g[1]}return[o,a,d]},vertical:function(o,n,r,a,s,h){var l=i.thumbMoveState.selectedElement,u=e.getPlotOffset(),d=!1;if(i.thumbMoveState.inParkingLot){var c=e.offset();if(h>=c.top&&h<=c.top+e.height()){t.thumb.setHidden(l,!1);var f={target:l,edge:i.thumbMoveState.parkingLotLocation,orientation:"vertical",position:h-c.top+u.top};i.thumbMoveState.axisHandle&&(f.axisHandle=i.thumbMoveState.axisHandle),i._dispatchThumbEvent("thumbIntoRange",f,e.getEventHolder()),d=!0,i.thumbMoveState.inParkingLot=!1}}else{var p=i._willVerticalThumbBeMovedOffGraph(l,h,e),g=_slicedToArray(p,2);i.thumbMoveState.inParkingLot=g[0],i.thumbMoveState.parkingLotLocation=g[1]}return[r,n,d]}}}},{key:"_createAxisHandleThumbConstrain",value:function(t,e){var i=this;return{horizontal:function(){return i.thumbMoveState.axisHandle=e,t.horizontal.apply(t,arguments)},vertical:function(){return i.thumbMoveState.axisHandle=e,t.vertical.apply(t,arguments)}}}},{key:"_willVerticalThumbBeMovedOffGraph",value:function(e,i,n){var r,a=n.offset(),s=!1;return i<a.top?(r="left"===e.shape?o.topLeft:o.topRight,s=!0):i>a.top+n.height()&&(r="left"===e.shape?o.bottomLeft:o.bottomRight,s=!0),s&&(t.thumb.setHidden(e,!0),this._dispatchThumbEvent("thumbOutOfRange",{target:e,edge:r,orientation:"vertical"},n.getEventHolder())),[s,r]}},{key:"_willHorizontalThumbBeMovedOffGraph",value:function(e,i,n){var r,a=n.offset(),s=!1;return i<a.left?(r="top"===e.shape?o.topLeft:o.bottomLeft,s=!0):i>a.left+n.width()&&(r="top"===e.shape?o.topRight:o.bottomRight,s=!0),s&&(t.thumb.setHidden(e,!0),this._dispatchThumbEvent("thumbOutOfRange",{target:e,edge:r,orientation:"horizontal"},n.getEventHolder())),[s,r]}},{key:"_dispatchThumbEvent",value:function(t,e,i){var o=new CustomEvent(t,{detail:e});i.dispatchEvent(o)}},{key:"_createPlotValueConstrain",value:function(t){return function(e,i){var o=t.offset();return[Math.max(-1,Math.min(e-o.left,t.width()+1)),Math.max(-1,Math.min(i-o.top,t.height()+1))]}}},{key:"render",value:function(t){this._lazyInitializeForRender(t),this._renderDockers(t)}},{key:"_lazyInitializeForRender",value:function(e){var i=this;if(!this.svgRoot){this.svgRoot=t.thumb.createSVGLayer(e.getPlaceholder(),e.getEventHolder());var n=(new DOMParser).parseFromString('<defs xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">\n                        <symbol id="left-arrow" viewBox="0 0 40 50">\n                            <rect x="0" y="0" width="40" height="50"/>\n                            <polyline points="20,10 10,25 20,40" fill="none"/>\n                            <polyline points="10,25 30,25" fill="none"/>\n                        </symbol>\n                        <symbol id="up-arrow" viewBox="0 0 50 40">\n                            <rect x="0" y="0" width="50" height="40" />\n                            <polyline points="10,20 25,10 40,20" fill="none"/>\n                            <polyline points="25,10 25,30" fill="none"/>\n                        </symbol>\n                        <symbol id="right-arrow" viewBox="0 0 40 50">\n                            <use xlink:href="#left-arrow" x="0" y="0" width="40" height="50" transform="rotate(180,20,25)"/>\n                        </symbol>\n                        <symbol id="down-arrow" viewBox="0 0 50 40">\n                            <use xlink:href="#up-arrow" x="0" y="0" width="50" height="40" transform="rotate(180,25,20)"/>\n                        </symbol>\n                     </defs>',"image/svg+xml"),r=document.importNode(n.documentElement,!0);this.svgRoot.appendChild(r);var a=function(t,e){t.setAttributeNS("http://www.w3.org/1999/xlink","xlink:href",e),t.setAttributeNS("http://www.w3.org/1999/xlink","href",e)},s={topLeft:{horizontal:"#left-arrow",vertical:"#up-arrow"},topRight:{horizontal:"#right-arrow",vertical:"#up-arrow"},bottomLeft:{horizontal:"#left-arrow",vertical:"#down-arrow"},bottomRight:{horizontal:"#right-arrow",vertical:"#down-arrow"}};this._dockerIndicators={},this._dockerBorders={},Object.keys(o).forEach(function(t){i._dockerIndicators[t]={},i._dockerBorders[t]={},["horizontal","vertical"].forEach(function(e){
var o=document.createElementNS("http://www.w3.org/2000/svg","use");a(o,s[t][e]),"horizontal"===e?(o.setAttributeNS(null,"height","".concat(2*i._thumbRadius)),o.setAttributeNS(null,"width","".concat(2*i._thumbRadius*.8))):(o.setAttributeNS(null,"width","".concat(2*i._thumbRadius)),o.setAttributeNS(null,"height","".concat(2*i._thumbRadius*.8))),o.setAttributeNS(null,"x","0"),o.setAttributeNS(null,"y","0"),o.setAttributeNS(null,"display","none"),o.style.pointerEvents="none",o.classList.add("parkingLot-dockerArrow"),i.svgRoot.appendChild(o),i._dockerIndicators[t][e]=o;var n=document.createElementNS("http://www.w3.org/2000/svg","rect");n.setAttributeNS(null,"display","none"),n.style.pointerEvents="none",n.classList.add("parkingLot-docker"),i._dockerBorders[t][e]=n,i.svgRoot.appendChild(n)})})}}},{key:"_renderDockers",value:function(t){this._renderTopLeftHorizontalDocker(),this._renderTopLeftVerticalDocker();var e=t.getPlotOffset(),i=t.width()+e.left+e.right,o=t.height()+e.top+e.bottom;this._renderTopRightHorizontalDocker(i),this._renderTopRightVerticalDocker(i),this._renderBottomLeftHorizontalDocker(o),this._renderBottomLeftVerticalDocker(o),this._renderBottomRightHorizontalDocker(i,o),this._renderBottomRightVerticalDocker(i,o)}},{key:"_renderBottomRightVerticalDocker",value:function(e,i){var o=this;if(this._show&&this.bottomRightVerticalDocker.size>0){var n=0,r=0===this.bottomRightHorizontalDocker.size,a=r?0:2*this._thumbRadius;this.bottomRightVerticalDocker.forEach(function(r){var s="matrix(1 0 0 1 ".concat(e-o._thumbRadius," ").concat(i-(a+o._thumbRadius+2*o._thumbRadius*n++),")");r.setAttribute("transform",s),t.thumb.setHidden(r,!1)});var s=this.bottomRightVerticalDocker.size*this._thumbRadius*2;this._updateBorderAttributes(this._dockerBorders.bottomRight.vertical,e-2*this._thumbRadius,i-(s+a),2*this._thumbRadius,s),this._updateArrowPosition(this._dockerIndicators.bottomRight.vertical,e-2*this._thumbRadius,i-(s+a+2*this._thumbRadius*.8))}else this._dockerBorders.bottomRight.vertical.setAttributeNS(null,"display","none"),this._dockerIndicators.bottomRight.vertical.setAttributeNS(null,"display","none")}},{key:"_renderBottomRightHorizontalDocker",value:function(e,i){var o=this;if(this._show&&this.bottomRightHorizontalDocker.size>0){var n=0;this.bottomRightHorizontalDocker.forEach(function(r){var a="matrix(1 0 0 1 ".concat(e-o._thumbRadius-2*o._thumbRadius*n++," ").concat(i-o._thumbRadius,")");r.setAttribute("transform",a),t.thumb.setHidden(r,!1)});var r=this.bottomRightHorizontalDocker.size*this._thumbRadius*2;this._updateBorderAttributes(this._dockerBorders.bottomRight.horizontal,e-r,i-2*this._thumbRadius,r,2*this._thumbRadius),this._updateArrowPosition(this._dockerIndicators.bottomRight.horizontal,e-r-2*this._thumbRadius*.8,i-2*this._thumbRadius)}else this._dockerBorders.bottomRight.horizontal.setAttributeNS(null,"display","none"),this._dockerIndicators.bottomRight.horizontal.setAttributeNS(null,"display","none")}},{key:"_renderBottomLeftVerticalDocker",value:function(e){var i=this;if(this._show&&this.bottomLeftVerticalDocker.size>0){var o=0,n=0===this.bottomLeftHorizontalDocker.size,r=n?0:2*this._thumbRadius;this.bottomLeftVerticalDocker.forEach(function(n){var a="matrix(1 0 0 1 ".concat(i._thumbRadius," ").concat(e-(r+i._thumbRadius+2*i._thumbRadius*o++),")");n.setAttribute("transform",a),t.thumb.setHidden(n,!1)});var a=this.bottomLeftVerticalDocker.size*this._thumbRadius*2;this._updateBorderAttributes(this._dockerBorders.bottomLeft.vertical,0,e-(a+r),2*this._thumbRadius,a),this._updateArrowPosition(this._dockerIndicators.bottomLeft.vertical,0,e-(a+r+2*this._thumbRadius*.8))}else this._dockerBorders.bottomLeft.vertical.setAttributeNS(null,"display","none"),this._dockerIndicators.bottomLeft.vertical.setAttributeNS(null,"display","none")}},{key:"_renderBottomLeftHorizontalDocker",value:function(e){var i=this;if(this._show&&this.bottomLeftHorizontalDocker.size>0){var o=0;this.bottomLeftHorizontalDocker.forEach(function(n){var r="matrix(1 0 0 1 ".concat(i._thumbRadius+2*i._thumbRadius*o++," ").concat(e-i._thumbRadius,")");n.setAttribute("transform",r),t.thumb.setHidden(n,!1)}),this._updateBorderAttributes(this._dockerBorders.bottomLeft.horizontal,0,e-2*this._thumbRadius,this.bottomLeftHorizontalDocker.size*this._thumbRadius*2,2*this._thumbRadius),this._updateArrowPosition(this._dockerIndicators.bottomLeft.horizontal,this.bottomLeftHorizontalDocker.size*this._thumbRadius*2,e-2*this._thumbRadius)}else this._dockerBorders.bottomLeft.horizontal.setAttributeNS(null,"display","none"),this._dockerIndicators.bottomLeft.horizontal.setAttributeNS(null,"display","none")}},{key:"_renderTopRightVerticalDocker",value:function(e){var i=this;if(this._show&&this.topRightVerticalDocker.size>0){var o=0,n=0===this.topRightHorizontalDocker.size,r=n?0:2*this._thumbRadius;this.topRightVerticalDocker.forEach(function(n){var a="matrix(1 0 0 1 ".concat(e-i._thumbRadius," ").concat(r+i._thumbRadius+2*i._thumbRadius*o++,")");n.setAttribute("transform",a),t.thumb.setHidden(n,!1)}),this._updateBorderAttributes(this._dockerBorders.topRight.vertical,e-2*this._thumbRadius,r,2*this._thumbRadius,this.topRightVerticalDocker.size*this._thumbRadius*2),this._updateArrowPosition(this._dockerIndicators.topRight.vertical,e-2*this._thumbRadius,r+this.topRightVerticalDocker.size*this._thumbRadius*2)}else this._dockerBorders.topRight.vertical.setAttributeNS(null,"display","none"),this._dockerIndicators.topRight.vertical.setAttributeNS(null,"display","none")}},{key:"_renderTopRightHorizontalDocker",value:function(e){var i=this;if(this._show&&this.topRightHorizontalDocker.size>0){var o=0;this.topRightHorizontalDocker.forEach(function(n){var r="matrix(1 0 0 1 ".concat(e-i._thumbRadius-2*i._thumbRadius*o++," ").concat(i._thumbRadius,")");n.setAttribute("transform",r),t.thumb.setHidden(n,!1)});var n=this.topRightHorizontalDocker.size*this._thumbRadius*2;this._updateBorderAttributes(this._dockerBorders.topRight.horizontal,e-n,0,n,2*this._thumbRadius),this._updateArrowPosition(this._dockerIndicators.topRight.horizontal,e-n-2*this._thumbRadius*.8,0)}else this._dockerBorders.topRight.horizontal.setAttributeNS(null,"display","none"),this._dockerIndicators.topRight.horizontal.setAttributeNS(null,"display","none")}},{key:"_renderTopLeftVerticalDocker",value:function(){var e=this;if(this._show&&this.topLeftVerticalDocker.size>0){var i=0,o=0===this.topLeftHorizontalDocker.size,n=o?0:2*this._thumbRadius;this.topLeftVerticalDocker.forEach(function(o){var r="matrix(1 0 0 1 ".concat(e._thumbRadius," ").concat(n+e._thumbRadius+2*e._thumbRadius*i++,")");o.setAttribute("transform",r),t.thumb.setHidden(o,!1)}),this._updateBorderAttributes(this._dockerBorders.topLeft.vertical,0,n,2*this._thumbRadius,this.topLeftVerticalDocker.size*this._thumbRadius*2),this._updateArrowPosition(this._dockerIndicators.topLeft.vertical,0,this.topLeftVerticalDocker.size*this._thumbRadius*2+n)}else this._dockerBorders.topLeft.vertical.setAttributeNS(null,"display","none"),this._dockerIndicators.topLeft.vertical.setAttributeNS(null,"display","none")}},{key:"_renderTopLeftHorizontalDocker",value:function(){var e=this;if(this._show&&this.topLeftHorizontalDocker.size>0){var i=0;this.topLeftHorizontalDocker.forEach(function(o){var n="matrix(1 0 0 1 ".concat(e._thumbRadius+2*e._thumbRadius*i++," ").concat(e._thumbRadius,")");o.setAttribute("transform",n),t.thumb.setHidden(o,!1)}),this._updateBorderAttributes(this._dockerBorders.topLeft.horizontal,0,0,this.topLeftHorizontalDocker.size*this._thumbRadius*2,2*this._thumbRadius),this._updateArrowPosition(this._dockerIndicators.topLeft.horizontal,this.topLeftHorizontalDocker.size*this._thumbRadius*2,0)}else this._dockerBorders.topLeft.horizontal.setAttributeNS(null,"display","none"),this._dockerIndicators.topLeft.horizontal.setAttributeNS(null,"display","none")}},{key:"_updateBorderAttributes",value:function(t,e,i,o,n){t.setAttributeNS(null,"x",e.toString()),t.setAttributeNS(null,"y",i.toString()),t.setAttributeNS(null,"width",o.toString()),t.setAttributeNS(null,"height",n.toString()),t.setAttributeNS(null,"display","inline")}},{key:"_updateArrowPosition",value:function(t,e,i){t.setAttributeNS(null,"transform","matrix(1 0 0 1 ".concat(e," ").concat(i,")")),t.setAttributeNS(null,"display","inline")}},{key:"_attachConstrains",value:function(t){var e=this,i=this._createPlotValueConstrain(t),o=this._createThumbConstrain(t),n=t.getOptions();n.cursors&&(t.setPlotPositionConstrain(i),t.getCursors().forEach(function(t){t.horizontalThumbConstrain=o.horizontal,t.verticalThumbConstrain=o.vertical})),n.axisHandles&&(t.setAxisHandlePlotPositionConstrain(i),t.getAxisHandles().forEach(function(t){var i=e._createAxisHandleThumbConstrain(o,t);t.horizontalHandleConstrain=i.horizontal,t.verticalHandleConstrain=i.vertical}))}},{key:"bindEvents",value:function(t){var e=t.getEventHolder();e.addEventListener("thumbIntoRange",this._onThumbIntoRange,!1),e.addEventListener("thumbOutOfRange",this._onThumbOutOfRange,!1);var i=t.getPlaceholder()[0];i.addEventListener("thumbCreated",this._onThumbCreated,!1),i.addEventListener("thumbWillBeRemoved",this._onThumbWillBeRemoved,!1),i.addEventListener("thumbVisibilityChanged",this._onThumbVisibilityChanged,!1)}},{key:"_onThumbCreated",value:function(t,e){var i=e.detail.current;i.addEventListener("mousedown",this._onThumbMoveStart,!1),i.addEventListener("touchstart",this._onThumbMoveStart,!1),this.thumbs.add(i),this._addThumbIfWithinParkingLot(i,t)}},{key:"_onThumbWillBeRemoved",value:function(t,e){var i=e.detail.current;i.removeEventListener("mousedown",this._onThumbMoveStart),i.removeEventListener("touchstart",this._onThumbMoveStart),this.thumbs.delete(i),this._removeThumbIfOutsideParkingLot(i,t)}},{key:"_onThumbVisibilityChanged",value:function(t,e){var i=e.detail.current;e.detail.visible?this._addThumbIfWithinParkingLot(i,t):this._removeThumbIfOutsideParkingLot(i,t)}},{key:"_removeThumbIfOutsideParkingLot",value:function(t,e){var i=this._getThumbXYCoordinates(t),o=_slicedToArray(i,2),n=o[0],r=o[1],a=e.getPlotOffset();switch(t.shape){case"top":r<a.top-2*this._thumbRadius&&(this.topLeftHorizontalDocker.delete(t),this.topRightHorizontalDocker.delete(t));break;case"bottom":r>a.top+e.height()+2*this._thumbRadius&&(this.bottomLeftHorizontalDocker.delete(t),this.bottomRightHorizontalDocker.delete(t));break;case"left":n<a.left-2*this._thumbRadius&&(this.topLeftVerticalDocker.delete(t),this.bottomLeftVerticalDocker.delete(t));break;case"right":n>a.left+e.width()+2*this._thumbRadius&&(this.topRightVerticalDocker.delete(t),this.bottomRightVerticalDocker.delete(t))}}},{key:"_addThumbIfWithinParkingLot",value:function(t,e){var i=this._getThumbXYCoordinates(t),o=_slicedToArray(i,2),n=o[0],r=o[1],a=e.getPlotOffset();switch(t.shape){case"top":n<a.left?this.topLeftHorizontalDocker.add(t):n>a.left+e.width()&&this.topRightHorizontalDocker.add(t);break;case"bottom":n<a.left?this.bottomLeftHorizontalDocker.add(t):n>a.left+e.width()&&this.bottomRightHorizontalDocker.add(t);break;case"left":r<a.top?this.topLeftVerticalDocker.add(t):r>a.top+e.height()&&this.bottomLeftVerticalDocker.add(t);break;case"right":r<a.top?this.topRightVerticalDocker.add(t):r>a.top+e.height()&&this.bottomRightVerticalDocker.add(t)}}},{key:"_onThumbOutOfRange",value:function(t){var e=t.detail.orientation,i=t.detail.edge,n=t.detail.target;switch(i){case o.topLeft:"horizontal"===e?this.topLeftHorizontalDocker.add(n):this.topLeftVerticalDocker.add(n);break;case o.topRight:"horizontal"===e?this.topRightHorizontalDocker.add(n):this.topRightVerticalDocker.add(n);break;case o.bottomLeft:"horizontal"===e?this.bottomLeftHorizontalDocker.add(n):this.bottomLeftVerticalDocker.add(n);break;case o.bottomRight:"horizontal"===e?this.bottomRightHorizontalDocker.add(n):this.bottomRightVerticalDocker.add(n)}}},{key:"_onThumbIntoRange",value:function(t,i){var n=i.detail.orientation,r=i.detail.edge,a=i.detail.target,s=i.detail.position,h=t.getPlotOffset();switch(r){case o.topLeft:"horizontal"===n?(this.topLeftHorizontalDocker.delete(a),e._updateThumbPosition(a,s,h.top-this._thumbRadius)):(this.topLeftVerticalDocker.delete(a),e._updateThumbPosition(a,h.left-this._thumbRadius,s));break;case o.topRight:"horizontal"===n?(this.topRightHorizontalDocker.delete(a),e._updateThumbPosition(a,s,h.top-this._thumbRadius)):(this.topRightVerticalDocker.delete(a),e._updateThumbPosition(a,h.left+t.width()+this._thumbRadius,s));break;case o.bottomLeft:"horizontal"===n?(this.bottomLeftHorizontalDocker.delete(a),e._updateThumbPosition(a,s,h.top+t.height()+this._thumbRadius)):(this.bottomLeftVerticalDocker.delete(a),e._updateThumbPosition(a,h.left-this._thumbRadius,s));break;case o.bottomRight:"horizontal"===n?(this.bottomRightHorizontalDocker.delete(a),e._updateThumbPosition(a,s,h.top+t.height()+this._thumbRadius)):(this.bottomRightVerticalDocker.delete(a),e._updateThumbPosition(a,h.left+t.width()+this._thumbRadius,s))}if(i.detail.axisHandle){var l=i.detail.axisHandle,u="horizontal"===l.orientation?t.getXAxes()[l.axisIndex]:t.getYAxes()[l.axisIndex];if(l.absolutePosition>=u.min&&l.absolutePosition<=u.max)return;var d=s-("horizontal"===l.orientation?h.left:h.top),c=u.c2p(d),f=l.absolutePosition-c,p=u.options.offset;u.options.offset={below:p.below+f,above:p.above+f},t.setupGrid(!0),t.draw()}}},{key:"_onThumbMoveStart",value:function(t){this.thumbMoveState=null;var i=e._getThumb(t.target);if(i.classList.contains("draggable")){var o,n=!1;i.classList.contains("top")?this.topLeftHorizontalDocker.has(i)?(n=!0,o="topleft"):this.topRightHorizontalDocker.has(i)&&(n=!0,o="topright"):i.classList.contains("bottom")?this.bottomLeftHorizontalDocker.has(i)?(n=!0,o="bottomleft"):this.bottomRightHorizontalDocker.has(i)&&(n=!0,o="bottomright"):i.classList.contains("left")?this.bottomLeftVerticalDocker.has(i)?(n=!0,o="bottomleft"):this.topLeftVerticalDocker.has(i)&&(n=!0,o="topleft"):i.classList.contains("right")&&(this.bottomRightVerticalDocker.has(i)?(n=!0,o="bottomright"):this.topRightVerticalDocker.has(i)&&(n=!0,o="topright")),this.thumbMoveState={selectedElement:i,inParkingLot:n,parkingLotLocation:o}}}},{key:"_unbindEvents",value:function(t){var e=this;t.getEventHolder().removeEventListener("thumbIntoRange",this._onThumbIntoRange),t.getEventHolder().removeEventListener("thumbOutOfRange",this._onThumbOutOfRange);var i=t.getPlaceholder()[0];i.removeEventListener("thumbCreated",this._onThumbCreated),i.removeEventListener("thumbWillBeRemoved",this._onThumbWillBeRemoved),i.removeEventListener("thumbVisibilityChanged",this._onThumbVisibilityChanged),this.thumbs.forEach(function(t){t.removeEventListener("mousedown",e._onThumbMoveStart),t.removeEventListener("touchstart",e._onThumbMoveStart)}),this.thumbs.clear()}},{key:"_getThumbXYCoordinates",value:function(t){var e=t.getCTM();return[e.e,e.f]}}],[{key:"_updateThumbPosition",value:function(t,e,i){var o=t.getCTM(),n="matrix(".concat(o.a," ").concat(o.b," ").concat(o.c," ").concat(o.d," ").concat(e," ").concat(i,")");t.setAttribute("transform",n)}},{key:"_getThumb",value:function(t){for(var e=t;!e.classList.contains("thumb");)e=e.parentNode;return e}}]),e}();t.plot.plugins.push({init:e,name:"parkingLot",version:"1.1.1"})}(jQuery),function(t){function e(e){function r(t){return i(t,{name:"unnamed "+P.length,type:"range-cursor",position:t.position||{relativeXStart:.45,relativeXEnd:.55,xstart:void 0,xend:void 0,relativeYStart:.45,relativeYEnd:.55,ystart:void 0,yend:void 0},mousePosition:{relativeXStart:void 0,relativeXEnd:void 0,relativeYStart:void 0,relativeYEnd:void 0},xstart:void 0,xend:void 0,ystart:void 0,yend:void 0,startMovePosition:{x:0,y:0},show:!0,selected:!1,highlighted:!1,orientation:"vertical",halign:"top",dragLocation:"",transparentRange:"outside",showLabel:!1,showValue:!1,showBorders:!0,color:"gray",fillColor:"#4F4F4F4F",fontSize:"10px",fontFamily:"sans-serif",fontStyle:"",fontWeight:"",lineWidth:1,movable:!0,mouseButton:"all",dashes:[],defaultxaxis:1,defaultyaxis:1,constrainToEdge:!0})}function l(){z=!1,P.forEach(function(t){if(!isNaN(t.start)&&!isNaN(t.end)){var i={relativeXStart:t.position.relativeXStart||t.xstart/e.width(),relativeYStart:t.position.relativeYStart||t.ystart/e.height(),relativeXEnd:t.position.relativeXEnd||t.xend/e.width(),relativeYEnd:t.position.relativeYEnd||t.yend/e.width()};isNaN(i.relativeStart)||isNaN(i.relativeEnd)||(t.position=i)}})}function u(){z=!0,P.forEach(function(t){var i=d(e,t),o=c(e,t);t.mousePosition={},void 0===t.position.xstart&&(t.position.xstart=i.c2p?i.c2p(t.xstart):void 0),void 0===t.position.ystart&&(t.position.ystart=o.c2p?o.c2p(t.ystart):void 0),void 0===t.position.xend&&(t.position.xend=i.c2p?i.c2p(t.xend):void 0),void 0===t.position.yend&&(t.position.yend=o.c2p?o.c2p(t.yend):void 0),t.position.relativeXStart=void 0,t.position.relativeXEnd=void 0,t.position.relativeYStart=void 0,t.position.relativeYEnd=void 0})}function p(t,i,o,n,r){var a=E(P);a&&""!==a.dragLocation?(S(a,i,o),a.startMovePosition.x=i,a.startMovePosition.y=o,e.getPlaceholder().trigger("cursordrag",a),e.triggerRedrawOverlay(),t.stopImmediatePropagation(),t.preventDefault()):(a&&""!==a.dragLocation&&(a.selected=!1,a.dragLocation="",e.triggerRedrawOverlay()),O(P).forEach(function(t){var i={shape:""};t.movable&&(""!==x(n,r,e,t,i)?(t.highlighted||(t.highlighted=!0,e.triggerRedrawOverlay()),e.getPlaceholder().css("cursor",i.shape)):y(n,r,e,t)?(t.highlighted||(t.highlighted=!0,e.triggerRedrawOverlay()),e.getPlaceholder().css("cursor","move")):t.highlighted&&(t.highlighted=!1,e.getPlaceholder().css("cursor","default"),e.triggerRedrawOverlay()))}))}function v(t,i,o,n,r){var a=E(P);if(a&&""!==a.dragLocation)e.getPlaceholder().css("cursor","default"),S(a,i,o),e.triggerRedrawOverlay();else{var s,h;O(P).forEach(function(t){var a={shape:""};t.movable&&(""!==(h=x(n,r,e,t,a))?s=t:y(n,r,e,t)&&(s=t,h="between",t.startMovePosition.x=i,t.startMovePosition.y=o))}),s&&(s.selected=!0,s.dragLocation=h,e.getPlaceholder().css("cursor","move"),e.getPlaceholder().trigger("cursordragstart",s),e.triggerRedrawOverlay(),t.stopImmediatePropagation(),t.preventDefault())}}function b(t,i,o,n,r){var a=E(P);a&&(a.selected=!1,S(a,i,o),e.getPlaceholder().css("cursor","default"),e.getPlaceholder().trigger("cursordragend",a),e.triggerRedrawOverlay(),t.stopImmediatePropagation(),t.preventDefault())}function w(t,i,o,n,r){var a=E(P);a&&0===t.buttons&&(a.selected=!1,e.triggerRedrawOverlay()),O(P).forEach(function(t){k(n,r,e,t)})}function _(t){t.highlighted||(t.highlighted=!0,e.triggerRedrawOverlay())}function k(t,e,i,o){var n={shape:""};o.movable&&(""!==x(t,e,i,o,n)?(_(o),i.getPlaceholder().css("cursor",n.shape)):y(t,e,i,o)?(_(o),i.getPlaceholder().css("cursor","move")):o.highlighted&&(o.highlighted=!1,i.getPlaceholder().css("cursor","default"),i.triggerRedrawOverlay()))}function T(t,i,o,n,r){var a,s;a=d(e,t),s=c(e,t),void 0!==i&&(t.mousePosition.relativeXStart=i/e.width(),t.position.relativeXStart=i/e.width(),t.position.xstart=a.c2p?a.c2p(i):void 0),void 0!==o&&(t.mousePosition.relativeXEnd=o/e.width(),t.position.relativeXEnd=o/e.width(),t.position.xend=a.c2p?a.c2p(o):void 0),void 0!==n&&(t.mousePosition.relativeYStart=n/e.height(),t.position.relativeYStart=n/e.height(),t.position.ystart=s.c2p?s.c2p(n):void 0),void 0!==r&&(t.mousePosition.relativeYEnd=r/e.height(),t.position.relativeYEnd=r/e.height(),t.position.yend=s.c2p?s.c2p(r):void 0)}function S(t,e,i){"edge-w"===t.dragLocation?(t.xstart=e,T(t,t.xstart,t.xend,t.ystart,t.yend)):"edge-e"===t.dragLocation?(t.xend=e,T(t,t.xstart,t.xend,t.ystart,t.yend)):"edge-n"===t.dragLocation?(t.ystart=i,T(t,t.xstart,t.xend,t.ystart,t.yend)):"edge-s"===t.dragLocation?(t.yend=i,T(t,t.xstart,t.xend,t.ystart,t.yend)):"between"===t.dragLocation&&("horizontal"!==t.orientation&&(t.xstart=t.xstart+e-t.startMovePosition.x,t.xend=t.xend+e-t.startMovePosition.x),"vertical"!==t.orientation&&(t.ystart=t.ystart+i-t.startMovePosition.y,t.yend=t.yend+i-t.startMovePosition.y),T(t,t.xstart,t.xend,t.ystart,t.yend))}function R(t){var i=e.offset();return Math.max(0,Math.min(t-i.left,e.width()))}function L(t){var i=e.offset();return Math.max(0,Math.min(t-i.top,e.height()))}var P=[],z=!0;e.hooks.processOptions.push(function(t){t.getOptions().rangecursors&&t.getOptions().rangecursors.forEach(function(e){t.addRangeCursor(e)})}),e.getRangeCursors=function(){return P},e.addRangeCursor=function(t){var i=r(t);n(e,i,i.position),P.push(i),e.triggerRedrawOverlay()},e.removeRangeCursor=function(t){var i=P.indexOf(t);-1!==i&&P.splice(i,1),e.triggerRedrawOverlay()},e.setRangeCursor=function(t,o){var r=P.indexOf(t);-1!==r&&(i(o,P[r]),n(e,P[r],P[r].position),e.triggerRedrawOverlay())},e.formatCursorRange=f;var E=function(t){var e;return t.forEach(function(t){t.selected&&(e||(e=t))}),e},O=function(t){return t.filter(function(t){return t.show})},C={start:function(t){v(t,R(t.detail.touches[0].pageX),L(t.detail.touches[0].pageY),t.detail.touches[0].pageX,t.detail.touches[0].pageY)},drag:function(t){p(t,R(t.detail.touches[0].pageX),L(t.detail.touches[0].pageY),t.detail.touches[0].pageX,t.detail.touches[0].pageY)},end:function(t){var e=E(P);e&&(e.selected=!1)}},A={start:function(t){v(t,R(t.detail.touches[0].pageX),L(t.detail.touches[0].pageY),t.detail.touches[0].pageX,t.detail.touches[0].pageY)},drag:function(t){p(t,R(t.detail.touches[0].pageX),L(t.detail.touches[0].pageY),t.detail.touches[0].pageX,t.detail.touches[0].pageY)},end:function(t){var e=E(P);e&&(e.selected=!1)}},M={start:function(e){var i=t.plot.browser.getPageXY(e);v(e,R(i.X),L(i.Y),i.X,i.Y)},drag:function(e){var i=t.plot.browser.getPageXY(e);p(e,R(i.X),L(i.Y),i.X,i.Y)},mouseover:function(e){var i=t.plot.browser.getPageXY(e);w(e,R(i.X),L(i.Y),i.X,i.Y)},end:function(e){var i=t.plot.browser.getPageXY(e);b(e,R(i.X),L(i.Y),i.X,i.Y)}};e.hooks.bindEvents.push(function(t,e){e[0].addEventListener("panstart",C.start,!1),e[0].addEventListener("pandrag",C.drag,!1),e[0].addEventListener("panend",C.end,!1),e[0].addEventListener("pinchstart",A.start,!1),e[0].addEventListener("pinchdrag",A.drag,!1),e[0].addEventListener("pinchend",A.end,!1),t.getPlaceholder().bind("plotpan",u),t.getPlaceholder().bind("plotzoom",u),t.addEventHandler("dragstart",M.start,e,10),t.addEventHandler("drag",M.drag,e,10),t.addEventHandler("dragend",M.end,e,10),e.bind("mousemove",M.mouseover)}),e.hooks.processRawData.push(function(t,e,i,o){e.historyBuffer&&l()}),e.hooks.drawOverlay.push(function(t,e){var i=[],r=function(t){return void 0!==t.relativeXStart&&void 0!==t.relativeXEnd&&void 0!==t.relativeYStart&&void 0!==t.relativeYEnd};P.forEach(function(l){if(o(t,l),n(t,l,l.position),T(l,l.xstart,l.xend,l.ystart,l.yend),r(l.mousePosition)||(l.mousePosition.relativeXStart=l.xstart/t.width(),l.mousePosition.relativeXEnd=l.xend/t.width(),l.mousePosition.relativeYStart=l.ystart/t.height(),l.mousePosition.relativeYEnd=l.yend/t.height()),l.show){var u=t.getPlotOffset();e.save(),e.translate(u.left,u.top),l.showBorders&&g(t,e,l),m(t,e,l),a(t,e,l),h(t,e,l),s(t,e,l),e.restore(),i.push({rangecursor:l.name,target:l,positionMode:z,position:l.position})}}),i.length>0&&t.getPlaceholder().trigger("cursorupdates",[i])}),e.hooks.shutdown.push(function(t,e){e[0].removeEventListener("panstart",C.start),e[0].removeEventListener("pandrag",C.drag),e[0].removeEventListener("panend",C.end),e[0].removeEventListener("pinchstart",A.start),e[0].removeEventListener("pinchdrag",A.drag),e[0].removeEventListener("pinchend",A.end);var i=t.getPlaceholder();i.unbind("plotpan",u),i.unbind("plotzoom",u),e.unbind("mousedown",M.start),e.unbind("mousemove",M.move),e.unbind("mouseup",M.end),i.css("cursor","default")})}function i(t,e){return Object.keys(t).forEach(function(i){e[i]=t[i]}),e}function o(t,e){var i=d(t,e),o=c(t,e),n=e.position;void 0!==n.xstart&&void 0!==n.xend||!i.c2p||0===i.min&&1===i.max||("horizontal"!==e.orientation?(n.xstart=i.c2p(n.relativeXStart*t.width()),n.xend=i.c2p(n.relativeXEnd*t.width())):(n.xstart=i.c2p(0),n.xend=i.c2p(t.width()))),void 0!==n.ystart&&void 0!==n.yend||!o.c2p||0===o.min&&1===o.max||("vertical"!==e.orientation?(n.ystart=o.c2p(n.relativeYStart*t.height()),n.yend=o.c2p(n.relativeYEnd*t.height())):(n.ystart=o.c2p(0),n.yend=o.c2p(t.height()))),void 0!==n.relativeXStart&&void 0!==n.relativeXEnd||!i.p2c||void 0===n.xstart||void 0===n.xend||("horizontal"!==e.orientation?(n.relativeXStart=i.p2c(n.xstart)/t.width(),n.relativeXEnd=i.p2c(n.xend)/t.width()):(n.relativeXStart=0,n.relativeXEnd=1)),void 0!==n.relativeYStart&&void 0!==n.relativeYEnd||!o.p2c||void 0===n.ystart||void 0===n.yend||("vertical"!==e.orientation?(n.relativeYStart=o.p2c(n.ystart)/t.height(),n.relativeYEnd=o.p2c(n.yend)/t.height()):(n.relativeYStart=0,n.relativeYEnd=1))}function n(t,e,i){var o=d(t,e),n=c(t,e),r=void 0!==i.xstart?o.p2c?o.p2c(i.xstart):void 0:i.relativeXStart*t.width(),a=void 0!==i.xend?o.p2c?o.p2c(i.xend):void 0:i.relativeXEnd*t.width(),s=void 0!==i.ystart?n.p2c?n.p2c(i.ystart):void 0:i.relativeYStart*t.height(),h=void 0!==i.yend?n.p2c?n.p2c(i.yend):void 0:i.relativeYEnd*t.height(),l=t.width(),u=Math.abs(a-r);u>l&&(u=l);var f=t.height(),p=Math.abs(h-s);p>f&&(p=f),r>a&&!o.inverted&&(r=a-u),e.constrainToEdge&&(a>l&&(a=l,r=l-u),r<0&&(r=0,a=u),h>f&&(h=f,s=f-p),s<0&&(s=0,h=p)),"vertical"===e.orientation?(e.ystart=0,e.yend=t.height(),e.xstart=r,e.xend=a):"horizontal"===e.orientation?(e.xstart=0,e.xend=t.width(),e.ystart=s,e.yend=h):(e.xstart=r,e.xend=a,e.ystart=s,e.yend=h)}function r(t,e,i,o){var n="left",r=Number(e.fontSize.substring(0,e.fontSize.length-2)),a=e.xstart+(e.xend-e.xstart)/2,s=e.ystart+(e.yend-e.ystart)/2;if("vertical"===e.orientation?"top"===i?(s-=_.labelPadding,n="center",s-=r,e.showLabel&&e.showValue&&0===o&&(s-=r)):(s+=_.labelPadding,n="center",s+=r,1===o&&(s+=r)):"horizontal"===e.orientation?"top"===i?(a+=_.labelPadding,1===o&&(s+=r)):(a-=_.labelPadding,n="right",1===o&&(s+=r)):(n="center",1===o&&(s+=r)),!(a<0||a>t.width()||s<0||s>t.height()))return{x:a,y:s,textAlign:n}}function a(t,e,i){if(i.showLabel){var o=r(t,i,i.halign,0);if(!o)return;e.beginPath(),e.fillStyle=i.color,e.textAlign=o.textAlign,e.font=i.fontStyle+" "+i.fontWeight+" "+i.fontSize+" "+i.fontFamily,e.fillText(i.name,o.x,o.y),e.textAlign="left",e.stroke()}}function s(t,e,i){if(i.showValue){var o=f(t,i),n=r(t,i,i.halign,i.showLabel?1:0);if(!n)return;e.fillStyle=i.color,e.textAlign=n.textAlign,e.font=i.fontStyle+" "+i.fontWeight+" "+i.fontSize+" "+i.fontFamily,e.fillText(o,n.x,n.y)}}function h(t,e,i){if(i.showBorders){var o=p(t,i);if(!o)return;if(e.beginPath(),e.strokeStyle=i.color,e.lineWidth=i.lineWidth,"vertical"===i.orientation){var n=o.xstart,r=o.xend;e.moveTo(n,t.height()/2),e.lineTo(r,t.height()/2),Math.abs(n-r)>Number.EPSILON&&l(e,i,"left",i.xstart,t.height()/2),Math.abs(r-n)>Number.EPSILON&&l(e,i,"right",i.end,t.height()/2)}else if("horizontal"===i.orientation){var n=o.ystart,r=o.yend;e.moveTo(t.width()/2,n),e.lineTo(t.width()/2,r),Math.abs(n-r)>Number.EPSILON&&l(e,i,"up",t.width()/2,i.ystart),Math.abs(r-n)>Number.EPSILON&&l(e,i,"down",t.width()/2,i.yend)}e.stroke()}}function l(t,e,i,o,n){switch(i){case"left":t.moveTo(o,n),t.lineTo(o+_.arrowHeadLength,n-_.arrowHeadLength/2),t.moveTo(o,n),t.lineTo(o+_.arrowHeadLength,n+_.arrowHeadLength/2);break;case"right":t.moveTo(o,n),t.lineTo(o-_.arrowHeadLength,n-_.arrowHeadLength/2),t.moveTo(o,n),t.lineTo(o-_.arrowHeadLength,n+_.arrowHeadLength/2);break;case"up":t.moveTo(o,n),t.lineTo(o-_.arrowHeadLength/2,n+_.arrowHeadLength),t.moveTo(o,n),t.lineTo(o+_.arrowHeadLength/2,n+_.arrowHeadLength);break;case"down":t.moveTo(o,n),t.lineTo(o-_.arrowHeadLength/2,n-_.arrowHeadLength),t.moveTo(o,n),t.lineTo(o+_.arrowHeadLength/2,n-_.arrowHeadLength)}}function u(t,e,i){var o="x"===e.direction?i+1:i-1,n=e.c2p(i),r=e.c2p(o);return t.computeValuePrecision(n,r,e.direction,1)}function d(t,e){return t.getXAxes()[e.defaultxaxis-1]}function c(t,e){return t.getYAxes()[e.defaultyaxis-1]}function f(t,e){var i=d(t,e),o=c(t,e),n=u(t,i,e.xstart),r=i.tickFormatter(i.c2p(e.xend)-i.c2p(e.xstart),i,n,t);r=r.replace("<br>"," "),r=r.replace("&nbsp;"," ");var a=u(t,o,e.ystart),s=o.tickFormatter(o.c2p(e.yend)-o.c2p(e.ystart),o,a,t);return s=s.replace("<br>"," "),s=s.replace("&nbsp;"," "),"box"===e.orientation?"["+r+" "+s+"]":"vertical"===e.orientation?r:s}function p(t,e){var i=e.mousePosition.relativeXStart,o=e.mousePosition.relativeXEnd,n=e.mousePosition.relativeYStart,r=e.mousePosition.relativeYEnd;if(!(i<=0&&o<=0||n<=0&&r<=0||n>=1&&r>=1||i>=1&&o>=1))return i=i<0?0:e.xstart,n=n<0?0:e.ystart,o=o>1?t.width():e.xend,r=r>1?t.height():e.yend,{xstart:i,xend:o,ystart:n,yend:r}}function g(t,e,i){if(0!==i.lineWidth){var o=i.lineWidth%2?.5:0;e.strokeStyle=i.color,e.lineWidth=i.lineWidth,e.lineJoin="round",e.beginPath(),i.dashes.length&&e.setLineDash(i.dashes);var n=Math.floor(i.xstart)+o,r=Math.floor(i.xend)+o,a=Math.floor(i.ystart)+o,s=Math.floor(i.yend)+o;"box"===i.orientation?e.strokeRect(n,a,r-n,s-a):"vertical"===i.orientation?(e.moveTo(n,a),e.lineTo(n,s),e.moveTo(r,a),e.lineTo(r,s),e.stroke()):(e.moveTo(n,a),e.lineTo(r,a),e.moveTo(n,s),e.lineTo(r,s),e.stroke())}}function m(t,e,i){e.fillStyle=i.fillColor;var o=p(t,i);if(o){var n=o.xstart,r=o.xend,a=o.ystart,s=o.yend;"outside"===i.transparentRange?e.fillRect(n,a,r-n,s-a):(e.fillRect(0,0,t.width(),a),e.fillRect(0,a,n,s-a),e.fillRect(r,a,t.width()-r,s-a),e.fillRect(0,s,t.width(),t.height()-s))}}function v(t,e,i,o,n,r){var a=i.offset(),s=Math.max(0,Math.min(t-a.left,i.width())),h=Math.max(0,Math.min(e-a.top,i.height()));return s>o-_.mouseGrabMargin&&s<o+_.mouseGrabMargin&&h>n&&h<r}function b(t,e,i,o,n,r){var a=i.offset(),s=Math.max(0,Math.min(t-a.left,i.width())),h=Math.max(0,Math.min(e-a.top,i.height()));return h>o-_.mouseGrabMargin&&h<o+_.mouseGrabMargin&&s>n&&s<r}function y(t,e,i,o){var n=i.offset(),r=Math.max(0,Math.min(t-n.left,i.width())),a=Math.max(0,Math.min(e-n.top,i.height())),s=p(i,o);if(s){var h=s.xstart,l=s.xend,u=s.ystart,d=s.yend;return a>u+_.mouseGrabMargin&&a<d-_.mouseGrabMargin&&r>h+_.mouseGrabMargin&&r<l+_.mouseGrabMargin}}function x(t,e,i,o,n){return"horizontal"!==o.orientation&&v(t,e,i,o.xstart,o.ystart,o.yend)?(n.shape="ew-resize","edge-w"):"horizontal"!==o.orientation&&v(t,e,i,o.xend,o.ystart,o.yend)?(n.shape="ew-resize","edge-e"):"vertical"!==o.orientation&&b(t,e,i,o.yend,o.xstart,o.xend)?(n.shape="ns-resize","edge-s"):"vertical"!==o.orientation&&b(t,e,i,o.ystart,o.xstart,o.xend)?(n.shape="ns-resize","edge-n"):""}var w={cursors:[]},_={mouseGrabMargin:12,arrowHeadLength:10,labelPadding:2};t.plot.plugins.push({init:e,options:w,name:"cursors",version:"0.2"})}(jQuery),function(t,e){function i(t){return t.options.type===o.ColorScaleType}function o(){function t(t,e,i,o){!0===t.getOptions().series.intensitygraph.show&&i[0].length>0&&(o.pointsize=2,o.points.length=0,o.points.push(0,0),o.points.push(i.length||0,i[0]?i[0].length:0))}this.pluginName="intensitygraph",this.pluginVersion="0.2",this.defaultOptions={series:{intensitygraph:{data:[],show:!1,lowColor:"rgba(0,0,0,1)",highColor:"rgba(255,255,255,1)",min:0,max:1}}};var n=[{value:0,color:"#3182bd"},{value:.5,color:"#9ecae1"},{value:1,color:"#deebf7"}],r={centerX:20,centerY:0};this.init=function(a){function s(e,i){if(i.series.intensitygraph.show){i.series.intensitygraph.gradient||(i.series.intensitygraph.gradient=n);var a=e.getYAxes(),s=a.filter(function(t){return o.prototype.isColorScale(t)})[0];!s||s.boxPosition&&0!==s.boxPosition.centerX||(s.boxPosition=r),e.hooks.drawSeries.push(l),e.hooks.processRawData.push(t),f=i,i.series.intensitygraph.palette=h(i)}}function h(t){var i,o,n=document.createElement("canvas");n.width="1",n.height="256";var r,a=n.getContext("2d"),s=a.createLinearGradient(0,0,0,256),h=t.series.intensitygraph.gradient,l=h[0].value,u=h[h.length-1].value;if(u===l)s.addColorStop(0,h[0].color),s.addColorStop(1,h[0].color);else for(i=0;i<h.length;i++)o=h[i].value,(r=(o-l)/(u-l))>=0&&r<=1&&s.addColorStop(r,h[i].color);a.fillStyle=s,a.fillRect(0,0,1,256);var d=[],c=a.getImageData(0,0,1,256).data
;for(i=0;i<c.length;i++)d[i]=c[i];var f=t.series.intensitygraph.lowColor,p=t.series.intensitygraph.highColor,g=e.color.parse(f),m=e.color.parse(p);return d.push(0|g.r),d.push(0|g.g),d.push(0|g.b),d.push(255*g.a|0),d.push(0|m.r),d.push(0|m.g),d.push(0|m.b),d.push(255*m.a|0),d}function l(t,e,n){function r(t,e,i,o,n,r,a,s,h,l,u,d,c,f){var p,g,m,v,b,y,x,w,_,k,T,S,R=c-d;for(p=0;p<r;p++)for(m=0|s(e+p/f),g=a-1;g>=0;g--){for(v=0|h(o-g/f),_=u[m][v],x=0|Math.min(s(e+p/f+1),u.length),w=0|Math.min(h(o-g/f-1),u[0].length),b=m;b<x;b++)for(y=v;y<w;y++)(k=u[b][y])>_&&(_=k);for(b=m;b<x;b++)(k=u[b][v])>_&&(_=k);for(y=v;y<w;y++)(k=u[m][y])>_&&(_=k);T=_<d?1024:_>c?1028:4*Math.round(255*(_-d)/R),S=4*(a-g-1)*r+4*p,t.data[S+0]=l[T+0],t.data[S+1]=l[T+1],t.data[S+2]=l[T+2],t.data[S+3]=l[T+3]}}function a(t,e,i,o,n,r,a,s,h,l,u,d,c){var f,p,g,m,v,b,y,x,w,_,k,T,S=c-d;for(f=0;f<r;f++)for(g=e+f*s|0,p=0;p<a;p++){for(m=o+p*h|0,w=u[g][m],y=0|Math.floor(Math.min(g+s,u.length)),x=0|Math.floor(Math.min(m+h,u[0].length)),v=g;v<y;v++)for(b=m;b<x;b++)(_=u[v][b])>w&&(w=_);k=w<d?1024:w>c?1028:4*Math.round(255*(w-d)/S),T=4*(a-p-1)*r+4*f,t.data[T+0]=l[k+0],t.data[T+1]=l[k+1],t.data[T+2]=l[k+2],t.data[T+3]=l[k+3]}}function s(t,e,i,o,n,r,a,s,h,l,u){var d,c,f,p,g,m=u-l;for(d=e;d<i;d++)for(c=o;c<n;c++)f=h[d][c],p=f<l?1024:f>u?1028:4*Math.round(255*(f-l)/m),g=4*(n-c-1)*r+4*(d-e),t.data[g+0]=s[p+0],t.data[g+1]=s[p+1],t.data[g+2]=s[p+2],t.data[g+3]=s[p+3]}function h(t,e,i){return u&&u.width===e&&u.height===i||(u=t.createImageData(e,i)),u}function l(t,e){return d||(d=document.createElement("canvas"),d.className="tempCanvas",d.style.visibility="hidden",c=null),c&&d.width===t&&d.height===e||(d.width=t,d.style.width=t+"px",d.height=e,d.style.height=e+"px",c=d.getContext("2d").createImageData(t,e)),c}var p=t.getPlotOffset(),g=t.getSurface().pixelRatio,m=t.getYAxes(),v=m.filter(function(t){return i(t)})[0],b=v&&"none"!==v.options.autoScale?v.min:n.intensitygraph.min,y=v&&"none"!==v.options.autoScale?v.max:n.intensitygraph.max;n.data.length>0&&n.data[0].length>0&&(e.save(),e.beginPath(),e.rect(p.left,p.top,t.width(),t.height()),e.clip(),function(t){return!(n.xaxis.options.mode&&"linear"!==n.xaxis.options.mode||n.yaxis.options.mode&&"linear"!==n.yaxis.options.mode)}(n)?function(e,i){var n,r,u,c=0|Math.floor(Math.max(e.xaxis.min,0)),f=0|Math.ceil(Math.min(e.data.length,e.xaxis.max)),m=0|Math.floor(Math.max(e.yaxis.min,0)),v=0|Math.ceil(Math.min(e.data[0].length,e.yaxis.max)),x=e.xaxis.p2c(c),w=e.xaxis.p2c(f),_=e.yaxis.p2c(m),k=e.yaxis.p2c(v),T=Math.abs((f-c)/(w-x))/g,S=Math.abs((v-m)/(k-_))/g,R=T>1&&S>1;if(t.getYAxes().filter(function(t){return o.prototype.isColorScale(t)})[0],R){var L=Math.floor(x*g),P=Math.floor(w*g),z=Math.floor(k*g),E=Math.floor(_*g);n=P-L,r=E-z,n>0&&r>0&&(u=h(i,n,r),a(u,c,f,m,v,n,r,T,S,e.intensitygraph.palette,e.data,b,y),i.putImageData(u,Math.ceil((x+p.left)*g),Math.ceil((k+p.top)*g)))}else n=f-c,r=v-m,n>0&&r>0&&(u=l(n,r),s(u,c,f,m,v,n,r,e.intensitygraph.palette,e.data,b,y),d.getContext("2d").putImageData(u,0,0),i.imageSmoothingEnabled=!1,i.webkitImageSmoothingEnabled=!1,i.msImageSmoothingEnabled=!1,i.drawImage(d,0,0,n,r,x+p.left,k+p.top,Math.max(w-x,1),Math.max(_-k,1)))}(n,e):function(t,e){var i=Math.max(t.xaxis.min,0),o=Math.min(t.data.length,t.xaxis.max),n=Math.max(t.yaxis.min,0),a=Math.min(t.data[0].length,t.yaxis.max),s=t.xaxis.p2c(i),l=t.xaxis.p2c(o),u=t.yaxis.p2c(n),d=t.yaxis.p2c(a),c=Math.floor(s*g),f=Math.floor(l*g),m=Math.floor(d*g),v=Math.floor(u*g),x=f-c,w=v-m;if(x>0&&w>0){var _=h(e,x,w);r(_,s,l,u,d,x,w,t.xaxis.c2p,t.yaxis.c2p,t.intensitygraph.palette,t.data,b,y,g),e.putImageData(_,Math.ceil((s+p.left)*g),Math.ceil((d+p.top)*g))}}(n,e),e.restore()),function(t,e,i){var n=i&&i.show?i.box.left+10:p.left+t.width()+20,r=f.series.intensitygraph.gradient,a=f.series.intensitygraph.lowColor,s=f.series.intensitygraph.highColor;i&&i.show&&o.prototype.drawLegend(e,n,p.top,10,t.height(),r,a,s)}(t,e,v)}var u,d,c,f=null;a.hooks.processOptions.push(s)}}var n=function(t,e,i,o,n,r,a,s){var h,l,u=t.createLinearGradient(0,i+n,0,i),d=r[0].value,c=r[r.length-1].value;for(l=0;l<r.length;l++)(h=(r[l].value-d)/(c-d))>=0&&h<=1&&u.addColorStop(h,r[l].color);t.fillStyle=u,t.fillRect(e,i,o,n),t.fillStyle=a,t.fillRect(e,i+n,o,7),t.strokeStyle="#000000",t.lineWidth=1,t.strokeRect(e-.5,i+n+.5,o+1,7),t.fillStyle=s,t.fillRect(e,i-7,o,7),t.strokeStyle="#000000",t.lineWidth=1,t.strokeRect(e-.5,i-7+.5,o+1,7)};o.ColorScaleType="colorScale",o.prototype.drawLegend=n,o.prototype.isColorScale=i;var r=new o;e.plot.plugins.push({init:r.init,options:r.defaultOptions,name:r.pluginName,version:r.pluginVersion}),e.plot.IntensityGraph=o}(0,jQuery),function(t){function e(t){var e;t.hooks.processOptions.push(function(t,i){i.series.digitalWaveform&&i.series.digitalWaveform.show&&(e=new n(t,i))}),t.getDigitalWaveform=function(){return e}}var i=function(){function e(){_classCallCheck(this,e)}return _createClass(e,[{key:"drawStep",value:function(t,e,i,o,n,r){t.beginPath(),t.strokeStyle=r,t.moveTo(e,null===n?o:n),null!==n&&o!==n&&t.lineTo(e,o),t.lineTo(i,o),t.stroke()}},{key:"drawRect",value:function(e,i,o,n,r,a,s,h,l){e.beginPath(),e.strokeStyle=a,e.moveTo(i,n),e.lineTo(o,n),l?e.lineTo(o,r):e.moveTo(o,r),e.lineTo(i,r),h&&e.lineTo(i,n),e.stroke(),s&&(e.fillStyle=t.color.parse(a).add("a",-.6),e.fillRect(i,n,o-i,r-n))}},{key:"drawRectCrossX",value:function(t,e,i,o,n,r,a,s,h,l){var u=function(t,e,i,o,n,r,a,s,h){s?(t.moveTo(e,r),t.lineTo(o,a)):t.moveTo(e,a),h?(t.lineTo(n,a),t.lineTo(i,r)):t.lineTo(i,a)};t.beginPath(),t.strokeStyle=s,u(t,e,i,o,n,(r+a)/2,r,h,l),u(t,e,i,o,n,(r+a)/2,a,h,l),t.stroke()}}]),e}(),o=function(){function t(e,i,o){_classCallCheck(this,t),this._x=e,this._state=i,this._strength=o}return _createClass(t,[{key:"equals",value:function(t){return this.state===t.state&&this.strength===t.strength}},{key:"x",get:function(){return this._x}},{key:"state",get:function(){return this._state}},{key:"strength",get:function(){return this._strength}}],[{key:"fromDatapoints",value:function(e,i){return new t(e.points[i],e.points[i+1],e.points[i+2])}}]),t}(),n=function(){function t(e,i){_classCallCheck(this,t),this._initialize(i),this._processOptions(i),this._createHooks(e),this._createPlotApi(e)}return _createClass(t,[{key:"renderer",get:function(){return this._renderer||(this._renderer=new i),this._renderer}}],[{key:"defaultOptions",get:function(){return{buses:[],series:{digitalWaveform:{show:!1,lineWidth:1,signal:{show:!0,bus:0,states:[{value:0,shape:"step_down"},{value:1,shape:"step_up"},{value:255,shape:"rect_filled",color:"#cb4b4b"},{value:254,shape:"step_center",color:"#cb4b4b"}],strengths:[{value:0,color:"#4da74d"},{value:1,color:"#3b7fed"},{value:2,color:"#cb4b4b"}]}}}}}},{key:"defaultBusOptions",get:function(){return{value:t.defaultLookupBusValue,shape:t.defaultLookupBusShape,color:t.defaultLookupBusColor,collapsed:!1,bitNumbering:"lsb",showLabels:!0,labelPosition:"center",labelFormatter:"binary"}}},{key:"defaultLookupBusValue",get:function(){return function(t){var e=t.map(function(t){return t.state}),i=e.find(function(t){return 0!==t&&1!==t});if(!i)return e.join("");switch(i){case 255:return"X";case 254:return"Z";default:return null}}}},{key:"defaultLookupBusShape",get:function(){return function(t){return t.map(function(t){return t.state}).some(function(t){return 0!==t&&1!==t})?"rect":"rect_cross_x"}}},{key:"defaultLookupBusColor",get:function(){return function(t){return t.map(function(t){return t.state}).some(function(t){return 0!==t&&1!==t})?"#cb4b4b":t.every(function(t){return 0===t.strength})?"#4da74d":"#edc240"}}}]),_createClass(t,[{key:"_initialize",value:function(t){var e=this;this._states=new Map,t.series.digitalWaveform.signal.states.forEach(function(t){e._states.set(t.value,{shape:t.shape,color:t.color})}),this._strengths=new Map,t.series.digitalWaveform.signal.strengths.forEach(function(t){e._strengths.set(t.value,{color:t.color})})}},{key:"_processOptions",value:function(e){e.buses=e.buses.map(function(e){return Object.assign(t.defaultBusOptions,e)})}},{key:"_createHooks",value:function(t){var e=this;t.hooks.processRawData.push(function(t,i,o,n){e._processRawData(t,i,o,n)}),t.hooks.adjustSeriesDataRange.push(function(t,i,o){e._adjustSeriesDataRange(t,i,o)}),t.hooks.setRange.push(function(t,i){e._setRange(t,i)}),t.hooks.draw.push(function(t,i){e._draw(t,i)})}},{key:"_createPlotApi",value:function(t){var e=this;t.expandBus=function(t){e._expandCollapseBus(this,t,!0)},t.collapseBus=function(t){e._expandCollapseBus(this,t,!1)}}},{key:"_expandCollapseBus",value:function(t,e,i){e.collapsed=!i,this._initializeSignalAndBusPositions(t)}},{key:"_processRawData",value:function(t,e,i,o){if(e.digitalWaveform.show){this._initializeSignalsAndBuses=!0,o.points=[];for(var n=e.start||0,r=e.step||1,a=0,s=0;a<i.length;a++,s=0)e.flatdata?o.points.push(n+a*r):o.points.push(i[a][s++]),Array.isArray(i[a])?(o.points.push(i[a][s++]),o.points.push(i[a][s]?i[a][s]:0)):o.points.push(i[a],0);o.pointsize=3}}},{key:"_lazyInitialize",value:function(t){var e=this;this._initializeSignalsAndBuses&&(this._busTransitionWidth=Number.POSITIVE_INFINITY,t.getOptions().buses.forEach(function(i){e._initializeBusValues(t,i)}),this._initializeSignalAndBusPositions(t),this._initializeSignalsAndBuses=!1)}},{key:"_initializeBusValues",value:function(t,e){var i=this._getBusSignals(t,e);e.visible=i.length>0,e.visible&&(e.samples=this._getBusSamples(i),e.values=e.samples.map(function(t){return e.value(t.samples)}),e.shapes=e.samples.map(function(t){return e.shape(t.samples)}),e.colors=e.samples.map(function(t){return e.color(t.samples)}))}},{key:"_getBusSignals",value:function(t,e){var i=t.getOptions().buses.indexOf(e),o=t.getData().filter(function(t){return t.digitalWaveform.signal.bus===i});switch(e.bitNumbering){case"lsb":o=o.reverse()}return o}},{key:"_getBusSamples",value:function(t){var e=this,i=t.map(function(t){for(var e=[],i=0;i<t.datapoints.points.length;i+=t.datapoints.pointsize)e.push(o.fromDatapoints(t.datapoints,i));return e}).filter(function(t){return t.length>0}),n=[];return i.length>0&&function(){for(var t=Math.max.apply(Math,_toConsumableArray(i.map(function(t){return t[0].x}))),o=Math.max.apply(Math,_toConsumableArray(i.map(function(t){return t[t.length-1].x}))),r=i.map(function(){return 0}),a=t;a<=o;){n.push({x:a,samples:i.map(function(t,e){return t[r[e]]})});var s=a;a=r.reduce(function(t,e,o){var n=i[o][e+1];return void 0!==n&&n.x<t&&(t=n.x),t},Number.POSITIVE_INFINITY),e._busTransitionWidth=Math.min(e._busTransitionWidth,.1*(a-s)),r.forEach(function(t,e){var o=i[e][t+1];void 0!==o&&o.x<=a&&r[e]++})}}(),n}},{key:"_initializeSignalAndBusPositions",value:function(t){var e=this;this._setSignalsVisibility(t),this._initializeBusPositions(t),t.getData().forEach(function(i){i.digitalWaveform.signal.visible&&e._initializeSignalPosition(t,i)})}},{key:"_setSignalsVisibility",value:function(t){var e=t.getOptions().buses;t.getData().forEach(function(t){var i=e[t.digitalWaveform.signal.bus];t.digitalWaveform.signal.visible=t.digitalWaveform.signal.show&&(!i||!i.collapsed)})}},{key:"_initializeBusPositions",value:function(t){var e=this,i=t.getData(),o=i.filter(function(t){return!t.digitalWaveform.signal.visible}),n=t.getOptions().buses.filter(function(t){return t.visible});n.forEach(function(o){var n=e._getBusSignals(t,o),r=n.map(function(t){return i.indexOf(t)}),a=Math.max.apply(Math,_toConsumableArray(r));o.index=a+1}),n.sort(function(t,e){return t.index-e.index}),n.forEach(function(t,n){var r=t.index,a=r-o.filter(function(t){return i.indexOf(t)<r}).length,s=a+n;t.index=a,t.top=e._calculateTopBoundary(s),t.bottom=e._calculateBottomBoundary(s)})}},{key:"_initializeSignalPosition",value:function(t,e){var i=t.getData(),o=t.getOptions().buses,n=i.filter(function(t){return!t.digitalWaveform.signal.visible}),r=i.indexOf(e),a=r-n.filter(function(t){return i.indexOf(t)<r}).length,s=a+o.filter(function(t){return t.index<=a}).length;e.digitalWaveform.signal.top=this._calculateTopBoundary(s),e.digitalWaveform.signal.bottom=this._calculateBottomBoundary(s)}},{key:"_adjustSeriesDataRange",value:function(t,e,i){if(this._lazyInitialize(t),e.digitalWaveform.show&&e.data.length>1){var o=e.datapoints.points,n=e.datapoints.pointsize,r=o[o.length-n]-o[o.length-2*n];i.xmax+=r}}},{key:"_setRange",value:function(t,e){switch(this._lazyInitialize(t),e.direction){case"y":var i=t.getData().filter(function(t){return t.digitalWaveform.signal.visible}),o=t.getOptions().buses.filter(function(t){return t.visible}),n=i.map(function(t){return t.digitalWaveform.signal.bottom}).concat(i.map(function(t){return t.digitalWaveform.signal.top})).concat(o.map(function(t){return t.bottom})).concat(o.map(function(t){return t.top}));e.datamin=Math.min.apply(Math,_toConsumableArray(n)),e.datamax=Math.max.apply(Math,_toConsumableArray(n))}}},{key:"_draw",value:function(t,e){this._lazyInitialize(t);var i=t.getOptions(),o=t.getPlotOffset();e.save(),e.translate(o.left,o.top),e.lineWidth=i.series.digitalWaveform.lineWidth,e.lineCap="round",e.lineJoin="round",this._drawSignals(t,e),this._drawBuses(t,e),e.restore()}},{key:"_drawSignals",value:function(t,e){var i=this;t.getData().forEach(function(t){t.digitalWaveform.signal.visible&&i._drawSignal(e,t)})}},{key:"_drawSignal",value:function(t,e){var i=e.digitalWaveform.signal.top,n=e.digitalWaveform.signal.bottom;if(!(i<e.yaxis.min||n>e.yaxis.max)){t.save(),this._clipCanvasToAxes(t,e.xaxis,e.yaxis);for(var r=e.yaxis.p2c(i),a=e.yaxis.p2c(n),s=0,h=null;s<e.datapoints.points.length;s+=e.datapoints.pointsize){var l=e.datapoints.points[s],u=s+e.datapoints.pointsize<e.datapoints.points.length?e.datapoints.points[s+e.datapoints.pointsize]:e.datapoints.points[s]+e.datapoints.points[s]-e.datapoints.points[s-e.datapoints.pointsize];if(!(l>e.xaxis.max||u<e.xaxis.min)){var d=o.fromDatapoints(e.datapoints,s),c=this._lookupStateShape(d),f=this._lookupStateColor(d);if(c&&f){var p=e.xaxis.p2c(l),g=e.xaxis.p2c(u),m=o.fromDatapoints(e.datapoints,s-e.datapoints.pointsize),v=o.fromDatapoints(e.datapoints,s+e.datapoints.pointsize);h=this._drawState(t,p,g,r,a,h,c,f,d.equals(m),d.equals(v))}else h=null}}t.restore()}}},{key:"_clipCanvasToAxes",value:function(t,e,i){var o=e.p2c(e.min),n=e.p2c(e.max),r=i.p2c(i.min),a=i.p2c(i.max);t.beginPath(),t.rect(o,a,n-o,r-a),t.clip()}},{key:"_lookupStateShape",value:function(t){var e=this._states.get(t.state);return e?e.shape:null}},{key:"_lookupStateColor",value:function(t){var e=this._states.get(t.state);if(e&&e.color)return e.color;var i=this._strengths.get(t.strength);return i?i.color:null}},{key:"_drawState",value:function(t,e,i,o,n,r,a,s,h,l){switch(a){case"step_down":this.renderer.drawStep(t,e,i,n,r,s),r=n;break;case"step_up":this.renderer.drawStep(t,e,i,o,r,s),r=o;break;case"step_center":var u=(o+n)/2;this.renderer.drawStep(t,e,i,u,r,s),r=u;break;case"rect_filled":this.renderer.drawRect(t,e,i,o,n,s,!0,!h,!l),r=null}return r}},{key:"_drawBuses",value:function(t,e){var i=this;t.getOptions().buses.forEach(function(o){o.visible&&o.samples.length>1&&i._drawBus(t,e,o)})}},{key:"_drawBus",value:function(t,e,i){this._drawBusLines(t,e,i),i.showLabels&&this._drawBusLabels(t,e,i)}},{key:"_drawBusLines",value:function(t,e,i){var o=t.getAxes(),n=i.top,r=i.bottom;if(!(n<o.yaxis.min||r>o.yaxis.max)){e.save(),this._clipCanvasToAxes(e,o.xaxis,o.yaxis);for(var a=o.yaxis.p2c(n),s=o.yaxis.p2c(r),h=0;h<i.samples.length;h++){var l=i.samples[h].x,u=h+1<i.samples.length?i.samples[h+1].x:i.samples[h].x+i.samples[h].x-i.samples[h-1].x;if(!(l>o.xaxis.max||u<o.xaxis.min)){var d=i.values[h],c=i.shapes[h],f=i.colors[h];if(d&&c&&f){var p=o.xaxis.p2c(l),g=o.xaxis.p2c(u),m=o.xaxis.p2c(l+this._busTransitionWidth/2),v=o.xaxis.p2c(u-this._busTransitionWidth/2),b=i.values[h-1],y=i.values[h+1];switch(c){case"rect":this.renderer.drawRect(e,p,g,a,s,f,!1,d!==b,d!==y);break;case"rect_cross_x":this.renderer.drawRectCrossX(e,p,g,m,v,a,s,f,d!==b,d!==y)}}}}e.restore()}}},{key:"_drawBusLabels",value:function(t,e,i){var o=t.getAxes(),n=i.top,r=i.bottom;if(!(n<o.yaxis.min||r>o.yaxis.max)){switch(e.save(),this._clipCanvasToAxes(e,o.xaxis,o.yaxis),e.font=t.getPlaceholder().css("font"),e.textBaseline="middle",i.labelPosition){case"center":e.textAlign="center";break;case"left":e.textAlign="left";break;case"right":e.textAlign="right"}for(var a=o.yaxis.p2c(n),s=o.yaxis.p2c(r),h=(a+s)/2,l=0,u=null;l<i.samples.length;l++){var d=i.values[l],c=i.values[l+1];if(d&&(null===u&&(u=i.samples[l].x),d!==c)){var f=l+1<i.samples.length?i.samples[l+1].x:i.samples[l].x+i.samples[l].x-i.samples[l-1].x;if(u<=o.xaxis.max&&f>=o.xaxis.min){var p=this._busTransitionWidth,g=void 0;switch(i.labelPosition){case"center":g=o.xaxis.p2c((u+f)/2);break;case"left":g=o.xaxis.p2c(u+p/2);break;case"right":g=o.xaxis.p2c(f-p/2)}var m=this._getFormattedBusValue(i,d),v=o.xaxis.p2c(f-p)-o.xaxis.p2c(u+p);this._drawText(e,g,h,m,v)}u=null}}e.restore()}}},{key:"_getFormattedBusValue",value:function(t,e){var i=parseInt(e,2);switch(t.labelFormatter){case"binary":var o=e.length;return isNaN(i)?e:i.toString(2).padStart(o,0);case"decimal":var n=Math.ceil(Math.log10(Math.pow(2,e.length)));return isNaN(i)?e:i.toString(10).padStart(n,0);case"hex":var r=Math.ceil(Math.log(Math.pow(2,e.length))/Math.log(16));return isNaN(i)?e:i.toString(16).toUpperCase().padStart(r,0);default:return e}}},{key:"_drawText",value:function(t,e,i,o,n){var r=this._getFittingText(t,o,n);t.fillText(r,e,i)}},{key:"_getFittingText",value:function(t,e,i){var o=t.measureText("...").width,n=t.measureText(e).width;if(n>i&&n>o){for(;n+o>i&&e.length>1;)e=e.substring(0,e.length-1),n=t.measureText(e).width;e+="..."}return e}},{key:"_calculateTopBoundary",value:function(t){return.9+1*t}},{key:"_calculateBottomBoundary",value:function(t){return(1-.8)/2+1*t}}]),t}();t.plot.plugins.push({init:e,options:n.defaultOptions,name:"digitalWaveform",version:"1.0"})}(jQuery),function(t){function e(t){var e=function(t){return"digital"===t.options.type};return t.getYAxes().filter(function(t){return e(t)})[0]}function i(t){t.hooks.processOptions.push(o)}function o(t,i){var o=e(t);if(o){t.hooks.processDatapoints.push(n),t.hooks.processOffset.push(r),t.hooks.draw.push(a),o.options.show=!1;for(var s=0;s<i.buses.length;s++)i.buses[s].label||(i.buses[s].label="Bus ".concat(s+1))}}function n(t,e,i){if(e.digitalWaveform.show&&!e.label){var o=t.getData();e.label="Signal ".concat(o.indexOf(e)+1)}}function r(t,i){var o=t.getPlaceholder(),n=e(t);if("automatic"===n.options.width){var r=t.getData(),a=t.getOptions().buses,s=0,h=function(t){t.css("visibility","hidden"),o.append(t);var e=t.outerWidth();return t.remove(),e};if(r.forEach(function(t){if(t.digitalWaveform.signal.visible){var e=void 0!==a[t.digitalWaveform.signal.bus],i=u(0,0,t.label,n.options.signalSymbol,e),o=h(i);s=Math.max(s,o)}}),a.forEach(function(t){var e=l(0,0,t.label,n.options.busSymbolCollapsed,!1),i=h(e);s=Math.max(s,i)}),s>0){var d=(s+10)/o.width(),c=Math.min(d,.5);n.options.elementWidth=o.width()*c}}else n.options.elementWidth=n.options.width;i.left+=n.options.elementWidth}function a(t,e){var i=t.getPlaceholder(),o=s(t);i.append(o)}function s(i){var o=i.getPlaceholder(),n="flot-digital-axis",r=o.find("#".concat(n));0===r.length?r=t('<div id="'.concat(n,'"></div>')):r.empty();var a=e(i),s=i.getPlotOffset();r.css({width:"".concat(a.options.elementWidth,"px"),position:"absolute",top:s.top,bottom:s.bottom,overflow:"hidden"});var u=i.getData(),d=i.getOptions().buses;return d.forEach(function(t,e){if(t.visible){var o=u.filter(function(t){return t.digitalWaveform.signal.bus===e}),n=o.some(function(t){return t.digitalWaveform.signal.visible}),s=function(){n?i.collapseBus(t):i.expandBus(t),i.setupGrid(!0),i.draw()},d=n?a.options.busSymbolExpanded:a.options.busSymbolCollapsed,c=l(a.p2c(t.top),a.p2c(t.bottom),t.label,d,n,s);r.append(c),o.forEach(function(t){t.digitalWaveform.signal.visible&&h(r,t,u,a,!0)})}}),u.filter(function(t){return!d[t.digitalWaveform.signal.bus]}).forEach(function(t){t.digitalWaveform.signal.visible&&h(r,t,u,a,!1)}),r}function h(t,e,i,o,n){var r=e.digitalWaveform.signal,a=o.options.signalSymbol,s=u(o.p2c(r.top),o.p2c(r.bottom),e.label,a,n);t.append(s)}function l(t,e,i,o,n,r){var a=d(t,e);a.addClass("flot-digital-axis-bus");var s=f(n?"arrow-up":"arrow-down",o);return s.css({cursor:"pointer"}),s.click(r),s.appendTo(a),c(i).appendTo(a),a}function u(t,e,i,o,n){var r=d(t,e);return r.addClass("flot-digital-axis-signal"),n&&r.css("padding-left","25px"),f("digital-signal",o).appendTo(r),c(i).appendTo(r),r}function d(e,i){return t("<div>",{css:{position:"absolute",top:e,height:i-e,display:"flex","align-items":"center"}})}function c(e){return t("<div>",{css:{order:2,"white-space":"nowrap"}}).append(t("<span>",{html:e}))}function f(e,i){var o=t("<div>",{css:{order:1,display:"flex","align-items":"center","margin-right":"10px"}});if(i)o.append(i);else{o.css("width","12px");var n=t(document.createElementNS("http://www.w3.org/2000/svg","svg"));n.css({width:"100%",height:"100%"}),n.attr({viewBox:"0 0 100 100"}),n.appendTo(o);var r=t(document.createElementNS("http://www.w3.org/2000/svg","path"));r.attr({stroke:"black","stroke-width":15,fill:"transparent",d:function(t){switch(t){case"arrow-down":return"M10 25 L 50 75 L 90 25";case"arrow-up":return"M10 75 L 50 25 L 90 75";case"digital-signal":return"M0 80 L 50 80 L 50 20 L 100 20";default:return null}}(e)}),r.appendTo(n)}return o}var p={yaxis:{width:"automatic"}};t.plot.plugins.push({init:i,options:p,name:"digitalAxis",version:"1.0"})}(jQuery),function(t){function e(t){var e;t.hooks.processOptions.push(function(t,o){o.series.highlights&&o.series.highlights.show&&(e=new i(t,o))}),t.getHighlights=function(){return e}}var i=function(){function e(t,i){_classCallCheck(this,e),this._processOptions(i),this._createHooks(t)}return _createClass(e,null,[{key:"defaultOptions",get:function(){return{series:{highlights:{selectedRange:[],selectedIndexes:[],show:!1,highlightLineWidth:1,highlightColor:"#ffffff",highlightPoints:!0,highlightLines:!1,highlightBars:!1}}}}}]),_createClass(e,[{key:"_createHooks",value:function(t){var e=this;t.hooks.drawOverlay.push(function(t,i,o){e._drawOverlay(t,i,o)})}},{key:"_processOptions",value:function(e){t.extend(!0,e,this.defaultOptions),this._options=e.series.highlights}},{key:"_drawOverlay",value:function(t,e){var i=t.getData();if(this._options.show){var o=t.getPlotOffset();e.save(),e.translate(o.left,o.top),e.lineWidth=this._options.lineWidth,e.lineCap="round",e.lineJoin="round";for(var n=0;n<i.length;n++){var r=i[n].datapoints.pointsize,a=this._options.selectedIndexes[n];if(a)for(var s=0;s<a.length;s++){var h=a[s];this._options.highlightPoints&&this._drawPointHighlight(i[n],t,e,h),this._options.highlightBars&&this._drawBarHighlight(i[n],[i[n].datapoints.points[h*r],i[n].datapoints.points[h*r+1]],e)}var l=this._options.selectedRange[n];if(l){for(var u=l[0];u<l[1];u++)this._options.highlightPoints&&this._drawPointHighlight(i[n],t,e,u),this._options.highlightBars&&this._drawBarHighlight(i[n],[i[n].datapoints.points[u*r],i[n].datapoints.points[u*r+1]],e);this._options.highlightLines&&this._drawLineHighlight(i[n],t,e,l)}this._options.highlightLines&&a&&a.length>0&&this._drawLineHighlight(i[n],t,e)}e.restore()}}},{key:"_drawPointHighlight",value:function(e,i,o,n){var r=e.datapoints.pointsize,a=e.datapoints.points[n*r],s=e.datapoints.points[n*r+1],h=e.xaxis,l=e.yaxis,u="string"==typeof this._options.highlightColor?this._options.highlightColor:t.color.parse(e.color).scale("a",.5).toString();if(!(a<h.min||a>h.max||s<l.min||s>l.max)){o.save();var d=e.points.radius+e.points.lineWidth/2;o.lineWidth=d,o.strokeStyle=u,o.fillStyle=u,o.shadowColor="black",o.shadowBlur=3,o.shadowOffsetY=1;var c=1.5*d;a=h.p2c(a),s=l.p2c(s),o.beginPath();var f=e.points.symbol;"circle"===f?o.arc(a,s,c,0,2*Math.PI,!1):"string"==typeof f&&i.drawSymbol&&i.drawSymbol[f]&&i.drawSymbol[f](o,a,s,c,!1),o.closePath(),o.fill(),o.restore()}}},{key:"_drawLineHighlight",value:function(e,i,o,n){var r,a=this,s=e.datapoints.pointsize,h=i.getPlotOffset();o.translate(-h.left,-h.top);var l=e.lines.lineWidth,u=e.color;e.lines.lineWidth+=this._options.lineWidth,e.color=this._options.highlightColor,n&&(r=_toConsumableArray(e.datapoints.points),e.datapoints.points.splice(n[1]*s),e.datapoints.points.splice(0,n[0]*s)),t.plot.drawSeries.drawSeriesLines(e,o,h,i.width(),i.height(),i.drawSymbol,function(){return a._options.highlightColor}),n&&(e.datapoints.points=r),e.lines.lineWidth=l,e.color=u,t.plot.drawSeries.drawSeriesLines(e,o,h,i.width(),i.height(),i.drawSymbol,function(){return a._options.highlightColor}),t.plot.drawSeries.drawSeriesPoints(e,o,h,i.width(),i.height(),i.drawSymbol,function(){return a._options.highlightColor}),o.translate(h.left,h.top)}},{key:"_drawBarHighlight",value:function(e,i,o){var n,r="string"==typeof this._options.highlightColor?this._options.highlightColor:t.color.parse(e.color).scale("a",.5).toString(),a=e.bars.barWidth[0]||e.bars.barWidth;switch(e.bars.align){case"left":n=0;break;case"right":n=-a;break;default:n=-a/2}o.lineWidth=e.bars.lineWidth,o.strokeStyle=r;var s=e.bars.fillTowards||0,h=s>e.yaxis.min?Math.min(e.yaxis.max,s):e.yaxis.min;t.plot.drawSeries.drawBar(i[0],i[1],i[2]||h,n,n+a,function(){return"transparent"},e.xaxis,e.yaxis,o,e.bars.horizontal,e.bars.lineWidth)}}]),e}();t.plot.plugins.push({init:e,options:i.defaultOptions,name:"highlights",version:"1.0"})}(jQuery),function(t){function e(){if(!(this instanceof e))return arguments.length>1||"number"!=typeof arguments[0]?e.apply(new e(arguments.length),arguments):new e(arguments[0]);if(0===arguments.length)throw new Error("Missing Argument: You must pass a valid buffer length");return this.size=this.start=0,this.overflow=null,arguments.length>1||"number"!=typeof arguments[0]?(this.data=new Array(arguments.length),this.end=(this.length=arguments.length)-1,this.push.apply(this,arguments)):(this.data=new Array(arguments[0]),this.end=(this.length=arguments[0])-1),this}function i(t,e){return t==e?0:t>e?1:-1}e.prototype={constructor:e,pop:function(){var t;if(0!==this.size)return t=this.data[this.end],delete this.data[this.end],this.end=(this.end-1+this.length)%this.length,this.size--,t},push:function(t){return this.data[(this.end+1)%this.length]=t,this.size<this.length&&this.size++,this.end=(this.end+1)%this.length,this.start=(this.length+this.end-this.size+1)%this.length,this.size},reverse:function(){for(var t,e=0;e<~~(this.size/2);e++)t=this.data[(this.start+e)%this.length],this.data[(this.start+e)%this.length]=this.data[(this.start+(this.size-e-1))%this.length],this.data[(this.start+(this.size-e-1))%this.length]=t;return this},rotateLeft:function(t){if(void 0===t&&(t=1),"number"!=typeof t)throw new Error("Argument must be a number");for(;--t>=0;)this.push(this.shift());return this},rotateRight:function(t){if(void 0===t&&(t=1),"number"!=typeof t)throw new Error("Argument must be a number");for(;--t>=0;)this.unshift(this.pop());return this},shift:function(){var t;if(0!==this.size)return t=this.data[this.start],this.start=(this.start+1)%this.length,this.size--,t},sort:function(t){return this.data.sort(t||i),this.start=0,this.end=this.size-1,this},unshift:function(){var t=0;if(this.overflow&&this.size+arguments.length>this.length)for(;t<this.size+arguments.length-this.length;t++)this.overflow(this.data[this.end-t%this.length],this);for(t=0;t<arguments.length;t++)this.data[(this.length+this.start-t%this.length-1)%this.length]=arguments[t];return this.length-this.size-t<0&&(this.end+=this.length-this.size-t,this.end<0&&(this.end=this.length+this.end%this.length)),this.size<this.length&&(this.size+t>this.length?this.size=this.length:this.size+=t),this.start-=arguments.length,this.start<0&&(this.start=this.length+this.start%this.length),this.size},indexOf:function(t,e){for(e||(e=0);e<this.size;e++)if(this.data[(this.start+e)%this.length]===t)return e;return-1},lastIndexOf:function(t,e){for(e||(e=this.size-1);e>=0;e--)if(this.data[(this.start+e)%this.length]===t)return e;return-1},sortedIndex:function(t,e,o){e=e||i;var n=this.start,r=this.size-1;for(n&&e.call(o,t,this.data[r])>0&&(n=0,r=this.end);n<r;){var a=n+r>>>1;e.call(o,t,this.data[a])>0?n=a+1:r=a}return((n-this.start)%this.size+this.size)%this.size},every:function(t,e){for(var i=0;i<this.size;i++)if(!t.call(e,this.data[(this.start+i)%this.length],i,this))return!1;return!0},forEach:function(t,e){for(var i=0;i<this.size;i++)t.call(e,this.data[(this.start+i)%this.length],i,this)},some:function(t,e){for(var i=0;i<this.size;i++)if(t.call(e,this.data[(this.start+i)%this.length],i,this))return!0;return!1},avg:function(){return 0==this.size?0:this.sum()/this.size},sum:function(){for(var t=this.size,e=0;t--;)e+=this.data[t];return e},median:function(){if(0===this.size)return 0;var t=this.slice().sort(i),e=Math.floor(t.length/2);return t.length%2?t[e]:(t[e-1]+t[e])/2},empty:function(){return this.size=this.start=0,this.end=this.length-1,this},fill:function(t){var e=0;if("function"==typeof t)for(;this.data[e]=t(),++e<this.length;);else for(;this.data[e]=t,++e<this.length;);return this.start=0,this.end=this.length-1,this.size=this.length,this},first:function(){return this.data[this.start]},last:function(){return this.data[this.end]},get:function(t){return this.data[(this.start+t)%this.length]},isFull:function(t){return this.length===this.size},set:function(t,e){return this.data[(this.start+t)%this.length]=e},toArray:function(){return this.slice()},slice:function(t,e){var i=this.size;if((t=+t||0)<0){if(t>=e)return[];t=-t>i?0:i+t}null==e||e>i?e=i:e<0?e+=i:e=+e||0,i=t<e?e-t:0;for(var o=Array(i),n=0;n<i;n++)o[n]=this.data[(this.start+t+n)%this.length];return o}},"object"===("undefined"==typeof module?"undefined":_typeof(module))&&module.exports?module.exports=e:t.CBuffer=e}(window),function(t){var e=function(t,e){this.hb=new HistoryBufferNumeric(t,e),this.hbType="numeric"};e.prototype.setType=function(t){var e=this;if(t!==this.hbType){if("numeric"===t){var i=this.hb.callbacks;this.hb.callbacks=void 0,this.hb=new HistoryBufferNumeric(this.capacity,this.width),i.forEach(function(t,i){e.hb.registerOnChange(i,t)}),this.hbType="numeric",this.hb.callOnChange()}if("analogWaveform"===t){var i=this.hb.callbacks;this.hb.callbacks=void 0,this.hb=new HistoryBufferWaveform(this.capacity,this.width),i.forEach(function(t,i){e.hb.registerOnChange(i,t)}),this.hbType="analogWaveform",this.hb.callOnChange()}}},e.prototype.clear=function(){this.hb.clear()},e.prototype.setCapacity=function(t){this.hb.setCapacity(t)},e.prototype.setWidth=function(t){this.hb.setWidth(t)},e.prototype.push=function(t){this.hb.push(t)},e.prototype.startIndex=function(){return this.hb.startIndex()},e.prototype.lastIndex=function(){return this.hb.lastIndex()},e.prototype.get=function(t){return this.hb.get(t)},e.prototype.appendArray=function(t){this.hb.appendArray(t)},e.prototype.toArray=function(){return this.hb.toArray()},e.prototype.toDataSeries=function(t){return this.hb.toDataSeries(t)},e.prototype.registerOnChange=function(t,e){this.hb.registerOnChange(t,e)},e.prototype.deregisterOnChange=function(t,e){this.hb.deregisterOnChange(t,e)},e.prototype.query=function(t,e,i,o){return this.hb.query(t,e,i,o)},e.prototype.rangeX=function(t){return this.hb.rangeX(t)},e.prototype.rangeY=function(t,e,i){return this.hb.rangeY(t,e,i)},e.prototype.toJSON=function(){return this.hb.toJSON()},Object.defineProperty(e.prototype,"width",{get:function(){return this.hb.width}}),Object.defineProperty(e.prototype,"count",{get:function(){return this.hb.count},set:function(t){this.hb.count=t}}),Object.defineProperty(e.prototype,"capacity",{get:function(){return this.hb.capacity}}),"object"===("undefined"==typeof module?"undefined":_typeof(module))&&module.exports?module.exports=e:t.HistoryBuffer=e}(window),function(t){var e=function(t,e){this.capacity=t||1024,this.width=e||1,this.lastUpdatedIndex=0,this.firstUpdatedIndex=0,this.branchFactor=32,this.buffers=[],this.trees=[]
;for(var i=0;i<this.width;i++)this.buffers.push(new CBuffer(t)),this.trees.push(new SegmentTree(this,this.buffers[i]));this.buffer=this.buffers[0],this.tree=this.trees[0],this.count=0,this.callbacks=new Map,this.changed=!1};e.prototype.callOnChange=function(t){this.callbacks.forEach(function(e){e(t)})},e.prototype.setBranchingFactor=function(t){this.branchFactor=t,this.rebuildSegmentTrees()},e.prototype.getDefaultBranchingFactor=function(){return 32},e.prototype.rebuildSegmentTrees=function(){this.trees=[];for(var t=0;t<this.width;t++)this.trees.push(new SegmentTree(this,this.buffers[t]));this.tree=this.trees[0],this.firstUpdatedIndex=this.startIndex(),this.lastUpdatedIndex=this.firstUpdatedIndex,this.updateSegmentTrees()},e.prototype.clear=function(){for(var t=0;t<this.width;t++)this.buffers[t].empty();this.count=0,this.rebuildSegmentTrees(),this.changed=!0,this.callOnChange&&this.callOnChange()},e.prototype.setCapacity=function(t){if(t!==this.capacity){this.capacity=t,this.buffers=[];for(var e=0;e<this.width;e++)this.buffers.push(new CBuffer(t));this.buffer=this.buffers[0],this.count=0,this.rebuildSegmentTrees(),this.changed=!0,this.callOnChange&&this.callOnChange()}},e.prototype.setWidth=function(t){if(t!==this.width){this.width=t,this.buffers=[];for(var e=0;e<this.width;e++)this.buffers.push(new CBuffer(this.capacity));this.buffer=this.buffers[0],this.count=0,this.rebuildSegmentTrees(),this.changed=!0,this.callOnChange&&this.callOnChange()}},e.prototype.getWidth=function(){return this.width},e.prototype.pushNoStatsUpdate=function(t){if("number"==typeof t&&1===this.width)this.buffer.push(t);else if(Array.isArray(t)&&t.length===this.width)for(var e=0;e<this.width;e++)this.buffers[e].push(t[e])},e.prototype.push=function(t){this.pushNoStatsUpdate(t),this.count++,this.changed=!0,this.callOnChange&&this.callOnChange()},e.prototype.startIndex=function(){return Math.max(0,this.count-this.capacity)},e.prototype.lastIndex=function(){return this.startIndex()+this.buffer.size},e.prototype.get=function(t){if(t-=this.startIndex(),1===this.width)return this.buffer.get(t);for(var e=[],i=0;i<this.width;i++)e.push(this.buffers[i].get(t));return e},e.prototype.appendArray=function(t){for(var e=0;e<t.length;e++)this.pushNoStatsUpdate(t[e]);this.count+=t.length,this.changed=!0,this.callOnChange&&this.callOnChange()},e.prototype.toArray=function(){if(1===this.width)return this.buffer.toArray();for(var t=this.startIndex(),e=this.lastIndex(),i=[],o=t;o<e;o++)i.push(this.get(o));return i},e.prototype.updateSegmentTrees=function(){var t=this.buffer;this.trees.forEach(function(t){t.updateSegmentTree()}),this.firstUpdatedIndex=this.startIndex(),this.lastUpdatedIndex=this.firstUpdatedIndex+t.size},e.prototype.toDataSeries=function(t){for(var e=this.buffer,i=[],o=this.startIndex(),n=0;n<e.size;n++)i.push([n+o,this.buffers[t||0].get(n)]);return i},e.prototype.registerOnChange=function(t,e){if(this.callbacks.has(t))return void console.log("Callback with the given key has already been registered.");this.callbacks.set(t,e)},e.prototype.deregisterOnChange=function(t){this.callbacks.delete(t)},e.prototype.query=function(t,e,i,o){return void 0===o&&(o=0),this.changed&&(this.updateSegmentTrees(),this.changed=!1),this.trees[o].query(t,e,i)},e.prototype.rangeX=function(t){var e=this.startIndex(),i=this.lastIndex()-1;return i===e-1?{}:{xmin:e,xmax:i,deltamin:1}},e.prototype.rangeY=function(t,e,i){null!==t&&void 0!==t||(t=this.startIndex()),null!==e&&void 0!==e||(e=this.lastIndex()-1),null!==i&&void 0!==i||(i=0),this.changed&&(this.updateSegmentTrees(),this.changed=!1);var o=this.query(t,e,e-t,i),n=o.length;if(n>0){for(var r={ymin:1/0,ymax:-1/0},a=0;a<n;a+=2)null==o[a+1]||o[a+1]===1/0||o[a+1]===-1/0||isNaN(o[a+1])||(r.ymin=Math.min(r.ymin,o[a+1]),r.ymax=Math.max(r.ymax,o[a+1]));return r}return{}},e.prototype.toJSON=function(){var t={data:[],width:this.width,capacity:this.capacity,valueType:"HistoryBuffer",startIndex:this.startIndex(),count:this.count};if(1===this.width)t.data=this.buffer.toArray();else for(var e=0;e<this.width;e++)t.data.push(this.buffers[e].toArray());return t},"object"===("undefined"==typeof module?"undefined":_typeof(module))&&module.exports?module.exports=e:t.HistoryBufferNumeric=e}(window),function(t){function e(t,e,i){if(0===t.Y.length)return!1;var o=new NITimestamp(t.t0),n=o.valueOf(),r=o.valueOf()+t.Y.length*t.dt;return!(n<e&&r<e)&&!(n>i&&r>i)}function i(t,e){if(1==t.Y.length||1==e.Y.length)return!1;var i=new NITimestamp(t.t0).add(t.dt*(t.Y.length-1)).valueOf();return new NITimestamp(e.t0).valueOf()-i>=2*t.dt}function o(t,e,i,o){for(var n,r=t.Y,a=t.t0,s=new NITimestamp(a),h=0;h<r.length;h++)n=s.valueOf(),n>=e-t.dt&&n<=i+t.dt&&(o.push(n),o.push(r[h])),s.add(t.dt)}function n(t,e){for(var i,o=t.Y,n=t.t0,r=new NITimestamp(n),a=0;a<o.length;a++)i=r.valueOf(),e.push([i,o[a]]),r.add(t.dt)}function r(t,e,i,o){var n,r,a,s=t.Y,h=new NITimestamp(t.t0);if(0!==s.length&&(n=h.valueOf(),r=new NITimestamp(h).add(t.dt*t.Y.length).valueOf(),!(n>o||r<i)))for(var l=0;l<s.length;l++)(a=new NITimestamp(h).add(t.dt*l).valueOf())<i||a>o||null==s[l]||s[l]===1/0||s[l]===-1/0||isNaN(s[l])||(s[l]>e.max&&(e.max=s[l]),s[l]<e.min&&(e.min=s[l]))}var a=function(t,e){this.capacity=t||1024,this.width=e||1,this.buffers=[];for(var i=0;i<this.width;i++)this.buffers.push(new CBuffer(t));this.buffer=this.buffers[0],this.count=0,this.callbacks=new Map,this.changed=!1};a.prototype.__proto__=HistoryBufferNumeric.prototype,a.prototype.rebuildSegmentTrees=function(){},a.prototype.pushNoStatsUpdate=function(t){if(1!==this.width||Array.isArray(t)){if(Array.isArray(t)&&t.length===this.width)for(var e=0;e<this.width;e++)this.buffers[e].push(t[e])}else this.buffer.push(t)},a.prototype.getTreeNodes=function(t,e,i){},a.prototype.updateSegmentTrees=function(){},a.prototype.query=function(t,n,r,a){void 0===a&&(a=0);var s=[],h=this.buffers[a].toArray(),l=h[0];return h.forEach(function(r){e(r,t,n)&&(i(l,r)&&(s.push(null),s.push(null)),l=r,o(r,t,n,s))}),s},a.prototype.toDataSeries=function(t){void 0===t&&(t=0);var e=[],o=this.buffers[t].toArray(),r=o[0];return o.forEach(function(t){i(r,t)&&e.push([null,null]),r=t,n(t,e)}),e},a.prototype.rangeX=function(t){var e,i,o,n=1/0,r=-1/0,a=1/0;void 0===t&&(t=0);var s=this.buffers[t].toArray();if(0===s.length)return{};if(s.forEach(function(t){e=new NITimestamp(t.t0),i=e.valueOf(),o=new NITimestamp(e).add(t.dt*(t.Y.length-1)).valueOf(),i<n&&(n=i),o>r&&(r=o),a>Math.abs(t.dt)&&(a=Math.abs(t.dt))}),0===a&&(a=1),n>r){var h=n;n=r,r=h}return{xmin:n,xmax:r,deltamin:a}},a.prototype.rangeY=function(t,e,i){var o={min:1/0,max:-1/0};null!==i&&void 0!==i||(i=0);var n=this.buffers[i].toArray();if(0===n.length)return{};if(null!==t&&void 0!==t||(t=new NITimestamp(n[0].t0).valueOf()),null===e||void 0===e){var a=n[n.length-1];e=new NITimestamp(a.t0).add(a.dt*a.Y.length).valueOf()}return n.forEach(function(i){r(i,o,t,e)}),{ymin:o.min,ymax:o.max}},a.prototype.toJSON=function(){return{data:this.toArray(),width:this.width,capacity:this.capacity,valueType:"HistoryBuffer",startIndex:this.startIndex(),count:this.count}},"object"===("undefined"==typeof module?"undefined":_typeof(module))&&module.exports?module.exports=a:t.HistoryBufferWaveform=a}(window),function(t){function e(t,e,i){e<i.min&&(i.min=e,i.minIndex=t),e>i.max&&(i.max=e,i.maxIndex=t)}function i(t,e){t.min<e.min&&(e.min=t.min,e.minIndex=t.minIndex),t.max>e.max&&(e.max=t.max,e.maxIndex=t.maxIndex)}function o(t,e){return e*Math.floor(t/e)}var n=function(){this.init()},r=function(t,e){this.historyBuffer=t,this.cbuffer=e,this.tree=this.buildEmptySegmentTree()};n.prototype.init=function(){this.maxIndex=0,this.minIndex=0,this.max=Math.Nan,this.min=Math.Nan};var a=function(t,e){this.level=e,this.step=Math.pow(t.branchFactor,e),this.capacity=Math.ceil(t.capacity/Math.pow(t.branchFactor,e))+1,this.startIndex=0,this.nodes=new CBuffer(this.capacity)};a.prototype.rotate=function(){this.startIndex+=this.step;var t=this.nodes.shift();t.init(),this.nodes.push(t)},a.prototype.init=function(t){this.startIndex=t,this.nodes.forEach(function(t){t.init()})},r.prototype.get=function(t){return t-=this.historyBuffer.startIndex(),this.cbuffer.get(t)},r.prototype.getTreeNode=function(t,e){var i=this.tree.levels[t],o=i.step,n=Math.floor((e-i.startIndex)/o);return n<0||n>=i.capacity?null:i.nodes.get(n)},r.prototype.buildEmptySegmentTree=function(){var t=this.historyBuffer,e=Math.ceil(Math.log(t.capacity)/Math.log(t.branchFactor))-1;e<1&&(e=1);for(var i={depth:e,levels:[]},o=0;o<e;o++){var r=new a(t,o+1);i.levels.push(r);for(var s=0;s<r.capacity;s++){var h=new n;r.nodes.push(h)}}return i},r.prototype.populateTreeLevel=function(t,e){var i,n,r,a,s,h=this.historyBuffer,l=this.cbuffer,u=h.startIndex(),d=h.lastIndex(),c=0,f=0,p=!0,g={step:1,startIndex:u},m=0===e?g:this.tree.levels[e-1],v=this.tree.levels[e];for(t=o(t,v.step),m.startIndex>t&&(t=m.startIndex,c=t/m.step%h.branchFactor),f=t;f<d;f+=m.step){if(0===e){var b=l.get(f-u);p?(n=b,r=f,a=b,s=f,p=!1):(b>n&&(n=b,r=f),b<a&&(a=b,s=f))}else{var y=this.getTreeNode(e-1,f);p?(n=y.max,r=y.maxIndex,a=y.min,s=y.minIndex,p=!1):(y.max>n&&(n=y.max,r=y.maxIndex),y.min<a&&(a=y.min,s=y.minIndex))}c++,c===h.branchFactor&&(c=0,p=!0,i=this.getTreeNode(e,f),i.max=n,i.maxIndex=r,i.min=a,i.minIndex=s)}0!==c&&(i=this.getTreeNode(e,f),i.max=n,i.maxIndex=r,i.min=a,i.minIndex=s)},r.prototype.rotateTreeLevel=function(t){var n=this.historyBuffer,r=n.startIndex(),a=this.tree.levels[t],s=o(r,a.step);if(s-a.startIndex>n.capacity)a.init(s);else for(;a.startIndex<s;)a.rotate();if(r!==s){var h,l={minIndex:r,min:this.get(r),maxIndex:r,max:this.get(r)},u=a.nodes.get(0);if(0===t)for(h=r;h<s+n.branchFactor;h++)e(h,this.get(h),l);else for(h=r;h<s+a.step;h+=a.step/n.branchFactor)i(this.getTreeNode(t-1,h),l);u.minIndex=l.minIndex,u.min=l.min,u.maxIndex=l.maxIndex,u.max=l.max}},r.prototype.updateSegmentTree=function(){var t;for(t=0;t<this.tree.depth;t++)this.rotateTreeLevel(t);for(t=0;t<this.tree.depth;t++)this.populateTreeLevel(this.historyBuffer.lastUpdatedIndex,t)},r.prototype.readMinMax=function(t,n,r){var a,s=n-t,h=this.historyBuffer,l=h.startIndex(),u=this.cbuffer,d=Math.floor(Math.log(s)/Math.log(h.branchFactor));if(d<=0){for(a=t;a<n;a++)e(a,u.get(a-l),r);return r}d>this.tree.levels.length&&(d=this.tree.levels.length);var c=Math.pow(h.branchFactor,d),f=Math.ceil(t/c)*c,p=o(n,c);t!==f&&this.readMinMax(t,f,r);var g=o(l,c),m=(f-g)/c,v=(p-g)/c;for(a=m;a<v;a++)i(this.tree.levels[d-1].nodes.get(a),r);return n!==p&&this.readMinMax(p,n,r),r},r.prototype.query=function(t,e,i){var o,r=this.historyBuffer;t=Math.floor(t),e=Math.ceil(e);var a=[],s=r.startIndex(),h=r.lastIndex();if(t<s&&(t=s),t>h&&(t=h),e<s&&(e=s-1),e>h-1&&(e=h-1),i<4)for(o=t;o<=e;o++)a.push(o),a.push(this.get(o));else{var l,u,d=new n;for(o=t;o<=e;o=Math.round(o+i)){var c=Math.min(e+1,Math.round(o+i));d.max=Number.NEGATIVE_INFINITY,d.min=Number.POSITIVE_INFINITY,d.minIndex=0,d.maxIndex=0,d=this.readMinMax(o,c,d),l=d.maxIndex,u=d.minIndex,u===l?(a.push(u),a.push(d.min)):u<l?(a.push(u),a.push(d.min),a.push(l),a.push(d.max)):(a.push(l),a.push(d.max),a.push(u),a.push(d.min))}}return a},"object"===("undefined"==typeof module?"undefined":_typeof(module))&&module.exports?module.exports=r:t.SegmentTree=r}(window),function(t){function e(t,e,n,r){var a;if(e.historyBuffer){var s=e.historyBuffer;a=s.indexMap;var h,l=t.getData().indexOf(e);l<s.width?(h=i(s,l),e.index=l):h=[];for(var u=r.points,d=0;d<h.length;d+=2)u[d]=a?a[h[d]]:h[d],u[d+1]=h[d+1];u.length=h.length,r.pointsize=2,e.decimate=o,e.decimatePoints=o}}function i(t,e){var i=t.rangeX(e),o=[];return void 0===i.xmin||void 0===i.xmax||void 0===i.deltamin?[]:(o[0]=i.xmin,o[2]=i.xmax,o[4]=i.xmax-i.deltamin,o[1]=0,o[3]=1,o[5]=2,o)}function o(t,e,i,o){var n,r=t.historyBuffer,a=i-e,s=r.indexMap,h=t.datapoints,l=Math.floor(a/o),u=t.index;if(u<r.width)var n=t.historyBuffer.query(e,i,l,u);else n=[];for(var d=h.points,c=0;c<n.length;c+=2)d[c]=s?s[n[c]]:n[c],d[c+1]=n[c+1];return d.length=n.length,h.pointsize=2,d}function n(t,e){for(var i=t.getData(),o=0;o<e.width;o++)"object"===_typeof(i[o])?(i[o].data=[],i[o].datapoints=void 0):i[o]={data:[]};t.setData(i)}function r(t,e,i){e.datapoints.points&&(i.xmin=e.datapoints.points[0])}function a(t,e){if("y"===e.direction&&"none"!==e.options.autoScale){var i,o,n,r,a,s=t.getData(),h=s.filter(function(t){return t.yaxis===e}),l=h.length;for(i=0;i<l;i++)a=h[i].index,o=h[i].xaxis.min?h[i].xaxis.min:h[i].xaxis.options.min,n=h[i].xaxis.max?h[i].xaxis.max:h[i].xaxis.options.max,i<h[i].historyBuffer.width&&(r=h[i].historyBuffer.rangeY(o,n,a),0===i?(e.datamin=r.ymin,e.datamax=r.ymax):(e.datamin=Math.min(e.datamin,r.ymin)||void 0,e.datamax=Math.max(e.datamax,r.ymax)||void 0))}}function s(t){t.setupGrid(!0),t.draw()}function h(t){function i(t,e){t.dataUpdateTriggered||(t.dataUpdateTriggered=requestAnimationFrame(function(){o||(n(t,e),s(t)),t.dataUpdateTriggered=null}))}var o=!1;t.hooks.processOptions.push(function(t){var s=t.getOptions().series.historyBuffer;s&&(t.hooks.processRawData.push(e),s.registerOnChange("setDataCallback",function(){i(t,s)}),n(t,s),t.hooks.adjustSeriesDataRange.push(r),t.hooks.setRange.push(a),t.hooks.shutdown.push(function(){s.deregisterOnChange("setDataCallback"),o=!0}))})}t.plot.plugins.push({init:h,name:"charting",version:"0.3"})}(jQuery);
//# sourceMappingURL=jquery.flot.plugins.js.map

// threejs.org/license
(function(m,na){"object"===typeof exports&&"undefined"!==typeof module?na(exports):"function"===typeof define&&define.amd?define(["exports"],na):na(m.THREE=m.THREE||{})})(this,function(m){function na(){}function D(a,b){this.x=a||0;this.y=b||0}function N(a,b,c,d,e,f,g,h,k,l){Object.defineProperty(this,"id",{value:lf++});this.uuid=R.generateUUID();this.name="";this.image=void 0!==a?a:N.DEFAULT_IMAGE;this.mipmaps=[];this.mapping=void 0!==b?b:N.DEFAULT_MAPPING;this.wrapS=void 0!==c?c:1001;this.wrapT=
void 0!==d?d:1001;this.magFilter=void 0!==e?e:1006;this.minFilter=void 0!==f?f:1008;this.anisotropy=void 0!==k?k:1;this.format=void 0!==g?g:1023;this.type=void 0!==h?h:1009;this.offset=new D(0,0);this.repeat=new D(1,1);this.generateMipmaps=!0;this.premultiplyAlpha=!1;this.flipY=!0;this.unpackAlignment=4;this.encoding=void 0!==l?l:3E3;this.version=0;this.onUpdate=null}function S(a,b,c,d){this.x=a||0;this.y=b||0;this.z=c||0;this.w=void 0!==d?d:1}function Ab(a,b,c){this.uuid=R.generateUUID();this.width=
a;this.height=b;this.scissor=new S(0,0,a,b);this.scissorTest=!1;this.viewport=new S(0,0,a,b);c=c||{};void 0===c.minFilter&&(c.minFilter=1006);this.texture=new N(void 0,void 0,c.wrapS,c.wrapT,c.magFilter,c.minFilter,c.format,c.type,c.anisotropy,c.encoding);this.depthBuffer=void 0!==c.depthBuffer?c.depthBuffer:!0;this.stencilBuffer=void 0!==c.stencilBuffer?c.stencilBuffer:!0;this.depthTexture=void 0!==c.depthTexture?c.depthTexture:null}function Bb(a,b,c){Ab.call(this,a,b,c);this.activeMipMapLevel=this.activeCubeFace=
0}function ia(a,b,c,d){this._x=a||0;this._y=b||0;this._z=c||0;this._w=void 0!==d?d:1}function n(a,b,c){this.x=a||0;this.y=b||0;this.z=c||0}function O(){this.elements=[1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1];0<arguments.length&&console.error("THREE.Matrix4: the constructor no longer reads arguments. use .set() instead.")}function bb(a,b,c,d,e,f,g,h,k,l,q,p){N.call(this,null,f,g,h,k,l,d,e,q,p);this.image={data:a,width:b,height:c};this.magFilter=void 0!==k?k:1003;this.minFilter=void 0!==l?l:1003;this.flipY=
this.generateMipmaps=!1;this.unpackAlignment=1}function Va(a,b,c,d,e,f,g,h,k,l){a=void 0!==a?a:[];N.call(this,a,void 0!==b?b:301,c,d,e,f,g,h,k,l);this.flipY=!1}function Cb(a,b,c){var d=a[0];if(0>=d||0<d)return a;var e=b*c,f=ye[e];void 0===f&&(f=new Float32Array(e),ye[e]=f);if(0!==b)for(d.toArray(f,0),d=1,e=0;d!==b;++d)e+=c,a[d].toArray(f,e);return f}function ze(a,b){var c=Ae[b];void 0===c&&(c=new Int32Array(b),Ae[b]=c);for(var d=0;d!==b;++d)c[d]=a.allocTextureUnit();return c}function mf(a,b){a.uniform1f(this.addr,
b)}function nf(a,b){a.uniform1i(this.addr,b)}function of(a,b){void 0===b.x?a.uniform2fv(this.addr,b):a.uniform2f(this.addr,b.x,b.y)}function pf(a,b){void 0!==b.x?a.uniform3f(this.addr,b.x,b.y,b.z):void 0!==b.r?a.uniform3f(this.addr,b.r,b.g,b.b):a.uniform3fv(this.addr,b)}function qf(a,b){void 0===b.x?a.uniform4fv(this.addr,b):a.uniform4f(this.addr,b.x,b.y,b.z,b.w)}function rf(a,b){a.uniformMatrix2fv(this.addr,!1,b.elements||b)}function sf(a,b){void 0===b.elements?a.uniformMatrix3fv(this.addr,!1,b):
(Be.set(b.elements),a.uniformMatrix3fv(this.addr,!1,Be))}function tf(a,b){void 0===b.elements?a.uniformMatrix4fv(this.addr,!1,b):(Ce.set(b.elements),a.uniformMatrix4fv(this.addr,!1,Ce))}function uf(a,b,c){var d=c.allocTextureUnit();a.uniform1i(this.addr,d);c.setTexture2D(b||De,d)}function vf(a,b,c){var d=c.allocTextureUnit();a.uniform1i(this.addr,d);c.setTextureCube(b||Ee,d)}function Fe(a,b){a.uniform2iv(this.addr,b)}function Ge(a,b){a.uniform3iv(this.addr,b)}function He(a,b){a.uniform4iv(this.addr,
b)}function wf(a){switch(a){case 5126:return mf;case 35664:return of;case 35665:return pf;case 35666:return qf;case 35674:return rf;case 35675:return sf;case 35676:return tf;case 35678:case 36198:return uf;case 35680:return vf;case 5124:case 35670:return nf;case 35667:case 35671:return Fe;case 35668:case 35672:return Ge;case 35669:case 35673:return He}}function xf(a,b){a.uniform1fv(this.addr,b)}function yf(a,b){a.uniform1iv(this.addr,b)}function zf(a,b){a.uniform2fv(this.addr,Cb(b,this.size,2))}function Af(a,
b){a.uniform3fv(this.addr,Cb(b,this.size,3))}function Bf(a,b){a.uniform4fv(this.addr,Cb(b,this.size,4))}function Cf(a,b){a.uniformMatrix2fv(this.addr,!1,Cb(b,this.size,4))}function Df(a,b){a.uniformMatrix3fv(this.addr,!1,Cb(b,this.size,9))}function Ef(a,b){a.uniformMatrix4fv(this.addr,!1,Cb(b,this.size,16))}function Ff(a,b,c){var d=b.length,e=ze(c,d);a.uniform1iv(this.addr,e);for(a=0;a!==d;++a)c.setTexture2D(b[a]||De,e[a])}function Gf(a,b,c){var d=b.length,e=ze(c,d);a.uniform1iv(this.addr,e);for(a=
0;a!==d;++a)c.setTextureCube(b[a]||Ee,e[a])}function Hf(a){switch(a){case 5126:return xf;case 35664:return zf;case 35665:return Af;case 35666:return Bf;case 35674:return Cf;case 35675:return Df;case 35676:return Ef;case 35678:return Ff;case 35680:return Gf;case 5124:case 35670:return yf;case 35667:case 35671:return Fe;case 35668:case 35672:return Ge;case 35669:case 35673:return He}}function If(a,b,c){this.id=a;this.addr=c;this.setValue=wf(b.type)}function Jf(a,b,c){this.id=a;this.addr=c;this.size=
b.size;this.setValue=Hf(b.type)}function Ie(a){this.id=a;this.seq=[];this.map={}}function cb(a,b,c){this.seq=[];this.map={};this.renderer=c;c=a.getProgramParameter(b,a.ACTIVE_UNIFORMS);for(var d=0;d<c;++d){var e=a.getActiveUniform(b,d),f=a.getUniformLocation(b,e.name),g=this,h=e.name,k=h.length;for(Pd.lastIndex=0;;){var l=Pd.exec(h),q=Pd.lastIndex,p=l[1],t=l[3];"]"===l[2]&&(p|=0);if(void 0===t||"["===t&&q+2===k){h=g;e=void 0===t?new If(p,e,f):new Jf(p,e,f);h.seq.push(e);h.map[e.id]=e;break}else t=
g.map[p],void 0===t&&(t=new Ie(p),p=g,g=t,p.seq.push(g),p.map[g.id]=g),g=t}}}function C(a,b,c){return void 0===b&&void 0===c?this.set(a):this.setRGB(a,b,c)}function id(a,b){this.min=void 0!==a?a:new D(Infinity,Infinity);this.max=void 0!==b?b:new D(-Infinity,-Infinity)}function Kf(a,b,c,d,e){var f,g,h,k,l,q,p,t,r,m,u,x,y,A,I,B;this.render=function(a,v,xa,la){if(0!==a.length){v=new n;var H=la.w/la.z,va=.5*la.z,jd=.5*la.w,J=16/la.w,Ga=new D(J*H,J),ga=new n(1,1,0),M=new D(1,1),T=new id;T.min.set(la.x,
la.y);T.max.set(la.x+(la.z-16),la.y+(la.w-16));if(void 0===A){var J=new Float32Array([-1,-1,0,0,1,-1,1,0,1,1,1,1,-1,1,0,1]),La=new Uint16Array([0,1,2,0,2,3]);u=b.createBuffer();x=b.createBuffer();b.bindBuffer(b.ARRAY_BUFFER,u);b.bufferData(b.ARRAY_BUFFER,J,b.STATIC_DRAW);b.bindBuffer(b.ELEMENT_ARRAY_BUFFER,x);b.bufferData(b.ELEMENT_ARRAY_BUFFER,La,b.STATIC_DRAW);I=b.createTexture();B=b.createTexture();c.bindTexture(b.TEXTURE_2D,I);b.texImage2D(b.TEXTURE_2D,0,b.RGB,16,16,0,b.RGB,b.UNSIGNED_BYTE,null);
b.texParameteri(b.TEXTURE_2D,b.TEXTURE_WRAP_S,b.CLAMP_TO_EDGE);b.texParameteri(b.TEXTURE_2D,b.TEXTURE_WRAP_T,b.CLAMP_TO_EDGE);b.texParameteri(b.TEXTURE_2D,b.TEXTURE_MAG_FILTER,b.NEAREST);b.texParameteri(b.TEXTURE_2D,b.TEXTURE_MIN_FILTER,b.NEAREST);c.bindTexture(b.TEXTURE_2D,B);b.texImage2D(b.TEXTURE_2D,0,b.RGBA,16,16,0,b.RGBA,b.UNSIGNED_BYTE,null);b.texParameteri(b.TEXTURE_2D,b.TEXTURE_WRAP_S,b.CLAMP_TO_EDGE);b.texParameteri(b.TEXTURE_2D,b.TEXTURE_WRAP_T,b.CLAMP_TO_EDGE);b.texParameteri(b.TEXTURE_2D,
b.TEXTURE_MAG_FILTER,b.NEAREST);b.texParameteri(b.TEXTURE_2D,b.TEXTURE_MIN_FILTER,b.NEAREST);var J=y={vertexShader:"uniform lowp int renderType;\nuniform vec3 screenPosition;\nuniform vec2 scale;\nuniform float rotation;\nuniform sampler2D occlusionMap;\nattribute vec2 position;\nattribute vec2 uv;\nvarying vec2 vUV;\nvarying float vVisibility;\nvoid main() {\nvUV = uv;\nvec2 pos = position;\nif ( renderType == 2 ) {\nvec4 visibility = texture2D( occlusionMap, vec2( 0.1, 0.1 ) );\nvisibility += texture2D( occlusionMap, vec2( 0.5, 0.1 ) );\nvisibility += texture2D( occlusionMap, vec2( 0.9, 0.1 ) );\nvisibility += texture2D( occlusionMap, vec2( 0.9, 0.5 ) );\nvisibility += texture2D( occlusionMap, vec2( 0.9, 0.9 ) );\nvisibility += texture2D( occlusionMap, vec2( 0.5, 0.9 ) );\nvisibility += texture2D( occlusionMap, vec2( 0.1, 0.9 ) );\nvisibility += texture2D( occlusionMap, vec2( 0.1, 0.5 ) );\nvisibility += texture2D( occlusionMap, vec2( 0.5, 0.5 ) );\nvVisibility =        visibility.r / 9.0;\nvVisibility *= 1.0 - visibility.g / 9.0;\nvVisibility *=       visibility.b / 9.0;\nvVisibility *= 1.0 - visibility.a / 9.0;\npos.x = cos( rotation ) * position.x - sin( rotation ) * position.y;\npos.y = sin( rotation ) * position.x + cos( rotation ) * position.y;\n}\ngl_Position = vec4( ( pos * scale + screenPosition.xy ).xy, screenPosition.z, 1.0 );\n}",
fragmentShader:"uniform lowp int renderType;\nuniform sampler2D map;\nuniform float opacity;\nuniform vec3 color;\nvarying vec2 vUV;\nvarying float vVisibility;\nvoid main() {\nif ( renderType == 0 ) {\ngl_FragColor = vec4( 1.0, 0.0, 1.0, 0.0 );\n} else if ( renderType == 1 ) {\ngl_FragColor = texture2D( map, vUV );\n} else {\nvec4 texture = texture2D( map, vUV );\ntexture.a *= opacity * vVisibility;\ngl_FragColor = texture;\ngl_FragColor.rgb *= color;\n}\n}"},La=b.createProgram(),z=b.createShader(b.FRAGMENT_SHADER),
Y=b.createShader(b.VERTEX_SHADER),w="precision "+e.precision+" float;\n";b.shaderSource(z,w+J.fragmentShader);b.shaderSource(Y,w+J.vertexShader);b.compileShader(z);b.compileShader(Y);b.attachShader(La,z);b.attachShader(La,Y);b.linkProgram(La);A=La;r=b.getAttribLocation(A,"position");m=b.getAttribLocation(A,"uv");f=b.getUniformLocation(A,"renderType");g=b.getUniformLocation(A,"map");h=b.getUniformLocation(A,"occlusionMap");k=b.getUniformLocation(A,"opacity");l=b.getUniformLocation(A,"color");q=b.getUniformLocation(A,
"scale");p=b.getUniformLocation(A,"rotation");t=b.getUniformLocation(A,"screenPosition")}c.useProgram(A);c.initAttributes();c.enableAttribute(r);c.enableAttribute(m);c.disableUnusedAttributes();b.uniform1i(h,0);b.uniform1i(g,1);b.bindBuffer(b.ARRAY_BUFFER,u);b.vertexAttribPointer(r,2,b.FLOAT,!1,16,0);b.vertexAttribPointer(m,2,b.FLOAT,!1,16,8);b.bindBuffer(b.ELEMENT_ARRAY_BUFFER,x);c.disable(b.CULL_FACE);c.buffers.depth.setMask(!1);La=0;for(z=a.length;La<z;La++)if(J=16/la.w,Ga.set(J*H,J),Y=a[La],v.set(Y.matrixWorld.elements[12],
Y.matrixWorld.elements[13],Y.matrixWorld.elements[14]),v.applyMatrix4(xa.matrixWorldInverse),v.applyMatrix4(xa.projectionMatrix),ga.copy(v),M.x=la.x+ga.x*va+va-8,M.y=la.y+ga.y*jd+jd-8,!0===T.containsPoint(M)){c.activeTexture(b.TEXTURE0);c.bindTexture(b.TEXTURE_2D,null);c.activeTexture(b.TEXTURE1);c.bindTexture(b.TEXTURE_2D,I);b.copyTexImage2D(b.TEXTURE_2D,0,b.RGB,M.x,M.y,16,16,0);b.uniform1i(f,0);b.uniform2f(q,Ga.x,Ga.y);b.uniform3f(t,ga.x,ga.y,ga.z);c.disable(b.BLEND);c.enable(b.DEPTH_TEST);b.drawElements(b.TRIANGLES,
6,b.UNSIGNED_SHORT,0);c.activeTexture(b.TEXTURE0);c.bindTexture(b.TEXTURE_2D,B);b.copyTexImage2D(b.TEXTURE_2D,0,b.RGBA,M.x,M.y,16,16,0);b.uniform1i(f,1);c.disable(b.DEPTH_TEST);c.activeTexture(b.TEXTURE1);c.bindTexture(b.TEXTURE_2D,I);b.drawElements(b.TRIANGLES,6,b.UNSIGNED_SHORT,0);Y.positionScreen.copy(ga);Y.customUpdateCallback?Y.customUpdateCallback(Y):Y.updateLensFlares();b.uniform1i(f,2);c.enable(b.BLEND);for(var w=0,F=Y.lensFlares.length;w<F;w++){var C=Y.lensFlares[w];.001<C.opacity&&.001<
C.scale&&(ga.x=C.x,ga.y=C.y,ga.z=C.z,J=C.size*C.scale/la.w,Ga.x=J*H,Ga.y=J,b.uniform3f(t,ga.x,ga.y,ga.z),b.uniform2f(q,Ga.x,Ga.y),b.uniform1f(p,C.rotation),b.uniform1f(k,C.opacity),b.uniform3f(l,C.color.r,C.color.g,C.color.b),c.setBlending(C.blending,C.blendEquation,C.blendSrc,C.blendDst),d.setTexture2D(C.texture,1),b.drawElements(b.TRIANGLES,6,b.UNSIGNED_SHORT,0))}}c.enable(b.CULL_FACE);c.enable(b.DEPTH_TEST);c.buffers.depth.setMask(!0);c.reset()}}}function oc(a,b,c,d,e,f,g,h,k){N.call(this,a,b,
c,d,e,f,g,h,k);this.needsUpdate=!0}function Lf(a,b,c,d,e){var f,g,h,k,l,q,p,t,r,m,u,x,y,A,I,B,H;function va(a,b){return a.renderOrder!==b.renderOrder?a.renderOrder-b.renderOrder:a.z!==b.z?b.z-a.z:b.id-a.id}var xa,la,ba,Je,jd=new n,J=new ia,Ga=new n;this.render=function(v,n,T){if(0!==v.length){if(void 0===ba){var M=new Float32Array([-.5,-.5,0,0,.5,-.5,1,0,.5,.5,1,1,-.5,.5,0,1]),z=new Uint16Array([0,1,2,0,2,3]);xa=b.createBuffer();la=b.createBuffer();b.bindBuffer(b.ARRAY_BUFFER,xa);b.bufferData(b.ARRAY_BUFFER,
M,b.STATIC_DRAW);b.bindBuffer(b.ELEMENT_ARRAY_BUFFER,la);b.bufferData(b.ELEMENT_ARRAY_BUFFER,z,b.STATIC_DRAW);M=b.createProgram();z=b.createShader(b.VERTEX_SHADER);var w=b.createShader(b.FRAGMENT_SHADER);b.shaderSource(z,["precision "+e.precision+" float;","#define SHADER_NAME SpriteMaterial\nuniform mat4 modelViewMatrix;\nuniform mat4 projectionMatrix;\nuniform float rotation;\nuniform vec2 scale;\nuniform vec2 uvOffset;\nuniform vec2 uvScale;\nattribute vec2 position;\nattribute vec2 uv;\nvarying vec2 vUV;\nvoid main() {\nvUV = uvOffset + uv * uvScale;\nvec2 alignedPosition = position * scale;\nvec2 rotatedPosition;\nrotatedPosition.x = cos( rotation ) * alignedPosition.x - sin( rotation ) * alignedPosition.y;\nrotatedPosition.y = sin( rotation ) * alignedPosition.x + cos( rotation ) * alignedPosition.y;\nvec4 finalPosition;\nfinalPosition = modelViewMatrix * vec4( 0.0, 0.0, 0.0, 1.0 );\nfinalPosition.xy += rotatedPosition;\nfinalPosition = projectionMatrix * finalPosition;\ngl_Position = finalPosition;\n}"].join("\n"));
b.shaderSource(w,["precision "+e.precision+" float;","#define SHADER_NAME SpriteMaterial\nuniform vec3 color;\nuniform sampler2D map;\nuniform float opacity;\nuniform int fogType;\nuniform vec3 fogColor;\nuniform float fogDensity;\nuniform float fogNear;\nuniform float fogFar;\nuniform float alphaTest;\nvarying vec2 vUV;\nvoid main() {\nvec4 texture = texture2D( map, vUV );\nif ( texture.a < alphaTest ) discard;\ngl_FragColor = vec4( color * texture.xyz, texture.a * opacity );\nif ( fogType > 0 ) {\nfloat depth = gl_FragCoord.z / gl_FragCoord.w;\nfloat fogFactor = 0.0;\nif ( fogType == 1 ) {\nfogFactor = smoothstep( fogNear, fogFar, depth );\n} else {\nconst float LOG2 = 1.442695;\nfogFactor = exp2( - fogDensity * fogDensity * depth * depth * LOG2 );\nfogFactor = 1.0 - clamp( fogFactor, 0.0, 1.0 );\n}\ngl_FragColor = mix( gl_FragColor, vec4( fogColor, gl_FragColor.w ), fogFactor );\n}\n}"].join("\n"));
b.compileShader(z);b.compileShader(w);b.attachShader(M,z);b.attachShader(M,w);b.linkProgram(M);ba=M;B=b.getAttribLocation(ba,"position");H=b.getAttribLocation(ba,"uv");f=b.getUniformLocation(ba,"uvOffset");g=b.getUniformLocation(ba,"uvScale");h=b.getUniformLocation(ba,"rotation");k=b.getUniformLocation(ba,"scale");l=b.getUniformLocation(ba,"color");q=b.getUniformLocation(ba,"map");p=b.getUniformLocation(ba,"opacity");t=b.getUniformLocation(ba,"modelViewMatrix");r=b.getUniformLocation(ba,"projectionMatrix");
m=b.getUniformLocation(ba,"fogType");u=b.getUniformLocation(ba,"fogDensity");x=b.getUniformLocation(ba,"fogNear");y=b.getUniformLocation(ba,"fogFar");A=b.getUniformLocation(ba,"fogColor");I=b.getUniformLocation(ba,"alphaTest");M=document.createElementNS("http://www.w3.org/1999/xhtml","canvas");M.width=8;M.height=8;z=M.getContext("2d");z.fillStyle="white";z.fillRect(0,0,8,8);Je=new oc(M)}c.useProgram(ba);c.initAttributes();c.enableAttribute(B);c.enableAttribute(H);c.disableUnusedAttributes();c.disable(b.CULL_FACE);
c.enable(b.BLEND);b.bindBuffer(b.ARRAY_BUFFER,xa);b.vertexAttribPointer(B,2,b.FLOAT,!1,16,0);b.vertexAttribPointer(H,2,b.FLOAT,!1,16,8);b.bindBuffer(b.ELEMENT_ARRAY_BUFFER,la);b.uniformMatrix4fv(r,!1,T.projectionMatrix.elements);c.activeTexture(b.TEXTURE0);b.uniform1i(q,0);z=M=0;(w=n.fog)?(b.uniform3f(A,w.color.r,w.color.g,w.color.b),w.isFog?(b.uniform1f(x,w.near),b.uniform1f(y,w.far),b.uniform1i(m,1),z=M=1):w.isFogExp2&&(b.uniform1f(u,w.density),b.uniform1i(m,2),z=M=2)):(b.uniform1i(m,0),z=M=0);
for(var D=0,C=v.length;D<C;D++)w=v[D],w.modelViewMatrix.multiplyMatrices(T.matrixWorldInverse,w.matrixWorld),w.z=-w.modelViewMatrix.elements[14];v.sort(va);for(var ga=[],D=0,C=v.length;D<C;D++){w=v[D];var G=w.material;if(!1!==G.visible){w.onBeforeRender(a,n,T,void 0,G,void 0);b.uniform1f(I,G.alphaTest);b.uniformMatrix4fv(t,!1,w.modelViewMatrix.elements);w.matrixWorld.decompose(jd,J,Ga);ga[0]=Ga.x;ga[1]=Ga.y;var F=0;n.fog&&G.fog&&(F=z);M!==F&&(b.uniform1i(m,F),M=F);null!==G.map?(b.uniform2f(f,G.map.offset.x,
G.map.offset.y),b.uniform2f(g,G.map.repeat.x,G.map.repeat.y)):(b.uniform2f(f,0,0),b.uniform2f(g,1,1));b.uniform1f(p,G.opacity);b.uniform3f(l,G.color.r,G.color.g,G.color.b);b.uniform1f(h,G.rotation);b.uniform2fv(k,ga);c.setBlending(G.blending,G.blendEquation,G.blendSrc,G.blendDst,G.blendEquationAlpha,G.blendSrcAlpha,G.blendDstAlpha,G.premultipliedAlpha);c.buffers.depth.setTest(G.depthTest);c.buffers.depth.setMask(G.depthWrite);d.setTexture2D(G.map||Je,0);b.drawElements(b.TRIANGLES,6,b.UNSIGNED_SHORT,
0);w.onAfterRender(a,n,T,void 0,G,void 0)}}c.enable(b.CULL_FACE);c.reset()}}}function P(){Object.defineProperty(this,"id",{value:Mf++});this.uuid=R.generateUUID();this.name="";this.type="Material";this.lights=this.fog=!0;this.blending=1;this.side=0;this.flatShading=!1;this.vertexColors=0;this.opacity=1;this.transparent=!1;this.blendSrc=204;this.blendDst=205;this.blendEquation=100;this.blendEquationAlpha=this.blendDstAlpha=this.blendSrcAlpha=null;this.depthFunc=3;this.depthWrite=this.depthTest=!0;
this.clippingPlanes=null;this.clipShadows=this.clipIntersection=!1;this.colorWrite=!0;this.precision=null;this.polygonOffset=!1;this.polygonOffsetUnits=this.polygonOffsetFactor=0;this.dithering=!1;this.alphaTest=0;this.premultipliedAlpha=!1;this.overdraw=0;this.visible=!0;this.userData={};this.needsUpdate=!0}function ya(a){P.call(this);this.type="ShaderMaterial";this.defines={};this.uniforms={};this.vertexShader="void main() {\n\tgl_Position = projectionMatrix * modelViewMatrix * vec4( position, 1.0 );\n}";
this.fragmentShader="void main() {\n\tgl_FragColor = vec4( 1.0, 0.0, 0.0, 1.0 );\n}";this.linewidth=1;this.wireframe=!1;this.wireframeLinewidth=1;this.morphNormals=this.morphTargets=this.skinning=this.clipping=this.lights=this.fog=!1;this.extensions={derivatives:!1,fragDepth:!1,drawBuffers:!1,shaderTextureLOD:!1};this.defaultAttributeValues={color:[1,1,1],uv:[0,0],uv2:[0,0]};this.index0AttributeName=void 0;void 0!==a&&(void 0!==a.attributes&&console.error("THREE.ShaderMaterial: attributes should now be defined in THREE.BufferGeometry instead."),
this.setValues(a))}function Wa(a){P.call(this);this.type="MeshDepthMaterial";this.depthPacking=3200;this.morphTargets=this.skinning=!1;this.displacementMap=this.alphaMap=this.map=null;this.displacementScale=1;this.displacementBias=0;this.wireframe=!1;this.wireframeLinewidth=1;this.lights=this.fog=!1;this.setValues(a)}function Xa(a){P.call(this);this.type="MeshDistanceMaterial";this.referencePosition=new n;this.nearDistance=1;this.farDistance=1E3;this.morphTargets=this.skinning=!1;this.displacementMap=
this.alphaMap=this.map=null;this.displacementScale=1;this.displacementBias=0;this.lights=this.fog=!1;this.setValues(a)}function Pa(a,b){this.min=void 0!==a?a:new n(Infinity,Infinity,Infinity);this.max=void 0!==b?b:new n(-Infinity,-Infinity,-Infinity)}function Ca(a,b){this.center=void 0!==a?a:new n;this.radius=void 0!==b?b:0}function qa(){this.elements=[1,0,0,0,1,0,0,0,1];0<arguments.length&&console.error("THREE.Matrix3: the constructor no longer reads arguments. use .set() instead.")}function za(a,
b){this.normal=void 0!==a?a:new n(1,0,0);this.constant=void 0!==b?b:0}function kd(a,b,c,d,e,f){this.planes=[void 0!==a?a:new za,void 0!==b?b:new za,void 0!==c?c:new za,void 0!==d?d:new za,void 0!==e?e:new za,void 0!==f?f:new za]}function Ke(a,b,c){function d(b,c,d,e,f,g){var h=b.geometry;var l=p;var k=b.customDepthMaterial;d&&(l=t,k=b.customDistanceMaterial);k?l=k:(k=!1,c.morphTargets&&(h&&h.isBufferGeometry?k=h.morphAttributes&&h.morphAttributes.position&&0<h.morphAttributes.position.length:h&&h.isGeometry&&
(k=h.morphTargets&&0<h.morphTargets.length)),b.isSkinnedMesh&&!1===c.skinning&&console.warn("THREE.WebGLShadowMap: THREE.SkinnedMesh with material.skinning set to false:",b),b=b.isSkinnedMesh&&c.skinning,h=0,k&&(h|=1),b&&(h|=2),l=l[h]);a.localClippingEnabled&&!0===c.clipShadows&&0!==c.clippingPlanes.length&&(h=l.uuid,k=c.uuid,b=r[h],void 0===b&&(b={},r[h]=b),h=b[k],void 0===h&&(h=l.clone(),b[k]=h),l=h);l.visible=c.visible;l.wireframe=c.wireframe;k=c.side;B.renderSingleSided&&2==k&&(k=0);B.renderReverseSided&&
(0===k?k=1:1===k&&(k=0));l.side=k;l.clipShadows=c.clipShadows;l.clippingPlanes=c.clippingPlanes;l.clipIntersection=c.clipIntersection;l.wireframeLinewidth=c.wireframeLinewidth;l.linewidth=c.linewidth;d&&l.isMeshDistanceMaterial&&(l.referencePosition.copy(e),l.nearDistance=f,l.farDistance=g);return l}function e(c,g,h,l){var k;if(!1!==c.visible){if(c.layers.test(g.layers)&&(c.isMesh||c.isLine||c.isPoints)&&c.castShadow&&(!c.frustumCulled||f.intersectsObject(c))){c.modelViewMatrix.multiplyMatrices(h.matrixWorldInverse,
c.matrixWorld);var p=b.update(c),t=c.material;if(Array.isArray(t))for(var r=p.groups,A=0,m=r.length;A<m;A++){var v=r[A];(k=t[v.materialIndex])&&k.visible&&(k=d(c,k,l,q,h.near,h.far),a.renderBufferDirect(h,null,p,k,c,v))}else t.visible&&(k=d(c,t,l,q,h.near,h.far),a.renderBufferDirect(h,null,p,k,c,null))}c=c.children;p=0;for(t=c.length;p<t;p++)e(c[p],g,h,l)}}var f=new kd,g=new O,h=new D,k=new D(c,c),l=new n,q=new n,p=Array(4),t=Array(4),r={},m=[new n(1,0,0),new n(-1,0,0),new n(0,0,1),new n(0,0,-1),
new n(0,1,0),new n(0,-1,0)],u=[new n(0,1,0),new n(0,1,0),new n(0,1,0),new n(0,1,0),new n(0,0,1),new n(0,0,-1)],x=[new S,new S,new S,new S,new S,new S];for(c=0;4!==c;++c){var y=0!==(c&1),A=0!==(c&2),I=new Wa({depthPacking:3201,morphTargets:y,skinning:A});p[c]=I;y=new Xa({morphTargets:y,skinning:A});t[c]=y}var B=this;this.enabled=!1;this.autoUpdate=!0;this.needsUpdate=!1;this.type=1;this.renderSingleSided=this.renderReverseSided=!0;this.render=function(b,c,d){if(!1!==B.enabled&&(!1!==B.autoUpdate||
!1!==B.needsUpdate)&&0!==b.length){var p=a.state;p.disable(a.context.BLEND);p.buffers.color.setClear(1,1,1,1);p.buffers.depth.setTest(!0);p.setScissorTest(!1);for(var t,r=0,A=b.length;r<A;r++){var v=b[r];t=v.shadow;var I=v&&v.isPointLight;if(void 0===t)console.warn("THREE.WebGLShadowMap:",v,"has no shadow.");else{var n=t.camera;h.copy(t.mapSize);h.min(k);if(I){var y=h.x,H=h.y;x[0].set(2*y,H,y,H);x[1].set(0,H,y,H);x[2].set(3*y,H,y,H);x[3].set(y,H,y,H);x[4].set(3*y,0,y,H);x[5].set(y,0,y,H);h.x*=4;h.y*=
2}null===t.map&&(t.map=new Ab(h.x,h.y,{minFilter:1003,magFilter:1003,format:1023}),t.map.texture.name=v.name+".shadowMap",n.updateProjectionMatrix());t.isSpotLightShadow&&t.update(v);y=t.map;H=t.matrix;q.setFromMatrixPosition(v.matrixWorld);n.position.copy(q);I?(t=6,H.makeTranslation(-q.x,-q.y,-q.z)):(t=1,l.setFromMatrixPosition(v.target.matrixWorld),n.lookAt(l),n.updateMatrixWorld(),H.set(.5,0,0,.5,0,.5,0,.5,0,0,.5,.5,0,0,0,1),H.multiply(n.projectionMatrix),H.multiply(n.matrixWorldInverse));a.setRenderTarget(y);
a.clear();for(v=0;v<t;v++)I&&(l.copy(n.position),l.add(m[v]),n.up.copy(u[v]),n.lookAt(l),n.updateMatrixWorld(),p.viewport(x[v])),g.multiplyMatrices(n.projectionMatrix,n.matrixWorldInverse),f.setFromMatrix(g),e(c,d,n,I)}}B.needsUpdate=!1}}}function Nf(a){var b={};return{get:function(a){a.isInterleavedBufferAttribute&&(a=a.data);return b[a.uuid]},remove:function(c){c.isInterleavedBufferAttribute&&(c=c.data);var d=b[c.uuid];d&&(a.deleteBuffer(d.buffer),delete b[c.uuid])},update:function(c,d){c.isInterleavedBufferAttribute&&
(c=c.data);var e=b[c.uuid];if(void 0===e){var e=c.uuid,f=c.array,g=c.dynamic?a.DYNAMIC_DRAW:a.STATIC_DRAW,h=a.createBuffer();a.bindBuffer(d,h);a.bufferData(d,f,g);c.onUploadCallback();d=a.FLOAT;f instanceof Float32Array?d=a.FLOAT:f instanceof Float64Array?console.warn("THREE.WebGLAttributes: Unsupported data buffer format: Float64Array."):f instanceof Uint16Array?d=a.UNSIGNED_SHORT:f instanceof Int16Array?d=a.SHORT:f instanceof Uint32Array?d=a.UNSIGNED_INT:f instanceof Int32Array?d=a.INT:f instanceof
Int8Array?d=a.BYTE:f instanceof Uint8Array&&(d=a.UNSIGNED_BYTE);b[e]={buffer:h,type:d,bytesPerElement:f.BYTES_PER_ELEMENT,version:c.version}}else e.version<c.version&&(f=c,h=f.array,g=f.updateRange,a.bindBuffer(d,e.buffer),!1===f.dynamic?a.bufferData(d,h,a.STATIC_DRAW):-1===g.count?a.bufferSubData(d,0,h):0===g.count?console.error("THREE.WebGLObjects.updateBuffer: dynamic THREE.BufferAttribute marked as needsUpdate but updateRange.count is 0, ensure you are using set methods or updating manually."):
(a.bufferSubData(d,g.offset*h.BYTES_PER_ELEMENT,h.subarray(g.offset,g.offset+g.count)),g.count=-1),e.version=c.version)}}}function Ya(a,b,c,d){this._x=a||0;this._y=b||0;this._z=c||0;this._order=d||Ya.DefaultOrder}function Qd(){this.mask=1}function w(){Object.defineProperty(this,"id",{value:Of++});this.uuid=R.generateUUID();this.name="";this.type="Object3D";this.parent=null;this.children=[];this.up=w.DefaultUp.clone();var a=new n,b=new Ya,c=new ia,d=new n(1,1,1);b.onChange(function(){c.setFromEuler(b,
!1)});c.onChange(function(){b.setFromQuaternion(c,void 0,!1)});Object.defineProperties(this,{position:{enumerable:!0,value:a},rotation:{enumerable:!0,value:b},quaternion:{enumerable:!0,value:c},scale:{enumerable:!0,value:d},modelViewMatrix:{value:new O},normalMatrix:{value:new qa}});this.matrix=new O;this.matrixWorld=new O;this.matrixAutoUpdate=w.DefaultMatrixAutoUpdate;this.matrixWorldNeedsUpdate=!1;this.layers=new Qd;this.visible=!0;this.receiveShadow=this.castShadow=!1;this.frustumCulled=!0;this.renderOrder=
0;this.userData={}}function Ma(){w.call(this);this.type="Camera";this.matrixWorldInverse=new O;this.projectionMatrix=new O}function Db(a,b,c,d,e,f){Ma.call(this);this.type="OrthographicCamera";this.zoom=1;this.view=null;this.left=a;this.right=b;this.top=c;this.bottom=d;this.near=void 0!==e?e:.1;this.far=void 0!==f?f:2E3;this.updateProjectionMatrix()}function ja(a,b,c,d){Ma.call(this);this.type="PerspectiveCamera";this.fov=void 0!==a?a:50;this.zoom=1;this.near=void 0!==c?c:.1;this.far=void 0!==d?d:
2E3;this.focus=10;this.aspect=void 0!==b?b:1;this.view=null;this.filmGauge=35;this.filmOffset=0;this.updateProjectionMatrix()}function Qa(a,b,c,d,e,f){this.a=a;this.b=b;this.c=c;this.normal=d&&d.isVector3?d:new n;this.vertexNormals=Array.isArray(d)?d:[];this.color=e&&e.isColor?e:new C;this.vertexColors=Array.isArray(e)?e:[];this.materialIndex=void 0!==f?f:0}function Q(){Object.defineProperty(this,"id",{value:Rd++});this.uuid=R.generateUUID();this.name="";this.type="Geometry";this.vertices=[];this.colors=
[];this.faces=[];this.faceVertexUvs=[[]];this.morphTargets=[];this.morphNormals=[];this.skinWeights=[];this.skinIndices=[];this.lineDistances=[];this.boundingSphere=this.boundingBox=null;this.groupsNeedUpdate=this.lineDistancesNeedUpdate=this.colorsNeedUpdate=this.normalsNeedUpdate=this.uvsNeedUpdate=this.verticesNeedUpdate=this.elementsNeedUpdate=!1}function K(a,b,c){if(Array.isArray(a))throw new TypeError("THREE.BufferAttribute: array should be a Typed Array.");this.uuid=R.generateUUID();this.name=
"";this.array=a;this.itemSize=b;this.count=void 0!==a?a.length/b:0;this.normalized=!0===c;this.dynamic=!1;this.updateRange={offset:0,count:-1};this.onUploadCallback=function(){};this.version=0}function pc(a,b){K.call(this,new Int8Array(a),b)}function qc(a,b){K.call(this,new Uint8Array(a),b)}function rc(a,b){K.call(this,new Uint8ClampedArray(a),b)}function sc(a,b){K.call(this,new Int16Array(a),b)}function db(a,b){K.call(this,new Uint16Array(a),b)}function tc(a,b){K.call(this,new Int32Array(a),b)}function eb(a,
b){K.call(this,new Uint32Array(a),b)}function z(a,b){K.call(this,new Float32Array(a),b)}function uc(a,b){K.call(this,new Float64Array(a),b)}function Le(){this.indices=[];this.vertices=[];this.normals=[];this.colors=[];this.uvs=[];this.uvs2=[];this.groups=[];this.morphTargets={};this.skinWeights=[];this.skinIndices=[];this.boundingSphere=this.boundingBox=null;this.groupsNeedUpdate=this.uvsNeedUpdate=this.colorsNeedUpdate=this.normalsNeedUpdate=this.verticesNeedUpdate=!1}function Sd(a){if(0===a.length)return-Infinity;
for(var b=a[0],c=1,d=a.length;c<d;++c)a[c]>b&&(b=a[c]);return b}function F(){Object.defineProperty(this,"id",{value:Rd++});this.uuid=R.generateUUID();this.name="";this.type="BufferGeometry";this.index=null;this.attributes={};this.morphAttributes={};this.groups=[];this.boundingSphere=this.boundingBox=null;this.drawRange={start:0,count:Infinity}}function Eb(a,b,c,d,e,f){Q.call(this);this.type="BoxGeometry";this.parameters={width:a,height:b,depth:c,widthSegments:d,heightSegments:e,depthSegments:f};this.fromBufferGeometry(new fb(a,
b,c,d,e,f));this.mergeVertices()}function fb(a,b,c,d,e,f){function g(a,b,c,d,e,f,g,m,va,xa,la){var A=f/va,v=g/xa,u=f/2,x=g/2,I=m/2;g=va+1;var B=xa+1,y=f=0,H,w,z=new n;for(w=0;w<B;w++){var D=w*v-x;for(H=0;H<g;H++)z[a]=(H*A-u)*d,z[b]=D*e,z[c]=I,l.push(z.x,z.y,z.z),z[a]=0,z[b]=0,z[c]=0<m?1:-1,q.push(z.x,z.y,z.z),p.push(H/va),p.push(1-w/xa),f+=1}for(w=0;w<xa;w++)for(H=0;H<va;H++)a=t+H+g*(w+1),b=t+(H+1)+g*(w+1),c=t+(H+1)+g*w,k.push(t+H+g*w,a,c),k.push(a,b,c),y+=6;h.addGroup(r,y,la);r+=y;t+=f}F.call(this);
this.type="BoxBufferGeometry";this.parameters={width:a,height:b,depth:c,widthSegments:d,heightSegments:e,depthSegments:f};var h=this;d=Math.floor(d)||1;e=Math.floor(e)||1;f=Math.floor(f)||1;var k=[],l=[],q=[],p=[],t=0,r=0;g("z","y","x",-1,-1,c,b,a,f,e,0);g("z","y","x",1,-1,c,b,-a,f,e,1);g("x","z","y",1,1,a,c,b,d,f,2);g("x","z","y",1,-1,a,c,-b,d,f,3);g("x","y","z",1,-1,a,b,c,d,e,4);g("x","y","z",-1,-1,a,b,-c,d,e,5);this.setIndex(k);this.addAttribute("position",new z(l,3));this.addAttribute("normal",
new z(q,3));this.addAttribute("uv",new z(p,2))}function vc(a,b,c,d){Q.call(this);this.type="PlaneGeometry";this.parameters={width:a,height:b,widthSegments:c,heightSegments:d};this.fromBufferGeometry(new gb(a,b,c,d));this.mergeVertices()}function gb(a,b,c,d){F.call(this);this.type="PlaneBufferGeometry";this.parameters={width:a,height:b,widthSegments:c,heightSegments:d};var e=a/2,f=b/2;c=Math.floor(c)||1;d=Math.floor(d)||1;var g=c+1,h=d+1,k=a/c,l=b/d,q=[],p=[],t=[],r=[];for(a=0;a<h;a++){var m=a*l-f;
for(b=0;b<g;b++)p.push(b*k-e,-m,0),t.push(0,0,1),r.push(b/c),r.push(1-a/d)}for(a=0;a<d;a++)for(b=0;b<c;b++)e=b+g*(a+1),f=b+1+g*(a+1),h=b+1+g*a,q.push(b+g*a,e,h),q.push(e,f,h);this.setIndex(q);this.addAttribute("position",new z(p,3));this.addAttribute("normal",new z(t,3));this.addAttribute("uv",new z(r,2))}function sa(a){P.call(this);this.type="MeshBasicMaterial";this.color=new C(16777215);this.lightMap=this.map=null;this.lightMapIntensity=1;this.aoMap=null;this.aoMapIntensity=1;this.envMap=this.alphaMap=
this.specularMap=null;this.combine=0;this.reflectivity=1;this.refractionRatio=.98;this.wireframe=!1;this.wireframeLinewidth=1;this.wireframeLinejoin=this.wireframeLinecap="round";this.lights=this.morphTargets=this.skinning=!1;this.setValues(a)}function hb(a,b){this.origin=void 0!==a?a:new n;this.direction=void 0!==b?b:new n}function Fb(a,b){this.start=void 0!==a?a:new n;this.end=void 0!==b?b:new n}function Ra(a,b,c){this.a=void 0!==a?a:new n;this.b=void 0!==b?b:new n;this.c=void 0!==c?c:new n}function fa(a,
b){w.call(this);this.type="Mesh";this.geometry=void 0!==a?a:new F;this.material=void 0!==b?b:new sa({color:16777215*Math.random()});this.drawMode=0;this.updateMorphTargets()}function Pf(a,b,c,d){function e(a,c){b.buffers.color.setClear(a.r,a.g,a.b,c,d)}var f=new C(0),g=0,h,k,l;return{getClearColor:function(){return f},setClearColor:function(a,b){f.set(a);g=void 0!==b?b:1;e(f,g)},getClearAlpha:function(){return g},setClearAlpha:function(a){g=a;e(f,g)},render:function(b,d,t,r){d=d.background;null===
d?e(f,g):d&&d.isColor&&(e(d,1),r=!0);(a.autoClear||r)&&a.clear(a.autoClearColor,a.autoClearDepth,a.autoClearStencil);d&&d.isCubeTexture?(void 0===l&&(l=new fa(new fb(1,1,1),new ya({uniforms:ib.cube.uniforms,vertexShader:ib.cube.vertexShader,fragmentShader:ib.cube.fragmentShader,side:1,depthTest:!0,depthWrite:!1,polygonOffset:!0,fog:!1})),l.geometry.removeAttribute("normal"),l.geometry.removeAttribute("uv"),l.onBeforeRender=function(a,b,c){a=c.far;this.matrixWorld.makeScale(a,a,a);this.matrixWorld.copyPosition(c.matrixWorld);
this.material.polygonOffsetUnits=10*a},c.update(l.geometry)),l.material.uniforms.tCube.value=d,b.push(l,l.geometry,l.material,0,null)):d&&d.isTexture&&(void 0===h&&(h=new Db(-1,1,1,-1,0,1),k=new fa(new gb(2,2),new sa({depthTest:!1,depthWrite:!1,fog:!1})),c.update(k.geometry)),k.material.map=d,a.renderBufferDirect(h,null,k.geometry,k.material,k,null))}}}function Qf(a,b){return a.renderOrder!==b.renderOrder?a.renderOrder-b.renderOrder:a.program&&b.program&&a.program!==b.program?a.program.id-b.program.id:
a.material.id!==b.material.id?a.material.id-b.material.id:a.z!==b.z?a.z-b.z:a.id-b.id}function Rf(a,b){return a.renderOrder!==b.renderOrder?a.renderOrder-b.renderOrder:a.z!==b.z?b.z-a.z:a.id-b.id}function Sf(){var a=[],b=0,c=[],d=[];return{opaque:c,transparent:d,init:function(){b=0;c.length=0;d.length=0},push:function(e,f,g,h,k){var l=a[b];void 0===l?(l={id:e.id,object:e,geometry:f,material:g,program:g.program,renderOrder:e.renderOrder,z:h,group:k},a[b]=l):(l.id=e.id,l.object=e,l.geometry=f,l.material=
g,l.program=g.program,l.renderOrder=e.renderOrder,l.z=h,l.group=k);(!0===g.transparent?d:c).push(l);b++},sort:function(){1<c.length&&c.sort(Qf);1<d.length&&d.sort(Rf)}}}function Tf(){var a={};return{get:function(b,c){b=b.id+","+c.id;c=a[b];void 0===c&&(c=new Sf,a[b]=c);return c},dispose:function(){a={}}}}function Uf(a,b){return Math.abs(b[1])-Math.abs(a[1])}function Vf(a){var b={},c=new Float32Array(8);return{update:function(d,e,f,g){var h=d.morphTargetInfluences,k=h.length;d=b[e.id];if(void 0===
d){d=[];for(var l=0;l<k;l++)d[l]=[l,0];b[e.id]=d}var q=f.morphTargets&&e.morphAttributes.position;f=f.morphNormals&&e.morphAttributes.normal;for(l=0;l<k;l++){var p=d[l];0!==p[1]&&(q&&e.removeAttribute("morphTarget"+l),f&&e.removeAttribute("morphNormal"+l))}for(l=0;l<k;l++)p=d[l],p[0]=l,p[1]=h[l];d.sort(Uf);for(l=0;8>l;l++){if(p=d[l])if(h=p[0],p=p[1]){q&&e.addAttribute("morphTarget"+l,q[h]);f&&e.addAttribute("morphNormal"+l,f[h]);c[l]=p;continue}c[l]=0}g.getUniforms().setValue(a,"morphTargetInfluences",
c)}}}function Wf(a,b,c){var d,e,f;this.setMode=function(a){d=a};this.setIndex=function(a){e=a.type;f=a.bytesPerElement};this.render=function(b,h){a.drawElements(d,h,e,b*f);c.calls++;c.vertices+=h;d===a.TRIANGLES?c.faces+=h/3:d===a.POINTS&&(c.points+=h)};this.renderInstances=function(g,h,k){var l=b.get("ANGLE_instanced_arrays");null===l?console.error("THREE.WebGLIndexedBufferRenderer: using THREE.InstancedBufferGeometry but hardware does not support extension ANGLE_instanced_arrays."):(l.drawElementsInstancedANGLE(d,
k,e,h*f,g.maxInstancedCount),c.calls++,c.vertices+=k*g.maxInstancedCount,d===a.TRIANGLES?c.faces+=g.maxInstancedCount*k/3:d===a.POINTS&&(c.points+=g.maxInstancedCount*k))}}function Xf(a,b,c){var d;this.setMode=function(a){d=a};this.render=function(b,f){a.drawArrays(d,b,f);c.calls++;c.vertices+=f;d===a.TRIANGLES?c.faces+=f/3:d===a.POINTS&&(c.points+=f)};this.renderInstances=function(e,f,g){var h=b.get("ANGLE_instanced_arrays");if(null===h)console.error("THREE.WebGLBufferRenderer: using THREE.InstancedBufferGeometry but hardware does not support extension ANGLE_instanced_arrays.");
else{var k=e.attributes.position;k.isInterleavedBufferAttribute?(g=k.data.count,h.drawArraysInstancedANGLE(d,0,g,e.maxInstancedCount)):h.drawArraysInstancedANGLE(d,f,g,e.maxInstancedCount);c.calls++;c.vertices+=g*e.maxInstancedCount;d===a.TRIANGLES?c.faces+=e.maxInstancedCount*g/3:d===a.POINTS&&(c.points+=e.maxInstancedCount*g)}}}function Yf(a,b,c){function d(a){a=a.target;var g=e[a.id];null!==g.index&&b.remove(g.index);for(var k in g.attributes)b.remove(g.attributes[k]);a.removeEventListener("dispose",
d);delete e[a.id];if(k=f[a.id])b.remove(k),delete f[a.id];if(k=f[g.id])b.remove(k),delete f[g.id];c.geometries--}var e={},f={};return{get:function(a,b){var f=e[b.id];if(f)return f;b.addEventListener("dispose",d);b.isBufferGeometry?f=b:b.isGeometry&&(void 0===b._bufferGeometry&&(b._bufferGeometry=(new F).setFromObject(a)),f=b._bufferGeometry);e[b.id]=f;c.geometries++;return f},update:function(c){var d=c.index,e=c.attributes;null!==d&&b.update(d,a.ELEMENT_ARRAY_BUFFER);for(var f in e)b.update(e[f],
a.ARRAY_BUFFER);c=c.morphAttributes;for(f in c)for(var d=c[f],e=0,g=d.length;e<g;e++)b.update(d[e],a.ARRAY_BUFFER)},getWireframeAttribute:function(c){var d=f[c.id];if(d)return d;d=[];var e=c.index;var g=c.attributes;if(null!==e){var q=e.array;for(var p=0,t=q.length;p<t;p+=3){var r=q[p+0];g=q[p+1];e=q[p+2];d.push(r,g,g,e,e,r)}}else for(q=g.position.array,p=0,t=q.length/3-1;p<t;p+=3)r=p+0,g=p+1,e=p+2,d.push(r,g,g,e,e,r);d=new (65535<Sd(d)?eb:db)(d,1);b.update(d,a.ELEMENT_ARRAY_BUFFER);return f[c.id]=
d}}}function Zf(){var a={};return{get:function(b){if(void 0!==a[b.id])return a[b.id];switch(b.type){case "DirectionalLight":var c={direction:new n,color:new C,shadow:!1,shadowBias:0,shadowRadius:1,shadowMapSize:new D};break;case "SpotLight":c={position:new n,direction:new n,color:new C,distance:0,coneCos:0,penumbraCos:0,decay:0,shadow:!1,shadowBias:0,shadowRadius:1,shadowMapSize:new D};break;case "PointLight":c={position:new n,color:new C,distance:0,decay:0,shadow:!1,shadowBias:0,shadowRadius:1,shadowMapSize:new D,
shadowCameraNear:1,shadowCameraFar:1E3};break;case "HemisphereLight":c={direction:new n,skyColor:new C,groundColor:new C};break;case "RectAreaLight":c={color:new C,position:new n,halfWidth:new n,halfHeight:new n}}return a[b.id]=c}}}function $f(){var a=new Zf,b={hash:"",ambient:[0,0,0],directional:[],directionalShadowMap:[],directionalShadowMatrix:[],spot:[],spotShadowMap:[],spotShadowMatrix:[],rectArea:[],point:[],pointShadowMap:[],pointShadowMatrix:[],hemi:[]},c=new n,d=new O,e=new O;return{setup:function(f,
g,h){for(var k,l=0,q=0,p=0,t=0,r=0,m=0,u=0,x=0,n=h.matrixWorldInverse,A=0,I=f.length;A<I;A++){var B=f[A];k=B.color;var H=B.intensity,va=B.distance,xa=B.shadow&&B.shadow.map?B.shadow.map.texture:null;if(B.isAmbientLight)l+=k.r*H,q+=k.g*H,p+=k.b*H;else if(B.isDirectionalLight){h=a.get(B);h.color.copy(B.color).multiplyScalar(B.intensity);h.direction.setFromMatrixPosition(B.matrixWorld);c.setFromMatrixPosition(B.target.matrixWorld);h.direction.sub(c);h.direction.transformDirection(n);if(h.shadow=B.castShadow)k=
B.shadow,h.shadowBias=k.bias,h.shadowRadius=k.radius,h.shadowMapSize=k.mapSize;b.directionalShadowMap[t]=xa;b.directionalShadowMatrix[t]=B.shadow.matrix;b.directional[t]=h;t++}else if(B.isSpotLight){h=a.get(B);h.position.setFromMatrixPosition(B.matrixWorld);h.position.applyMatrix4(n);h.color.copy(k).multiplyScalar(H);h.distance=va;h.direction.setFromMatrixPosition(B.matrixWorld);c.setFromMatrixPosition(B.target.matrixWorld);h.direction.sub(c);h.direction.transformDirection(n);h.coneCos=Math.cos(B.angle);
h.penumbraCos=Math.cos(B.angle*(1-B.penumbra));h.decay=0===B.distance?0:B.decay;if(h.shadow=B.castShadow)k=B.shadow,h.shadowBias=k.bias,h.shadowRadius=k.radius,h.shadowMapSize=k.mapSize;b.spotShadowMap[m]=xa;b.spotShadowMatrix[m]=B.shadow.matrix;b.spot[m]=h;m++}else if(B.isRectAreaLight)h=a.get(B),h.color.copy(k).multiplyScalar(H/(B.width*B.height)),h.position.setFromMatrixPosition(B.matrixWorld),h.position.applyMatrix4(n),e.identity(),d.copy(B.matrixWorld),d.premultiply(n),e.extractRotation(d),h.halfWidth.set(.5*
B.width,0,0),h.halfHeight.set(0,.5*B.height,0),h.halfWidth.applyMatrix4(e),h.halfHeight.applyMatrix4(e),b.rectArea[u]=h,u++;else if(B.isPointLight){h=a.get(B);h.position.setFromMatrixPosition(B.matrixWorld);h.position.applyMatrix4(n);h.color.copy(B.color).multiplyScalar(B.intensity);h.distance=B.distance;h.decay=0===B.distance?0:B.decay;if(h.shadow=B.castShadow)k=B.shadow,h.shadowBias=k.bias,h.shadowRadius=k.radius,h.shadowMapSize=k.mapSize,h.shadowCameraNear=k.camera.near,h.shadowCameraFar=k.camera.far;
b.pointShadowMap[r]=xa;b.pointShadowMatrix[r]=B.shadow.matrix;b.point[r]=h;r++}else B.isHemisphereLight&&(h=a.get(B),h.direction.setFromMatrixPosition(B.matrixWorld),h.direction.transformDirection(n),h.direction.normalize(),h.skyColor.copy(B.color).multiplyScalar(H),h.groundColor.copy(B.groundColor).multiplyScalar(H),b.hemi[x]=h,x++)}b.ambient[0]=l;b.ambient[1]=q;b.ambient[2]=p;b.directional.length=t;b.spot.length=m;b.rectArea.length=u;b.point.length=r;b.hemi.length=x;b.hash=t+","+r+","+m+","+u+","+
x+","+g.length},state:b}}function ag(a,b){var c={};return{update:function(d){var e=b.frame,f=d.geometry,g=a.get(d,f);c[g.id]!==e&&(f.isGeometry&&g.updateFromObject(d),a.update(g),c[g.id]=e);return g},clear:function(){c={}}}}function bg(a){a=a.split("\n");for(var b=0;b<a.length;b++)a[b]=b+1+": "+a[b];return a.join("\n")}function Me(a,b,c){var d=a.createShader(b);a.shaderSource(d,c);a.compileShader(d);!1===a.getShaderParameter(d,a.COMPILE_STATUS)&&console.error("THREE.WebGLShader: Shader couldn't compile.");
""!==a.getShaderInfoLog(d)&&console.warn("THREE.WebGLShader: gl.getShaderInfoLog()",b===a.VERTEX_SHADER?"vertex":"fragment",a.getShaderInfoLog(d),bg(c));return d}function Ne(a){switch(a){case 3E3:return["Linear","( value )"];case 3001:return["sRGB","( value )"];case 3002:return["RGBE","( value )"];case 3004:return["RGBM","( value, 7.0 )"];case 3005:return["RGBM","( value, 16.0 )"];case 3006:return["RGBD","( value, 256.0 )"];case 3007:return["Gamma","( value, float( GAMMA_FACTOR ) )"];default:throw Error("unsupported encoding: "+
a);}}function Td(a,b){b=Ne(b);return"vec4 "+a+"( vec4 value ) { return "+b[0]+"ToLinear"+b[1]+"; }"}function cg(a,b){b=Ne(b);return"vec4 "+a+"( vec4 value ) { return LinearTo"+b[0]+b[1]+"; }"}function dg(a,b){switch(b){case 1:b="Linear";break;case 2:b="Reinhard";break;case 3:b="Uncharted2";break;case 4:b="OptimizedCineon";break;default:throw Error("unsupported toneMapping: "+b);}return"vec3 "+a+"( vec3 color ) { return "+b+"ToneMapping( color ); }"}function eg(a,b,c){a=a||{};return[a.derivatives||
b.envMapCubeUV||b.bumpMap||b.normalMap||b.flatShading?"#extension GL_OES_standard_derivatives : enable":"",(a.fragDepth||b.logarithmicDepthBuffer)&&c.get("EXT_frag_depth")?"#extension GL_EXT_frag_depth : enable":"",a.drawBuffers&&c.get("WEBGL_draw_buffers")?"#extension GL_EXT_draw_buffers : require":"",(a.shaderTextureLOD||b.envMap)&&c.get("EXT_shader_texture_lod")?"#extension GL_EXT_shader_texture_lod : enable":""].filter(wc).join("\n")}function fg(a){var b=[],c;for(c in a){var d=a[c];!1!==d&&b.push("#define "+
c+" "+d)}return b.join("\n")}function wc(a){return""!==a}function Oe(a,b){return a.replace(/NUM_DIR_LIGHTS/g,b.numDirLights).replace(/NUM_SPOT_LIGHTS/g,b.numSpotLights).replace(/NUM_RECT_AREA_LIGHTS/g,b.numRectAreaLights).replace(/NUM_POINT_LIGHTS/g,b.numPointLights).replace(/NUM_HEMI_LIGHTS/g,b.numHemiLights)}function Ud(a){return a.replace(/^[ \t]*#include +<([\w\d.]+)>/gm,function(a,c){a=V[c];if(void 0===a)throw Error("Can not resolve #include <"+c+">");return Ud(a)})}function Pe(a){return a.replace(/for \( int i \= (\d+)\; i < (\d+)\; i \+\+ \) \{([\s\S]+?)(?=\})\}/g,
function(a,c,d,e){a="";for(c=parseInt(c);c<parseInt(d);c++)a+=e.replace(/\[ i \]/g,"[ "+c+" ]");return a})}function gg(a,b,c,d,e,f){var g=a.context,h=d.defines,k=e.vertexShader,l=e.fragmentShader,q="SHADOWMAP_TYPE_BASIC";1===f.shadowMapType?q="SHADOWMAP_TYPE_PCF":2===f.shadowMapType&&(q="SHADOWMAP_TYPE_PCF_SOFT");var p="ENVMAP_TYPE_CUBE",t="ENVMAP_MODE_REFLECTION",r="ENVMAP_BLENDING_MULTIPLY";if(f.envMap){switch(d.envMap.mapping){case 301:case 302:p="ENVMAP_TYPE_CUBE";break;case 306:case 307:p="ENVMAP_TYPE_CUBE_UV";
break;case 303:case 304:p="ENVMAP_TYPE_EQUIREC";break;case 305:p="ENVMAP_TYPE_SPHERE"}switch(d.envMap.mapping){case 302:case 304:t="ENVMAP_MODE_REFRACTION"}switch(d.combine){case 0:r="ENVMAP_BLENDING_MULTIPLY";break;case 1:r="ENVMAP_BLENDING_MIX";break;case 2:r="ENVMAP_BLENDING_ADD"}}var m=0<a.gammaFactor?a.gammaFactor:1,u=eg(d.extensions,f,b),x=fg(h),n=g.createProgram();d.isRawShaderMaterial?(h=[x,"\n"].filter(wc).join("\n"),b=[u,x,"\n"].filter(wc).join("\n")):(h=["precision "+f.precision+" float;",
"precision "+f.precision+" int;","#define SHADER_NAME "+e.name,x,f.supportsVertexTextures?"#define VERTEX_TEXTURES":"","#define GAMMA_FACTOR "+m,"#define MAX_BONES "+f.maxBones,f.useFog&&f.fog?"#define USE_FOG":"",f.useFog&&f.fogExp?"#define FOG_EXP2":"",f.map?"#define USE_MAP":"",f.envMap?"#define USE_ENVMAP":"",f.envMap?"#define "+t:"",f.lightMap?"#define USE_LIGHTMAP":"",f.aoMap?"#define USE_AOMAP":"",f.emissiveMap?"#define USE_EMISSIVEMAP":"",f.bumpMap?"#define USE_BUMPMAP":"",f.normalMap?"#define USE_NORMALMAP":
"",f.displacementMap&&f.supportsVertexTextures?"#define USE_DISPLACEMENTMAP":"",f.specularMap?"#define USE_SPECULARMAP":"",f.roughnessMap?"#define USE_ROUGHNESSMAP":"",f.metalnessMap?"#define USE_METALNESSMAP":"",f.alphaMap?"#define USE_ALPHAMAP":"",f.vertexColors?"#define USE_COLOR":"",f.flatShading?"#define FLAT_SHADED":"",f.skinning?"#define USE_SKINNING":"",f.useVertexTexture?"#define BONE_TEXTURE":"",f.morphTargets?"#define USE_MORPHTARGETS":"",f.morphNormals&&!1===f.flatShading?"#define USE_MORPHNORMALS":
"",f.doubleSided?"#define DOUBLE_SIDED":"",f.flipSided?"#define FLIP_SIDED":"","#define NUM_CLIPPING_PLANES "+f.numClippingPlanes,f.shadowMapEnabled?"#define USE_SHADOWMAP":"",f.shadowMapEnabled?"#define "+q:"",f.sizeAttenuation?"#define USE_SIZEATTENUATION":"",f.logarithmicDepthBuffer?"#define USE_LOGDEPTHBUF":"",f.logarithmicDepthBuffer&&b.get("EXT_frag_depth")?"#define USE_LOGDEPTHBUF_EXT":"","uniform mat4 modelMatrix;","uniform mat4 modelViewMatrix;","uniform mat4 projectionMatrix;","uniform mat4 viewMatrix;",
"uniform mat3 normalMatrix;","uniform vec3 cameraPosition;","attribute vec3 position;","attribute vec3 normal;","attribute vec2 uv;","#ifdef USE_COLOR","\tattribute vec3 color;","#endif","#ifdef USE_MORPHTARGETS","\tattribute vec3 morphTarget0;","\tattribute vec3 morphTarget1;","\tattribute vec3 morphTarget2;","\tattribute vec3 morphTarget3;","\t#ifdef USE_MORPHNORMALS","\t\tattribute vec3 morphNormal0;","\t\tattribute vec3 morphNormal1;","\t\tattribute vec3 morphNormal2;","\t\tattribute vec3 morphNormal3;",
"\t#else","\t\tattribute vec3 morphTarget4;","\t\tattribute vec3 morphTarget5;","\t\tattribute vec3 morphTarget6;","\t\tattribute vec3 morphTarget7;","\t#endif","#endif","#ifdef USE_SKINNING","\tattribute vec4 skinIndex;","\tattribute vec4 skinWeight;","#endif","\n"].filter(wc).join("\n"),b=[u,"precision "+f.precision+" float;","precision "+f.precision+" int;","#define SHADER_NAME "+e.name,x,f.alphaTest?"#define ALPHATEST "+f.alphaTest:"","#define GAMMA_FACTOR "+m,f.useFog&&f.fog?"#define USE_FOG":
"",f.useFog&&f.fogExp?"#define FOG_EXP2":"",f.map?"#define USE_MAP":"",f.envMap?"#define USE_ENVMAP":"",f.envMap?"#define "+p:"",f.envMap?"#define "+t:"",f.envMap?"#define "+r:"",f.lightMap?"#define USE_LIGHTMAP":"",f.aoMap?"#define USE_AOMAP":"",f.emissiveMap?"#define USE_EMISSIVEMAP":"",f.bumpMap?"#define USE_BUMPMAP":"",f.normalMap?"#define USE_NORMALMAP":"",f.specularMap?"#define USE_SPECULARMAP":"",f.roughnessMap?"#define USE_ROUGHNESSMAP":"",f.metalnessMap?"#define USE_METALNESSMAP":"",f.alphaMap?
"#define USE_ALPHAMAP":"",f.vertexColors?"#define USE_COLOR":"",f.gradientMap?"#define USE_GRADIENTMAP":"",f.flatShading?"#define FLAT_SHADED":"",f.doubleSided?"#define DOUBLE_SIDED":"",f.flipSided?"#define FLIP_SIDED":"","#define NUM_CLIPPING_PLANES "+f.numClippingPlanes,"#define UNION_CLIPPING_PLANES "+(f.numClippingPlanes-f.numClipIntersection),f.shadowMapEnabled?"#define USE_SHADOWMAP":"",f.shadowMapEnabled?"#define "+q:"",f.premultipliedAlpha?"#define PREMULTIPLIED_ALPHA":"",f.physicallyCorrectLights?
"#define PHYSICALLY_CORRECT_LIGHTS":"",f.logarithmicDepthBuffer?"#define USE_LOGDEPTHBUF":"",f.logarithmicDepthBuffer&&b.get("EXT_frag_depth")?"#define USE_LOGDEPTHBUF_EXT":"",f.envMap&&b.get("EXT_shader_texture_lod")?"#define TEXTURE_LOD_EXT":"","uniform mat4 viewMatrix;","uniform vec3 cameraPosition;",0!==f.toneMapping?"#define TONE_MAPPING":"",0!==f.toneMapping?V.tonemapping_pars_fragment:"",0!==f.toneMapping?dg("toneMapping",f.toneMapping):"",f.dithering?"#define DITHERING":"",f.outputEncoding||
f.mapEncoding||f.envMapEncoding||f.emissiveMapEncoding?V.encodings_pars_fragment:"",f.mapEncoding?Td("mapTexelToLinear",f.mapEncoding):"",f.envMapEncoding?Td("envMapTexelToLinear",f.envMapEncoding):"",f.emissiveMapEncoding?Td("emissiveMapTexelToLinear",f.emissiveMapEncoding):"",f.outputEncoding?cg("linearToOutputTexel",f.outputEncoding):"",f.depthPacking?"#define DEPTH_PACKING "+d.depthPacking:"","\n"].filter(wc).join("\n"));k=Ud(k);k=Oe(k,f);l=Ud(l);l=Oe(l,f);d.isShaderMaterial||(k=Pe(k),l=Pe(l));
l=b+l;k=Me(g,g.VERTEX_SHADER,h+k);l=Me(g,g.FRAGMENT_SHADER,l);g.attachShader(n,k);g.attachShader(n,l);void 0!==d.index0AttributeName?g.bindAttribLocation(n,0,d.index0AttributeName):!0===f.morphTargets&&g.bindAttribLocation(n,0,"position");g.linkProgram(n);f=g.getProgramInfoLog(n);e=g.getShaderInfoLog(k);q=g.getShaderInfoLog(l);t=p=!0;if(!1===g.getProgramParameter(n,g.LINK_STATUS))p=!1,console.error("THREE.WebGLProgram: shader error: ",g.getError(),"gl.VALIDATE_STATUS",g.getProgramParameter(n,g.VALIDATE_STATUS),
"gl.getProgramInfoLog",f,e,q);else if(""!==f)console.warn("THREE.WebGLProgram: gl.getProgramInfoLog()",f);else if(""===e||""===q)t=!1;t&&(this.diagnostics={runnable:p,material:d,programLog:f,vertexShader:{log:e,prefix:h},fragmentShader:{log:q,prefix:b}});g.deleteShader(k);g.deleteShader(l);var A;this.getUniforms=function(){void 0===A&&(A=new cb(g,n,a));return A};var I;this.getAttributes=function(){if(void 0===I){for(var a={},b=g.getProgramParameter(n,g.ACTIVE_ATTRIBUTES),c=0;c<b;c++){var d=g.getActiveAttrib(n,
c).name;a[d]=g.getAttribLocation(n,d)}I=a}return I};this.destroy=function(){g.deleteProgram(n);this.program=void 0};Object.defineProperties(this,{uniforms:{get:function(){console.warn("THREE.WebGLProgram: .uniforms is now .getUniforms().");return this.getUniforms()}},attributes:{get:function(){console.warn("THREE.WebGLProgram: .attributes is now .getAttributes().");return this.getAttributes()}}});this.id=hg++;this.code=c;this.usedTimes=1;this.program=n;this.vertexShader=k;this.fragmentShader=l;return this}
function ig(a,b,c){function d(a,b){if(a)a.isTexture?c=a.encoding:a.isWebGLRenderTarget&&(console.warn("THREE.WebGLPrograms.getTextureEncodingFromMap: don't use render targets as textures. Use their .texture property instead."),c=a.texture.encoding);else var c=3E3;3E3===c&&b&&(c=3007);return c}var e=[],f={MeshDepthMaterial:"depth",MeshDistanceMaterial:"distanceRGBA",MeshNormalMaterial:"normal",MeshBasicMaterial:"basic",MeshLambertMaterial:"lambert",MeshPhongMaterial:"phong",MeshToonMaterial:"phong",
MeshStandardMaterial:"physical",MeshPhysicalMaterial:"physical",LineBasicMaterial:"basic",LineDashedMaterial:"dashed",PointsMaterial:"points",ShadowMaterial:"shadow"},g="precision supportsVertexTextures map mapEncoding envMap envMapMode envMapEncoding lightMap aoMap emissiveMap emissiveMapEncoding bumpMap normalMap displacementMap specularMap roughnessMap metalnessMap gradientMap alphaMap combine vertexColors fog useFog fogExp flatShading sizeAttenuation logarithmicDepthBuffer skinning maxBones useVertexTexture morphTargets morphNormals maxMorphTargets maxMorphNormals premultipliedAlpha numDirLights numPointLights numSpotLights numHemiLights numRectAreaLights shadowMapEnabled shadowMapType toneMapping physicallyCorrectLights alphaTest doubleSided flipSided numClippingPlanes numClipIntersection depthPacking dithering".split(" ");
this.getParameters=function(b,e,g,q,p,t,r){var h=f[b.type];if(r.isSkinnedMesh){var l=r.skeleton.bones;if(c.floatVertexTextures)l=1024;else{var k=Math.min(Math.floor((c.maxVertexUniforms-20)/4),l.length);k<l.length?(console.warn("THREE.WebGLRenderer: Skeleton has "+l.length+" bones. This GPU supports "+k+"."),l=0):l=k}}else l=0;k=c.precision;null!==b.precision&&(k=c.getMaxPrecision(b.precision),k!==b.precision&&console.warn("THREE.WebGLProgram.getParameters:",b.precision,"not supported, using",k,"instead."));
var m=a.getRenderTarget();return{shaderID:h,precision:k,supportsVertexTextures:c.vertexTextures,outputEncoding:d(m?m.texture:null,a.gammaOutput),map:!!b.map,mapEncoding:d(b.map,a.gammaInput),envMap:!!b.envMap,envMapMode:b.envMap&&b.envMap.mapping,envMapEncoding:d(b.envMap,a.gammaInput),envMapCubeUV:!!b.envMap&&(306===b.envMap.mapping||307===b.envMap.mapping),lightMap:!!b.lightMap,aoMap:!!b.aoMap,emissiveMap:!!b.emissiveMap,emissiveMapEncoding:d(b.emissiveMap,a.gammaInput),bumpMap:!!b.bumpMap,normalMap:!!b.normalMap,
displacementMap:!!b.displacementMap,roughnessMap:!!b.roughnessMap,metalnessMap:!!b.metalnessMap,specularMap:!!b.specularMap,alphaMap:!!b.alphaMap,gradientMap:!!b.gradientMap,combine:b.combine,vertexColors:b.vertexColors,fog:!!q,useFog:b.fog,fogExp:q&&q.isFogExp2,flatShading:b.flatShading,sizeAttenuation:b.sizeAttenuation,logarithmicDepthBuffer:c.logarithmicDepthBuffer,skinning:b.skinning&&0<l,maxBones:l,useVertexTexture:c.floatVertexTextures,morphTargets:b.morphTargets,morphNormals:b.morphNormals,
maxMorphTargets:a.maxMorphTargets,maxMorphNormals:a.maxMorphNormals,numDirLights:e.directional.length,numPointLights:e.point.length,numSpotLights:e.spot.length,numRectAreaLights:e.rectArea.length,numHemiLights:e.hemi.length,numClippingPlanes:p,numClipIntersection:t,dithering:b.dithering,shadowMapEnabled:a.shadowMap.enabled&&r.receiveShadow&&0<g.length,shadowMapType:a.shadowMap.type,toneMapping:a.toneMapping,physicallyCorrectLights:a.physicallyCorrectLights,premultipliedAlpha:b.premultipliedAlpha,
alphaTest:b.alphaTest,doubleSided:2===b.side,flipSided:1===b.side,depthPacking:void 0!==b.depthPacking?b.depthPacking:!1}};this.getProgramCode=function(b,c){var d=[];c.shaderID?d.push(c.shaderID):(d.push(b.fragmentShader),d.push(b.vertexShader));if(void 0!==b.defines)for(var e in b.defines)d.push(e),d.push(b.defines[e]);for(e=0;e<g.length;e++)d.push(c[g[e]]);d.push(b.onBeforeCompile.toString());d.push(a.gammaOutput);return d.join()};this.acquireProgram=function(c,d,f,g){for(var h,l=0,k=e.length;l<
k;l++){var q=e[l];if(q.code===g){h=q;++h.usedTimes;break}}void 0===h&&(h=new gg(a,b,g,c,d,f),e.push(h));return h};this.releaseProgram=function(a){if(0===--a.usedTimes){var b=e.indexOf(a);e[b]=e[e.length-1];e.pop();a.destroy()}};this.programs=e}function jg(a,b,c,d,e,f,g){function h(a,b){if(a.width>b||a.height>b){b/=Math.max(a.width,a.height);var c=document.createElementNS("http://www.w3.org/1999/xhtml","canvas");c.width=Math.floor(a.width*b);c.height=Math.floor(a.height*b);c.getContext("2d").drawImage(a,
0,0,a.width,a.height,0,0,c.width,c.height);console.warn("THREE.WebGLRenderer: image is too big ("+a.width+"x"+a.height+"). Resized to "+c.width+"x"+c.height,a);return c}return a}function k(a){return R.isPowerOfTwo(a.width)&&R.isPowerOfTwo(a.height)}function l(a,b){return a.generateMipmaps&&b&&1003!==a.minFilter&&1006!==a.minFilter}function q(b){return 1003===b||1004===b||1005===b?a.NEAREST:a.LINEAR}function p(b){b=b.target;b.removeEventListener("dispose",p);a:{var c=d.get(b);if(b.image&&c.__image__webglTextureCube)a.deleteTexture(c.__image__webglTextureCube);
else{if(void 0===c.__webglInit)break a;a.deleteTexture(c.__webglTexture)}d.remove(b)}g.textures--}function t(b){b=b.target;b.removeEventListener("dispose",t);var c=d.get(b),e=d.get(b.texture);if(b){void 0!==e.__webglTexture&&a.deleteTexture(e.__webglTexture);b.depthTexture&&b.depthTexture.dispose();if(b.isWebGLRenderTargetCube)for(e=0;6>e;e++)a.deleteFramebuffer(c.__webglFramebuffer[e]),c.__webglDepthbuffer&&a.deleteRenderbuffer(c.__webglDepthbuffer[e]);else a.deleteFramebuffer(c.__webglFramebuffer),
c.__webglDepthbuffer&&a.deleteRenderbuffer(c.__webglDepthbuffer);d.remove(b.texture);d.remove(b)}g.textures--}function r(b,q){var t=d.get(b);if(0<b.version&&t.__version!==b.version){var r=b.image;if(void 0===r)console.warn("THREE.WebGLRenderer: Texture marked for update but image is undefined",b);else if(!1===r.complete)console.warn("THREE.WebGLRenderer: Texture marked for update but image is incomplete",b);else{void 0===t.__webglInit&&(t.__webglInit=!0,b.addEventListener("dispose",p),t.__webglTexture=
a.createTexture(),g.textures++);c.activeTexture(a.TEXTURE0+q);c.bindTexture(a.TEXTURE_2D,t.__webglTexture);a.pixelStorei(a.UNPACK_FLIP_Y_WEBGL,b.flipY);a.pixelStorei(a.UNPACK_PREMULTIPLY_ALPHA_WEBGL,b.premultiplyAlpha);a.pixelStorei(a.UNPACK_ALIGNMENT,b.unpackAlignment);var v=h(b.image,e.maxTextureSize);(1001!==b.wrapS||1001!==b.wrapT||1003!==b.minFilter&&1006!==b.minFilter)&&!1===k(v)&&(q=v,q instanceof HTMLImageElement||q instanceof HTMLCanvasElement?(r=document.createElementNS("http://www.w3.org/1999/xhtml",
"canvas"),r.width=R.nearestPowerOfTwo(q.width),r.height=R.nearestPowerOfTwo(q.height),r.getContext("2d").drawImage(q,0,0,r.width,r.height),console.warn("THREE.WebGLRenderer: image is not power of two ("+q.width+"x"+q.height+"). Resized to "+r.width+"x"+r.height,q),v=r):v=q);q=k(v);var r=f.convert(b.format),A=f.convert(b.type);m(a.TEXTURE_2D,b,q);var n=b.mipmaps;if(b.isDepthTexture){n=a.DEPTH_COMPONENT;if(1015===b.type){if(!y)throw Error("Float Depth Texture only supported in WebGL2.0");n=a.DEPTH_COMPONENT32F}else y&&
(n=a.DEPTH_COMPONENT16);1026===b.format&&n===a.DEPTH_COMPONENT&&1012!==b.type&&1014!==b.type&&(console.warn("THREE.WebGLRenderer: Use UnsignedShortType or UnsignedIntType for DepthFormat DepthTexture."),b.type=1012,A=f.convert(b.type));1027===b.format&&(n=a.DEPTH_STENCIL,1020!==b.type&&(console.warn("THREE.WebGLRenderer: Use UnsignedInt248Type for DepthStencilFormat DepthTexture."),b.type=1020,A=f.convert(b.type)));c.texImage2D(a.TEXTURE_2D,0,n,v.width,v.height,0,r,A,null)}else if(b.isDataTexture)if(0<
n.length&&q){for(var u=0,x=n.length;u<x;u++)v=n[u],c.texImage2D(a.TEXTURE_2D,u,r,v.width,v.height,0,r,A,v.data);b.generateMipmaps=!1}else c.texImage2D(a.TEXTURE_2D,0,r,v.width,v.height,0,r,A,v.data);else if(b.isCompressedTexture)for(u=0,x=n.length;u<x;u++)v=n[u],1023!==b.format&&1022!==b.format?-1<c.getCompressedTextureFormats().indexOf(r)?c.compressedTexImage2D(a.TEXTURE_2D,u,r,v.width,v.height,0,v.data):console.warn("THREE.WebGLRenderer: Attempt to load unsupported compressed texture format in .uploadTexture()"):
c.texImage2D(a.TEXTURE_2D,u,r,v.width,v.height,0,r,A,v.data);else if(0<n.length&&q){u=0;for(x=n.length;u<x;u++)v=n[u],c.texImage2D(a.TEXTURE_2D,u,r,r,A,v);b.generateMipmaps=!1}else c.texImage2D(a.TEXTURE_2D,0,r,r,A,v);l(b,q)&&a.generateMipmap(a.TEXTURE_2D);t.__version=b.version;if(b.onUpdate)b.onUpdate(b);return}}c.activeTexture(a.TEXTURE0+q);c.bindTexture(a.TEXTURE_2D,t.__webglTexture)}function m(c,g,h){h?(a.texParameteri(c,a.TEXTURE_WRAP_S,f.convert(g.wrapS)),a.texParameteri(c,a.TEXTURE_WRAP_T,
f.convert(g.wrapT)),a.texParameteri(c,a.TEXTURE_MAG_FILTER,f.convert(g.magFilter)),a.texParameteri(c,a.TEXTURE_MIN_FILTER,f.convert(g.minFilter))):(a.texParameteri(c,a.TEXTURE_WRAP_S,a.CLAMP_TO_EDGE),a.texParameteri(c,a.TEXTURE_WRAP_T,a.CLAMP_TO_EDGE),1001===g.wrapS&&1001===g.wrapT||console.warn("THREE.WebGLRenderer: Texture is not power of two. Texture.wrapS and Texture.wrapT should be set to THREE.ClampToEdgeWrapping.",g),a.texParameteri(c,a.TEXTURE_MAG_FILTER,q(g.magFilter)),a.texParameteri(c,
a.TEXTURE_MIN_FILTER,q(g.minFilter)),1003!==g.minFilter&&1006!==g.minFilter&&console.warn("THREE.WebGLRenderer: Texture is not power of two. Texture.minFilter should be set to THREE.NearestFilter or THREE.LinearFilter.",g));!(h=b.get("EXT_texture_filter_anisotropic"))||1015===g.type&&null===b.get("OES_texture_float_linear")||1016===g.type&&null===b.get("OES_texture_half_float_linear")||!(1<g.anisotropy||d.get(g).__currentAnisotropy)||(a.texParameterf(c,h.TEXTURE_MAX_ANISOTROPY_EXT,Math.min(g.anisotropy,
e.getMaxAnisotropy())),d.get(g).__currentAnisotropy=g.anisotropy)}function n(b,e,g,h){var l=f.convert(e.texture.format),k=f.convert(e.texture.type);c.texImage2D(h,0,l,e.width,e.height,0,l,k,null);a.bindFramebuffer(a.FRAMEBUFFER,b);a.framebufferTexture2D(a.FRAMEBUFFER,g,h,d.get(e.texture).__webglTexture,0);a.bindFramebuffer(a.FRAMEBUFFER,null)}function x(b,c){a.bindRenderbuffer(a.RENDERBUFFER,b);c.depthBuffer&&!c.stencilBuffer?(a.renderbufferStorage(a.RENDERBUFFER,a.DEPTH_COMPONENT16,c.width,c.height),
a.framebufferRenderbuffer(a.FRAMEBUFFER,a.DEPTH_ATTACHMENT,a.RENDERBUFFER,b)):c.depthBuffer&&c.stencilBuffer?(a.renderbufferStorage(a.RENDERBUFFER,a.DEPTH_STENCIL,c.width,c.height),a.framebufferRenderbuffer(a.FRAMEBUFFER,a.DEPTH_STENCIL_ATTACHMENT,a.RENDERBUFFER,b)):a.renderbufferStorage(a.RENDERBUFFER,a.RGBA4,c.width,c.height);a.bindRenderbuffer(a.RENDERBUFFER,null)}var y="undefined"!==typeof WebGL2RenderingContext&&a instanceof WebGL2RenderingContext;this.setTexture2D=r;this.setTextureCube=function(b,
q){var t=d.get(b);if(6===b.image.length)if(0<b.version&&t.__version!==b.version){t.__image__webglTextureCube||(b.addEventListener("dispose",p),t.__image__webglTextureCube=a.createTexture(),g.textures++);c.activeTexture(a.TEXTURE0+q);c.bindTexture(a.TEXTURE_CUBE_MAP,t.__image__webglTextureCube);a.pixelStorei(a.UNPACK_FLIP_Y_WEBGL,b.flipY);q=b&&b.isCompressedTexture;for(var r=b.image[0]&&b.image[0].isDataTexture,v=[],n=0;6>n;n++)v[n]=q||r?r?b.image[n].image:b.image[n]:h(b.image[n],e.maxCubemapSize);
var u=k(v[0]),x=f.convert(b.format),A=f.convert(b.type);m(a.TEXTURE_CUBE_MAP,b,u);for(n=0;6>n;n++)if(q)for(var y,I=v[n].mipmaps,w=0,z=I.length;w<z;w++)y=I[w],1023!==b.format&&1022!==b.format?-1<c.getCompressedTextureFormats().indexOf(x)?c.compressedTexImage2D(a.TEXTURE_CUBE_MAP_POSITIVE_X+n,w,x,y.width,y.height,0,y.data):console.warn("THREE.WebGLRenderer: Attempt to load unsupported compressed texture format in .setTextureCube()"):c.texImage2D(a.TEXTURE_CUBE_MAP_POSITIVE_X+n,w,x,y.width,y.height,
0,x,A,y.data);else r?c.texImage2D(a.TEXTURE_CUBE_MAP_POSITIVE_X+n,0,x,v[n].width,v[n].height,0,x,A,v[n].data):c.texImage2D(a.TEXTURE_CUBE_MAP_POSITIVE_X+n,0,x,x,A,v[n]);l(b,u)&&a.generateMipmap(a.TEXTURE_CUBE_MAP);t.__version=b.version;if(b.onUpdate)b.onUpdate(b)}else c.activeTexture(a.TEXTURE0+q),c.bindTexture(a.TEXTURE_CUBE_MAP,t.__image__webglTextureCube)};this.setTextureCubeDynamic=function(b,e){c.activeTexture(a.TEXTURE0+e);c.bindTexture(a.TEXTURE_CUBE_MAP,d.get(b).__webglTexture)};this.setupRenderTarget=
function(b){var e=d.get(b),f=d.get(b.texture);b.addEventListener("dispose",t);f.__webglTexture=a.createTexture();g.textures++;var h=!0===b.isWebGLRenderTargetCube,p=k(b);if(h){e.__webglFramebuffer=[];for(var q=0;6>q;q++)e.__webglFramebuffer[q]=a.createFramebuffer()}else e.__webglFramebuffer=a.createFramebuffer();if(h){c.bindTexture(a.TEXTURE_CUBE_MAP,f.__webglTexture);m(a.TEXTURE_CUBE_MAP,b.texture,p);for(q=0;6>q;q++)n(e.__webglFramebuffer[q],b,a.COLOR_ATTACHMENT0,a.TEXTURE_CUBE_MAP_POSITIVE_X+q);
l(b.texture,p)&&a.generateMipmap(a.TEXTURE_CUBE_MAP);c.bindTexture(a.TEXTURE_CUBE_MAP,null)}else c.bindTexture(a.TEXTURE_2D,f.__webglTexture),m(a.TEXTURE_2D,b.texture,p),n(e.__webglFramebuffer,b,a.COLOR_ATTACHMENT0,a.TEXTURE_2D),l(b.texture,p)&&a.generateMipmap(a.TEXTURE_2D),c.bindTexture(a.TEXTURE_2D,null);if(b.depthBuffer){e=d.get(b);f=!0===b.isWebGLRenderTargetCube;if(b.depthTexture){if(f)throw Error("target.depthTexture not supported in Cube render targets");if(b&&b.isWebGLRenderTargetCube)throw Error("Depth Texture with cube render targets is not supported");
a.bindFramebuffer(a.FRAMEBUFFER,e.__webglFramebuffer);if(!b.depthTexture||!b.depthTexture.isDepthTexture)throw Error("renderTarget.depthTexture must be an instance of THREE.DepthTexture");d.get(b.depthTexture).__webglTexture&&b.depthTexture.image.width===b.width&&b.depthTexture.image.height===b.height||(b.depthTexture.image.width=b.width,b.depthTexture.image.height=b.height,b.depthTexture.needsUpdate=!0);r(b.depthTexture,0);e=d.get(b.depthTexture).__webglTexture;if(1026===b.depthTexture.format)a.framebufferTexture2D(a.FRAMEBUFFER,
a.DEPTH_ATTACHMENT,a.TEXTURE_2D,e,0);else if(1027===b.depthTexture.format)a.framebufferTexture2D(a.FRAMEBUFFER,a.DEPTH_STENCIL_ATTACHMENT,a.TEXTURE_2D,e,0);else throw Error("Unknown depthTexture format");}else if(f)for(e.__webglDepthbuffer=[],f=0;6>f;f++)a.bindFramebuffer(a.FRAMEBUFFER,e.__webglFramebuffer[f]),e.__webglDepthbuffer[f]=a.createRenderbuffer(),x(e.__webglDepthbuffer[f],b);else a.bindFramebuffer(a.FRAMEBUFFER,e.__webglFramebuffer),e.__webglDepthbuffer=a.createRenderbuffer(),x(e.__webglDepthbuffer,
b);a.bindFramebuffer(a.FRAMEBUFFER,null)}};this.updateRenderTargetMipmap=function(b){var e=b.texture,f=k(b);l(e,f)&&(b=b.isWebGLRenderTargetCube?a.TEXTURE_CUBE_MAP:a.TEXTURE_2D,e=d.get(e).__webglTexture,c.bindTexture(b,e),a.generateMipmap(b),c.bindTexture(b,null))}}function kg(){var a={};return{get:function(b){b=b.uuid;var c=a[b];void 0===c&&(c={},a[b]=c);return c},remove:function(b){delete a[b.uuid]},clear:function(){a={}}}}function lg(a,b,c){function d(b,c,d){var e=new Uint8Array(4),f=a.createTexture();
a.bindTexture(b,f);a.texParameteri(b,a.TEXTURE_MIN_FILTER,a.NEAREST);a.texParameteri(b,a.TEXTURE_MAG_FILTER,a.NEAREST);for(b=0;b<d;b++)a.texImage2D(c+b,0,a.RGBA,1,1,0,a.RGBA,a.UNSIGNED_BYTE,e);return f}function e(b){!0!==A[b]&&(a.enable(b),A[b]=!0)}function f(b){!1!==A[b]&&(a.disable(b),A[b]=!1)}function g(b,d,g,h,l,k,p,q){0!==b?e(a.BLEND):f(a.BLEND);if(5!==b){if(b!==H||q!==J)switch(b){case 2:q?(a.blendEquationSeparate(a.FUNC_ADD,a.FUNC_ADD),a.blendFuncSeparate(a.ONE,a.ONE,a.ONE,a.ONE)):(a.blendEquation(a.FUNC_ADD),
a.blendFunc(a.SRC_ALPHA,a.ONE));break;case 3:q?(a.blendEquationSeparate(a.FUNC_ADD,a.FUNC_ADD),a.blendFuncSeparate(a.ZERO,a.ZERO,a.ONE_MINUS_SRC_COLOR,a.ONE_MINUS_SRC_ALPHA)):(a.blendEquation(a.FUNC_ADD),a.blendFunc(a.ZERO,a.ONE_MINUS_SRC_COLOR));break;case 4:q?(a.blendEquationSeparate(a.FUNC_ADD,a.FUNC_ADD),a.blendFuncSeparate(a.ZERO,a.SRC_COLOR,a.ZERO,a.SRC_ALPHA)):(a.blendEquation(a.FUNC_ADD),a.blendFunc(a.ZERO,a.SRC_COLOR));break;default:q?(a.blendEquationSeparate(a.FUNC_ADD,a.FUNC_ADD),a.blendFuncSeparate(a.ONE,
a.ONE_MINUS_SRC_ALPHA,a.ONE,a.ONE_MINUS_SRC_ALPHA)):(a.blendEquationSeparate(a.FUNC_ADD,a.FUNC_ADD),a.blendFuncSeparate(a.SRC_ALPHA,a.ONE_MINUS_SRC_ALPHA,a.ONE,a.ONE_MINUS_SRC_ALPHA))}C=D=ba=z=w=va=null}else{l=l||d;k=k||g;p=p||h;if(d!==va||l!==ba)a.blendEquationSeparate(c.convert(d),c.convert(l)),va=d,ba=l;if(g!==w||h!==z||k!==D||p!==C)a.blendFuncSeparate(c.convert(g),c.convert(h),c.convert(k),c.convert(p)),w=g,z=h,D=k,C=p}H=b;J=q}function h(b){F!==b&&(b?a.frontFace(a.CW):a.frontFace(a.CCW),F=b)}
function k(b){0!==b?(e(a.CULL_FACE),b!==ga&&(1===b?a.cullFace(a.BACK):2===b?a.cullFace(a.FRONT):a.cullFace(a.FRONT_AND_BACK))):f(a.CULL_FACE);ga=b}function l(b,c,d){if(b){if(e(a.POLYGON_OFFSET_FILL),T!==c||L!==d)a.polygonOffset(c,d),T=c,L=d}else f(a.POLYGON_OFFSET_FILL)}function q(b){void 0===b&&(b=a.TEXTURE0+O-1);K!==b&&(a.activeTexture(b),K=b)}var p=new function(){var b=!1,c=new S,d=null,e=new S(0,0,0,0);return{setMask:function(c){d===c||b||(a.colorMask(c,c,c,c),d=c)},setLocked:function(a){b=a},
setClear:function(b,d,f,g,h){!0===h&&(b*=g,d*=g,f*=g);c.set(b,d,f,g);!1===e.equals(c)&&(a.clearColor(b,d,f,g),e.copy(c))},reset:function(){b=!1;d=null;e.set(-1,0,0,0)}}},t=new function(){var b=!1,c=null,d=null,g=null;return{setTest:function(b){b?e(a.DEPTH_TEST):f(a.DEPTH_TEST)},setMask:function(d){c===d||b||(a.depthMask(d),c=d)},setFunc:function(b){if(d!==b){if(b)switch(b){case 0:a.depthFunc(a.NEVER);break;case 1:a.depthFunc(a.ALWAYS);break;case 2:a.depthFunc(a.LESS);break;case 3:a.depthFunc(a.LEQUAL);
break;case 4:a.depthFunc(a.EQUAL);break;case 5:a.depthFunc(a.GEQUAL);break;case 6:a.depthFunc(a.GREATER);break;case 7:a.depthFunc(a.NOTEQUAL);break;default:a.depthFunc(a.LEQUAL)}else a.depthFunc(a.LEQUAL);d=b}},setLocked:function(a){b=a},setClear:function(b){g!==b&&(a.clearDepth(b),g=b)},reset:function(){b=!1;g=d=c=null}}},r=new function(){var b=!1,c=null,d=null,g=null,h=null,l=null,k=null,p=null,q=null;return{setTest:function(b){b?e(a.STENCIL_TEST):f(a.STENCIL_TEST)},setMask:function(d){c===d||b||
(a.stencilMask(d),c=d)},setFunc:function(b,c,e){if(d!==b||g!==c||h!==e)a.stencilFunc(b,c,e),d=b,g=c,h=e},setOp:function(b,c,d){if(l!==b||k!==c||p!==d)a.stencilOp(b,c,d),l=b,k=c,p=d},setLocked:function(a){b=a},setClear:function(b){q!==b&&(a.clearStencil(b),q=b)},reset:function(){b=!1;q=p=k=l=h=g=d=c=null}}},m=a.getParameter(a.MAX_VERTEX_ATTRIBS),n=new Uint8Array(m),x=new Uint8Array(m),y=new Uint8Array(m),A={},I=null,B=null,H=null,va=null,w=null,z=null,ba=null,D=null,C=null,J=!1,F=null,ga=null,M=null,
T=null,L=null,O=a.getParameter(a.MAX_COMBINED_TEXTURE_IMAGE_UNITS),m=parseFloat(/^WebGL\ ([0-9])/.exec(a.getParameter(a.VERSION))[1]),Q=1<=parseFloat(m),K=null,R={},P=new S,G=new S,U={};U[a.TEXTURE_2D]=d(a.TEXTURE_2D,a.TEXTURE_2D,1);U[a.TEXTURE_CUBE_MAP]=d(a.TEXTURE_CUBE_MAP,a.TEXTURE_CUBE_MAP_POSITIVE_X,6);p.setClear(0,0,0,1);t.setClear(1);r.setClear(0);e(a.DEPTH_TEST);t.setFunc(3);h(!1);k(1);e(a.CULL_FACE);e(a.BLEND);g(1);return{buffers:{color:p,depth:t,stencil:r},initAttributes:function(){for(var a=
0,b=n.length;a<b;a++)n[a]=0},enableAttribute:function(c){n[c]=1;0===x[c]&&(a.enableVertexAttribArray(c),x[c]=1);0!==y[c]&&(b.get("ANGLE_instanced_arrays").vertexAttribDivisorANGLE(c,0),y[c]=0)},enableAttributeAndDivisor:function(c,d){n[c]=1;0===x[c]&&(a.enableVertexAttribArray(c),x[c]=1);y[c]!==d&&(b.get("ANGLE_instanced_arrays").vertexAttribDivisorANGLE(c,d),y[c]=d)},disableUnusedAttributes:function(){for(var b=0,c=x.length;b!==c;++b)x[b]!==n[b]&&(a.disableVertexAttribArray(b),x[b]=0)},enable:e,
disable:f,getCompressedTextureFormats:function(){if(null===I&&(I=[],b.get("WEBGL_compressed_texture_pvrtc")||b.get("WEBGL_compressed_texture_s3tc")||b.get("WEBGL_compressed_texture_etc1")))for(var c=a.getParameter(a.COMPRESSED_TEXTURE_FORMATS),d=0;d<c.length;d++)I.push(c[d]);return I},useProgram:function(b){return B!==b?(a.useProgram(b),B=b,!0):!1},setBlending:g,setMaterial:function(b){2===b.side?f(a.CULL_FACE):e(a.CULL_FACE);h(1===b.side);!0===b.transparent?g(b.blending,b.blendEquation,b.blendSrc,
b.blendDst,b.blendEquationAlpha,b.blendSrcAlpha,b.blendDstAlpha,b.premultipliedAlpha):g(0);t.setFunc(b.depthFunc);t.setTest(b.depthTest);t.setMask(b.depthWrite);p.setMask(b.colorWrite);l(b.polygonOffset,b.polygonOffsetFactor,b.polygonOffsetUnits)},setFlipSided:h,setCullFace:k,setLineWidth:function(b){b!==M&&(Q&&a.lineWidth(b),M=b)},setPolygonOffset:l,setScissorTest:function(b){b?e(a.SCISSOR_TEST):f(a.SCISSOR_TEST)},activeTexture:q,bindTexture:function(b,c){null===K&&q();var d=R[K];void 0===d&&(d=
{type:void 0,texture:void 0},R[K]=d);if(d.type!==b||d.texture!==c)a.bindTexture(b,c||U[b]),d.type=b,d.texture=c},compressedTexImage2D:function(){try{a.compressedTexImage2D.apply(a,arguments)}catch(ca){console.error("THREE.WebGLState:",ca)}},texImage2D:function(){try{a.texImage2D.apply(a,arguments)}catch(ca){console.error("THREE.WebGLState:",ca)}},scissor:function(b){!1===P.equals(b)&&(a.scissor(b.x,b.y,b.z,b.w),P.copy(b))},viewport:function(b){!1===G.equals(b)&&(a.viewport(b.x,b.y,b.z,b.w),G.copy(b))},
reset:function(){for(var b=0;b<x.length;b++)1===x[b]&&(a.disableVertexAttribArray(b),x[b]=0);A={};K=I=null;R={};ga=F=H=B=null;p.reset();t.reset();r.reset()}}}function mg(a,b,c){function d(b){if("highp"===b){if(0<a.getShaderPrecisionFormat(a.VERTEX_SHADER,a.HIGH_FLOAT).precision&&0<a.getShaderPrecisionFormat(a.FRAGMENT_SHADER,a.HIGH_FLOAT).precision)return"highp";b="mediump"}return"mediump"===b&&0<a.getShaderPrecisionFormat(a.VERTEX_SHADER,a.MEDIUM_FLOAT).precision&&0<a.getShaderPrecisionFormat(a.FRAGMENT_SHADER,
a.MEDIUM_FLOAT).precision?"mediump":"lowp"}var e,f=void 0!==c.precision?c.precision:"highp",g=d(f);g!==f&&(console.warn("THREE.WebGLRenderer:",f,"not supported, using",g,"instead."),f=g);c=!0===c.logarithmicDepthBuffer&&!!b.get("EXT_frag_depth");var g=a.getParameter(a.MAX_TEXTURE_IMAGE_UNITS),h=a.getParameter(a.MAX_VERTEX_TEXTURE_IMAGE_UNITS),k=a.getParameter(a.MAX_TEXTURE_SIZE),l=a.getParameter(a.MAX_CUBE_MAP_TEXTURE_SIZE),q=a.getParameter(a.MAX_VERTEX_ATTRIBS),p=a.getParameter(a.MAX_VERTEX_UNIFORM_VECTORS),
t=a.getParameter(a.MAX_VARYING_VECTORS),r=a.getParameter(a.MAX_FRAGMENT_UNIFORM_VECTORS),m=0<h,n=!!b.get("OES_texture_float");return{getMaxAnisotropy:function(){if(void 0!==e)return e;var c=b.get("EXT_texture_filter_anisotropic");return e=null!==c?a.getParameter(c.MAX_TEXTURE_MAX_ANISOTROPY_EXT):0},getMaxPrecision:d,precision:f,logarithmicDepthBuffer:c,maxTextures:g,maxVertexTextures:h,maxTextureSize:k,maxCubemapSize:l,maxAttributes:q,maxVertexUniforms:p,maxVaryings:t,maxFragmentUniforms:r,vertexTextures:m,
floatFragmentTextures:n,floatVertexTextures:m&&n}}function md(a){ja.call(this);this.cameras=a||[]}function ng(a){function b(){if(null!==d&&d.isPresenting){var b=d.getEyeParameters("left"),e=b.renderWidth,b=b.renderHeight;t=a.getPixelRatio();p=a.getSize();a.setDrawingBufferSize(2*e,b,1)}else c.enabled&&a.setDrawingBufferSize(p.width,p.height,t)}var c=this,d=null,e=null;"VRFrameData"in window&&(e=new window.VRFrameData);var f=new O,g=new O,h=new O,k=new ja;k.bounds=new S(0,0,.5,1);k.layers.enable(1);
var l=new ja;l.bounds=new S(.5,0,.5,1);l.layers.enable(2);var q=new md([k,l]);q.layers.enable(1);q.layers.enable(2);var p,t;window.addEventListener("vrdisplaypresentchange",b,!1);this.standing=this.enabled=!1;this.getDevice=function(){return d};this.setDevice=function(a){void 0!==a&&(d=a)};this.getCamera=function(a){if(null===d)return a;d.depthNear=a.near;d.depthFar=a.far;d.getFrameData(e);var b=e.pose;null!==b.position?a.position.fromArray(b.position):a.position.set(0,0,0);null!==b.orientation&&
a.quaternion.fromArray(b.orientation);a.updateMatrixWorld();b=d.stageParameters;this.standing&&b&&(g.fromArray(b.sittingToStandingTransform),h.getInverse(g),a.matrixWorld.multiply(g),a.matrixWorldInverse.multiply(h));if(!1===d.isPresenting)return a;k.near=a.near;l.near=a.near;k.far=a.far;l.far=a.far;q.matrixWorld.copy(a.matrixWorld);q.matrixWorldInverse.copy(a.matrixWorldInverse);k.matrixWorldInverse.fromArray(e.leftViewMatrix);l.matrixWorldInverse.fromArray(e.rightViewMatrix);this.standing&&b&&(k.matrixWorldInverse.multiply(h),
l.matrixWorldInverse.multiply(h));a=a.parent;null!==a&&(f.getInverse(a.matrixWorld),k.matrixWorldInverse.multiply(f),l.matrixWorldInverse.multiply(f));k.matrixWorld.getInverse(k.matrixWorldInverse);l.matrixWorld.getInverse(l.matrixWorldInverse);k.projectionMatrix.fromArray(e.leftProjectionMatrix);l.projectionMatrix.fromArray(e.rightProjectionMatrix);q.projectionMatrix.copy(k.projectionMatrix);a=d.getLayers();a.length&&(a=a[0],null!==a.leftBounds&&4===a.leftBounds.length&&k.bounds.fromArray(a.leftBounds),
null!==a.rightBounds&&4===a.rightBounds.length&&l.bounds.fromArray(a.rightBounds));return q};this.getStandingMatrix=function(){return g};this.submitFrame=function(){d&&d.isPresenting&&d.submitFrame()};this.dispose=function(){window.removeEventListener("vrdisplaypresentchange",b)}}function og(a){var b={};return{get:function(c){if(void 0!==b[c])return b[c];switch(c){case "WEBGL_depth_texture":var d=a.getExtension("WEBGL_depth_texture")||a.getExtension("MOZ_WEBGL_depth_texture")||a.getExtension("WEBKIT_WEBGL_depth_texture");
break;case "EXT_texture_filter_anisotropic":d=a.getExtension("EXT_texture_filter_anisotropic")||a.getExtension("MOZ_EXT_texture_filter_anisotropic")||a.getExtension("WEBKIT_EXT_texture_filter_anisotropic");break;case "WEBGL_compressed_texture_s3tc":d=a.getExtension("WEBGL_compressed_texture_s3tc")||a.getExtension("MOZ_WEBGL_compressed_texture_s3tc")||a.getExtension("WEBKIT_WEBGL_compressed_texture_s3tc");break;case "WEBGL_compressed_texture_pvrtc":d=a.getExtension("WEBGL_compressed_texture_pvrtc")||
a.getExtension("WEBKIT_WEBGL_compressed_texture_pvrtc");break;case "WEBGL_compressed_texture_etc1":d=a.getExtension("WEBGL_compressed_texture_etc1");break;default:d=a.getExtension(c)}null===d&&console.warn("THREE.WebGLRenderer: "+c+" extension not supported.");return b[c]=d}}}function pg(){function a(){l.value!==d&&(l.value=d,l.needsUpdate=0<e);c.numPlanes=e;c.numIntersection=0}function b(a,b,d,e){var f=null!==a?a.length:0,g=null;if(0!==f){g=l.value;if(!0!==e||null===g){e=d+4*f;b=b.matrixWorldInverse;
k.getNormalMatrix(b);if(null===g||g.length<e)g=new Float32Array(e);for(e=0;e!==f;++e,d+=4)h.copy(a[e]).applyMatrix4(b,k),h.normal.toArray(g,d),g[d+3]=h.constant}l.value=g;l.needsUpdate=!0}c.numPlanes=f;return g}var c=this,d=null,e=0,f=!1,g=!1,h=new za,k=new qa,l={value:null,needsUpdate:!1};this.uniform=l;this.numIntersection=this.numPlanes=0;this.init=function(a,c,g){var h=0!==a.length||c||0!==e||f;f=c;d=b(a,g,0);e=a.length;return h};this.beginShadows=function(){g=!0;b(null)};this.endShadows=function(){g=
!1;a()};this.setState=function(c,h,k,r,m,n){if(!f||null===c||0===c.length||g&&!k)g?b(null):a();else{k=g?0:e;var p=4*k,q=m.clippingState||null;l.value=q;q=b(c,r,p,n);for(c=0;c!==p;++c)q[c]=d[c];m.clippingState=q;this.numIntersection=h?this.numPlanes:0;this.numPlanes+=k}}}function Qe(a,b){return{convert:function(c){if(1E3===c)return a.REPEAT;if(1001===c)return a.CLAMP_TO_EDGE;if(1002===c)return a.MIRRORED_REPEAT;if(1003===c)return a.NEAREST;if(1004===c)return a.NEAREST_MIPMAP_NEAREST;if(1005===c)return a.NEAREST_MIPMAP_LINEAR;
if(1006===c)return a.LINEAR;if(1007===c)return a.LINEAR_MIPMAP_NEAREST;if(1008===c)return a.LINEAR_MIPMAP_LINEAR;if(1009===c)return a.UNSIGNED_BYTE;if(1017===c)return a.UNSIGNED_SHORT_4_4_4_4;if(1018===c)return a.UNSIGNED_SHORT_5_5_5_1;if(1019===c)return a.UNSIGNED_SHORT_5_6_5;if(1010===c)return a.BYTE;if(1011===c)return a.SHORT;if(1012===c)return a.UNSIGNED_SHORT;if(1013===c)return a.INT;if(1014===c)return a.UNSIGNED_INT;if(1015===c)return a.FLOAT;if(1016===c){var d=b.get("OES_texture_half_float");
if(null!==d)return d.HALF_FLOAT_OES}if(1021===c)return a.ALPHA;if(1022===c)return a.RGB;if(1023===c)return a.RGBA;if(1024===c)return a.LUMINANCE;if(1025===c)return a.LUMINANCE_ALPHA;if(1026===c)return a.DEPTH_COMPONENT;if(1027===c)return a.DEPTH_STENCIL;if(100===c)return a.FUNC_ADD;if(101===c)return a.FUNC_SUBTRACT;if(102===c)return a.FUNC_REVERSE_SUBTRACT;if(200===c)return a.ZERO;if(201===c)return a.ONE;if(202===c)return a.SRC_COLOR;if(203===c)return a.ONE_MINUS_SRC_COLOR;if(204===c)return a.SRC_ALPHA;
if(205===c)return a.ONE_MINUS_SRC_ALPHA;if(206===c)return a.DST_ALPHA;if(207===c)return a.ONE_MINUS_DST_ALPHA;if(208===c)return a.DST_COLOR;if(209===c)return a.ONE_MINUS_DST_COLOR;if(210===c)return a.SRC_ALPHA_SATURATE;if(2001===c||2002===c||2003===c||2004===c)if(d=b.get("WEBGL_compressed_texture_s3tc"),null!==d){if(2001===c)return d.COMPRESSED_RGB_S3TC_DXT1_EXT;if(2002===c)return d.COMPRESSED_RGBA_S3TC_DXT1_EXT;if(2003===c)return d.COMPRESSED_RGBA_S3TC_DXT3_EXT;if(2004===c)return d.COMPRESSED_RGBA_S3TC_DXT5_EXT}if(2100===
c||2101===c||2102===c||2103===c)if(d=b.get("WEBGL_compressed_texture_pvrtc"),null!==d){if(2100===c)return d.COMPRESSED_RGB_PVRTC_4BPPV1_IMG;if(2101===c)return d.COMPRESSED_RGB_PVRTC_2BPPV1_IMG;if(2102===c)return d.COMPRESSED_RGBA_PVRTC_4BPPV1_IMG;if(2103===c)return d.COMPRESSED_RGBA_PVRTC_2BPPV1_IMG}if(2151===c&&(d=b.get("WEBGL_compressed_texture_etc1"),null!==d))return d.COMPRESSED_RGB_ETC1_WEBGL;if(103===c||104===c)if(d=b.get("EXT_blend_minmax"),null!==d){if(103===c)return d.MIN_EXT;if(104===c)return d.MAX_EXT}return 1020===
c&&(d=b.get("WEBGL_depth_texture"),null!==d)?d.UNSIGNED_INT_24_8_WEBGL:0}}}function Yd(a){function b(){ka=new og(E);ka.get("WEBGL_depth_texture");ka.get("OES_texture_float");ka.get("OES_texture_float_linear");ka.get("OES_texture_half_float");ka.get("OES_texture_half_float_linear");ka.get("OES_standard_derivatives");ka.get("ANGLE_instanced_arrays");ka.get("OES_element_index_uint")&&(F.MaxIndex=4294967296);qa=new Qe(E,ka);ea=new mg(E,ka,a);Z=new lg(E,ka,qa);Z.scissor(W.copy(ia).multiplyScalar(N));Z.viewport(V.copy(aa).multiplyScalar(N));
da=new kg;fa=new jg(E,ka,Z,da,ea,qa,Xd);pa=new Nf(E);ra=new Yf(E,pa,Xd);ua=new ag(ra,Sa);wa=new Vf(E);na=new ig(J,ka,ea);ta=new $f;sa=new Tf;oa=new Pf(J,Z,ra,H);ya=new Xf(E,ka,Sa);za=new Wf(E,ka,Sa);Ba=new Kf(J,E,Z,fa,ea);Ca=new Lf(J,E,Z,fa,ea);J.info.programs=na.programs;J.context=E;J.capabilities=ea;J.extensions=ka;J.properties=da;J.renderLists=sa;J.state=Z}function c(a){a.preventDefault();console.log("THREE.WebGLRenderer: Context Lost.");Q=!0}function d(a){console.log("THREE.WebGLRenderer: Context Restored.");
Q=!1;b()}function e(a){a=a.target;a.removeEventListener("dispose",e);f(a);da.remove(a)}function f(a){var b=da.get(a).program;a.program=void 0;void 0!==b&&na.releaseProgram(b)}function g(a,b,c){a.render(function(a){J.renderBufferImmediate(a,b,c)})}function h(a){null!==Aa&&Aa(a);(ma.getDevice()||window).requestAnimationFrame(h)}function k(a,b,c){if(a.visible){if(a.layers.test(b.layers))if(a.isLight)w.push(a),a.castShadow&&z.push(a);else if(a.isSprite)a.frustumCulled&&!Vd.intersectsSprite(a)||D.push(a);
else if(a.isLensFlare)C.push(a);else if(a.isImmediateRenderObject)c&&Gb.setFromMatrixPosition(a.matrixWorld).applyMatrix4(ld),ba.push(a,null,a.material,Gb.z,null);else if(a.isMesh||a.isLine||a.isPoints)if(a.isSkinnedMesh&&a.skeleton.update(),!a.frustumCulled||Vd.intersectsObject(a)){c&&Gb.setFromMatrixPosition(a.matrixWorld).applyMatrix4(ld);var d=ua.update(a),e=a.material;if(Array.isArray(e))for(var f=d.groups,g=0,h=f.length;g<h;g++){var l=f[g],p=e[l.materialIndex];p&&p.visible&&ba.push(a,d,p,Gb.z,
l)}else e.visible&&ba.push(a,d,e,Gb.z,null)}a=a.children;g=0;for(h=a.length;g<h;g++)k(a[g],b,c)}}function l(a,b,c,d){for(var e=0,f=a.length;e<f;e++){var g=a[e],h=g.object,l=g.geometry,k=void 0===d?g.material:d,g=g.group;if(c.isArrayCamera){Y=c;for(var p=c.cameras,t=0,r=p.length;t<r;t++){var m=p[t];if(h.layers.test(m.layers)){var v=m.bounds;Z.viewport(V.set(v.x*U,v.y*ca,v.z*U,v.w*ca).multiplyScalar(N));q(h,b,m,l,k,g)}}}else Y=null,q(h,b,c,l,k,g)}}function q(a,b,c,d,e,f){a.onBeforeRender(J,b,c,d,e,
f);a.modelViewMatrix.multiplyMatrices(c.matrixWorldInverse,a.matrixWorld);a.normalMatrix.getNormalMatrix(a.modelViewMatrix);if(a.isImmediateRenderObject){Z.setMaterial(e);var h=t(c,b.fog,e,a);K="";g(a,h,e)}else J.renderBufferDirect(c,b.fog,d,e,a,f);a.onAfterRender(J,b,c,d,e,f)}function p(a,b,c){var d=da.get(a);c=na.getParameters(a,ta.state,z,b,Ha.numPlanes,Ha.numIntersection,c);var g=na.getProgramCode(a,c),h=d.program,l=!0;if(void 0===h)a.addEventListener("dispose",e);else if(h.code!==g)f(a);else{if(void 0!==
c.shaderID)return;l=!1}l&&(c.shaderID?(h=ib[c.shaderID],d.shader={name:a.type,uniforms:Da.clone(h.uniforms),vertexShader:h.vertexShader,fragmentShader:h.fragmentShader}):d.shader={name:a.type,uniforms:a.uniforms,vertexShader:a.vertexShader,fragmentShader:a.fragmentShader},a.onBeforeCompile(d.shader),h=na.acquireProgram(a,d.shader,c,g),d.program=h,a.program=h);c=h.getAttributes();if(a.morphTargets)for(g=a.numSupportedMorphTargets=0;g<J.maxMorphTargets;g++)0<=c["morphTarget"+g]&&a.numSupportedMorphTargets++;
if(a.morphNormals)for(g=a.numSupportedMorphNormals=0;g<J.maxMorphNormals;g++)0<=c["morphNormal"+g]&&a.numSupportedMorphNormals++;c=d.shader.uniforms;if(!a.isShaderMaterial&&!a.isRawShaderMaterial||!0===a.clipping)d.numClippingPlanes=Ha.numPlanes,d.numIntersection=Ha.numIntersection,c.clippingPlanes=Ha.uniform;d.fog=b;d.lightsHash=ta.state.hash;a.lights&&(c.ambientLightColor.value=ta.state.ambient,c.directionalLights.value=ta.state.directional,c.spotLights.value=ta.state.spot,c.rectAreaLights.value=
ta.state.rectArea,c.pointLights.value=ta.state.point,c.hemisphereLights.value=ta.state.hemi,c.directionalShadowMap.value=ta.state.directionalShadowMap,c.directionalShadowMatrix.value=ta.state.directionalShadowMatrix,c.spotShadowMap.value=ta.state.spotShadowMap,c.spotShadowMatrix.value=ta.state.spotShadowMatrix,c.pointShadowMap.value=ta.state.pointShadowMap,c.pointShadowMatrix.value=ta.state.pointShadowMatrix);a=d.program.getUniforms();a=cb.seqWithValue(a.seq,c);d.uniformsList=a}function t(a,b,c,d){G=
0;var e=da.get(c);ja&&(Wd||a!==P)&&Ha.setState(c.clippingPlanes,c.clipIntersection,c.clipShadows,a,e,a===P&&c.id===T);!1===c.needsUpdate&&(void 0===e.program?c.needsUpdate=!0:c.fog&&e.fog!==b?c.needsUpdate=!0:c.lights&&e.lightsHash!==ta.state.hash?c.needsUpdate=!0:void 0===e.numClippingPlanes||e.numClippingPlanes===Ha.numPlanes&&e.numIntersection===Ha.numIntersection||(c.needsUpdate=!0));c.needsUpdate&&(p(c,b,d),c.needsUpdate=!1);var f=!1,g=!1,h=!1,l=e.program,k=l.getUniforms(),q=e.shader.uniforms;
Z.useProgram(l.program)&&(h=g=f=!0);c.id!==T&&(T=c.id,g=!0);if(f||a!==P){k.setValue(E,"projectionMatrix",a.projectionMatrix);ea.logarithmicDepthBuffer&&k.setValue(E,"logDepthBufFC",2/(Math.log(a.far+1)/Math.LN2));P!==(Y||a)&&(P=Y||a,h=g=!0);if(c.isShaderMaterial||c.isMeshPhongMaterial||c.isMeshStandardMaterial||c.envMap)f=k.map.cameraPosition,void 0!==f&&f.setValue(E,Gb.setFromMatrixPosition(a.matrixWorld));(c.isMeshPhongMaterial||c.isMeshLambertMaterial||c.isMeshBasicMaterial||c.isMeshStandardMaterial||
c.isShaderMaterial||c.skinning)&&k.setValue(E,"viewMatrix",a.matrixWorldInverse)}if(c.skinning&&(k.setOptional(E,d,"bindMatrix"),k.setOptional(E,d,"bindMatrixInverse"),a=d.skeleton))if(f=a.bones,ea.floatVertexTextures){if(void 0===a.boneTexture){var f=Math.sqrt(4*f.length),f=R.nextPowerOfTwo(Math.ceil(f)),f=Math.max(f,4),t=new Float32Array(f*f*4);t.set(a.boneMatrices);var v=new bb(t,f,f,1023,1015);a.boneMatrices=t;a.boneTexture=v;a.boneTextureSize=f}k.setValue(E,"boneTexture",a.boneTexture);k.setValue(E,
"boneTextureSize",a.boneTextureSize)}else k.setOptional(E,a,"boneMatrices");g&&(k.setValue(E,"toneMappingExposure",J.toneMappingExposure),k.setValue(E,"toneMappingWhitePoint",J.toneMappingWhitePoint),c.lights&&(g=h,q.ambientLightColor.needsUpdate=g,q.directionalLights.needsUpdate=g,q.pointLights.needsUpdate=g,q.spotLights.needsUpdate=g,q.rectAreaLights.needsUpdate=g,q.hemisphereLights.needsUpdate=g),b&&c.fog&&(q.fogColor.value=b.color,b.isFog?(q.fogNear.value=b.near,q.fogFar.value=b.far):b.isFogExp2&&
(q.fogDensity.value=b.density)),c.isMeshBasicMaterial?r(q,c):c.isMeshLambertMaterial?(r(q,c),c.emissiveMap&&(q.emissiveMap.value=c.emissiveMap)):c.isMeshPhongMaterial?(r(q,c),c.isMeshToonMaterial?(m(q,c),c.gradientMap&&(q.gradientMap.value=c.gradientMap)):m(q,c)):c.isMeshStandardMaterial?(r(q,c),c.isMeshPhysicalMaterial&&(q.clearCoat.value=c.clearCoat,q.clearCoatRoughness.value=c.clearCoatRoughness),q.roughness.value=c.roughness,q.metalness.value=c.metalness,c.roughnessMap&&(q.roughnessMap.value=
c.roughnessMap),c.metalnessMap&&(q.metalnessMap.value=c.metalnessMap),c.emissiveMap&&(q.emissiveMap.value=c.emissiveMap),c.bumpMap&&(q.bumpMap.value=c.bumpMap,q.bumpScale.value=c.bumpScale),c.normalMap&&(q.normalMap.value=c.normalMap,q.normalScale.value.copy(c.normalScale)),c.displacementMap&&(q.displacementMap.value=c.displacementMap,q.displacementScale.value=c.displacementScale,q.displacementBias.value=c.displacementBias),c.envMap&&(q.envMapIntensity.value=c.envMapIntensity)):c.isMeshDepthMaterial?
(r(q,c),c.displacementMap&&(q.displacementMap.value=c.displacementMap,q.displacementScale.value=c.displacementScale,q.displacementBias.value=c.displacementBias)):c.isMeshDistanceMaterial?(r(q,c),c.displacementMap&&(q.displacementMap.value=c.displacementMap,q.displacementScale.value=c.displacementScale,q.displacementBias.value=c.displacementBias),q.referencePosition.value.copy(c.referencePosition),q.nearDistance.value=c.nearDistance,q.farDistance.value=c.farDistance):c.isMeshNormalMaterial?(r(q,c),
c.bumpMap&&(q.bumpMap.value=c.bumpMap,q.bumpScale.value=c.bumpScale),c.normalMap&&(q.normalMap.value=c.normalMap,q.normalScale.value.copy(c.normalScale)),c.displacementMap&&(q.displacementMap.value=c.displacementMap,q.displacementScale.value=c.displacementScale,q.displacementBias.value=c.displacementBias)):c.isLineBasicMaterial?(q.diffuse.value=c.color,q.opacity.value=c.opacity,c.isLineDashedMaterial&&(q.dashSize.value=c.dashSize,q.totalSize.value=c.dashSize+c.gapSize,q.scale.value=c.scale)):c.isPointsMaterial?
(q.diffuse.value=c.color,q.opacity.value=c.opacity,q.size.value=c.size*N,q.scale.value=.5*ca,q.map.value=c.map,null!==c.map&&(b=c.map.offset,c=c.map.repeat,q.offsetRepeat.value.set(b.x,b.y,c.x,c.y))):c.isShadowMaterial&&(q.color.value=c.color,q.opacity.value=c.opacity),void 0!==q.ltcMat&&(q.ltcMat.value=L.LTC_MAT_TEXTURE),void 0!==q.ltcMag&&(q.ltcMag.value=L.LTC_MAG_TEXTURE),cb.upload(E,e.uniformsList,q,J));k.setValue(E,"modelViewMatrix",d.modelViewMatrix);k.setValue(E,"normalMatrix",d.normalMatrix);
k.setValue(E,"modelMatrix",d.matrixWorld);return l}function r(a,b){a.opacity.value=b.opacity;b.color&&(a.diffuse.value=b.color);b.emissive&&a.emissive.value.copy(b.emissive).multiplyScalar(b.emissiveIntensity);b.map&&(a.map.value=b.map);b.alphaMap&&(a.alphaMap.value=b.alphaMap);b.specularMap&&(a.specularMap.value=b.specularMap);b.envMap&&(a.envMap.value=b.envMap,a.flipEnvMap.value=b.envMap&&b.envMap.isCubeTexture?-1:1,a.reflectivity.value=b.reflectivity,a.refractionRatio.value=b.refractionRatio);
b.lightMap&&(a.lightMap.value=b.lightMap,a.lightMapIntensity.value=b.lightMapIntensity);b.aoMap&&(a.aoMap.value=b.aoMap,a.aoMapIntensity.value=b.aoMapIntensity);if(b.map)var c=b.map;else b.specularMap?c=b.specularMap:b.displacementMap?c=b.displacementMap:b.normalMap?c=b.normalMap:b.bumpMap?c=b.bumpMap:b.roughnessMap?c=b.roughnessMap:b.metalnessMap?c=b.metalnessMap:b.alphaMap?c=b.alphaMap:b.emissiveMap&&(c=b.emissiveMap);void 0!==c&&(c.isWebGLRenderTarget&&(c=c.texture),b=c.offset,c=c.repeat,a.offsetRepeat.value.set(b.x,
b.y,c.x,c.y))}function m(a,b){a.specular.value=b.specular;a.shininess.value=Math.max(b.shininess,1E-4);b.emissiveMap&&(a.emissiveMap.value=b.emissiveMap);b.bumpMap&&(a.bumpMap.value=b.bumpMap,a.bumpScale.value=b.bumpScale);b.normalMap&&(a.normalMap.value=b.normalMap,a.normalScale.value.copy(b.normalScale));b.displacementMap&&(a.displacementMap.value=b.displacementMap,a.displacementScale.value=b.displacementScale,a.displacementBias.value=b.displacementBias)}console.log("THREE.WebGLRenderer","87");
a=a||{};var u=void 0!==a.canvas?a.canvas:document.createElementNS("http://www.w3.org/1999/xhtml","canvas"),x=void 0!==a.context?a.context:null,y=void 0!==a.alpha?a.alpha:!1,A=void 0!==a.depth?a.depth:!0,I=void 0!==a.stencil?a.stencil:!0,B=void 0!==a.antialias?a.antialias:!1,H=void 0!==a.premultipliedAlpha?a.premultipliedAlpha:!0,va=void 0!==a.preserveDrawingBuffer?a.preserveDrawingBuffer:!1,w=[],z=[],ba=null,D=[],C=[];this.domElement=u;this.context=null;this.sortObjects=this.autoClearStencil=this.autoClearDepth=
this.autoClearColor=this.autoClear=!0;this.clippingPlanes=[];this.localClippingEnabled=!1;this.gammaFactor=2;this.physicallyCorrectLights=this.gammaOutput=this.gammaInput=!1;this.toneMappingWhitePoint=this.toneMappingExposure=this.toneMapping=1;this.maxMorphTargets=8;this.maxMorphNormals=4;var J=this,Q=!1,ga=null,M=null,T=-1,K="",P=null,Y=null,V=new S,W=new S,X=null,G=0,U=u.width,ca=u.height,N=1,aa=new S(0,0,U,ca),ia=new S(0,0,U,ca),ha=!1,Vd=new kd,Ha=new pg,ja=!1,Wd=!1,ld=new O,Gb=new n,Xd={geometries:0,
textures:0},Sa={frame:0,calls:0,vertices:0,faces:0,points:0};this.info={render:Sa,memory:Xd,programs:null};try{y={alpha:y,depth:A,stencil:I,antialias:B,premultipliedAlpha:H,preserveDrawingBuffer:va};var E=x||u.getContext("webgl",y)||u.getContext("experimental-webgl",y);if(null===E){if(null!==u.getContext("webgl"))throw"Error creating WebGL context with your selected attributes.";throw"Error creating WebGL context.";}void 0===E.getShaderPrecisionFormat&&(E.getShaderPrecisionFormat=function(){return{rangeMin:1,
rangeMax:1,precision:1}});u.addEventListener("webglcontextlost",c,!1);u.addEventListener("webglcontextrestored",d,!1)}catch(qg){console.error("THREE.WebGLRenderer: "+qg)}var ka,ea,Z,da,fa,pa,ra,ua,ta,na,sa,oa,wa,ya,za,Ba,Ca,qa;b();var ma=new ng(J);this.vr=ma;var Ea=new Ke(J,ua,ea.maxTextureSize);this.shadowMap=Ea;this.getContext=function(){return E};this.getContextAttributes=function(){return E.getContextAttributes()};this.forceContextLoss=function(){var a=ka.get("WEBGL_lose_context");a&&a.loseContext()};
this.forceContextRestore=function(){var a=ka.get("WEBGL_lose_context");a&&a.restoreContext()};this.getPixelRatio=function(){return N};this.setPixelRatio=function(a){void 0!==a&&(N=a,this.setSize(U,ca,!1))};this.getSize=function(){return{width:U,height:ca}};this.setSize=function(a,b,c){var d=ma.getDevice();d&&d.isPresenting?console.warn("THREE.WebGLRenderer: Can't change size while VR device is presenting."):(U=a,ca=b,u.width=a*N,u.height=b*N,!1!==c&&(u.style.width=a+"px",u.style.height=b+"px"),this.setViewport(0,
0,a,b))};this.getDrawingBufferSize=function(){return{width:U*N,height:ca*N}};this.setDrawingBufferSize=function(a,b,c){U=a;ca=b;N=c;u.width=a*c;u.height=b*c;this.setViewport(0,0,a,b)};this.setViewport=function(a,b,c,d){aa.set(a,ca-b-d,c,d);Z.viewport(V.copy(aa).multiplyScalar(N))};this.setScissor=function(a,b,c,d){ia.set(a,ca-b-d,c,d);Z.scissor(W.copy(ia).multiplyScalar(N))};this.setScissorTest=function(a){Z.setScissorTest(ha=a)};this.getClearColor=oa.getClearColor;this.setClearColor=oa.setClearColor;
this.getClearAlpha=oa.getClearAlpha;this.setClearAlpha=oa.setClearAlpha;this.clear=function(a,b,c){var d=0;if(void 0===a||a)d|=E.COLOR_BUFFER_BIT;if(void 0===b||b)d|=E.DEPTH_BUFFER_BIT;if(void 0===c||c)d|=E.STENCIL_BUFFER_BIT;E.clear(d)};this.clearColor=function(){this.clear(!0,!1,!1)};this.clearDepth=function(){this.clear(!1,!0,!1)};this.clearStencil=function(){this.clear(!1,!1,!0)};this.clearTarget=function(a,b,c,d){this.setRenderTarget(a);this.clear(b,c,d)};this.dispose=function(){u.removeEventListener("webglcontextlost",
c,!1);u.removeEventListener("webglcontextrestored",d,!1);sa.dispose();ma.dispose()};this.renderBufferImmediate=function(a,b,c){Z.initAttributes();var d=da.get(a);a.hasPositions&&!d.position&&(d.position=E.createBuffer());a.hasNormals&&!d.normal&&(d.normal=E.createBuffer());a.hasUvs&&!d.uv&&(d.uv=E.createBuffer());a.hasColors&&!d.color&&(d.color=E.createBuffer());b=b.getAttributes();a.hasPositions&&(E.bindBuffer(E.ARRAY_BUFFER,d.position),E.bufferData(E.ARRAY_BUFFER,a.positionArray,E.DYNAMIC_DRAW),
Z.enableAttribute(b.position),E.vertexAttribPointer(b.position,3,E.FLOAT,!1,0,0));if(a.hasNormals){E.bindBuffer(E.ARRAY_BUFFER,d.normal);if(!c.isMeshPhongMaterial&&!c.isMeshStandardMaterial&&!c.isMeshNormalMaterial&&!0===c.flatShading)for(var e=0,f=3*a.count;e<f;e+=9){var g=a.normalArray,h=(g[e+0]+g[e+3]+g[e+6])/3,l=(g[e+1]+g[e+4]+g[e+7])/3,k=(g[e+2]+g[e+5]+g[e+8])/3;g[e+0]=h;g[e+1]=l;g[e+2]=k;g[e+3]=h;g[e+4]=l;g[e+5]=k;g[e+6]=h;g[e+7]=l;g[e+8]=k}E.bufferData(E.ARRAY_BUFFER,a.normalArray,E.DYNAMIC_DRAW);
Z.enableAttribute(b.normal);E.vertexAttribPointer(b.normal,3,E.FLOAT,!1,0,0)}a.hasUvs&&c.map&&(E.bindBuffer(E.ARRAY_BUFFER,d.uv),E.bufferData(E.ARRAY_BUFFER,a.uvArray,E.DYNAMIC_DRAW),Z.enableAttribute(b.uv),E.vertexAttribPointer(b.uv,2,E.FLOAT,!1,0,0));a.hasColors&&0!==c.vertexColors&&(E.bindBuffer(E.ARRAY_BUFFER,d.color),E.bufferData(E.ARRAY_BUFFER,a.colorArray,E.DYNAMIC_DRAW),Z.enableAttribute(b.color),E.vertexAttribPointer(b.color,3,E.FLOAT,!1,0,0));Z.disableUnusedAttributes();E.drawArrays(E.TRIANGLES,
0,a.count);a.count=0};this.renderBufferDirect=function(a,b,c,d,e,f){Z.setMaterial(d);var g=t(a,b,d,e);a=c.id+"_"+g.id+"_"+(!0===d.wireframe);var h=!1;a!==K&&(K=a,h=!0);e.morphTargetInfluences&&(wa.update(e,c,d,g),h=!0);var l=c.index,k=c.attributes.position;b=1;!0===d.wireframe&&(l=ra.getWireframeAttribute(c),b=2);a=ya;if(null!==l){var q=pa.get(l);a=za;a.setIndex(q)}if(h){h=void 0;if(c&&c.isInstancedBufferGeometry&&null===ka.get("ANGLE_instanced_arrays"))console.error("THREE.WebGLRenderer.setupVertexAttributes: using THREE.InstancedBufferGeometry but hardware does not support extension ANGLE_instanced_arrays.");
else{void 0===h&&(h=0);Z.initAttributes();var p=c.attributes,g=g.getAttributes(),r=d.defaultAttributeValues;for(H in g){var m=g[H];if(0<=m){var v=p[H];if(void 0!==v){var n=v.normalized,x=v.itemSize,u=pa.get(v);if(void 0!==u){var A=u.buffer,B=u.type,u=u.bytesPerElement;if(v.isInterleavedBufferAttribute){var y=v.data,I=y.stride,v=v.offset;y&&y.isInstancedInterleavedBuffer?(Z.enableAttributeAndDivisor(m,y.meshPerAttribute),void 0===c.maxInstancedCount&&(c.maxInstancedCount=y.meshPerAttribute*y.count)):
Z.enableAttribute(m);E.bindBuffer(E.ARRAY_BUFFER,A);E.vertexAttribPointer(m,x,B,n,I*u,(h*I+v)*u)}else v.isInstancedBufferAttribute?(Z.enableAttributeAndDivisor(m,v.meshPerAttribute),void 0===c.maxInstancedCount&&(c.maxInstancedCount=v.meshPerAttribute*v.count)):Z.enableAttribute(m),E.bindBuffer(E.ARRAY_BUFFER,A),E.vertexAttribPointer(m,x,B,n,0,h*x*u)}}else if(void 0!==r&&(n=r[H],void 0!==n))switch(n.length){case 2:E.vertexAttrib2fv(m,n);break;case 3:E.vertexAttrib3fv(m,n);break;case 4:E.vertexAttrib4fv(m,
n);break;default:E.vertexAttrib1fv(m,n)}}}Z.disableUnusedAttributes()}null!==l&&E.bindBuffer(E.ELEMENT_ARRAY_BUFFER,q.buffer)}q=0;null!==l?q=l.count:void 0!==k&&(q=k.count);l=c.drawRange.start*b;k=null!==f?f.start*b:0;var H=Math.max(l,k);f=Math.max(0,Math.min(q,l+c.drawRange.count*b,k+(null!==f?f.count*b:Infinity))-1-H+1);if(0!==f){if(e.isMesh)if(!0===d.wireframe)Z.setLineWidth(d.wireframeLinewidth*(null===ga?N:1)),a.setMode(E.LINES);else switch(e.drawMode){case 0:a.setMode(E.TRIANGLES);break;case 1:a.setMode(E.TRIANGLE_STRIP);
break;case 2:a.setMode(E.TRIANGLE_FAN)}else e.isLine?(d=d.linewidth,void 0===d&&(d=1),Z.setLineWidth(d*(null===ga?N:1)),e.isLineSegments?a.setMode(E.LINES):e.isLineLoop?a.setMode(E.LINE_LOOP):a.setMode(E.LINE_STRIP)):e.isPoints&&a.setMode(E.POINTS);c&&c.isInstancedBufferGeometry?0<c.maxInstancedCount&&a.renderInstances(c,H,f):a.render(H,f)}};this.compile=function(a,b){w.length=0;z.length=0;a.traverse(function(a){a.isLight&&(w.push(a),a.castShadow&&z.push(a))});ta.setup(w,z,b);a.traverse(function(b){if(b.material)if(Array.isArray(b.material))for(var c=
0;c<b.material.length;c++)p(b.material[c],a.fog,b);else p(b.material,a.fog,b)})};var Fa=!1,Aa=null;this.animate=function(a){Aa=a;Fa||((ma.getDevice()||window).requestAnimationFrame(h),Fa=!0)};this.render=function(a,b,c,d){if(!b||!b.isCamera)console.error("THREE.WebGLRenderer.render: camera is not an instance of THREE.Camera.");else if(!Q){K="";T=-1;P=null;!0===a.autoUpdate&&a.updateMatrixWorld();null===b.parent&&b.updateMatrixWorld();ma.enabled&&(b=ma.getCamera(b));ld.multiplyMatrices(b.projectionMatrix,
b.matrixWorldInverse);Vd.setFromMatrix(ld);w.length=0;z.length=0;D.length=0;C.length=0;Wd=this.localClippingEnabled;ja=Ha.init(this.clippingPlanes,Wd,b);ba=sa.get(a,b);ba.init();k(a,b,J.sortObjects);!0===J.sortObjects&&ba.sort();ja&&Ha.beginShadows();Ea.render(z,a,b);ta.setup(w,z,b);ja&&Ha.endShadows();Sa.frame++;Sa.calls=0;Sa.vertices=0;Sa.faces=0;Sa.points=0;void 0===c&&(c=null);this.setRenderTarget(c);oa.render(ba,a,b,d);d=ba.opaque;var e=ba.transparent;if(a.overrideMaterial){var f=a.overrideMaterial;
d.length&&l(d,a,b,f);e.length&&l(e,a,b,f)}else d.length&&l(d,a,b),e.length&&l(e,a,b);Ca.render(D,a,b);Ba.render(C,a,b,V);c&&fa.updateRenderTargetMipmap(c);Z.buffers.depth.setTest(!0);Z.buffers.depth.setMask(!0);Z.buffers.color.setMask(!0);Z.setPolygonOffset(!1);ma.enabled&&ma.submitFrame()}};this.setFaceCulling=function(a,b){Z.setCullFace(a);Z.setFlipSided(0===b)};this.allocTextureUnit=function(){var a=G;a>=ea.maxTextures&&console.warn("THREE.WebGLRenderer: Trying to use "+a+" texture units while this GPU supports only "+
ea.maxTextures);G+=1;return a};this.setTexture2D=function(){var a=!1;return function(b,c){b&&b.isWebGLRenderTarget&&(a||(console.warn("THREE.WebGLRenderer.setTexture2D: don't use render targets as textures. Use their .texture property instead."),a=!0),b=b.texture);fa.setTexture2D(b,c)}}();this.setTexture=function(){var a=!1;return function(b,c){a||(console.warn("THREE.WebGLRenderer: .setTexture is deprecated, use setTexture2D instead."),a=!0);fa.setTexture2D(b,c)}}();this.setTextureCube=function(){var a=
!1;return function(b,c){b&&b.isWebGLRenderTargetCube&&(a||(console.warn("THREE.WebGLRenderer.setTextureCube: don't use cube render targets as textures. Use their .texture property instead."),a=!0),b=b.texture);b&&b.isCubeTexture||Array.isArray(b.image)&&6===b.image.length?fa.setTextureCube(b,c):fa.setTextureCubeDynamic(b,c)}}();this.getRenderTarget=function(){return ga};this.setRenderTarget=function(a){(ga=a)&&void 0===da.get(a).__webglFramebuffer&&fa.setupRenderTarget(a);var b=null,c=!1;a?(b=da.get(a).__webglFramebuffer,
a.isWebGLRenderTargetCube&&(b=b[a.activeCubeFace],c=!0),V.copy(a.viewport),W.copy(a.scissor),X=a.scissorTest):(V.copy(aa).multiplyScalar(N),W.copy(ia).multiplyScalar(N),X=ha);M!==b&&(E.bindFramebuffer(E.FRAMEBUFFER,b),M=b);Z.viewport(V);Z.scissor(W);Z.setScissorTest(X);c&&(c=da.get(a.texture),E.framebufferTexture2D(E.FRAMEBUFFER,E.COLOR_ATTACHMENT0,E.TEXTURE_CUBE_MAP_POSITIVE_X+a.activeCubeFace,c.__webglTexture,a.activeMipMapLevel))};this.readRenderTargetPixels=function(a,b,c,d,e,f){if(a&&a.isWebGLRenderTarget){var g=
da.get(a).__webglFramebuffer;if(g){var h=!1;g!==M&&(E.bindFramebuffer(E.FRAMEBUFFER,g),h=!0);try{var l=a.texture,k=l.format,q=l.type;1023!==k&&qa.convert(k)!==E.getParameter(E.IMPLEMENTATION_COLOR_READ_FORMAT)?console.error("THREE.WebGLRenderer.readRenderTargetPixels: renderTarget is not in RGBA or implementation defined format."):1009===q||qa.convert(q)===E.getParameter(E.IMPLEMENTATION_COLOR_READ_TYPE)||1015===q&&(ka.get("OES_texture_float")||ka.get("WEBGL_color_buffer_float"))||1016===q&&ka.get("EXT_color_buffer_half_float")?
E.checkFramebufferStatus(E.FRAMEBUFFER)===E.FRAMEBUFFER_COMPLETE?0<=b&&b<=a.width-d&&0<=c&&c<=a.height-e&&E.readPixels(b,c,d,e,qa.convert(k),qa.convert(q),f):console.error("THREE.WebGLRenderer.readRenderTargetPixels: readPixels from renderTarget failed. Framebuffer not complete."):console.error("THREE.WebGLRenderer.readRenderTargetPixels: renderTarget is not in UnsignedByteType or implementation defined type.")}finally{h&&E.bindFramebuffer(E.FRAMEBUFFER,M)}}}else console.error("THREE.WebGLRenderer.readRenderTargetPixels: renderTarget is not THREE.WebGLRenderTarget.")}}
function Hb(a,b){this.name="";this.color=new C(a);this.density=void 0!==b?b:2.5E-4}function Ib(a,b,c){this.name="";this.color=new C(a);this.near=void 0!==b?b:1;this.far=void 0!==c?c:1E3}function nd(){w.call(this);this.type="Scene";this.overrideMaterial=this.fog=this.background=null;this.autoUpdate=!0}function Zd(a,b,c,d,e){w.call(this);this.lensFlares=[];this.positionScreen=new n;this.customUpdateCallback=void 0;void 0!==a&&this.add(a,b,c,d,e)}function Za(a){P.call(this);this.type="SpriteMaterial";
this.color=new C(16777215);this.map=null;this.rotation=0;this.lights=this.fog=!1;this.setValues(a)}function xc(a){w.call(this);this.type="Sprite";this.material=void 0!==a?a:new Za}function yc(){w.call(this);this.type="LOD";Object.defineProperties(this,{levels:{enumerable:!0,value:[]}})}function zc(a,b){a=a||[];this.bones=a.slice(0);this.boneMatrices=new Float32Array(16*this.bones.length);if(void 0===b)this.calculateInverses();else if(this.bones.length===b.length)this.boneInverses=b.slice(0);else for(console.warn("THREE.Skeleton boneInverses is the wrong length."),
this.boneInverses=[],a=0,b=this.bones.length;a<b;a++)this.boneInverses.push(new O)}function od(){w.call(this);this.type="Bone"}function pd(a,b){fa.call(this,a,b);this.type="SkinnedMesh";this.bindMode="attached";this.bindMatrix=new O;this.bindMatrixInverse=new O;a=this.initBones();a=new zc(a);this.bind(a,this.matrixWorld);this.normalizeSkinWeights()}function W(a){P.call(this);this.type="LineBasicMaterial";this.color=new C(16777215);this.linewidth=1;this.linejoin=this.linecap="round";this.lights=!1;
this.setValues(a)}function ra(a,b,c){if(1===c)return console.warn("THREE.Line: parameter THREE.LinePieces no longer supported. Created THREE.LineSegments instead."),new X(a,b);w.call(this);this.type="Line";this.geometry=void 0!==a?a:new F;this.material=void 0!==b?b:new W({color:16777215*Math.random()})}function X(a,b){ra.call(this,a,b);this.type="LineSegments"}function qd(a,b){ra.call(this,a,b);this.type="LineLoop"}function ma(a){P.call(this);this.type="PointsMaterial";this.color=new C(16777215);
this.map=null;this.size=1;this.sizeAttenuation=!0;this.lights=!1;this.setValues(a)}function Jb(a,b){w.call(this);this.type="Points";this.geometry=void 0!==a?a:new F;this.material=void 0!==b?b:new ma({color:16777215*Math.random()})}function Ac(){w.call(this);this.type="Group"}function rd(a,b,c,d,e,f,g,h,k){function l(){requestAnimationFrame(l);a.readyState>=a.HAVE_CURRENT_DATA&&(q.needsUpdate=!0)}N.call(this,a,b,c,d,e,f,g,h,k);this.generateMipmaps=!1;var q=this;l()}function Kb(a,b,c,d,e,f,g,h,k,l,
q,p){N.call(this,null,f,g,h,k,l,d,e,q,p);this.image={width:b,height:c};this.mipmaps=a;this.generateMipmaps=this.flipY=!1}function Bc(a,b,c,d,e,f,g,h,k,l){l=void 0!==l?l:1026;if(1026!==l&&1027!==l)throw Error("DepthTexture format must be either THREE.DepthFormat or THREE.DepthStencilFormat");void 0===c&&1026===l&&(c=1012);void 0===c&&1027===l&&(c=1020);N.call(this,null,d,e,f,g,h,l,c,k);this.image={width:a,height:b};this.magFilter=void 0!==g?g:1003;this.minFilter=void 0!==h?h:1003;this.generateMipmaps=
this.flipY=!1}function Lb(a){F.call(this);this.type="WireframeGeometry";var b=[],c,d,e,f=[0,0],g={},h=["a","b","c"];if(a&&a.isGeometry){var k=a.faces;var l=0;for(d=k.length;l<d;l++){var q=k[l];for(c=0;3>c;c++){var p=q[h[c]];var t=q[h[(c+1)%3]];f[0]=Math.min(p,t);f[1]=Math.max(p,t);p=f[0]+","+f[1];void 0===g[p]&&(g[p]={index1:f[0],index2:f[1]})}}for(p in g)l=g[p],h=a.vertices[l.index1],b.push(h.x,h.y,h.z),h=a.vertices[l.index2],b.push(h.x,h.y,h.z)}else if(a&&a.isBufferGeometry){var h=new n;if(null!==
a.index){k=a.attributes.position;q=a.index;var r=a.groups;0===r.length&&(r=[{start:0,count:q.count,materialIndex:0}]);a=0;for(e=r.length;a<e;++a)for(l=r[a],c=l.start,d=l.count,l=c,d=c+d;l<d;l+=3)for(c=0;3>c;c++)p=q.getX(l+c),t=q.getX(l+(c+1)%3),f[0]=Math.min(p,t),f[1]=Math.max(p,t),p=f[0]+","+f[1],void 0===g[p]&&(g[p]={index1:f[0],index2:f[1]});for(p in g)l=g[p],h.fromBufferAttribute(k,l.index1),b.push(h.x,h.y,h.z),h.fromBufferAttribute(k,l.index2),b.push(h.x,h.y,h.z)}else for(k=a.attributes.position,
l=0,d=k.count/3;l<d;l++)for(c=0;3>c;c++)g=3*l+c,h.fromBufferAttribute(k,g),b.push(h.x,h.y,h.z),g=3*l+(c+1)%3,h.fromBufferAttribute(k,g),b.push(h.x,h.y,h.z)}this.addAttribute("position",new z(b,3))}function Cc(a,b,c){Q.call(this);this.type="ParametricGeometry";this.parameters={func:a,slices:b,stacks:c};this.fromBufferGeometry(new Mb(a,b,c));this.mergeVertices()}function Mb(a,b,c){F.call(this);this.type="ParametricBufferGeometry";this.parameters={func:a,slices:b,stacks:c};var d=[],e=[],f=[],g=[],h=
new n,k=new n,l=new n,q=new n,p=new n,t,r,m=b+1;for(t=0;t<=c;t++){var u=t/c;for(r=0;r<=b;r++){var x=r/b,k=a(x,u,k);e.push(k.x,k.y,k.z);0<=x-1E-5?(l=a(x-1E-5,u,l),q.subVectors(k,l)):(l=a(x+1E-5,u,l),q.subVectors(l,k));0<=u-1E-5?(l=a(x,u-1E-5,l),p.subVectors(k,l)):(l=a(x,u+1E-5,l),p.subVectors(l,k));h.crossVectors(q,p).normalize();f.push(h.x,h.y,h.z);g.push(x,u)}}for(t=0;t<c;t++)for(r=0;r<b;r++)a=t*m+r+1,h=(t+1)*m+r+1,k=(t+1)*m+r,d.push(t*m+r,a,k),d.push(a,h,k);this.setIndex(d);this.addAttribute("position",
new z(e,3));this.addAttribute("normal",new z(f,3));this.addAttribute("uv",new z(g,2))}function Dc(a,b,c,d){Q.call(this);this.type="PolyhedronGeometry";this.parameters={vertices:a,indices:b,radius:c,detail:d};this.fromBufferGeometry(new ua(a,b,c,d));this.mergeVertices()}function ua(a,b,c,d){function e(a){h.push(a.x,a.y,a.z)}function f(b,c){b*=3;c.x=a[b+0];c.y=a[b+1];c.z=a[b+2]}function g(a,b,c,d){0>d&&1===a.x&&(k[b]=a.x-1);0===c.x&&0===c.z&&(k[b]=d/2/Math.PI+.5)}F.call(this);this.type="PolyhedronBufferGeometry";
this.parameters={vertices:a,indices:b,radius:c,detail:d};c=c||1;d=d||0;var h=[],k=[];(function(a){for(var c=new n,d=new n,g=new n,h=0;h<b.length;h+=3){f(b[h+0],c);f(b[h+1],d);f(b[h+2],g);var l,k,m=c,y=d,A=g,I=Math.pow(2,a),B=[];for(k=0;k<=I;k++){B[k]=[];var H=m.clone().lerp(A,k/I),w=y.clone().lerp(A,k/I),z=I-k;for(l=0;l<=z;l++)B[k][l]=0===l&&k===I?H:H.clone().lerp(w,l/z)}for(k=0;k<I;k++)for(l=0;l<2*(I-k)-1;l++)m=Math.floor(l/2),0===l%2?(e(B[k][m+1]),e(B[k+1][m]),e(B[k][m])):(e(B[k][m+1]),e(B[k+1][m+
1]),e(B[k+1][m]))}})(d);(function(a){for(var b=new n,c=0;c<h.length;c+=3)b.x=h[c+0],b.y=h[c+1],b.z=h[c+2],b.normalize().multiplyScalar(a),h[c+0]=b.x,h[c+1]=b.y,h[c+2]=b.z})(c);(function(){for(var a=new n,b=0;b<h.length;b+=3)a.x=h[b+0],a.y=h[b+1],a.z=h[b+2],k.push(Math.atan2(a.z,-a.x)/2/Math.PI+.5,1-(Math.atan2(-a.y,Math.sqrt(a.x*a.x+a.z*a.z))/Math.PI+.5));for(var a=new n,b=new n,c=new n,d=new n,e=new D,f=new D,m=new D,x=0,y=0;x<h.length;x+=9,y+=6){a.set(h[x+0],h[x+1],h[x+2]);b.set(h[x+3],h[x+4],h[x+
5]);c.set(h[x+6],h[x+7],h[x+8]);e.set(k[y+0],k[y+1]);f.set(k[y+2],k[y+3]);m.set(k[y+4],k[y+5]);d.copy(a).add(b).add(c).divideScalar(3);var A=Math.atan2(d.z,-d.x);g(e,y+0,a,A);g(f,y+2,b,A);g(m,y+4,c,A)}for(a=0;a<k.length;a+=6)b=k[a+0],c=k[a+2],d=k[a+4],e=Math.min(b,c,d),.9<Math.max(b,c,d)&&.1>e&&(.2>b&&(k[a+0]+=1),.2>c&&(k[a+2]+=1),.2>d&&(k[a+4]+=1))})();this.addAttribute("position",new z(h,3));this.addAttribute("normal",new z(h.slice(),3));this.addAttribute("uv",new z(k,2));0===d?this.computeVertexNormals():
this.normalizeNormals()}function Ec(a,b){Q.call(this);this.type="TetrahedronGeometry";this.parameters={radius:a,detail:b};this.fromBufferGeometry(new Nb(a,b));this.mergeVertices()}function Nb(a,b){ua.call(this,[1,1,1,-1,-1,1,-1,1,-1,1,-1,-1],[2,1,0,0,3,2,1,3,0,2,3,1],a,b);this.type="TetrahedronBufferGeometry";this.parameters={radius:a,detail:b}}function Fc(a,b){Q.call(this);this.type="OctahedronGeometry";this.parameters={radius:a,detail:b};this.fromBufferGeometry(new jb(a,b));this.mergeVertices()}
function jb(a,b){ua.call(this,[1,0,0,-1,0,0,0,1,0,0,-1,0,0,0,1,0,0,-1],[0,2,4,0,4,3,0,3,5,0,5,2,1,2,5,1,5,3,1,3,4,1,4,2],a,b);this.type="OctahedronBufferGeometry";this.parameters={radius:a,detail:b}}function Gc(a,b){Q.call(this);this.type="IcosahedronGeometry";this.parameters={radius:a,detail:b};this.fromBufferGeometry(new Ob(a,b));this.mergeVertices()}function Ob(a,b){var c=(1+Math.sqrt(5))/2;ua.call(this,[-1,c,0,1,c,0,-1,-c,0,1,-c,0,0,-1,c,0,1,c,0,-1,-c,0,1,-c,c,0,-1,c,0,1,-c,0,-1,-c,0,1],[0,11,
5,0,5,1,0,1,7,0,7,10,0,10,11,1,5,9,5,11,4,11,10,2,10,7,6,7,1,8,3,9,4,3,4,2,3,2,6,3,6,8,3,8,9,4,9,5,2,4,11,6,2,10,8,6,7,9,8,1],a,b);this.type="IcosahedronBufferGeometry";this.parameters={radius:a,detail:b}}function Hc(a,b){Q.call(this);this.type="DodecahedronGeometry";this.parameters={radius:a,detail:b};this.fromBufferGeometry(new Pb(a,b));this.mergeVertices()}function Pb(a,b){var c=(1+Math.sqrt(5))/2,d=1/c;ua.call(this,[-1,-1,-1,-1,-1,1,-1,1,-1,-1,1,1,1,-1,-1,1,-1,1,1,1,-1,1,1,1,0,-d,-c,0,-d,c,0,
d,-c,0,d,c,-d,-c,0,-d,c,0,d,-c,0,d,c,0,-c,0,-d,c,0,-d,-c,0,d,c,0,d],[3,11,7,3,7,15,3,15,13,7,19,17,7,17,6,7,6,15,17,4,8,17,8,10,17,10,6,8,0,16,8,16,2,8,2,10,0,12,1,0,1,18,0,18,16,6,10,2,6,2,13,6,13,15,2,16,18,2,18,3,2,3,13,18,1,9,18,9,11,18,11,3,4,14,12,4,12,0,4,0,8,11,9,5,11,5,19,11,19,7,19,5,14,19,14,4,19,4,17,1,12,14,1,14,5,1,5,9],a,b);this.type="DodecahedronBufferGeometry";this.parameters={radius:a,detail:b}}function Ic(a,b,c,d,e,f){Q.call(this);this.type="TubeGeometry";this.parameters={path:a,
tubularSegments:b,radius:c,radialSegments:d,closed:e};void 0!==f&&console.warn("THREE.TubeGeometry: taper has been removed.");a=new Qb(a,b,c,d,e);this.tangents=a.tangents;this.normals=a.normals;this.binormals=a.binormals;this.fromBufferGeometry(a);this.mergeVertices()}function Qb(a,b,c,d,e){function f(e){var f=a.getPointAt(e/b),l=g.normals[e];e=g.binormals[e];for(p=0;p<=d;p++){var q=p/d*Math.PI*2,r=Math.sin(q),q=-Math.cos(q);k.x=q*l.x+r*e.x;k.y=q*l.y+r*e.y;k.z=q*l.z+r*e.z;k.normalize();m.push(k.x,
k.y,k.z);h.x=f.x+c*k.x;h.y=f.y+c*k.y;h.z=f.z+c*k.z;t.push(h.x,h.y,h.z)}}F.call(this);this.type="TubeBufferGeometry";this.parameters={path:a,tubularSegments:b,radius:c,radialSegments:d,closed:e};b=b||64;c=c||1;d=d||8;e=e||!1;var g=a.computeFrenetFrames(b,e);this.tangents=g.tangents;this.normals=g.normals;this.binormals=g.binormals;var h=new n,k=new n,l=new D,q,p,t=[],m=[],v=[],u=[];for(q=0;q<b;q++)f(q);f(!1===e?b:0);for(q=0;q<=b;q++)for(p=0;p<=d;p++)l.x=q/b,l.y=p/d,v.push(l.x,l.y);(function(){for(p=
1;p<=b;p++)for(q=1;q<=d;q++){var a=(d+1)*p+(q-1),c=(d+1)*p+q,e=(d+1)*(p-1)+q;u.push((d+1)*(p-1)+(q-1),a,e);u.push(a,c,e)}})();this.setIndex(u);this.addAttribute("position",new z(t,3));this.addAttribute("normal",new z(m,3));this.addAttribute("uv",new z(v,2))}function Jc(a,b,c,d,e,f,g){Q.call(this);this.type="TorusKnotGeometry";this.parameters={radius:a,tube:b,tubularSegments:c,radialSegments:d,p:e,q:f};void 0!==g&&console.warn("THREE.TorusKnotGeometry: heightScale has been deprecated. Use .scale( x, y, z ) instead.");
this.fromBufferGeometry(new Rb(a,b,c,d,e,f));this.mergeVertices()}function Rb(a,b,c,d,e,f){function g(a,b,c,d,e){var f=Math.sin(a);b=c/b*a;c=Math.cos(b);e.x=d*(2+c)*.5*Math.cos(a);e.y=d*(2+c)*f*.5;e.z=d*Math.sin(b)*.5}F.call(this);this.type="TorusKnotBufferGeometry";this.parameters={radius:a,tube:b,tubularSegments:c,radialSegments:d,p:e,q:f};a=a||100;b=b||40;c=Math.floor(c)||64;d=Math.floor(d)||8;e=e||2;f=f||3;var h=[],k=[],l=[],q=[],p,t=new n,m=new n,v=new n,u=new n,x=new n,y=new n,A=new n;for(p=
0;p<=c;++p){var I=p/c*e*Math.PI*2;g(I,e,f,a,v);g(I+.01,e,f,a,u);y.subVectors(u,v);A.addVectors(u,v);x.crossVectors(y,A);A.crossVectors(x,y);x.normalize();A.normalize();for(I=0;I<=d;++I){var B=I/d*Math.PI*2,H=-b*Math.cos(B),B=b*Math.sin(B);t.x=v.x+(H*A.x+B*x.x);t.y=v.y+(H*A.y+B*x.y);t.z=v.z+(H*A.z+B*x.z);k.push(t.x,t.y,t.z);m.subVectors(t,v).normalize();l.push(m.x,m.y,m.z);q.push(p/c);q.push(I/d)}}for(I=1;I<=c;I++)for(p=1;p<=d;p++)a=(d+1)*I+(p-1),b=(d+1)*I+p,e=(d+1)*(I-1)+p,h.push((d+1)*(I-1)+(p-1),
a,e),h.push(a,b,e);this.setIndex(h);this.addAttribute("position",new z(k,3));this.addAttribute("normal",new z(l,3));this.addAttribute("uv",new z(q,2))}function Kc(a,b,c,d,e){Q.call(this);this.type="TorusGeometry";this.parameters={radius:a,tube:b,radialSegments:c,tubularSegments:d,arc:e};this.fromBufferGeometry(new Sb(a,b,c,d,e));this.mergeVertices()}function Sb(a,b,c,d,e){F.call(this);this.type="TorusBufferGeometry";this.parameters={radius:a,tube:b,radialSegments:c,tubularSegments:d,arc:e};a=a||100;
b=b||40;c=Math.floor(c)||8;d=Math.floor(d)||6;e=e||2*Math.PI;var f=[],g=[],h=[],k=[],l=new n,q=new n,p=new n,t,m;for(t=0;t<=c;t++)for(m=0;m<=d;m++){var v=m/d*e,u=t/c*Math.PI*2;q.x=(a+b*Math.cos(u))*Math.cos(v);q.y=(a+b*Math.cos(u))*Math.sin(v);q.z=b*Math.sin(u);g.push(q.x,q.y,q.z);l.x=a*Math.cos(v);l.y=a*Math.sin(v);p.subVectors(q,l).normalize();h.push(p.x,p.y,p.z);k.push(m/d);k.push(t/c)}for(t=1;t<=c;t++)for(m=1;m<=d;m++)a=(d+1)*(t-1)+m-1,b=(d+1)*(t-1)+m,e=(d+1)*t+m,f.push((d+1)*t+m-1,a,e),f.push(a,
b,e);this.setIndex(f);this.addAttribute("position",new z(g,3));this.addAttribute("normal",new z(h,3));this.addAttribute("uv",new z(k,2))}function $a(a,b){Q.call(this);this.type="ExtrudeGeometry";this.parameters={shapes:a,options:b};this.fromBufferGeometry(new Ea(a,b));this.mergeVertices()}function Ea(a,b){"undefined"!==typeof a&&(F.call(this),this.type="ExtrudeBufferGeometry",a=Array.isArray(a)?a:[a],this.addShapeList(a,b),this.computeVertexNormals())}function Lc(a,b){Q.call(this);this.type="TextGeometry";
this.parameters={text:a,parameters:b};this.fromBufferGeometry(new Tb(a,b));this.mergeVertices()}function Tb(a,b){b=b||{};var c=b.font;if(!c||!c.isFont)return console.error("THREE.TextGeometry: font parameter is not an instance of THREE.Font."),new Q;a=c.generateShapes(a,b.size,b.curveSegments);b.amount=void 0!==b.height?b.height:50;void 0===b.bevelThickness&&(b.bevelThickness=10);void 0===b.bevelSize&&(b.bevelSize=8);void 0===b.bevelEnabled&&(b.bevelEnabled=!1);Ea.call(this,a,b);this.type="TextBufferGeometry"}
function Mc(a,b,c,d,e,f,g){Q.call(this);this.type="SphereGeometry";this.parameters={radius:a,widthSegments:b,heightSegments:c,phiStart:d,phiLength:e,thetaStart:f,thetaLength:g};this.fromBufferGeometry(new kb(a,b,c,d,e,f,g));this.mergeVertices()}function kb(a,b,c,d,e,f,g){F.call(this);this.type="SphereBufferGeometry";this.parameters={radius:a,widthSegments:b,heightSegments:c,phiStart:d,phiLength:e,thetaStart:f,thetaLength:g};a=a||50;b=Math.max(3,Math.floor(b)||8);c=Math.max(2,Math.floor(c)||6);d=void 0!==
d?d:0;e=void 0!==e?e:2*Math.PI;f=void 0!==f?f:0;g=void 0!==g?g:Math.PI;var h=f+g,k,l,q=0,p=[],t=new n,m=new n,v=[],u=[],x=[],y=[];for(l=0;l<=c;l++){var A=[],I=l/c;for(k=0;k<=b;k++){var B=k/b;t.x=-a*Math.cos(d+B*e)*Math.sin(f+I*g);t.y=a*Math.cos(f+I*g);t.z=a*Math.sin(d+B*e)*Math.sin(f+I*g);u.push(t.x,t.y,t.z);m.set(t.x,t.y,t.z).normalize();x.push(m.x,m.y,m.z);y.push(B,1-I);A.push(q++)}p.push(A)}for(l=0;l<c;l++)for(k=0;k<b;k++)a=p[l][k+1],d=p[l][k],e=p[l+1][k],g=p[l+1][k+1],(0!==l||0<f)&&v.push(a,d,
g),(l!==c-1||h<Math.PI)&&v.push(d,e,g);this.setIndex(v);this.addAttribute("position",new z(u,3));this.addAttribute("normal",new z(x,3));this.addAttribute("uv",new z(y,2))}function Nc(a,b,c,d,e,f){Q.call(this);this.type="RingGeometry";this.parameters={innerRadius:a,outerRadius:b,thetaSegments:c,phiSegments:d,thetaStart:e,thetaLength:f};this.fromBufferGeometry(new Ub(a,b,c,d,e,f));this.mergeVertices()}function Ub(a,b,c,d,e,f){F.call(this);this.type="RingBufferGeometry";this.parameters={innerRadius:a,
outerRadius:b,thetaSegments:c,phiSegments:d,thetaStart:e,thetaLength:f};a=a||20;b=b||50;e=void 0!==e?e:0;f=void 0!==f?f:2*Math.PI;c=void 0!==c?Math.max(3,c):8;d=void 0!==d?Math.max(1,d):1;var g=[],h=[],k=[],l=[],q=a,p=(b-a)/d,t=new n,m=new D,v,u;for(v=0;v<=d;v++){for(u=0;u<=c;u++)a=e+u/c*f,t.x=q*Math.cos(a),t.y=q*Math.sin(a),h.push(t.x,t.y,t.z),k.push(0,0,1),m.x=(t.x/b+1)/2,m.y=(t.y/b+1)/2,l.push(m.x,m.y);q+=p}for(v=0;v<d;v++)for(b=v*(c+1),u=0;u<c;u++)a=u+b,e=a+c+1,f=a+c+2,q=a+1,g.push(a,e,q),g.push(e,
f,q);this.setIndex(g);this.addAttribute("position",new z(h,3));this.addAttribute("normal",new z(k,3));this.addAttribute("uv",new z(l,2))}function Oc(a,b,c,d){Q.call(this);this.type="LatheGeometry";this.parameters={points:a,segments:b,phiStart:c,phiLength:d};this.fromBufferGeometry(new Vb(a,b,c,d));this.mergeVertices()}function Vb(a,b,c,d){F.call(this);this.type="LatheBufferGeometry";this.parameters={points:a,segments:b,phiStart:c,phiLength:d};b=Math.floor(b)||12;c=c||0;d=d||2*Math.PI;d=R.clamp(d,
0,2*Math.PI);var e=[],f=[],g=[],h=1/b,k=new n,l=new D,q;for(q=0;q<=b;q++){var p=c+q*h*d;var t=Math.sin(p),m=Math.cos(p);for(p=0;p<=a.length-1;p++)k.x=a[p].x*t,k.y=a[p].y,k.z=a[p].x*m,f.push(k.x,k.y,k.z),l.x=q/b,l.y=p/(a.length-1),g.push(l.x,l.y)}for(q=0;q<b;q++)for(p=0;p<a.length-1;p++)c=p+q*a.length,h=c+a.length,k=c+a.length+1,l=c+1,e.push(c,h,l),e.push(h,k,l);this.setIndex(e);this.addAttribute("position",new z(f,3));this.addAttribute("uv",new z(g,2));this.computeVertexNormals();if(d===2*Math.PI)for(d=
this.attributes.normal.array,e=new n,f=new n,g=new n,c=b*a.length*3,p=q=0;q<a.length;q++,p+=3)e.x=d[p+0],e.y=d[p+1],e.z=d[p+2],f.x=d[c+p+0],f.y=d[c+p+1],f.z=d[c+p+2],g.addVectors(e,f).normalize(),d[p+0]=d[c+p+0]=g.x,d[p+1]=d[c+p+1]=g.y,d[p+2]=d[c+p+2]=g.z}function Wb(a,b){Q.call(this);this.type="ShapeGeometry";"object"===typeof b&&(console.warn("THREE.ShapeGeometry: Options parameter has been removed."),b=b.curveSegments);this.parameters={shapes:a,curveSegments:b};this.fromBufferGeometry(new Xb(a,
b));this.mergeVertices()}function Xb(a,b){function c(a){var c,h=e.length/3;a=a.extractPoints(b);var l=a.shape,q=a.holes;if(!1===Fa.isClockWise(l))for(l=l.reverse(),a=0,c=q.length;a<c;a++){var m=q[a];!0===Fa.isClockWise(m)&&(q[a]=m.reverse())}var n=Fa.triangulateShape(l,q);a=0;for(c=q.length;a<c;a++)m=q[a],l=l.concat(m);a=0;for(c=l.length;a<c;a++)m=l[a],e.push(m.x,m.y,0),f.push(0,0,1),g.push(m.x,m.y);a=0;for(c=n.length;a<c;a++)l=n[a],d.push(l[0]+h,l[1]+h,l[2]+h),k+=3}F.call(this);this.type="ShapeBufferGeometry";
this.parameters={shapes:a,curveSegments:b};b=b||12;var d=[],e=[],f=[],g=[],h=0,k=0;if(!1===Array.isArray(a))c(a);else for(var l=0;l<a.length;l++)c(a[l]),this.addGroup(h,k,l),h+=k,k=0;this.setIndex(d);this.addAttribute("position",new z(e,3));this.addAttribute("normal",new z(f,3));this.addAttribute("uv",new z(g,2))}function Yb(a,b){F.call(this);this.type="EdgesGeometry";this.parameters={thresholdAngle:b};var c=[];b=Math.cos(R.DEG2RAD*(void 0!==b?b:1));var d=[0,0],e={},f=["a","b","c"];if(a.isBufferGeometry){var g=
new Q;g.fromBufferGeometry(a)}else g=a.clone();g.mergeVertices();g.computeFaceNormals();a=g.vertices;g=g.faces;for(var h=0,k=g.length;h<k;h++)for(var l=g[h],q=0;3>q;q++){var p=l[f[q]];var t=l[f[(q+1)%3]];d[0]=Math.min(p,t);d[1]=Math.max(p,t);p=d[0]+","+d[1];void 0===e[p]?e[p]={index1:d[0],index2:d[1],face1:h,face2:void 0}:e[p].face2=h}for(p in e)if(d=e[p],void 0===d.face2||g[d.face1].normal.dot(g[d.face2].normal)<=b)f=a[d.index1],c.push(f.x,f.y,f.z),f=a[d.index2],c.push(f.x,f.y,f.z);this.addAttribute("position",
new z(c,3))}function lb(a,b,c,d,e,f,g,h){Q.call(this);this.type="CylinderGeometry";this.parameters={radiusTop:a,radiusBottom:b,height:c,radialSegments:d,heightSegments:e,openEnded:f,thetaStart:g,thetaLength:h};this.fromBufferGeometry(new Ta(a,b,c,d,e,f,g,h));this.mergeVertices()}function Ta(a,b,c,d,e,f,g,h){function k(c){var e,f=new D,k=new n,r=0,u=!0===c?a:b,A=!0===c?1:-1;var w=v;for(e=1;e<=d;e++)p.push(0,x*A,0),t.push(0,A,0),m.push(.5,.5),v++;var z=v;for(e=0;e<=d;e++){var C=e/d*h+g,J=Math.cos(C),
C=Math.sin(C);k.x=u*C;k.y=x*A;k.z=u*J;p.push(k.x,k.y,k.z);t.push(0,A,0);f.x=.5*J+.5;f.y=.5*C*A+.5;m.push(f.x,f.y);v++}for(e=0;e<d;e++)f=w+e,k=z+e,!0===c?q.push(k,k+1,f):q.push(k+1,k,f),r+=3;l.addGroup(y,r,!0===c?1:2);y+=r}F.call(this);this.type="CylinderBufferGeometry";this.parameters={radiusTop:a,radiusBottom:b,height:c,radialSegments:d,heightSegments:e,openEnded:f,thetaStart:g,thetaLength:h};var l=this;a=void 0!==a?a:20;b=void 0!==b?b:20;c=void 0!==c?c:100;d=Math.floor(d)||8;e=Math.floor(e)||1;
f=void 0!==f?f:!1;g=void 0!==g?g:0;h=void 0!==h?h:2*Math.PI;var q=[],p=[],t=[],m=[],v=0,u=[],x=c/2,y=0;(function(){var f,k,r=new n,H=new n,w=0,z=(b-a)/c;for(k=0;k<=e;k++){var D=[],C=k/e,F=C*(b-a)+a;for(f=0;f<=d;f++){var L=f/d,J=L*h+g,K=Math.sin(J),J=Math.cos(J);H.x=F*K;H.y=-C*c+x;H.z=F*J;p.push(H.x,H.y,H.z);r.set(K,z,J).normalize();t.push(r.x,r.y,r.z);m.push(L,1-C);D.push(v++)}u.push(D)}for(f=0;f<d;f++)for(k=0;k<e;k++)r=u[k+1][f],H=u[k+1][f+1],z=u[k][f+1],q.push(u[k][f],r,z),q.push(r,H,z),w+=6;l.addGroup(y,
w,0);y+=w})();!1===f&&(0<a&&k(!0),0<b&&k(!1));this.setIndex(q);this.addAttribute("position",new z(p,3));this.addAttribute("normal",new z(t,3));this.addAttribute("uv",new z(m,2))}function Pc(a,b,c,d,e,f,g){lb.call(this,0,a,b,c,d,e,f,g);this.type="ConeGeometry";this.parameters={radius:a,height:b,radialSegments:c,heightSegments:d,openEnded:e,thetaStart:f,thetaLength:g}}function Qc(a,b,c,d,e,f,g){Ta.call(this,0,a,b,c,d,e,f,g);this.type="ConeBufferGeometry";this.parameters={radius:a,height:b,radialSegments:c,
heightSegments:d,openEnded:e,thetaStart:f,thetaLength:g}}function Rc(a,b,c,d){Q.call(this);this.type="CircleGeometry";this.parameters={radius:a,segments:b,thetaStart:c,thetaLength:d};this.fromBufferGeometry(new Zb(a,b,c,d));this.mergeVertices()}function Zb(a,b,c,d){F.call(this);this.type="CircleBufferGeometry";this.parameters={radius:a,segments:b,thetaStart:c,thetaLength:d};a=a||50;b=void 0!==b?Math.max(3,b):8;c=void 0!==c?c:0;d=void 0!==d?d:2*Math.PI;var e=[],f=[],g=[],h=[],k,l=new n,q=new D;f.push(0,
0,0);g.push(0,0,1);h.push(.5,.5);var p=0;for(k=3;p<=b;p++,k+=3){var t=c+p/b*d;l.x=a*Math.cos(t);l.y=a*Math.sin(t);f.push(l.x,l.y,l.z);g.push(0,0,1);q.x=(f[k]/a+1)/2;q.y=(f[k+1]/a+1)/2;h.push(q.x,q.y)}for(k=1;k<=b;k++)e.push(k,k+1,0);this.setIndex(e);this.addAttribute("position",new z(f,3));this.addAttribute("normal",new z(g,3));this.addAttribute("uv",new z(h,2))}function $b(a){P.call(this);this.type="ShadowMaterial";this.color=new C(0);this.opacity=1;this.transparent=this.lights=!0;this.setValues(a)}
function ac(a){ya.call(this,a);this.type="RawShaderMaterial"}function Na(a){P.call(this);this.defines={STANDARD:""};this.type="MeshStandardMaterial";this.color=new C(16777215);this.metalness=this.roughness=.5;this.lightMap=this.map=null;this.lightMapIntensity=1;this.aoMap=null;this.aoMapIntensity=1;this.emissive=new C(0);this.emissiveIntensity=1;this.bumpMap=this.emissiveMap=null;this.bumpScale=1;this.normalMap=null;this.normalScale=new D(1,1);this.displacementMap=null;this.displacementScale=1;this.displacementBias=
0;this.envMap=this.alphaMap=this.metalnessMap=this.roughnessMap=null;this.envMapIntensity=1;this.refractionRatio=.98;this.wireframe=!1;this.wireframeLinewidth=1;this.wireframeLinejoin=this.wireframeLinecap="round";this.morphNormals=this.morphTargets=this.skinning=!1;this.setValues(a)}function mb(a){Na.call(this);this.defines={PHYSICAL:""};this.type="MeshPhysicalMaterial";this.reflectivity=.5;this.clearCoatRoughness=this.clearCoat=0;this.setValues(a)}function Aa(a){P.call(this);this.type="MeshPhongMaterial";
this.color=new C(16777215);this.specular=new C(1118481);this.shininess=30;this.lightMap=this.map=null;this.lightMapIntensity=1;this.aoMap=null;this.aoMapIntensity=1;this.emissive=new C(0);this.emissiveIntensity=1;this.bumpMap=this.emissiveMap=null;this.bumpScale=1;this.normalMap=null;this.normalScale=new D(1,1);this.displacementMap=null;this.displacementScale=1;this.displacementBias=0;this.envMap=this.alphaMap=this.specularMap=null;this.combine=0;this.reflectivity=1;this.refractionRatio=.98;this.wireframe=
!1;this.wireframeLinewidth=1;this.wireframeLinejoin=this.wireframeLinecap="round";this.morphNormals=this.morphTargets=this.skinning=!1;this.setValues(a)}function nb(a){Aa.call(this);this.defines={TOON:""};this.type="MeshToonMaterial";this.gradientMap=null;this.setValues(a)}function ob(a){P.call(this);this.type="MeshNormalMaterial";this.bumpMap=null;this.bumpScale=1;this.normalMap=null;this.normalScale=new D(1,1);this.displacementMap=null;this.displacementScale=1;this.displacementBias=0;this.wireframe=
!1;this.wireframeLinewidth=1;this.morphNormals=this.morphTargets=this.skinning=this.lights=this.fog=!1;this.setValues(a)}function pb(a){P.call(this);this.type="MeshLambertMaterial";this.color=new C(16777215);this.lightMap=this.map=null;this.lightMapIntensity=1;this.aoMap=null;this.aoMapIntensity=1;this.emissive=new C(0);this.emissiveIntensity=1;this.envMap=this.alphaMap=this.specularMap=this.emissiveMap=null;this.combine=0;this.reflectivity=1;this.refractionRatio=.98;this.wireframe=!1;this.wireframeLinewidth=
1;this.wireframeLinejoin=this.wireframeLinecap="round";this.morphNormals=this.morphTargets=this.skinning=!1;this.setValues(a)}function qb(a){W.call(this);this.type="LineDashedMaterial";this.scale=1;this.dashSize=3;this.gapSize=1;this.setValues(a)}function $d(a,b,c){var d=this,e=!1,f=0,g=0;this.onStart=void 0;this.onLoad=a;this.onProgress=b;this.onError=c;this.itemStart=function(a){g++;if(!1===e&&void 0!==d.onStart)d.onStart(a,f,g);e=!0};this.itemEnd=function(a){f++;if(void 0!==d.onProgress)d.onProgress(a,
f,g);if(f===g&&(e=!1,void 0!==d.onLoad))d.onLoad()};this.itemError=function(a){if(void 0!==d.onError)d.onError(a)}}function Ia(a){this.manager=void 0!==a?a:oa}function Re(a){this.manager=void 0!==a?a:oa;this._parser=null}function ae(a){this.manager=void 0!==a?a:oa;this._parser=null}function Sc(a){this.manager=void 0!==a?a:oa}function be(a){this.manager=void 0!==a?a:oa}function sd(a){this.manager=void 0!==a?a:oa}function aa(a,b){w.call(this);this.type="Light";this.color=new C(a);this.intensity=void 0!==
b?b:1;this.receiveShadow=void 0}function td(a,b,c){aa.call(this,a,c);this.type="HemisphereLight";this.castShadow=void 0;this.position.copy(w.DefaultUp);this.updateMatrix();this.groundColor=new C(b)}function rb(a){this.camera=a;this.bias=0;this.radius=1;this.mapSize=new D(512,512);this.map=null;this.matrix=new O}function ud(){rb.call(this,new ja(50,1,.5,500))}function vd(a,b,c,d,e,f){aa.call(this,a,b);this.type="SpotLight";this.position.copy(w.DefaultUp);this.updateMatrix();this.target=new w;Object.defineProperty(this,
"power",{get:function(){return this.intensity*Math.PI},set:function(a){this.intensity=a/Math.PI}});this.distance=void 0!==c?c:0;this.angle=void 0!==d?d:Math.PI/3;this.penumbra=void 0!==e?e:0;this.decay=void 0!==f?f:1;this.shadow=new ud}function wd(a,b,c,d){aa.call(this,a,b);this.type="PointLight";Object.defineProperty(this,"power",{get:function(){return 4*this.intensity*Math.PI},set:function(a){this.intensity=a/(4*Math.PI)}});this.distance=void 0!==c?c:0;this.decay=void 0!==d?d:1;this.shadow=new rb(new ja(90,
1,.5,500))}function xd(){rb.call(this,new Db(-5,5,5,-5,.5,500))}function yd(a,b){aa.call(this,a,b);this.type="DirectionalLight";this.position.copy(w.DefaultUp);this.updateMatrix();this.target=new w;this.shadow=new xd}function zd(a,b){aa.call(this,a,b);this.type="AmbientLight";this.castShadow=void 0}function Ad(a,b,c,d){aa.call(this,a,b);this.type="RectAreaLight";this.position.set(0,1,0);this.updateMatrix();this.width=void 0!==c?c:10;this.height=void 0!==d?d:10}function wa(a,b,c,d){this.parameterPositions=
a;this._cachedIndex=0;this.resultBuffer=void 0!==d?d:new b.constructor(c);this.sampleValues=b;this.valueSize=c}function Bd(a,b,c,d){wa.call(this,a,b,c,d);this._offsetNext=this._weightNext=this._offsetPrev=this._weightPrev=-0}function Tc(a,b,c,d){wa.call(this,a,b,c,d)}function Cd(a,b,c,d){wa.call(this,a,b,c,d)}function sb(a,b,c,d){if(void 0===a)throw Error("track name is undefined");if(void 0===b||0===b.length)throw Error("no keyframes in track named "+a);this.name=a;this.times=ea.convertArray(b,this.TimeBufferType);
this.values=ea.convertArray(c,this.ValueBufferType);this.setInterpolation(d||this.DefaultInterpolation);this.validate();this.optimize()}function bc(a,b,c,d){sb.call(this,a,b,c,d)}function Dd(a,b,c,d){wa.call(this,a,b,c,d)}function Uc(a,b,c,d){sb.call(this,a,b,c,d)}function cc(a,b,c,d){sb.call(this,a,b,c,d)}function Ed(a,b,c,d){sb.call(this,a,b,c,d)}function Fd(a,b,c){sb.call(this,a,b,c)}function Gd(a,b,c,d){sb.call(this,a,b,c,d)}function tb(a,b,c,d){sb.apply(this,arguments)}function Ba(a,b,c){this.name=
a;this.tracks=c;this.duration=void 0!==b?b:-1;this.uuid=R.generateUUID();0>this.duration&&this.resetDuration();this.optimize()}function Hd(a){this.manager=void 0!==a?a:oa;this.textures={}}function ce(a){this.manager=void 0!==a?a:oa}function dc(){this.onLoadStart=function(){};this.onLoadProgress=function(){};this.onLoadComplete=function(){}}function de(a){"boolean"===typeof a&&(console.warn("THREE.JSONLoader: showStatus parameter has been removed from constructor."),a=void 0);this.manager=void 0!==
a?a:oa;this.withCredentials=!1}function Se(a){this.manager=void 0!==a?a:oa;this.texturePath=""}function Te(a,b,c,d,e){b=.5*(d-b);e=.5*(e-c);var f=a*a;return(2*c-2*d+b+e)*a*f+(-3*c+3*d-2*b-e)*f+b*a+c}function ub(a,b,c,d){var e=1-a;return e*e*b+2*(1-a)*a*c+a*a*d}function vb(a,b,c,d,e){var f=1-a,g=1-a;return f*f*f*b+3*g*g*a*c+3*(1-a)*a*a*d+a*a*a*e}function pa(){this.arcLengthDivisions=200}function Oa(a,b){this.arcLengthDivisions=200;this.v1=a;this.v2=b}function Vc(){this.arcLengthDivisions=200;this.curves=
[];this.autoClose=!1}function Ua(a,b,c,d,e,f,g,h){this.arcLengthDivisions=200;this.aX=a;this.aY=b;this.xRadius=c;this.yRadius=d;this.aStartAngle=e;this.aEndAngle=f;this.aClockwise=g;this.aRotation=h||0}function wb(a){this.arcLengthDivisions=200;this.points=void 0===a?[]:a}function ec(a,b,c,d){this.arcLengthDivisions=200;this.v0=a;this.v1=b;this.v2=c;this.v3=d}function fc(a,b,c){this.arcLengthDivisions=200;this.v0=a;this.v1=b;this.v2=c}function Wc(a){Vc.call(this);this.currentPoint=new D;a&&this.fromPoints(a)}
function xb(){Wc.apply(this,arguments);this.holes=[]}function ee(){this.subPaths=[];this.currentPath=null}function fe(a){this.data=a}function Ue(a){this.manager=void 0!==a?a:oa}function ge(a){this.manager=void 0!==a?a:oa}function Ve(){this.type="StereoCamera";this.aspect=1;this.eyeSep=.064;this.cameraL=new ja;this.cameraL.layers.enable(1);this.cameraL.matrixAutoUpdate=!1;this.cameraR=new ja;this.cameraR.layers.enable(2);this.cameraR.matrixAutoUpdate=!1}function Xc(a,b,c){w.call(this);this.type="CubeCamera";
var d=new ja(90,1,a,b);d.up.set(0,-1,0);d.lookAt(new n(1,0,0));this.add(d);var e=new ja(90,1,a,b);e.up.set(0,-1,0);e.lookAt(new n(-1,0,0));this.add(e);var f=new ja(90,1,a,b);f.up.set(0,0,1);f.lookAt(new n(0,1,0));this.add(f);var g=new ja(90,1,a,b);g.up.set(0,0,-1);g.lookAt(new n(0,-1,0));this.add(g);var h=new ja(90,1,a,b);h.up.set(0,-1,0);h.lookAt(new n(0,0,1));this.add(h);var k=new ja(90,1,a,b);k.up.set(0,-1,0);k.lookAt(new n(0,0,-1));this.add(k);this.renderTarget=new Bb(c,c,{format:1022,magFilter:1006,
minFilter:1006});this.renderTarget.texture.name="CubeCamera";this.update=function(a,b){null===this.parent&&this.updateMatrixWorld();var c=this.renderTarget,l=c.texture.generateMipmaps;c.texture.generateMipmaps=!1;c.activeCubeFace=0;a.render(b,d,c);c.activeCubeFace=1;a.render(b,e,c);c.activeCubeFace=2;a.render(b,f,c);c.activeCubeFace=3;a.render(b,g,c);c.activeCubeFace=4;a.render(b,h,c);c.texture.generateMipmaps=l;c.activeCubeFace=5;a.render(b,k,c);a.setRenderTarget(null)};this.clear=function(a,b,c,
d){for(var e=this.renderTarget,f=0;6>f;f++)e.activeCubeFace=f,a.setRenderTarget(e),a.clear(b,c,d);a.setRenderTarget(null)}}function he(){w.call(this);this.type="AudioListener";this.context=ie.getContext();this.gain=this.context.createGain();this.gain.connect(this.context.destination);this.filter=null}function gc(a){w.call(this);this.type="Audio";this.context=a.context;this.gain=this.context.createGain();this.gain.connect(a.getInput());this.autoplay=!1;this.buffer=null;this.loop=!1;this.startTime=
0;this.playbackRate=1;this.isPlaying=!1;this.hasPlaybackControl=!0;this.sourceType="empty";this.filters=[]}function je(a){gc.call(this,a);this.panner=this.context.createPanner();this.panner.connect(this.gain)}function ke(a,b){this.analyser=a.context.createAnalyser();this.analyser.fftSize=void 0!==b?b:2048;this.data=new Uint8Array(this.analyser.frequencyBinCount);a.getOutput().connect(this.analyser)}function le(a,b,c){this.binding=a;this.valueSize=c;a=Float64Array;switch(b){case "quaternion":b=this._slerp;
break;case "string":case "bool":a=Array;b=this._select;break;default:b=this._lerp}this.buffer=new a(4*c);this._mixBufferRegion=b;this.referenceCount=this.useCount=this.cumulativeWeight=0}function We(a,b,c){c=c||da.parseTrackName(b);this._targetGroup=a;this._bindings=a.subscribe_(b,c)}function da(a,b,c){this.path=b;this.parsedPath=c||da.parseTrackName(b);this.node=da.findNode(a,this.parsedPath.nodeName)||a;this.rootNode=a}function Xe(a){this.uuid=R.generateUUID();this._objects=Array.prototype.slice.call(arguments);
this.nCachedObjects_=0;var b={};this._indicesByUUID=b;for(var c=0,d=arguments.length;c!==d;++c)b[arguments[c].uuid]=c;this._paths=[];this._parsedPaths=[];this._bindings=[];this._bindingsIndicesByPath={};var e=this;this.stats={objects:{get total(){return e._objects.length},get inUse(){return this.total-e.nCachedObjects_}},get bindingsPerObject(){return e._bindings.length}}}function Ye(a,b,c){this._mixer=a;this._clip=b;this._localRoot=c||null;a=b.tracks;b=a.length;c=Array(b);for(var d={endingStart:2400,
endingEnd:2400},e=0;e!==b;++e){var f=a[e].createInterpolant(null);c[e]=f;f.settings=d}this._interpolantSettings=d;this._interpolants=c;this._propertyBindings=Array(b);this._weightInterpolant=this._timeScaleInterpolant=this._byClipCacheIndex=this._cacheIndex=null;this.loop=2201;this._loopCount=-1;this._startTime=null;this.time=0;this._effectiveWeight=this.weight=this._effectiveTimeScale=this.timeScale=1;this.repetitions=Infinity;this.paused=!1;this.enabled=!0;this.clampWhenFinished=!1;this.zeroSlopeAtEnd=
this.zeroSlopeAtStart=!0}function Ze(a){this._root=a;this._initMemoryManager();this.time=this._accuIndex=0;this.timeScale=1}function Id(a,b){"string"===typeof a&&(console.warn("THREE.Uniform: Type parameter is no longer needed."),a=b);this.value=a}function me(){F.call(this);this.type="InstancedBufferGeometry";this.maxInstancedCount=void 0}function ne(a,b,c,d){this.uuid=R.generateUUID();this.data=a;this.itemSize=b;this.offset=c;this.normalized=!0===d}function hc(a,b){this.uuid=R.generateUUID();this.array=
a;this.stride=b;this.count=void 0!==a?a.length/b:0;this.dynamic=!1;this.updateRange={offset:0,count:-1};this.onUploadCallback=function(){};this.version=0}function oe(a,b,c){hc.call(this,a,b);this.meshPerAttribute=c||1}function pe(a,b,c){K.call(this,a,b);this.meshPerAttribute=c||1}function $e(a,b,c,d){this.ray=new hb(a,b);this.near=c||0;this.far=d||Infinity;this.params={Mesh:{},Line:{},LOD:{},Points:{threshold:1},Sprite:{}};Object.defineProperties(this.params,{PointCloud:{get:function(){console.warn("THREE.Raycaster: params.PointCloud has been renamed to params.Points.");
return this.Points}}})}function af(a,b){return a.distance-b.distance}function qe(a,b,c,d){if(!1!==a.visible&&(a.raycast(b,c),!0===d)){a=a.children;d=0;for(var e=a.length;d<e;d++)qe(a[d],b,c,!0)}}function bf(a){this.autoStart=void 0!==a?a:!0;this.elapsedTime=this.oldTime=this.startTime=0;this.running=!1}function cf(a,b,c){this.radius=void 0!==a?a:1;this.phi=void 0!==b?b:0;this.theta=void 0!==c?c:0;return this}function df(a,b,c){this.radius=void 0!==a?a:1;this.theta=void 0!==b?b:0;this.y=void 0!==c?
c:0;return this}function Yc(a){w.call(this);this.material=a;this.render=function(a){}}function Zc(a,b,c,d){this.object=a;this.size=void 0!==b?b:1;a=void 0!==c?c:16711680;d=void 0!==d?d:1;b=0;(c=this.object.geometry)&&c.isGeometry?b=3*c.faces.length:c&&c.isBufferGeometry&&(b=c.attributes.normal.count);c=new F;b=new z(6*b,3);c.addAttribute("position",b);X.call(this,c,new W({color:a,linewidth:d}));this.matrixAutoUpdate=!1;this.update()}function ic(a,b){w.call(this);this.light=a;this.light.updateMatrixWorld();
this.matrix=a.matrixWorld;this.matrixAutoUpdate=!1;this.color=b;a=new F;b=[0,0,0,0,0,1,0,0,0,1,0,1,0,0,0,-1,0,1,0,0,0,0,1,1,0,0,0,0,-1,1];for(var c=0,d=1;32>c;c++,d++){var e=c/32*Math.PI*2,f=d/32*Math.PI*2;b.push(Math.cos(e),Math.sin(e),1,Math.cos(f),Math.sin(f),1)}a.addAttribute("position",new z(b,3));b=new W({fog:!1});this.cone=new X(a,b);this.add(this.cone);this.update()}function ef(a){var b=[];a&&a.isBone&&b.push(a);for(var c=0;c<a.children.length;c++)b.push.apply(b,ef(a.children[c]));return b}
function jc(a){for(var b=ef(a),c=new F,d=[],e=[],f=new C(0,0,1),g=new C(0,1,0),h=0;h<b.length;h++){var k=b[h];k.parent&&k.parent.isBone&&(d.push(0,0,0),d.push(0,0,0),e.push(f.r,f.g,f.b),e.push(g.r,g.g,g.b))}c.addAttribute("position",new z(d,3));c.addAttribute("color",new z(e,3));d=new W({vertexColors:2,depthTest:!1,depthWrite:!1,transparent:!0});X.call(this,c,d);this.root=a;this.bones=b;this.matrix=a.matrixWorld;this.matrixAutoUpdate=!1;this.onBeforeRender()}function kc(a,b,c){this.light=a;this.light.updateMatrixWorld();
this.color=c;a=new kb(b,4,2);b=new sa({wireframe:!0,fog:!1});fa.call(this,a,b);this.matrix=this.light.matrixWorld;this.matrixAutoUpdate=!1;this.update()}function lc(a,b){w.call(this);this.light=a;this.light.updateMatrixWorld();this.matrix=a.matrixWorld;this.matrixAutoUpdate=!1;this.color=b;a=new W({fog:!1});b=new F;b.addAttribute("position",new K(new Float32Array(15),3));this.line=new ra(b,a);this.add(this.line);this.update()}function mc(a,b,c){w.call(this);this.light=a;this.light.updateMatrixWorld();
this.matrix=a.matrixWorld;this.matrixAutoUpdate=!1;this.color=c;a=new jb(b);a.rotateY(.5*Math.PI);this.material=new sa({wireframe:!0,fog:!1});void 0===this.color&&(this.material.vertexColors=2);b=a.getAttribute("position");b=new Float32Array(3*b.count);a.addAttribute("color",new K(b,3));this.add(new fa(a,this.material));this.update()}function $c(a,b,c,d){a=a||10;b=b||10;c=new C(void 0!==c?c:4473924);d=new C(void 0!==d?d:8947848);var e=b/2,f=a/b,g=a/2;a=[];for(var h=[],k=0,l=0,q=-g;k<=b;k++,q+=f){a.push(-g,
0,q,g,0,q);a.push(q,0,-g,q,0,g);var p=k===e?c:d;p.toArray(h,l);l+=3;p.toArray(h,l);l+=3;p.toArray(h,l);l+=3;p.toArray(h,l);l+=3}b=new F;b.addAttribute("position",new z(a,3));b.addAttribute("color",new z(h,3));c=new W({vertexColors:2});X.call(this,b,c)}function Jd(a,b,c,d,e,f){a=a||10;b=b||16;c=c||8;d=d||64;e=new C(void 0!==e?e:4473924);f=new C(void 0!==f?f:8947848);var g=[],h=[],k;for(k=0;k<=b;k++){var l=k/b*2*Math.PI;var q=Math.sin(l)*a;l=Math.cos(l)*a;g.push(0,0,0);g.push(q,0,l);var p=k&1?e:f;h.push(p.r,
p.g,p.b);h.push(p.r,p.g,p.b)}for(k=0;k<=c;k++){p=k&1?e:f;var m=a-a/c*k;for(b=0;b<d;b++)l=b/d*2*Math.PI,q=Math.sin(l)*m,l=Math.cos(l)*m,g.push(q,0,l),h.push(p.r,p.g,p.b),l=(b+1)/d*2*Math.PI,q=Math.sin(l)*m,l=Math.cos(l)*m,g.push(q,0,l),h.push(p.r,p.g,p.b)}a=new F;a.addAttribute("position",new z(g,3));a.addAttribute("color",new z(h,3));g=new W({vertexColors:2});X.call(this,a,g)}function ad(a,b,c,d){this.object=a;this.size=void 0!==b?b:1;a=void 0!==c?c:16776960;d=void 0!==d?d:1;b=0;(c=this.object.geometry)&&
c.isGeometry?b=c.faces.length:console.warn("THREE.FaceNormalsHelper: only THREE.Geometry is supported. Use THREE.VertexNormalsHelper, instead.");c=new F;b=new z(6*b,3);c.addAttribute("position",b);X.call(this,c,new W({color:a,linewidth:d}));this.matrixAutoUpdate=!1;this.update()}function nc(a,b,c){w.call(this);this.light=a;this.light.updateMatrixWorld();this.matrix=a.matrixWorld;this.matrixAutoUpdate=!1;this.color=c;void 0===b&&(b=1);a=new F;a.addAttribute("position",new z([-b,b,0,b,b,0,b,-b,0,-b,
-b,0,-b,b,0],3));b=new W({fog:!1});this.lightPlane=new ra(a,b);this.add(this.lightPlane);a=new F;a.addAttribute("position",new z([0,0,0,0,0,1],3));this.targetLine=new ra(a,b);this.add(this.targetLine);this.update()}function bd(a){function b(a,b,d){c(a,d);c(b,d)}function c(a,b){f.push(0,0,0);g.push(b.r,b.g,b.b);void 0===h[a]&&(h[a]=[]);h[a].push(f.length/3-1)}var d=new F,e=new W({color:16777215,vertexColors:1}),f=[],g=[],h={},k=new C(16755200),l=new C(16711680),q=new C(43775),p=new C(16777215),m=new C(3355443);
b("n1","n2",k);b("n2","n4",k);b("n4","n3",k);b("n3","n1",k);b("f1","f2",k);b("f2","f4",k);b("f4","f3",k);b("f3","f1",k);b("n1","f1",k);b("n2","f2",k);b("n3","f3",k);b("n4","f4",k);b("p","n1",l);b("p","n2",l);b("p","n3",l);b("p","n4",l);b("u1","u2",q);b("u2","u3",q);b("u3","u1",q);b("c","t",p);b("p","c",m);b("cn1","cn2",m);b("cn3","cn4",m);b("cf1","cf2",m);b("cf3","cf4",m);d.addAttribute("position",new z(f,3));d.addAttribute("color",new z(g,3));X.call(this,d,e);this.camera=a;this.camera.updateProjectionMatrix&&
this.camera.updateProjectionMatrix();this.matrix=a.matrixWorld;this.matrixAutoUpdate=!1;this.pointMap=h;this.update()}function yb(a,b){this.object=a;void 0===b&&(b=16776960);a=new Uint16Array([0,1,1,2,2,3,3,0,4,5,5,6,6,7,7,4,0,4,1,5,2,6,3,7]);var c=new Float32Array(24),d=new F;d.setIndex(new K(a,1));d.addAttribute("position",new K(c,3));X.call(this,d,new W({color:b}));this.matrixAutoUpdate=!1;this.update()}function cd(a,b){this.type="Box3Helper";this.box=a;a=void 0!==b?b:16776960;b=new Uint16Array([0,
1,1,2,2,3,3,0,4,5,5,6,6,7,7,4,0,4,1,5,2,6,3,7]);var c=new F;c.setIndex(new K(b,1));c.addAttribute("position",new z([1,1,1,-1,1,1,-1,-1,1,1,-1,1,1,1,-1,-1,1,-1,-1,-1,-1,1,-1,-1],3));X.call(this,c,new W({color:a}));this.geometry.computeBoundingSphere();this.onBeforeRender()}function dd(a,b,c){this.type="PlaneHelper";this.plane=a;this.size=void 0===b?1:b;a=void 0!==c?c:16776960;b=new F;b.addAttribute("position",new z([1,-1,1,-1,1,1,-1,-1,1,1,1,1,-1,1,1,-1,-1,1,1,-1,1,1,1,1,0,0,1,0,0,0],3));b.computeBoundingSphere();
ra.call(this,b,new W({color:a}));b=new F;b.addAttribute("position",new z([1,1,1,-1,1,1,-1,-1,1,1,1,1,-1,-1,1,1,-1,1],3));b.computeBoundingSphere();this.add(new fa(b,new sa({color:a,opacity:.2,transparent:!0,depthWrite:!1})));this.onBeforeRender()}function zb(a,b,c,d,e,f){w.call(this);void 0===d&&(d=16776960);void 0===c&&(c=1);void 0===e&&(e=.2*c);void 0===f&&(f=.2*e);void 0===Kd&&(Kd=new F,Kd.addAttribute("position",new z([0,0,0,0,1,0],3)),re=new Ta(0,.5,1,5,1),re.translate(0,-.5,0));this.position.copy(b);
this.line=new ra(Kd,new W({color:d}));this.line.matrixAutoUpdate=!1;this.add(this.line);this.cone=new fa(re,new sa({color:d}));this.cone.matrixAutoUpdate=!1;this.add(this.cone);this.setDirection(a);this.setLength(c,e,f)}function Ld(a){a=a||1;var b=[0,0,0,a,0,0,0,0,0,0,a,0,0,0,0,0,0,a];a=new F;a.addAttribute("position",new z(b,3));a.addAttribute("color",new z([1,0,0,1,.6,0,0,1,0,.6,1,0,0,0,1,0,.6,1],3));b=new W({vertexColors:2});X.call(this,a,b)}function se(){var a=0,b=0,c=0,d=0;return{initCatmullRom:function(e,
f,g,h,k){e=k*(g-e);h=k*(h-f);a=f;b=e;c=-3*f+3*g-2*e-h;d=2*f-2*g+e+h},initNonuniformCatmullRom:function(e,f,g,h,k,l,q){e=((f-e)/k-(g-e)/(k+l)+(g-f)/l)*l;h=((g-f)/l-(h-f)/(l+q)+(h-g)/q)*l;a=f;b=e;c=-3*f+3*g-2*e-h;d=2*f-2*g+e+h},calc:function(e){var f=e*e;return a+b*e+c*f+d*f*e}}}function Ja(a){this.arcLengthDivisions=200;2>a.length&&console.warn("THREE.CatmullRomCurve3: Points array needs at least two entries.");this.points=a||[];this.closed=!1}function ed(a,b,c,d){this.arcLengthDivisions=200;this.v0=
a;this.v1=b;this.v2=c;this.v3=d}function fd(a,b,c){this.arcLengthDivisions=200;this.v0=a;this.v1=b;this.v2=c}function gd(a,b){this.arcLengthDivisions=200;this.v1=a;this.v2=b}function Md(a,b,c,d,e,f){Ua.call(this,a,b,c,c,d,e,f)}function ff(a){console.warn("THREE.ClosedSplineCurve3 has been deprecated. Use THREE.CatmullRomCurve3 instead.");Ja.call(this,a);this.type="catmullrom";this.closed=!0}function gf(a){console.warn("THREE.SplineCurve3 has been deprecated. Use THREE.CatmullRomCurve3 instead.");
Ja.call(this,a);this.type="catmullrom"}function te(a){console.warn("THREE.Spline has been removed. Use THREE.CatmullRomCurve3 instead.");Ja.call(this,a);this.type="catmullrom"}void 0===Number.EPSILON&&(Number.EPSILON=Math.pow(2,-52));void 0===Number.isInteger&&(Number.isInteger=function(a){return"number"===typeof a&&isFinite(a)&&Math.floor(a)===a});void 0===Math.sign&&(Math.sign=function(a){return 0>a?-1:0<a?1:+a});void 0===Function.prototype.name&&Object.defineProperty(Function.prototype,"name",
{get:function(){return this.toString().match(/^\s*function\s*([^\(\s]*)/)[1]}});void 0===Object.assign&&function(){Object.assign=function(a){if(void 0===a||null===a)throw new TypeError("Cannot convert undefined or null to object");for(var b=Object(a),c=1;c<arguments.length;c++){var d=arguments[c];if(void 0!==d&&null!==d)for(var e in d)Object.prototype.hasOwnProperty.call(d,e)&&(b[e]=d[e])}return b}}();Object.assign(na.prototype,{addEventListener:function(a,b){void 0===this._listeners&&(this._listeners=
{});var c=this._listeners;void 0===c[a]&&(c[a]=[]);-1===c[a].indexOf(b)&&c[a].push(b)},hasEventListener:function(a,b){if(void 0===this._listeners)return!1;var c=this._listeners;return void 0!==c[a]&&-1!==c[a].indexOf(b)},removeEventListener:function(a,b){void 0!==this._listeners&&(a=this._listeners[a],void 0!==a&&(b=a.indexOf(b),-1!==b&&a.splice(b,1)))},dispatchEvent:function(a){if(void 0!==this._listeners){var b=this._listeners[a.type];if(void 0!==b){a.target=this;for(var b=b.slice(0),c=0,d=b.length;c<
d;c++)b[c].call(this,a)}}}});var R={DEG2RAD:Math.PI/180,RAD2DEG:180/Math.PI,generateUUID:function(){var a="0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz".split(""),b=Array(36),c=0,d;return function(){for(var e=0;36>e;e++)8===e||13===e||18===e||23===e?b[e]="-":14===e?b[e]="4":(2>=c&&(c=33554432+16777216*Math.random()|0),d=c&15,c>>=4,b[e]=a[19===e?d&3|8:d]);return b.join("")}}(),clamp:function(a,b,c){return Math.max(b,Math.min(c,a))},euclideanModulo:function(a,b){return(a%b+b)%b},mapLinear:function(a,
b,c,d,e){return d+(a-b)*(e-d)/(c-b)},lerp:function(a,b,c){return(1-c)*a+c*b},smoothstep:function(a,b,c){if(a<=b)return 0;if(a>=c)return 1;a=(a-b)/(c-b);return a*a*(3-2*a)},smootherstep:function(a,b,c){if(a<=b)return 0;if(a>=c)return 1;a=(a-b)/(c-b);return a*a*a*(a*(6*a-15)+10)},randInt:function(a,b){return a+Math.floor(Math.random()*(b-a+1))},randFloat:function(a,b){return a+Math.random()*(b-a)},randFloatSpread:function(a){return a*(.5-Math.random())},degToRad:function(a){return a*R.DEG2RAD},radToDeg:function(a){return a*
R.RAD2DEG},isPowerOfTwo:function(a){return 0===(a&a-1)&&0!==a},nearestPowerOfTwo:function(a){return Math.pow(2,Math.round(Math.log(a)/Math.LN2))},nextPowerOfTwo:function(a){a--;a|=a>>1;a|=a>>2;a|=a>>4;a|=a>>8;a|=a>>16;a++;return a}};Object.defineProperties(D.prototype,{width:{get:function(){return this.x},set:function(a){this.x=a}},height:{get:function(){return this.y},set:function(a){this.y=a}}});Object.assign(D.prototype,{isVector2:!0,set:function(a,b){this.x=a;this.y=b;return this},setScalar:function(a){this.y=
this.x=a;return this},setX:function(a){this.x=a;return this},setY:function(a){this.y=a;return this},setComponent:function(a,b){switch(a){case 0:this.x=b;break;case 1:this.y=b;break;default:throw Error("index is out of range: "+a);}return this},getComponent:function(a){switch(a){case 0:return this.x;case 1:return this.y;default:throw Error("index is out of range: "+a);}},clone:function(){return new this.constructor(this.x,this.y)},copy:function(a){this.x=a.x;this.y=a.y;return this},add:function(a,
b){if(void 0!==b)return console.warn("THREE.Vector2: .add() now only accepts one argument. Use .addVectors( a, b ) instead."),this.addVectors(a,b);this.x+=a.x;this.y+=a.y;return this},addScalar:function(a){this.x+=a;this.y+=a;return this},addVectors:function(a,b){this.x=a.x+b.x;this.y=a.y+b.y;return this},addScaledVector:function(a,b){this.x+=a.x*b;this.y+=a.y*b;return this},sub:function(a,b){if(void 0!==b)return console.warn("THREE.Vector2: .sub() now only accepts one argument. Use .subVectors( a, b ) instead."),
this.subVectors(a,b);this.x-=a.x;this.y-=a.y;return this},subScalar:function(a){this.x-=a;this.y-=a;return this},subVectors:function(a,b){this.x=a.x-b.x;this.y=a.y-b.y;return this},multiply:function(a){this.x*=a.x;this.y*=a.y;return this},multiplyScalar:function(a){this.x*=a;this.y*=a;return this},divide:function(a){this.x/=a.x;this.y/=a.y;return this},divideScalar:function(a){return this.multiplyScalar(1/a)},min:function(a){this.x=Math.min(this.x,a.x);this.y=Math.min(this.y,a.y);return this},max:function(a){this.x=
Math.max(this.x,a.x);this.y=Math.max(this.y,a.y);return this},clamp:function(a,b){this.x=Math.max(a.x,Math.min(b.x,this.x));this.y=Math.max(a.y,Math.min(b.y,this.y));return this},clampScalar:function(){var a=new D,b=new D;return function(c,d){a.set(c,c);b.set(d,d);return this.clamp(a,b)}}(),clampLength:function(a,b){var c=this.length();return this.divideScalar(c||1).multiplyScalar(Math.max(a,Math.min(b,c)))},floor:function(){this.x=Math.floor(this.x);this.y=Math.floor(this.y);return this},ceil:function(){this.x=
Math.ceil(this.x);this.y=Math.ceil(this.y);return this},round:function(){this.x=Math.round(this.x);this.y=Math.round(this.y);return this},roundToZero:function(){this.x=0>this.x?Math.ceil(this.x):Math.floor(this.x);this.y=0>this.y?Math.ceil(this.y):Math.floor(this.y);return this},negate:function(){this.x=-this.x;this.y=-this.y;return this},dot:function(a){return this.x*a.x+this.y*a.y},lengthSq:function(){return this.x*this.x+this.y*this.y},length:function(){return Math.sqrt(this.x*this.x+this.y*this.y)},
lengthManhattan:function(){return Math.abs(this.x)+Math.abs(this.y)},normalize:function(){return this.divideScalar(this.length()||1)},angle:function(){var a=Math.atan2(this.y,this.x);0>a&&(a+=2*Math.PI);return a},distanceTo:function(a){return Math.sqrt(this.distanceToSquared(a))},distanceToSquared:function(a){var b=this.x-a.x;a=this.y-a.y;return b*b+a*a},distanceToManhattan:function(a){return Math.abs(this.x-a.x)+Math.abs(this.y-a.y)},setLength:function(a){return this.normalize().multiplyScalar(a)},
lerp:function(a,b){this.x+=(a.x-this.x)*b;this.y+=(a.y-this.y)*b;return this},lerpVectors:function(a,b,c){return this.subVectors(b,a).multiplyScalar(c).add(a)},equals:function(a){return a.x===this.x&&a.y===this.y},fromArray:function(a,b){void 0===b&&(b=0);this.x=a[b];this.y=a[b+1];return this},toArray:function(a,b){void 0===a&&(a=[]);void 0===b&&(b=0);a[b]=this.x;a[b+1]=this.y;return a},fromBufferAttribute:function(a,b,c){void 0!==c&&console.warn("THREE.Vector2: offset has been removed from .fromBufferAttribute().");
this.x=a.getX(b);this.y=a.getY(b);return this},rotateAround:function(a,b){var c=Math.cos(b);b=Math.sin(b);var d=this.x-a.x,e=this.y-a.y;this.x=d*c-e*b+a.x;this.y=d*b+e*c+a.y;return this}});var lf=0;N.DEFAULT_IMAGE=void 0;N.DEFAULT_MAPPING=300;Object.defineProperty(N.prototype,"needsUpdate",{set:function(a){!0===a&&this.version++}});Object.assign(N.prototype,na.prototype,{constructor:N,isTexture:!0,clone:function(){return(new this.constructor).copy(this)},copy:function(a){this.name=a.name;this.image=
a.image;this.mipmaps=a.mipmaps.slice(0);this.mapping=a.mapping;this.wrapS=a.wrapS;this.wrapT=a.wrapT;this.magFilter=a.magFilter;this.minFilter=a.minFilter;this.anisotropy=a.anisotropy;this.format=a.format;this.type=a.type;this.offset.copy(a.offset);this.repeat.copy(a.repeat);this.generateMipmaps=a.generateMipmaps;this.premultiplyAlpha=a.premultiplyAlpha;this.flipY=a.flipY;this.unpackAlignment=a.unpackAlignment;this.encoding=a.encoding;return this},toJSON:function(a){if(void 0!==a.textures[this.uuid])return a.textures[this.uuid];
var b={metadata:{version:4.5,type:"Texture",generator:"Texture.toJSON"},uuid:this.uuid,name:this.name,mapping:this.mapping,repeat:[this.repeat.x,this.repeat.y],offset:[this.offset.x,this.offset.y],wrap:[this.wrapS,this.wrapT],minFilter:this.minFilter,magFilter:this.magFilter,anisotropy:this.anisotropy,flipY:this.flipY};if(void 0!==this.image){var c=this.image;void 0===c.uuid&&(c.uuid=R.generateUUID());if(void 0===a.images[c.uuid]){var d=a.images,e=c.uuid,f=c.uuid;if(c instanceof HTMLCanvasElement)var g=
c;else{g=document.createElementNS("http://www.w3.org/1999/xhtml","canvas");g.width=c.width;g.height=c.height;var h=g.getContext("2d");c instanceof ImageData?h.putImageData(c,0,0):h.drawImage(c,0,0,c.width,c.height)}g=2048<g.width||2048<g.height?g.toDataURL("image/jpeg",.6):g.toDataURL("image/png");d[e]={uuid:f,url:g}}b.image=c.uuid}return a.textures[this.uuid]=b},dispose:function(){this.dispatchEvent({type:"dispose"})},transformUv:function(a){if(300===this.mapping){a.multiply(this.repeat);a.add(this.offset);
if(0>a.x||1<a.x)switch(this.wrapS){case 1E3:a.x-=Math.floor(a.x);break;case 1001:a.x=0>a.x?0:1;break;case 1002:a.x=1===Math.abs(Math.floor(a.x)%2)?Math.ceil(a.x)-a.x:a.x-Math.floor(a.x)}if(0>a.y||1<a.y)switch(this.wrapT){case 1E3:a.y-=Math.floor(a.y);break;case 1001:a.y=0>a.y?0:1;break;case 1002:a.y=1===Math.abs(Math.floor(a.y)%2)?Math.ceil(a.y)-a.y:a.y-Math.floor(a.y)}this.flipY&&(a.y=1-a.y)}}});Object.assign(S.prototype,{isVector4:!0,set:function(a,b,c,d){this.x=a;this.y=b;this.z=c;this.w=d;return this},
setScalar:function(a){this.w=this.z=this.y=this.x=a;return this},setX:function(a){this.x=a;return this},setY:function(a){this.y=a;return this},setZ:function(a){this.z=a;return this},setW:function(a){this.w=a;return this},setComponent:function(a,b){switch(a){case 0:this.x=b;break;case 1:this.y=b;break;case 2:this.z=b;break;case 3:this.w=b;break;default:throw Error("index is out of range: "+a);}return this},getComponent:function(a){switch(a){case 0:return this.x;case 1:return this.y;case 2:return this.z;
case 3:return this.w;default:throw Error("index is out of range: "+a);}},clone:function(){return new this.constructor(this.x,this.y,this.z,this.w)},copy:function(a){this.x=a.x;this.y=a.y;this.z=a.z;this.w=void 0!==a.w?a.w:1;return this},add:function(a,b){if(void 0!==b)return console.warn("THREE.Vector4: .add() now only accepts one argument. Use .addVectors( a, b ) instead."),this.addVectors(a,b);this.x+=a.x;this.y+=a.y;this.z+=a.z;this.w+=a.w;return this},addScalar:function(a){this.x+=a;this.y+=a;
this.z+=a;this.w+=a;return this},addVectors:function(a,b){this.x=a.x+b.x;this.y=a.y+b.y;this.z=a.z+b.z;this.w=a.w+b.w;return this},addScaledVector:function(a,b){this.x+=a.x*b;this.y+=a.y*b;this.z+=a.z*b;this.w+=a.w*b;return this},sub:function(a,b){if(void 0!==b)return console.warn("THREE.Vector4: .sub() now only accepts one argument. Use .subVectors( a, b ) instead."),this.subVectors(a,b);this.x-=a.x;this.y-=a.y;this.z-=a.z;this.w-=a.w;return this},subScalar:function(a){this.x-=a;this.y-=a;this.z-=
a;this.w-=a;return this},subVectors:function(a,b){this.x=a.x-b.x;this.y=a.y-b.y;this.z=a.z-b.z;this.w=a.w-b.w;return this},multiplyScalar:function(a){this.x*=a;this.y*=a;this.z*=a;this.w*=a;return this},applyMatrix4:function(a){var b=this.x,c=this.y,d=this.z,e=this.w;a=a.elements;this.x=a[0]*b+a[4]*c+a[8]*d+a[12]*e;this.y=a[1]*b+a[5]*c+a[9]*d+a[13]*e;this.z=a[2]*b+a[6]*c+a[10]*d+a[14]*e;this.w=a[3]*b+a[7]*c+a[11]*d+a[15]*e;return this},divideScalar:function(a){return this.multiplyScalar(1/a)},setAxisAngleFromQuaternion:function(a){this.w=
2*Math.acos(a.w);var b=Math.sqrt(1-a.w*a.w);1E-4>b?(this.x=1,this.z=this.y=0):(this.x=a.x/b,this.y=a.y/b,this.z=a.z/b);return this},setAxisAngleFromRotationMatrix:function(a){a=a.elements;var b=a[0];var c=a[4];var d=a[8],e=a[1],f=a[5],g=a[9];var h=a[2];var k=a[6];var l=a[10];if(.01>Math.abs(c-e)&&.01>Math.abs(d-h)&&.01>Math.abs(g-k)){if(.1>Math.abs(c+e)&&.1>Math.abs(d+h)&&.1>Math.abs(g+k)&&.1>Math.abs(b+f+l-3))return this.set(1,0,0,0),this;a=Math.PI;b=(b+1)/2;f=(f+1)/2;l=(l+1)/2;c=(c+e)/4;d=(d+h)/
4;g=(g+k)/4;b>f&&b>l?.01>b?(k=0,c=h=.707106781):(k=Math.sqrt(b),h=c/k,c=d/k):f>l?.01>f?(k=.707106781,h=0,c=.707106781):(h=Math.sqrt(f),k=c/h,c=g/h):.01>l?(h=k=.707106781,c=0):(c=Math.sqrt(l),k=d/c,h=g/c);this.set(k,h,c,a);return this}a=Math.sqrt((k-g)*(k-g)+(d-h)*(d-h)+(e-c)*(e-c));.001>Math.abs(a)&&(a=1);this.x=(k-g)/a;this.y=(d-h)/a;this.z=(e-c)/a;this.w=Math.acos((b+f+l-1)/2);return this},min:function(a){this.x=Math.min(this.x,a.x);this.y=Math.min(this.y,a.y);this.z=Math.min(this.z,a.z);this.w=
Math.min(this.w,a.w);return this},max:function(a){this.x=Math.max(this.x,a.x);this.y=Math.max(this.y,a.y);this.z=Math.max(this.z,a.z);this.w=Math.max(this.w,a.w);return this},clamp:function(a,b){this.x=Math.max(a.x,Math.min(b.x,this.x));this.y=Math.max(a.y,Math.min(b.y,this.y));this.z=Math.max(a.z,Math.min(b.z,this.z));this.w=Math.max(a.w,Math.min(b.w,this.w));return this},clampScalar:function(){var a,b;return function(c,d){void 0===a&&(a=new S,b=new S);a.set(c,c,c,c);b.set(d,d,d,d);return this.clamp(a,
b)}}(),clampLength:function(a,b){var c=this.length();return this.divideScalar(c||1).multiplyScalar(Math.max(a,Math.min(b,c)))},floor:function(){this.x=Math.floor(this.x);this.y=Math.floor(this.y);this.z=Math.floor(this.z);this.w=Math.floor(this.w);return this},ceil:function(){this.x=Math.ceil(this.x);this.y=Math.ceil(this.y);this.z=Math.ceil(this.z);this.w=Math.ceil(this.w);return this},round:function(){this.x=Math.round(this.x);this.y=Math.round(this.y);this.z=Math.round(this.z);this.w=Math.round(this.w);
return this},roundToZero:function(){this.x=0>this.x?Math.ceil(this.x):Math.floor(this.x);this.y=0>this.y?Math.ceil(this.y):Math.floor(this.y);this.z=0>this.z?Math.ceil(this.z):Math.floor(this.z);this.w=0>this.w?Math.ceil(this.w):Math.floor(this.w);return this},negate:function(){this.x=-this.x;this.y=-this.y;this.z=-this.z;this.w=-this.w;return this},dot:function(a){return this.x*a.x+this.y*a.y+this.z*a.z+this.w*a.w},lengthSq:function(){return this.x*this.x+this.y*this.y+this.z*this.z+this.w*this.w},
length:function(){return Math.sqrt(this.x*this.x+this.y*this.y+this.z*this.z+this.w*this.w)},lengthManhattan:function(){return Math.abs(this.x)+Math.abs(this.y)+Math.abs(this.z)+Math.abs(this.w)},normalize:function(){return this.divideScalar(this.length()||1)},setLength:function(a){return this.normalize().multiplyScalar(a)},lerp:function(a,b){this.x+=(a.x-this.x)*b;this.y+=(a.y-this.y)*b;this.z+=(a.z-this.z)*b;this.w+=(a.w-this.w)*b;return this},lerpVectors:function(a,b,c){return this.subVectors(b,
a).multiplyScalar(c).add(a)},equals:function(a){return a.x===this.x&&a.y===this.y&&a.z===this.z&&a.w===this.w},fromArray:function(a,b){void 0===b&&(b=0);this.x=a[b];this.y=a[b+1];this.z=a[b+2];this.w=a[b+3];return this},toArray:function(a,b){void 0===a&&(a=[]);void 0===b&&(b=0);a[b]=this.x;a[b+1]=this.y;a[b+2]=this.z;a[b+3]=this.w;return a},fromBufferAttribute:function(a,b,c){void 0!==c&&console.warn("THREE.Vector4: offset has been removed from .fromBufferAttribute().");this.x=a.getX(b);this.y=a.getY(b);
this.z=a.getZ(b);this.w=a.getW(b);return this}});Object.assign(Ab.prototype,na.prototype,{isWebGLRenderTarget:!0,setSize:function(a,b){if(this.width!==a||this.height!==b)this.width=a,this.height=b,this.dispose();this.viewport.set(0,0,a,b);this.scissor.set(0,0,a,b)},clone:function(){return(new this.constructor).copy(this)},copy:function(a){this.width=a.width;this.height=a.height;this.viewport.copy(a.viewport);this.texture=a.texture.clone();this.depthBuffer=a.depthBuffer;this.stencilBuffer=a.stencilBuffer;
this.depthTexture=a.depthTexture;return this},dispose:function(){this.dispatchEvent({type:"dispose"})}});Bb.prototype=Object.create(Ab.prototype);Bb.prototype.constructor=Bb;Bb.prototype.isWebGLRenderTargetCube=!0;Object.assign(ia,{slerp:function(a,b,c,d){return c.copy(a).slerp(b,d)},slerpFlat:function(a,b,c,d,e,f,g){var h=c[d+0],k=c[d+1],l=c[d+2];c=c[d+3];d=e[f+0];var q=e[f+1],p=e[f+2];e=e[f+3];if(c!==e||h!==d||k!==q||l!==p){f=1-g;var m=h*d+k*q+l*p+c*e,r=0<=m?1:-1,n=1-m*m;n>Number.EPSILON&&(n=Math.sqrt(n),
m=Math.atan2(n,m*r),f=Math.sin(f*m)/n,g=Math.sin(g*m)/n);r*=g;h=h*f+d*r;k=k*f+q*r;l=l*f+p*r;c=c*f+e*r;f===1-g&&(g=1/Math.sqrt(h*h+k*k+l*l+c*c),h*=g,k*=g,l*=g,c*=g)}a[b]=h;a[b+1]=k;a[b+2]=l;a[b+3]=c}});Object.defineProperties(ia.prototype,{x:{get:function(){return this._x},set:function(a){this._x=a;this.onChangeCallback()}},y:{get:function(){return this._y},set:function(a){this._y=a;this.onChangeCallback()}},z:{get:function(){return this._z},set:function(a){this._z=a;this.onChangeCallback()}},w:{get:function(){return this._w},
set:function(a){this._w=a;this.onChangeCallback()}}});Object.assign(ia.prototype,{set:function(a,b,c,d){this._x=a;this._y=b;this._z=c;this._w=d;this.onChangeCallback();return this},clone:function(){return new this.constructor(this._x,this._y,this._z,this._w)},copy:function(a){this._x=a.x;this._y=a.y;this._z=a.z;this._w=a.w;this.onChangeCallback();return this},setFromEuler:function(a,b){if(!a||!a.isEuler)throw Error("THREE.Quaternion: .setFromEuler() now expects an Euler rotation rather than a Vector3 and order.");
var c=a._x,d=a._y,e=a._z;a=a.order;var f=Math.cos,g=Math.sin,h=f(c/2),k=f(d/2),f=f(e/2),c=g(c/2),d=g(d/2),e=g(e/2);"XYZ"===a?(this._x=c*k*f+h*d*e,this._y=h*d*f-c*k*e,this._z=h*k*e+c*d*f,this._w=h*k*f-c*d*e):"YXZ"===a?(this._x=c*k*f+h*d*e,this._y=h*d*f-c*k*e,this._z=h*k*e-c*d*f,this._w=h*k*f+c*d*e):"ZXY"===a?(this._x=c*k*f-h*d*e,this._y=h*d*f+c*k*e,this._z=h*k*e+c*d*f,this._w=h*k*f-c*d*e):"ZYX"===a?(this._x=c*k*f-h*d*e,this._y=h*d*f+c*k*e,this._z=h*k*e-c*d*f,this._w=h*k*f+c*d*e):"YZX"===a?(this._x=
c*k*f+h*d*e,this._y=h*d*f+c*k*e,this._z=h*k*e-c*d*f,this._w=h*k*f-c*d*e):"XZY"===a&&(this._x=c*k*f-h*d*e,this._y=h*d*f-c*k*e,this._z=h*k*e+c*d*f,this._w=h*k*f+c*d*e);if(!1!==b)this.onChangeCallback();return this},setFromAxisAngle:function(a,b){b/=2;var c=Math.sin(b);this._x=a.x*c;this._y=a.y*c;this._z=a.z*c;this._w=Math.cos(b);this.onChangeCallback();return this},setFromRotationMatrix:function(a){var b=a.elements,c=b[0];a=b[4];var d=b[8],e=b[1],f=b[5],g=b[9],h=b[2],k=b[6],b=b[10],l=c+f+b;0<l?(c=.5/
Math.sqrt(l+1),this._w=.25/c,this._x=(k-g)*c,this._y=(d-h)*c,this._z=(e-a)*c):c>f&&c>b?(c=2*Math.sqrt(1+c-f-b),this._w=(k-g)/c,this._x=.25*c,this._y=(a+e)/c,this._z=(d+h)/c):f>b?(c=2*Math.sqrt(1+f-c-b),this._w=(d-h)/c,this._x=(a+e)/c,this._y=.25*c,this._z=(g+k)/c):(c=2*Math.sqrt(1+b-c-f),this._w=(e-a)/c,this._x=(d+h)/c,this._y=(g+k)/c,this._z=.25*c);this.onChangeCallback();return this},setFromUnitVectors:function(){var a=new n,b;return function(c,d){void 0===a&&(a=new n);b=c.dot(d)+1;1E-6>b?(b=0,
Math.abs(c.x)>Math.abs(c.z)?a.set(-c.y,c.x,0):a.set(0,-c.z,c.y)):a.crossVectors(c,d);this._x=a.x;this._y=a.y;this._z=a.z;this._w=b;return this.normalize()}}(),inverse:function(){return this.conjugate().normalize()},conjugate:function(){this._x*=-1;this._y*=-1;this._z*=-1;this.onChangeCallback();return this},dot:function(a){return this._x*a._x+this._y*a._y+this._z*a._z+this._w*a._w},lengthSq:function(){return this._x*this._x+this._y*this._y+this._z*this._z+this._w*this._w},length:function(){return Math.sqrt(this._x*
this._x+this._y*this._y+this._z*this._z+this._w*this._w)},normalize:function(){var a=this.length();0===a?(this._z=this._y=this._x=0,this._w=1):(a=1/a,this._x*=a,this._y*=a,this._z*=a,this._w*=a);this.onChangeCallback();return this},multiply:function(a,b){return void 0!==b?(console.warn("THREE.Quaternion: .multiply() now only accepts one argument. Use .multiplyQuaternions( a, b ) instead."),this.multiplyQuaternions(a,b)):this.multiplyQuaternions(this,a)},premultiply:function(a){return this.multiplyQuaternions(a,
this)},multiplyQuaternions:function(a,b){var c=a._x,d=a._y,e=a._z;a=a._w;var f=b._x,g=b._y,h=b._z;b=b._w;this._x=c*b+a*f+d*h-e*g;this._y=d*b+a*g+e*f-c*h;this._z=e*b+a*h+c*g-d*f;this._w=a*b-c*f-d*g-e*h;this.onChangeCallback();return this},slerp:function(a,b){if(0===b)return this;if(1===b)return this.copy(a);var c=this._x,d=this._y,e=this._z,f=this._w,g=f*a._w+c*a._x+d*a._y+e*a._z;0>g?(this._w=-a._w,this._x=-a._x,this._y=-a._y,this._z=-a._z,g=-g):this.copy(a);if(1<=g)return this._w=f,this._x=c,this._y=
d,this._z=e,this;a=Math.sqrt(1-g*g);if(.001>Math.abs(a))return this._w=.5*(f+this._w),this._x=.5*(c+this._x),this._y=.5*(d+this._y),this._z=.5*(e+this._z),this;var h=Math.atan2(a,g),g=Math.sin((1-b)*h)/a;b=Math.sin(b*h)/a;this._w=f*g+this._w*b;this._x=c*g+this._x*b;this._y=d*g+this._y*b;this._z=e*g+this._z*b;this.onChangeCallback();return this},equals:function(a){return a._x===this._x&&a._y===this._y&&a._z===this._z&&a._w===this._w},fromArray:function(a,b){void 0===b&&(b=0);this._x=a[b];this._y=a[b+
1];this._z=a[b+2];this._w=a[b+3];this.onChangeCallback();return this},toArray:function(a,b){void 0===a&&(a=[]);void 0===b&&(b=0);a[b]=this._x;a[b+1]=this._y;a[b+2]=this._z;a[b+3]=this._w;return a},onChange:function(a){this.onChangeCallback=a;return this},onChangeCallback:function(){}});Object.assign(n.prototype,{isVector3:!0,set:function(a,b,c){this.x=a;this.y=b;this.z=c;return this},setScalar:function(a){this.z=this.y=this.x=a;return this},setX:function(a){this.x=a;return this},setY:function(a){this.y=
a;return this},setZ:function(a){this.z=a;return this},setComponent:function(a,b){switch(a){case 0:this.x=b;break;case 1:this.y=b;break;case 2:this.z=b;break;default:throw Error("index is out of range: "+a);}return this},getComponent:function(a){switch(a){case 0:return this.x;case 1:return this.y;case 2:return this.z;default:throw Error("index is out of range: "+a);}},clone:function(){return new this.constructor(this.x,this.y,this.z)},copy:function(a){this.x=a.x;this.y=a.y;this.z=a.z;return this},
add:function(a,b){if(void 0!==b)return console.warn("THREE.Vector3: .add() now only accepts one argument. Use .addVectors( a, b ) instead."),this.addVectors(a,b);this.x+=a.x;this.y+=a.y;this.z+=a.z;return this},addScalar:function(a){this.x+=a;this.y+=a;this.z+=a;return this},addVectors:function(a,b){this.x=a.x+b.x;this.y=a.y+b.y;this.z=a.z+b.z;return this},addScaledVector:function(a,b){this.x+=a.x*b;this.y+=a.y*b;this.z+=a.z*b;return this},sub:function(a,b){if(void 0!==b)return console.warn("THREE.Vector3: .sub() now only accepts one argument. Use .subVectors( a, b ) instead."),
this.subVectors(a,b);this.x-=a.x;this.y-=a.y;this.z-=a.z;return this},subScalar:function(a){this.x-=a;this.y-=a;this.z-=a;return this},subVectors:function(a,b){this.x=a.x-b.x;this.y=a.y-b.y;this.z=a.z-b.z;return this},multiply:function(a,b){if(void 0!==b)return console.warn("THREE.Vector3: .multiply() now only accepts one argument. Use .multiplyVectors( a, b ) instead."),this.multiplyVectors(a,b);this.x*=a.x;this.y*=a.y;this.z*=a.z;return this},multiplyScalar:function(a){this.x*=a;this.y*=a;this.z*=
a;return this},multiplyVectors:function(a,b){this.x=a.x*b.x;this.y=a.y*b.y;this.z=a.z*b.z;return this},applyEuler:function(){var a=new ia;return function(b){b&&b.isEuler||console.error("THREE.Vector3: .applyEuler() now expects an Euler rotation rather than a Vector3 and order.");return this.applyQuaternion(a.setFromEuler(b))}}(),applyAxisAngle:function(){var a=new ia;return function(b,c){return this.applyQuaternion(a.setFromAxisAngle(b,c))}}(),applyMatrix3:function(a){var b=this.x,c=this.y,d=this.z;
a=a.elements;this.x=a[0]*b+a[3]*c+a[6]*d;this.y=a[1]*b+a[4]*c+a[7]*d;this.z=a[2]*b+a[5]*c+a[8]*d;return this},applyMatrix4:function(a){var b=this.x,c=this.y,d=this.z;a=a.elements;var e=1/(a[3]*b+a[7]*c+a[11]*d+a[15]);this.x=(a[0]*b+a[4]*c+a[8]*d+a[12])*e;this.y=(a[1]*b+a[5]*c+a[9]*d+a[13])*e;this.z=(a[2]*b+a[6]*c+a[10]*d+a[14])*e;return this},applyQuaternion:function(a){var b=this.x,c=this.y,d=this.z,e=a.x,f=a.y,g=a.z;a=a.w;var h=a*b+f*d-g*c,k=a*c+g*b-e*d,l=a*d+e*c-f*b,b=-e*b-f*c-g*d;this.x=h*a+b*
-e+k*-g-l*-f;this.y=k*a+b*-f+l*-e-h*-g;this.z=l*a+b*-g+h*-f-k*-e;return this},project:function(){var a=new O;return function(b){a.multiplyMatrices(b.projectionMatrix,a.getInverse(b.matrixWorld));return this.applyMatrix4(a)}}(),unproject:function(){var a=new O;return function(b){a.multiplyMatrices(b.matrixWorld,a.getInverse(b.projectionMatrix));return this.applyMatrix4(a)}}(),transformDirection:function(a){var b=this.x,c=this.y,d=this.z;a=a.elements;this.x=a[0]*b+a[4]*c+a[8]*d;this.y=a[1]*b+a[5]*c+
a[9]*d;this.z=a[2]*b+a[6]*c+a[10]*d;return this.normalize()},divide:function(a){this.x/=a.x;this.y/=a.y;this.z/=a.z;return this},divideScalar:function(a){return this.multiplyScalar(1/a)},min:function(a){this.x=Math.min(this.x,a.x);this.y=Math.min(this.y,a.y);this.z=Math.min(this.z,a.z);return this},max:function(a){this.x=Math.max(this.x,a.x);this.y=Math.max(this.y,a.y);this.z=Math.max(this.z,a.z);return this},clamp:function(a,b){this.x=Math.max(a.x,Math.min(b.x,this.x));this.y=Math.max(a.y,Math.min(b.y,
this.y));this.z=Math.max(a.z,Math.min(b.z,this.z));return this},clampScalar:function(){var a=new n,b=new n;return function(c,d){a.set(c,c,c);b.set(d,d,d);return this.clamp(a,b)}}(),clampLength:function(a,b){var c=this.length();return this.divideScalar(c||1).multiplyScalar(Math.max(a,Math.min(b,c)))},floor:function(){this.x=Math.floor(this.x);this.y=Math.floor(this.y);this.z=Math.floor(this.z);return this},ceil:function(){this.x=Math.ceil(this.x);this.y=Math.ceil(this.y);this.z=Math.ceil(this.z);return this},
round:function(){this.x=Math.round(this.x);this.y=Math.round(this.y);this.z=Math.round(this.z);return this},roundToZero:function(){this.x=0>this.x?Math.ceil(this.x):Math.floor(this.x);this.y=0>this.y?Math.ceil(this.y):Math.floor(this.y);this.z=0>this.z?Math.ceil(this.z):Math.floor(this.z);return this},negate:function(){this.x=-this.x;this.y=-this.y;this.z=-this.z;return this},dot:function(a){return this.x*a.x+this.y*a.y+this.z*a.z},lengthSq:function(){return this.x*this.x+this.y*this.y+this.z*this.z},
length:function(){return Math.sqrt(this.x*this.x+this.y*this.y+this.z*this.z)},lengthManhattan:function(){return Math.abs(this.x)+Math.abs(this.y)+Math.abs(this.z)},normalize:function(){return this.divideScalar(this.length()||1)},setLength:function(a){return this.normalize().multiplyScalar(a)},lerp:function(a,b){this.x+=(a.x-this.x)*b;this.y+=(a.y-this.y)*b;this.z+=(a.z-this.z)*b;return this},lerpVectors:function(a,b,c){return this.subVectors(b,a).multiplyScalar(c).add(a)},cross:function(a,b){if(void 0!==
b)return console.warn("THREE.Vector3: .cross() now only accepts one argument. Use .crossVectors( a, b ) instead."),this.crossVectors(a,b);b=this.x;var c=this.y,d=this.z;this.x=c*a.z-d*a.y;this.y=d*a.x-b*a.z;this.z=b*a.y-c*a.x;return this},crossVectors:function(a,b){var c=a.x,d=a.y;a=a.z;var e=b.x,f=b.y;b=b.z;this.x=d*b-a*f;this.y=a*e-c*b;this.z=c*f-d*e;return this},projectOnVector:function(a){var b=a.dot(this)/a.lengthSq();return this.copy(a).multiplyScalar(b)},projectOnPlane:function(){var a=new n;
return function(b){a.copy(this).projectOnVector(b);return this.sub(a)}}(),reflect:function(){var a=new n;return function(b){return this.sub(a.copy(b).multiplyScalar(2*this.dot(b)))}}(),angleTo:function(a){a=this.dot(a)/Math.sqrt(this.lengthSq()*a.lengthSq());return Math.acos(R.clamp(a,-1,1))},distanceTo:function(a){return Math.sqrt(this.distanceToSquared(a))},distanceToSquared:function(a){var b=this.x-a.x,c=this.y-a.y;a=this.z-a.z;return b*b+c*c+a*a},distanceToManhattan:function(a){return Math.abs(this.x-
a.x)+Math.abs(this.y-a.y)+Math.abs(this.z-a.z)},setFromSpherical:function(a){var b=Math.sin(a.phi)*a.radius;this.x=b*Math.sin(a.theta);this.y=Math.cos(a.phi)*a.radius;this.z=b*Math.cos(a.theta);return this},setFromCylindrical:function(a){this.x=a.radius*Math.sin(a.theta);this.y=a.y;this.z=a.radius*Math.cos(a.theta);return this},setFromMatrixPosition:function(a){a=a.elements;this.x=a[12];this.y=a[13];this.z=a[14];return this},setFromMatrixScale:function(a){var b=this.setFromMatrixColumn(a,0).length(),
c=this.setFromMatrixColumn(a,1).length();a=this.setFromMatrixColumn(a,2).length();this.x=b;this.y=c;this.z=a;return this},setFromMatrixColumn:function(a,b){return this.fromArray(a.elements,4*b)},equals:function(a){return a.x===this.x&&a.y===this.y&&a.z===this.z},fromArray:function(a,b){void 0===b&&(b=0);this.x=a[b];this.y=a[b+1];this.z=a[b+2];return this},toArray:function(a,b){void 0===a&&(a=[]);void 0===b&&(b=0);a[b]=this.x;a[b+1]=this.y;a[b+2]=this.z;return a},fromBufferAttribute:function(a,b,c){void 0!==
c&&console.warn("THREE.Vector3: offset has been removed from .fromBufferAttribute().");this.x=a.getX(b);this.y=a.getY(b);this.z=a.getZ(b);return this}});Object.assign(O.prototype,{isMatrix4:!0,set:function(a,b,c,d,e,f,g,h,k,l,q,p,m,r,n,u){var t=this.elements;t[0]=a;t[4]=b;t[8]=c;t[12]=d;t[1]=e;t[5]=f;t[9]=g;t[13]=h;t[2]=k;t[6]=l;t[10]=q;t[14]=p;t[3]=m;t[7]=r;t[11]=n;t[15]=u;return this},identity:function(){this.set(1,0,0,0,0,1,0,0,0,0,1,0,0,0,0,1);return this},clone:function(){return(new O).fromArray(this.elements)},
copy:function(a){var b=this.elements;a=a.elements;b[0]=a[0];b[1]=a[1];b[2]=a[2];b[3]=a[3];b[4]=a[4];b[5]=a[5];b[6]=a[6];b[7]=a[7];b[8]=a[8];b[9]=a[9];b[10]=a[10];b[11]=a[11];b[12]=a[12];b[13]=a[13];b[14]=a[14];b[15]=a[15];return this},copyPosition:function(a){var b=this.elements;a=a.elements;b[12]=a[12];b[13]=a[13];b[14]=a[14];return this},extractBasis:function(a,b,c){a.setFromMatrixColumn(this,0);b.setFromMatrixColumn(this,1);c.setFromMatrixColumn(this,2);return this},makeBasis:function(a,b,c){this.set(a.x,
b.x,c.x,0,a.y,b.y,c.y,0,a.z,b.z,c.z,0,0,0,0,1);return this},extractRotation:function(){var a=new n;return function(b){var c=this.elements,d=b.elements,e=1/a.setFromMatrixColumn(b,0).length(),f=1/a.setFromMatrixColumn(b,1).length();b=1/a.setFromMatrixColumn(b,2).length();c[0]=d[0]*e;c[1]=d[1]*e;c[2]=d[2]*e;c[4]=d[4]*f;c[5]=d[5]*f;c[6]=d[6]*f;c[8]=d[8]*b;c[9]=d[9]*b;c[10]=d[10]*b;return this}}(),makeRotationFromEuler:function(a){a&&a.isEuler||console.error("THREE.Matrix4: .makeRotationFromEuler() now expects a Euler rotation rather than a Vector3 and order.");
var b=this.elements,c=a.x,d=a.y,e=a.z,f=Math.cos(c),c=Math.sin(c),g=Math.cos(d),d=Math.sin(d),h=Math.cos(e),e=Math.sin(e);if("XYZ"===a.order){var k=f*h;var l=f*e;var q=c*h;a=c*e;b[0]=g*h;b[4]=-g*e;b[8]=d;b[1]=l+q*d;b[5]=k-a*d;b[9]=-c*g;b[2]=a-k*d;b[6]=q+l*d;b[10]=f*g}else"YXZ"===a.order?(k=g*h,l=g*e,q=d*h,a=d*e,b[0]=k+a*c,b[4]=q*c-l,b[8]=f*d,b[1]=f*e,b[5]=f*h,b[9]=-c,b[2]=l*c-q,b[6]=a+k*c,b[10]=f*g):"ZXY"===a.order?(k=g*h,l=g*e,q=d*h,a=d*e,b[0]=k-a*c,b[4]=-f*e,b[8]=q+l*c,b[1]=l+q*c,b[5]=f*h,b[9]=
a-k*c,b[2]=-f*d,b[6]=c,b[10]=f*g):"ZYX"===a.order?(k=f*h,l=f*e,q=c*h,a=c*e,b[0]=g*h,b[4]=q*d-l,b[8]=k*d+a,b[1]=g*e,b[5]=a*d+k,b[9]=l*d-q,b[2]=-d,b[6]=c*g,b[10]=f*g):"YZX"===a.order?(k=f*g,l=f*d,q=c*g,a=c*d,b[0]=g*h,b[4]=a-k*e,b[8]=q*e+l,b[1]=e,b[5]=f*h,b[9]=-c*h,b[2]=-d*h,b[6]=l*e+q,b[10]=k-a*e):"XZY"===a.order&&(k=f*g,l=f*d,q=c*g,a=c*d,b[0]=g*h,b[4]=-e,b[8]=d*h,b[1]=k*e+a,b[5]=f*h,b[9]=l*e-q,b[2]=q*e-l,b[6]=c*h,b[10]=a*e+k);b[3]=0;b[7]=0;b[11]=0;b[12]=0;b[13]=0;b[14]=0;b[15]=1;return this},makeRotationFromQuaternion:function(a){var b=
this.elements,c=a._x,d=a._y,e=a._z,f=a._w,g=c+c,h=d+d,k=e+e;a=c*g;var l=c*h,c=c*k,q=d*h,d=d*k,e=e*k,g=f*g,h=f*h,f=f*k;b[0]=1-(q+e);b[4]=l-f;b[8]=c+h;b[1]=l+f;b[5]=1-(a+e);b[9]=d-g;b[2]=c-h;b[6]=d+g;b[10]=1-(a+q);b[3]=0;b[7]=0;b[11]=0;b[12]=0;b[13]=0;b[14]=0;b[15]=1;return this},lookAt:function(){var a=new n,b=new n,c=new n;return function(d,e,f){var g=this.elements;c.subVectors(d,e);0===c.lengthSq()&&(c.z=1);c.normalize();a.crossVectors(f,c);0===a.lengthSq()&&(1===Math.abs(f.z)?c.x+=1E-4:c.z+=1E-4,
c.normalize(),a.crossVectors(f,c));a.normalize();b.crossVectors(c,a);g[0]=a.x;g[4]=b.x;g[8]=c.x;g[1]=a.y;g[5]=b.y;g[9]=c.y;g[2]=a.z;g[6]=b.z;g[10]=c.z;return this}}(),multiply:function(a,b){return void 0!==b?(console.warn("THREE.Matrix4: .multiply() now only accepts one argument. Use .multiplyMatrices( a, b ) instead."),this.multiplyMatrices(a,b)):this.multiplyMatrices(this,a)},premultiply:function(a){return this.multiplyMatrices(a,this)},multiplyMatrices:function(a,b){var c=a.elements,d=b.elements;
b=this.elements;a=c[0];var e=c[4],f=c[8],g=c[12],h=c[1],k=c[5],l=c[9],q=c[13],p=c[2],m=c[6],r=c[10],n=c[14],u=c[3],x=c[7],y=c[11],c=c[15],A=d[0],I=d[4],B=d[8],H=d[12],w=d[1],z=d[5],D=d[9],C=d[13],F=d[2],L=d[6],J=d[10],K=d[14],ga=d[3],M=d[7],T=d[11],d=d[15];b[0]=a*A+e*w+f*F+g*ga;b[4]=a*I+e*z+f*L+g*M;b[8]=a*B+e*D+f*J+g*T;b[12]=a*H+e*C+f*K+g*d;b[1]=h*A+k*w+l*F+q*ga;b[5]=h*I+k*z+l*L+q*M;b[9]=h*B+k*D+l*J+q*T;b[13]=h*H+k*C+l*K+q*d;b[2]=p*A+m*w+r*F+n*ga;b[6]=p*I+m*z+r*L+n*M;b[10]=p*B+m*D+r*J+n*T;b[14]=p*
H+m*C+r*K+n*d;b[3]=u*A+x*w+y*F+c*ga;b[7]=u*I+x*z+y*L+c*M;b[11]=u*B+x*D+y*J+c*T;b[15]=u*H+x*C+y*K+c*d;return this},multiplyScalar:function(a){var b=this.elements;b[0]*=a;b[4]*=a;b[8]*=a;b[12]*=a;b[1]*=a;b[5]*=a;b[9]*=a;b[13]*=a;b[2]*=a;b[6]*=a;b[10]*=a;b[14]*=a;b[3]*=a;b[7]*=a;b[11]*=a;b[15]*=a;return this},applyToBufferAttribute:function(){var a=new n;return function(b){for(var c=0,d=b.count;c<d;c++)a.x=b.getX(c),a.y=b.getY(c),a.z=b.getZ(c),a.applyMatrix4(this),b.setXYZ(c,a.x,a.y,a.z);return b}}(),
determinant:function(){var a=this.elements,b=a[0],c=a[4],d=a[8],e=a[12],f=a[1],g=a[5],h=a[9],k=a[13],l=a[2],q=a[6],p=a[10],m=a[14];return a[3]*(+e*h*q-d*k*q-e*g*p+c*k*p+d*g*m-c*h*m)+a[7]*(+b*h*m-b*k*p+e*f*p-d*f*m+d*k*l-e*h*l)+a[11]*(+b*k*q-b*g*m-e*f*q+c*f*m+e*g*l-c*k*l)+a[15]*(-d*g*l-b*h*q+b*g*p+d*f*q-c*f*p+c*h*l)},transpose:function(){var a=this.elements;var b=a[1];a[1]=a[4];a[4]=b;b=a[2];a[2]=a[8];a[8]=b;b=a[6];a[6]=a[9];a[9]=b;b=a[3];a[3]=a[12];a[12]=b;b=a[7];a[7]=a[13];a[13]=b;b=a[11];a[11]=a[14];
a[14]=b;return this},setPosition:function(a){var b=this.elements;b[12]=a.x;b[13]=a.y;b[14]=a.z;return this},getInverse:function(a,b){var c=this.elements,d=a.elements;a=d[0];var e=d[1],f=d[2],g=d[3],h=d[4],k=d[5],l=d[6],q=d[7],p=d[8],m=d[9],r=d[10],n=d[11],u=d[12],x=d[13],y=d[14],d=d[15],A=m*y*q-x*r*q+x*l*n-k*y*n-m*l*d+k*r*d,I=u*r*q-p*y*q-u*l*n+h*y*n+p*l*d-h*r*d,B=p*x*q-u*m*q+u*k*n-h*x*n-p*k*d+h*m*d,H=u*m*l-p*x*l-u*k*r+h*x*r+p*k*y-h*m*y,w=a*A+e*I+f*B+g*H;if(0===w){if(!0===b)throw Error("THREE.Matrix4: .getInverse() can't invert matrix, determinant is 0");
console.warn("THREE.Matrix4: .getInverse() can't invert matrix, determinant is 0");return this.identity()}b=1/w;c[0]=A*b;c[1]=(x*r*g-m*y*g-x*f*n+e*y*n+m*f*d-e*r*d)*b;c[2]=(k*y*g-x*l*g+x*f*q-e*y*q-k*f*d+e*l*d)*b;c[3]=(m*l*g-k*r*g-m*f*q+e*r*q+k*f*n-e*l*n)*b;c[4]=I*b;c[5]=(p*y*g-u*r*g+u*f*n-a*y*n-p*f*d+a*r*d)*b;c[6]=(u*l*g-h*y*g-u*f*q+a*y*q+h*f*d-a*l*d)*b;c[7]=(h*r*g-p*l*g+p*f*q-a*r*q-h*f*n+a*l*n)*b;c[8]=B*b;c[9]=(u*m*g-p*x*g-u*e*n+a*x*n+p*e*d-a*m*d)*b;c[10]=(h*x*g-u*k*g+u*e*q-a*x*q-h*e*d+a*k*d)*b;c[11]=
(p*k*g-h*m*g-p*e*q+a*m*q+h*e*n-a*k*n)*b;c[12]=H*b;c[13]=(p*x*f-u*m*f+u*e*r-a*x*r-p*e*y+a*m*y)*b;c[14]=(u*k*f-h*x*f-u*e*l+a*x*l+h*e*y-a*k*y)*b;c[15]=(h*m*f-p*k*f+p*e*l-a*m*l-h*e*r+a*k*r)*b;return this},scale:function(a){var b=this.elements,c=a.x,d=a.y;a=a.z;b[0]*=c;b[4]*=d;b[8]*=a;b[1]*=c;b[5]*=d;b[9]*=a;b[2]*=c;b[6]*=d;b[10]*=a;b[3]*=c;b[7]*=d;b[11]*=a;return this},getMaxScaleOnAxis:function(){var a=this.elements;return Math.sqrt(Math.max(a[0]*a[0]+a[1]*a[1]+a[2]*a[2],a[4]*a[4]+a[5]*a[5]+a[6]*a[6],
a[8]*a[8]+a[9]*a[9]+a[10]*a[10]))},makeTranslation:function(a,b,c){this.set(1,0,0,a,0,1,0,b,0,0,1,c,0,0,0,1);return this},makeRotationX:function(a){var b=Math.cos(a);a=Math.sin(a);this.set(1,0,0,0,0,b,-a,0,0,a,b,0,0,0,0,1);return this},makeRotationY:function(a){var b=Math.cos(a);a=Math.sin(a);this.set(b,0,a,0,0,1,0,0,-a,0,b,0,0,0,0,1);return this},makeRotationZ:function(a){var b=Math.cos(a);a=Math.sin(a);this.set(b,-a,0,0,a,b,0,0,0,0,1,0,0,0,0,1);return this},makeRotationAxis:function(a,b){var c=
Math.cos(b);b=Math.sin(b);var d=1-c,e=a.x,f=a.y;a=a.z;var g=d*e,h=d*f;this.set(g*e+c,g*f-b*a,g*a+b*f,0,g*f+b*a,h*f+c,h*a-b*e,0,g*a-b*f,h*a+b*e,d*a*a+c,0,0,0,0,1);return this},makeScale:function(a,b,c){this.set(a,0,0,0,0,b,0,0,0,0,c,0,0,0,0,1);return this},makeShear:function(a,b,c){this.set(1,b,c,0,a,1,c,0,a,b,1,0,0,0,0,1);return this},compose:function(a,b,c){this.makeRotationFromQuaternion(b);this.scale(c);this.setPosition(a);return this},decompose:function(){var a=new n,b=new O;return function(c,
d,e){var f=this.elements,g=a.set(f[0],f[1],f[2]).length(),h=a.set(f[4],f[5],f[6]).length(),k=a.set(f[8],f[9],f[10]).length();0>this.determinant()&&(g=-g);c.x=f[12];c.y=f[13];c.z=f[14];b.copy(this);c=1/g;var f=1/h,l=1/k;b.elements[0]*=c;b.elements[1]*=c;b.elements[2]*=c;b.elements[4]*=f;b.elements[5]*=f;b.elements[6]*=f;b.elements[8]*=l;b.elements[9]*=l;b.elements[10]*=l;d.setFromRotationMatrix(b);e.x=g;e.y=h;e.z=k;return this}}(),makePerspective:function(a,b,c,d,e,f){void 0===f&&console.warn("THREE.Matrix4: .makePerspective() has been redefined and has a new signature. Please check the docs.");
var g=this.elements;g[0]=2*e/(b-a);g[4]=0;g[8]=(b+a)/(b-a);g[12]=0;g[1]=0;g[5]=2*e/(c-d);g[9]=(c+d)/(c-d);g[13]=0;g[2]=0;g[6]=0;g[10]=-(f+e)/(f-e);g[14]=-2*f*e/(f-e);g[3]=0;g[7]=0;g[11]=-1;g[15]=0;return this},makeOrthographic:function(a,b,c,d,e,f){var g=this.elements,h=1/(b-a),k=1/(c-d),l=1/(f-e);g[0]=2*h;g[4]=0;g[8]=0;g[12]=-((b+a)*h);g[1]=0;g[5]=2*k;g[9]=0;g[13]=-((c+d)*k);g[2]=0;g[6]=0;g[10]=-2*l;g[14]=-((f+e)*l);g[3]=0;g[7]=0;g[11]=0;g[15]=1;return this},equals:function(a){var b=this.elements;
a=a.elements;for(var c=0;16>c;c++)if(b[c]!==a[c])return!1;return!0},fromArray:function(a,b){void 0===b&&(b=0);for(var c=0;16>c;c++)this.elements[c]=a[c+b];return this},toArray:function(a,b){void 0===a&&(a=[]);void 0===b&&(b=0);var c=this.elements;a[b]=c[0];a[b+1]=c[1];a[b+2]=c[2];a[b+3]=c[3];a[b+4]=c[4];a[b+5]=c[5];a[b+6]=c[6];a[b+7]=c[7];a[b+8]=c[8];a[b+9]=c[9];a[b+10]=c[10];a[b+11]=c[11];a[b+12]=c[12];a[b+13]=c[13];a[b+14]=c[14];a[b+15]=c[15];return a}});bb.prototype=Object.create(N.prototype);
bb.prototype.constructor=bb;bb.prototype.isDataTexture=!0;Va.prototype=Object.create(N.prototype);Va.prototype.constructor=Va;Va.prototype.isCubeTexture=!0;Object.defineProperty(Va.prototype,"images",{get:function(){return this.image},set:function(a){this.image=a}});var De=new N,Ee=new Va,ye=[],Ae=[],Ce=new Float32Array(16),Be=new Float32Array(9);Ie.prototype.setValue=function(a,b){for(var c=this.seq,d=0,e=c.length;d!==e;++d){var f=c[d];f.setValue(a,b[f.id])}};var Pd=/([\w\d_]+)(\])?(\[|\.)?/g;cb.prototype.setValue=
function(a,b,c){b=this.map[b];void 0!==b&&b.setValue(a,c,this.renderer)};cb.prototype.setOptional=function(a,b,c){b=b[c];void 0!==b&&this.setValue(a,c,b)};cb.upload=function(a,b,c,d){for(var e=0,f=b.length;e!==f;++e){var g=b[e],h=c[g.id];!1!==h.needsUpdate&&g.setValue(a,h.value,d)}};cb.seqWithValue=function(a,b){for(var c=[],d=0,e=a.length;d!==e;++d){var f=a[d];f.id in b&&c.push(f)}return c};var rg={aliceblue:15792383,antiquewhite:16444375,aqua:65535,aquamarine:8388564,azure:15794175,beige:16119260,
bisque:16770244,black:0,blanchedalmond:16772045,blue:255,blueviolet:9055202,brown:10824234,burlywood:14596231,cadetblue:6266528,chartreuse:8388352,chocolate:13789470,coral:16744272,cornflowerblue:6591981,cornsilk:16775388,crimson:14423100,cyan:65535,darkblue:139,darkcyan:35723,darkgoldenrod:12092939,darkgray:11119017,darkgreen:25600,darkgrey:11119017,darkkhaki:12433259,darkmagenta:9109643,darkolivegreen:5597999,darkorange:16747520,darkorchid:10040012,darkred:9109504,darksalmon:15308410,darkseagreen:9419919,
darkslateblue:4734347,darkslategray:3100495,darkslategrey:3100495,darkturquoise:52945,darkviolet:9699539,deeppink:16716947,deepskyblue:49151,dimgray:6908265,dimgrey:6908265,dodgerblue:2003199,firebrick:11674146,floralwhite:16775920,forestgreen:2263842,fuchsia:16711935,gainsboro:14474460,ghostwhite:16316671,gold:16766720,goldenrod:14329120,gray:8421504,green:32768,greenyellow:11403055,grey:8421504,honeydew:15794160,hotpink:16738740,indianred:13458524,indigo:4915330,ivory:16777200,khaki:15787660,lavender:15132410,
lavenderblush:16773365,lawngreen:8190976,lemonchiffon:16775885,lightblue:11393254,lightcoral:15761536,lightcyan:14745599,lightgoldenrodyellow:16448210,lightgray:13882323,lightgreen:9498256,lightgrey:13882323,lightpink:16758465,lightsalmon:16752762,lightseagreen:2142890,lightskyblue:8900346,lightslategray:7833753,lightslategrey:7833753,lightsteelblue:11584734,lightyellow:16777184,lime:65280,limegreen:3329330,linen:16445670,magenta:16711935,maroon:8388608,mediumaquamarine:6737322,mediumblue:205,mediumorchid:12211667,
mediumpurple:9662683,mediumseagreen:3978097,mediumslateblue:8087790,mediumspringgreen:64154,mediumturquoise:4772300,mediumvioletred:13047173,midnightblue:1644912,mintcream:16121850,mistyrose:16770273,moccasin:16770229,navajowhite:16768685,navy:128,oldlace:16643558,olive:8421376,olivedrab:7048739,orange:16753920,orangered:16729344,orchid:14315734,palegoldenrod:15657130,palegreen:10025880,paleturquoise:11529966,palevioletred:14381203,papayawhip:16773077,peachpuff:16767673,peru:13468991,pink:16761035,
plum:14524637,powderblue:11591910,purple:8388736,rebeccapurple:6697881,red:16711680,rosybrown:12357519,royalblue:4286945,saddlebrown:9127187,salmon:16416882,sandybrown:16032864,seagreen:3050327,seashell:16774638,sienna:10506797,silver:12632256,skyblue:8900331,slateblue:6970061,slategray:7372944,slategrey:7372944,snow:16775930,springgreen:65407,steelblue:4620980,tan:13808780,teal:32896,thistle:14204888,tomato:16737095,turquoise:4251856,violet:15631086,wheat:16113331,white:16777215,whitesmoke:16119285,
yellow:16776960,yellowgreen:10145074};Object.assign(C.prototype,{isColor:!0,r:1,g:1,b:1,set:function(a){a&&a.isColor?this.copy(a):"number"===typeof a?this.setHex(a):"string"===typeof a&&this.setStyle(a);return this},setScalar:function(a){this.b=this.g=this.r=a;return this},setHex:function(a){a=Math.floor(a);this.r=(a>>16&255)/255;this.g=(a>>8&255)/255;this.b=(a&255)/255;return this},setRGB:function(a,b,c){this.r=a;this.g=b;this.b=c;return this},setHSL:function(){function a(a,c,d){0>d&&(d+=1);1<d&&
--d;return d<1/6?a+6*(c-a)*d:.5>d?c:d<2/3?a+6*(c-a)*(2/3-d):a}return function(b,c,d){b=R.euclideanModulo(b,1);c=R.clamp(c,0,1);d=R.clamp(d,0,1);0===c?this.r=this.g=this.b=d:(c=.5>=d?d*(1+c):d+c-d*c,d=2*d-c,this.r=a(d,c,b+1/3),this.g=a(d,c,b),this.b=a(d,c,b-1/3));return this}}(),setStyle:function(a){function b(b){void 0!==b&&1>parseFloat(b)&&console.warn("THREE.Color: Alpha component of "+a+" will be ignored.")}var c;if(c=/^((?:rgb|hsl)a?)\(\s*([^\)]*)\)/.exec(a)){var d=c[2];switch(c[1]){case "rgb":case "rgba":if(c=
/^(\d+)\s*,\s*(\d+)\s*,\s*(\d+)\s*(,\s*([0-9]*\.?[0-9]+)\s*)?$/.exec(d))return this.r=Math.min(255,parseInt(c[1],10))/255,this.g=Math.min(255,parseInt(c[2],10))/255,this.b=Math.min(255,parseInt(c[3],10))/255,b(c[5]),this;if(c=/^(\d+)\%\s*,\s*(\d+)\%\s*,\s*(\d+)\%\s*(,\s*([0-9]*\.?[0-9]+)\s*)?$/.exec(d))return this.r=Math.min(100,parseInt(c[1],10))/100,this.g=Math.min(100,parseInt(c[2],10))/100,this.b=Math.min(100,parseInt(c[3],10))/100,b(c[5]),this;break;case "hsl":case "hsla":if(c=/^([0-9]*\.?[0-9]+)\s*,\s*(\d+)\%\s*,\s*(\d+)\%\s*(,\s*([0-9]*\.?[0-9]+)\s*)?$/.exec(d)){var d=
parseFloat(c[1])/360,e=parseInt(c[2],10)/100,f=parseInt(c[3],10)/100;b(c[5]);return this.setHSL(d,e,f)}}}else if(c=/^\#([A-Fa-f0-9]+)$/.exec(a)){c=c[1];d=c.length;if(3===d)return this.r=parseInt(c.charAt(0)+c.charAt(0),16)/255,this.g=parseInt(c.charAt(1)+c.charAt(1),16)/255,this.b=parseInt(c.charAt(2)+c.charAt(2),16)/255,this;if(6===d)return this.r=parseInt(c.charAt(0)+c.charAt(1),16)/255,this.g=parseInt(c.charAt(2)+c.charAt(3),16)/255,this.b=parseInt(c.charAt(4)+c.charAt(5),16)/255,this}a&&0<a.length&&
(c=rg[a],void 0!==c?this.setHex(c):console.warn("THREE.Color: Unknown color "+a));return this},clone:function(){return new this.constructor(this.r,this.g,this.b)},copy:function(a){this.r=a.r;this.g=a.g;this.b=a.b;return this},copyGammaToLinear:function(a,b){void 0===b&&(b=2);this.r=Math.pow(a.r,b);this.g=Math.pow(a.g,b);this.b=Math.pow(a.b,b);return this},copyLinearToGamma:function(a,b){void 0===b&&(b=2);b=0<b?1/b:1;this.r=Math.pow(a.r,b);this.g=Math.pow(a.g,b);this.b=Math.pow(a.b,b);return this},
convertGammaToLinear:function(){var a=this.r,b=this.g,c=this.b;this.r=a*a;this.g=b*b;this.b=c*c;return this},convertLinearToGamma:function(){this.r=Math.sqrt(this.r);this.g=Math.sqrt(this.g);this.b=Math.sqrt(this.b);return this},getHex:function(){return 255*this.r<<16^255*this.g<<8^255*this.b<<0},getHexString:function(){return("000000"+this.getHex().toString(16)).slice(-6)},getHSL:function(a){a=a||{h:0,s:0,l:0};var b=this.r,c=this.g,d=this.b,e=Math.max(b,c,d),f=Math.min(b,c,d),g,h=(f+e)/2;if(f===
e)f=g=0;else{var k=e-f,f=.5>=h?k/(e+f):k/(2-e-f);switch(e){case b:g=(c-d)/k+(c<d?6:0);break;case c:g=(d-b)/k+2;break;case d:g=(b-c)/k+4}g/=6}a.h=g;a.s=f;a.l=h;return a},getStyle:function(){return"rgb("+(255*this.r|0)+","+(255*this.g|0)+","+(255*this.b|0)+")"},offsetHSL:function(a,b,c){var d=this.getHSL();d.h+=a;d.s+=b;d.l+=c;this.setHSL(d.h,d.s,d.l);return this},add:function(a){this.r+=a.r;this.g+=a.g;this.b+=a.b;return this},addColors:function(a,b){this.r=a.r+b.r;this.g=a.g+b.g;this.b=a.b+b.b;return this},
addScalar:function(a){this.r+=a;this.g+=a;this.b+=a;return this},sub:function(a){this.r=Math.max(0,this.r-a.r);this.g=Math.max(0,this.g-a.g);this.b=Math.max(0,this.b-a.b);return this},multiply:function(a){this.r*=a.r;this.g*=a.g;this.b*=a.b;return this},multiplyScalar:function(a){this.r*=a;this.g*=a;this.b*=a;return this},lerp:function(a,b){this.r+=(a.r-this.r)*b;this.g+=(a.g-this.g)*b;this.b+=(a.b-this.b)*b;return this},equals:function(a){return a.r===this.r&&a.g===this.g&&a.b===this.b},fromArray:function(a,
b){void 0===b&&(b=0);this.r=a[b];this.g=a[b+1];this.b=a[b+2];return this},toArray:function(a,b){void 0===a&&(a=[]);void 0===b&&(b=0);a[b]=this.r;a[b+1]=this.g;a[b+2]=this.b;return a},toJSON:function(){return this.getHex()}});var L={common:{diffuse:{value:new C(15658734)},opacity:{value:1},map:{value:null},offsetRepeat:{value:new S(0,0,1,1)},alphaMap:{value:null}},specularmap:{specularMap:{value:null}},envmap:{envMap:{value:null},flipEnvMap:{value:-1},reflectivity:{value:1},refractionRatio:{value:.98}},
aomap:{aoMap:{value:null},aoMapIntensity:{value:1}},lightmap:{lightMap:{value:null},lightMapIntensity:{value:1}},emissivemap:{emissiveMap:{value:null}},bumpmap:{bumpMap:{value:null},bumpScale:{value:1}},normalmap:{normalMap:{value:null},normalScale:{value:new D(1,1)}},displacementmap:{displacementMap:{value:null},displacementScale:{value:1},displacementBias:{value:0}},roughnessmap:{roughnessMap:{value:null}},metalnessmap:{metalnessMap:{value:null}},gradientmap:{gradientMap:{value:null}},fog:{fogDensity:{value:2.5E-4},
fogNear:{value:1},fogFar:{value:2E3},fogColor:{value:new C(16777215)}},lights:{ambientLightColor:{value:[]},directionalLights:{value:[],properties:{direction:{},color:{},shadow:{},shadowBias:{},shadowRadius:{},shadowMapSize:{}}},directionalShadowMap:{value:[]},directionalShadowMatrix:{value:[]},spotLights:{value:[],properties:{color:{},position:{},direction:{},distance:{},coneCos:{},penumbraCos:{},decay:{},shadow:{},shadowBias:{},shadowRadius:{},shadowMapSize:{}}},spotShadowMap:{value:[]},spotShadowMatrix:{value:[]},
pointLights:{value:[],properties:{color:{},position:{},decay:{},distance:{},shadow:{},shadowBias:{},shadowRadius:{},shadowMapSize:{},shadowCameraNear:{},shadowCameraFar:{}}},pointShadowMap:{value:[]},pointShadowMatrix:{value:[]},hemisphereLights:{value:[],properties:{direction:{},skyColor:{},groundColor:{}}},rectAreaLights:{value:[],properties:{color:{},position:{},width:{},height:{}}}},points:{diffuse:{value:new C(15658734)},opacity:{value:1},size:{value:1},scale:{value:1},map:{value:null},offsetRepeat:{value:new S(0,
0,1,1)}}},Da={merge:function(a){for(var b={},c=0;c<a.length;c++){var d=this.clone(a[c]),e;for(e in d)b[e]=d[e]}return b},clone:function(a){var b={},c;for(c in a){b[c]={};for(var d in a[c]){var e=a[c][d];e&&(e.isColor||e.isMatrix3||e.isMatrix4||e.isVector2||e.isVector3||e.isVector4||e.isTexture)?b[c][d]=e.clone():Array.isArray(e)?b[c][d]=e.slice():b[c][d]=e}}return b}},V={alphamap_fragment:"#ifdef USE_ALPHAMAP\n\tdiffuseColor.a *= texture2D( alphaMap, vUv ).g;\n#endif\n",alphamap_pars_fragment:"#ifdef USE_ALPHAMAP\n\tuniform sampler2D alphaMap;\n#endif\n",
alphatest_fragment:"#ifdef ALPHATEST\n\tif ( diffuseColor.a < ALPHATEST ) discard;\n#endif\n",aomap_fragment:"#ifdef USE_AOMAP\n\tfloat ambientOcclusion = ( texture2D( aoMap, vUv2 ).r - 1.0 ) * aoMapIntensity + 1.0;\n\treflectedLight.indirectDiffuse *= ambientOcclusion;\n\t#if defined( USE_ENVMAP ) && defined( PHYSICAL )\n\t\tfloat dotNV = saturate( dot( geometry.normal, geometry.viewDir ) );\n\t\treflectedLight.indirectSpecular *= computeSpecularOcclusion( dotNV, ambientOcclusion, material.specularRoughness );\n\t#endif\n#endif\n",
aomap_pars_fragment:"#ifdef USE_AOMAP\n\tuniform sampler2D aoMap;\n\tuniform float aoMapIntensity;\n#endif",begin_vertex:"\nvec3 transformed = vec3( position );\n",beginnormal_vertex:"\nvec3 objectNormal = vec3( normal );\n",bsdfs:"float punctualLightIntensityToIrradianceFactor( const in float lightDistance, const in float cutoffDistance, const in float decayExponent ) {\n\tif( decayExponent > 0.0 ) {\n#if defined ( PHYSICALLY_CORRECT_LIGHTS )\n\t\tfloat distanceFalloff = 1.0 / max( pow( lightDistance, decayExponent ), 0.01 );\n\t\tfloat maxDistanceCutoffFactor = pow2( saturate( 1.0 - pow4( lightDistance / cutoffDistance ) ) );\n\t\treturn distanceFalloff * maxDistanceCutoffFactor;\n#else\n\t\treturn pow( saturate( -lightDistance / cutoffDistance + 1.0 ), decayExponent );\n#endif\n\t}\n\treturn 1.0;\n}\nvec3 BRDF_Diffuse_Lambert( const in vec3 diffuseColor ) {\n\treturn RECIPROCAL_PI * diffuseColor;\n}\nvec3 F_Schlick( const in vec3 specularColor, const in float dotLH ) {\n\tfloat fresnel = exp2( ( -5.55473 * dotLH - 6.98316 ) * dotLH );\n\treturn ( 1.0 - specularColor ) * fresnel + specularColor;\n}\nfloat G_GGX_Smith( const in float alpha, const in float dotNL, const in float dotNV ) {\n\tfloat a2 = pow2( alpha );\n\tfloat gl = dotNL + sqrt( a2 + ( 1.0 - a2 ) * pow2( dotNL ) );\n\tfloat gv = dotNV + sqrt( a2 + ( 1.0 - a2 ) * pow2( dotNV ) );\n\treturn 1.0 / ( gl * gv );\n}\nfloat G_GGX_SmithCorrelated( const in float alpha, const in float dotNL, const in float dotNV ) {\n\tfloat a2 = pow2( alpha );\n\tfloat gv = dotNL * sqrt( a2 + ( 1.0 - a2 ) * pow2( dotNV ) );\n\tfloat gl = dotNV * sqrt( a2 + ( 1.0 - a2 ) * pow2( dotNL ) );\n\treturn 0.5 / max( gv + gl, EPSILON );\n}\nfloat D_GGX( const in float alpha, const in float dotNH ) {\n\tfloat a2 = pow2( alpha );\n\tfloat denom = pow2( dotNH ) * ( a2 - 1.0 ) + 1.0;\n\treturn RECIPROCAL_PI * a2 / pow2( denom );\n}\nvec3 BRDF_Specular_GGX( const in IncidentLight incidentLight, const in GeometricContext geometry, const in vec3 specularColor, const in float roughness ) {\n\tfloat alpha = pow2( roughness );\n\tvec3 halfDir = normalize( incidentLight.direction + geometry.viewDir );\n\tfloat dotNL = saturate( dot( geometry.normal, incidentLight.direction ) );\n\tfloat dotNV = saturate( dot( geometry.normal, geometry.viewDir ) );\n\tfloat dotNH = saturate( dot( geometry.normal, halfDir ) );\n\tfloat dotLH = saturate( dot( incidentLight.direction, halfDir ) );\n\tvec3 F = F_Schlick( specularColor, dotLH );\n\tfloat G = G_GGX_SmithCorrelated( alpha, dotNL, dotNV );\n\tfloat D = D_GGX( alpha, dotNH );\n\treturn F * ( G * D );\n}\nvec2 LTC_Uv( const in vec3 N, const in vec3 V, const in float roughness ) {\n\tconst float LUT_SIZE  = 64.0;\n\tconst float LUT_SCALE = ( LUT_SIZE - 1.0 ) / LUT_SIZE;\n\tconst float LUT_BIAS  = 0.5 / LUT_SIZE;\n\tfloat theta = acos( dot( N, V ) );\n\tvec2 uv = vec2(\n\t\tsqrt( saturate( roughness ) ),\n\t\tsaturate( theta / ( 0.5 * PI ) ) );\n\tuv = uv * LUT_SCALE + LUT_BIAS;\n\treturn uv;\n}\nfloat LTC_ClippedSphereFormFactor( const in vec3 f ) {\n\tfloat l = length( f );\n\treturn max( ( l * l + f.z ) / ( l + 1.0 ), 0.0 );\n}\nvec3 LTC_EdgeVectorFormFactor( const in vec3 v1, const in vec3 v2 ) {\n\tfloat x = dot( v1, v2 );\n\tfloat y = abs( x );\n\tfloat a = 0.86267 + (0.49788 + 0.01436 * y ) * y;\n\tfloat b = 3.45068 + (4.18814 + y) * y;\n\tfloat v = a / b;\n\tfloat theta_sintheta = (x > 0.0) ? v : 0.5 * inversesqrt( 1.0 - x * x ) - v;\n\treturn cross( v1, v2 ) * theta_sintheta;\n}\nvec3 LTC_Evaluate( const in vec3 N, const in vec3 V, const in vec3 P, const in mat3 mInv, const in vec3 rectCoords[ 4 ] ) {\n\tvec3 v1 = rectCoords[ 1 ] - rectCoords[ 0 ];\n\tvec3 v2 = rectCoords[ 3 ] - rectCoords[ 0 ];\n\tvec3 lightNormal = cross( v1, v2 );\n\tif( dot( lightNormal, P - rectCoords[ 0 ] ) < 0.0 ) return vec3( 0.0 );\n\tvec3 T1, T2;\n\tT1 = normalize( V - N * dot( V, N ) );\n\tT2 = - cross( N, T1 );\n\tmat3 mat = mInv * transpose( mat3( T1, T2, N ) );\n\tvec3 coords[ 4 ];\n\tcoords[ 0 ] = mat * ( rectCoords[ 0 ] - P );\n\tcoords[ 1 ] = mat * ( rectCoords[ 1 ] - P );\n\tcoords[ 2 ] = mat * ( rectCoords[ 2 ] - P );\n\tcoords[ 3 ] = mat * ( rectCoords[ 3 ] - P );\n\tcoords[ 0 ] = normalize( coords[ 0 ] );\n\tcoords[ 1 ] = normalize( coords[ 1 ] );\n\tcoords[ 2 ] = normalize( coords[ 2 ] );\n\tcoords[ 3 ] = normalize( coords[ 3 ] );\n\tvec3 vectorFormFactor = vec3( 0.0 );\n\tvectorFormFactor += LTC_EdgeVectorFormFactor( coords[ 0 ], coords[ 1 ] );\n\tvectorFormFactor += LTC_EdgeVectorFormFactor( coords[ 1 ], coords[ 2 ] );\n\tvectorFormFactor += LTC_EdgeVectorFormFactor( coords[ 2 ], coords[ 3 ] );\n\tvectorFormFactor += LTC_EdgeVectorFormFactor( coords[ 3 ], coords[ 0 ] );\n\tvec3 result = vec3( LTC_ClippedSphereFormFactor( vectorFormFactor ) );\n\treturn result;\n}\nvec3 BRDF_Specular_GGX_Environment( const in GeometricContext geometry, const in vec3 specularColor, const in float roughness ) {\n\tfloat dotNV = saturate( dot( geometry.normal, geometry.viewDir ) );\n\tconst vec4 c0 = vec4( - 1, - 0.0275, - 0.572, 0.022 );\n\tconst vec4 c1 = vec4( 1, 0.0425, 1.04, - 0.04 );\n\tvec4 r = roughness * c0 + c1;\n\tfloat a004 = min( r.x * r.x, exp2( - 9.28 * dotNV ) ) * r.x + r.y;\n\tvec2 AB = vec2( -1.04, 1.04 ) * a004 + r.zw;\n\treturn specularColor * AB.x + AB.y;\n}\nfloat G_BlinnPhong_Implicit( ) {\n\treturn 0.25;\n}\nfloat D_BlinnPhong( const in float shininess, const in float dotNH ) {\n\treturn RECIPROCAL_PI * ( shininess * 0.5 + 1.0 ) * pow( dotNH, shininess );\n}\nvec3 BRDF_Specular_BlinnPhong( const in IncidentLight incidentLight, const in GeometricContext geometry, const in vec3 specularColor, const in float shininess ) {\n\tvec3 halfDir = normalize( incidentLight.direction + geometry.viewDir );\n\tfloat dotNH = saturate( dot( geometry.normal, halfDir ) );\n\tfloat dotLH = saturate( dot( incidentLight.direction, halfDir ) );\n\tvec3 F = F_Schlick( specularColor, dotLH );\n\tfloat G = G_BlinnPhong_Implicit( );\n\tfloat D = D_BlinnPhong( shininess, dotNH );\n\treturn F * ( G * D );\n}\nfloat GGXRoughnessToBlinnExponent( const in float ggxRoughness ) {\n\treturn ( 2.0 / pow2( ggxRoughness + 0.0001 ) - 2.0 );\n}\nfloat BlinnExponentToGGXRoughness( const in float blinnExponent ) {\n\treturn sqrt( 2.0 / ( blinnExponent + 2.0 ) );\n}\n",
bumpmap_pars_fragment:"#ifdef USE_BUMPMAP\n\tuniform sampler2D bumpMap;\n\tuniform float bumpScale;\n\tvec2 dHdxy_fwd() {\n\t\tvec2 dSTdx = dFdx( vUv );\n\t\tvec2 dSTdy = dFdy( vUv );\n\t\tfloat Hll = bumpScale * texture2D( bumpMap, vUv ).x;\n\t\tfloat dBx = bumpScale * texture2D( bumpMap, vUv + dSTdx ).x - Hll;\n\t\tfloat dBy = bumpScale * texture2D( bumpMap, vUv + dSTdy ).x - Hll;\n\t\treturn vec2( dBx, dBy );\n\t}\n\tvec3 perturbNormalArb( vec3 surf_pos, vec3 surf_norm, vec2 dHdxy ) {\n\t\tvec3 vSigmaX = vec3( dFdx( surf_pos.x ), dFdx( surf_pos.y ), dFdx( surf_pos.z ) );\n\t\tvec3 vSigmaY = vec3( dFdy( surf_pos.x ), dFdy( surf_pos.y ), dFdy( surf_pos.z ) );\n\t\tvec3 vN = surf_norm;\n\t\tvec3 R1 = cross( vSigmaY, vN );\n\t\tvec3 R2 = cross( vN, vSigmaX );\n\t\tfloat fDet = dot( vSigmaX, R1 );\n\t\tvec3 vGrad = sign( fDet ) * ( dHdxy.x * R1 + dHdxy.y * R2 );\n\t\treturn normalize( abs( fDet ) * surf_norm - vGrad );\n\t}\n#endif\n",
clipping_planes_fragment:"#if NUM_CLIPPING_PLANES > 0\n\tfor ( int i = 0; i < UNION_CLIPPING_PLANES; ++ i ) {\n\t\tvec4 plane = clippingPlanes[ i ];\n\t\tif ( dot( vViewPosition, plane.xyz ) > plane.w ) discard;\n\t}\n\t\t\n\t#if UNION_CLIPPING_PLANES < NUM_CLIPPING_PLANES\n\t\tbool clipped = true;\n\t\tfor ( int i = UNION_CLIPPING_PLANES; i < NUM_CLIPPING_PLANES; ++ i ) {\n\t\t\tvec4 plane = clippingPlanes[ i ];\n\t\t\tclipped = ( dot( vViewPosition, plane.xyz ) > plane.w ) && clipped;\n\t\t}\n\t\tif ( clipped ) discard;\n\t\n\t#endif\n#endif\n",
clipping_planes_pars_fragment:"#if NUM_CLIPPING_PLANES > 0\n\t#if ! defined( PHYSICAL ) && ! defined( PHONG )\n\t\tvarying vec3 vViewPosition;\n\t#endif\n\tuniform vec4 clippingPlanes[ NUM_CLIPPING_PLANES ];\n#endif\n",clipping_planes_pars_vertex:"#if NUM_CLIPPING_PLANES > 0 && ! defined( PHYSICAL ) && ! defined( PHONG )\n\tvarying vec3 vViewPosition;\n#endif\n",clipping_planes_vertex:"#if NUM_CLIPPING_PLANES > 0 && ! defined( PHYSICAL ) && ! defined( PHONG )\n\tvViewPosition = - mvPosition.xyz;\n#endif\n",
color_fragment:"#ifdef USE_COLOR\n\tdiffuseColor.rgb *= vColor;\n#endif",color_pars_fragment:"#ifdef USE_COLOR\n\tvarying vec3 vColor;\n#endif\n",color_pars_vertex:"#ifdef USE_COLOR\n\tvarying vec3 vColor;\n#endif",color_vertex:"#ifdef USE_COLOR\n\tvColor.xyz = color.xyz;\n#endif",common:"#define PI 3.14159265359\n#define PI2 6.28318530718\n#define PI_HALF 1.5707963267949\n#define RECIPROCAL_PI 0.31830988618\n#define RECIPROCAL_PI2 0.15915494\n#define LOG2 1.442695\n#define EPSILON 1e-6\n#define saturate(a) clamp( a, 0.0, 1.0 )\n#define whiteCompliment(a) ( 1.0 - saturate( a ) )\nfloat pow2( const in float x ) { return x*x; }\nfloat pow3( const in float x ) { return x*x*x; }\nfloat pow4( const in float x ) { float x2 = x*x; return x2*x2; }\nfloat average( const in vec3 color ) { return dot( color, vec3( 0.3333 ) ); }\nhighp float rand( const in vec2 uv ) {\n\tconst highp float a = 12.9898, b = 78.233, c = 43758.5453;\n\thighp float dt = dot( uv.xy, vec2( a,b ) ), sn = mod( dt, PI );\n\treturn fract(sin(sn) * c);\n}\nstruct IncidentLight {\n\tvec3 color;\n\tvec3 direction;\n\tbool visible;\n};\nstruct ReflectedLight {\n\tvec3 directDiffuse;\n\tvec3 directSpecular;\n\tvec3 indirectDiffuse;\n\tvec3 indirectSpecular;\n};\nstruct GeometricContext {\n\tvec3 position;\n\tvec3 normal;\n\tvec3 viewDir;\n};\nvec3 transformDirection( in vec3 dir, in mat4 matrix ) {\n\treturn normalize( ( matrix * vec4( dir, 0.0 ) ).xyz );\n}\nvec3 inverseTransformDirection( in vec3 dir, in mat4 matrix ) {\n\treturn normalize( ( vec4( dir, 0.0 ) * matrix ).xyz );\n}\nvec3 projectOnPlane(in vec3 point, in vec3 pointOnPlane, in vec3 planeNormal ) {\n\tfloat distance = dot( planeNormal, point - pointOnPlane );\n\treturn - distance * planeNormal + point;\n}\nfloat sideOfPlane( in vec3 point, in vec3 pointOnPlane, in vec3 planeNormal ) {\n\treturn sign( dot( point - pointOnPlane, planeNormal ) );\n}\nvec3 linePlaneIntersect( in vec3 pointOnLine, in vec3 lineDirection, in vec3 pointOnPlane, in vec3 planeNormal ) {\n\treturn lineDirection * ( dot( planeNormal, pointOnPlane - pointOnLine ) / dot( planeNormal, lineDirection ) ) + pointOnLine;\n}\nmat3 transpose( const in mat3 v ) {\n\tmat3 tmp;\n\ttmp[0] = vec3(v[0].x, v[1].x, v[2].x);\n\ttmp[1] = vec3(v[0].y, v[1].y, v[2].y);\n\ttmp[2] = vec3(v[0].z, v[1].z, v[2].z);\n\treturn tmp;\n}\n",
cube_uv_reflection_fragment:"#ifdef ENVMAP_TYPE_CUBE_UV\n#define cubeUV_textureSize (1024.0)\nint getFaceFromDirection(vec3 direction) {\n\tvec3 absDirection = abs(direction);\n\tint face = -1;\n\tif( absDirection.x > absDirection.z ) {\n\t\tif(absDirection.x > absDirection.y )\n\t\t\tface = direction.x > 0.0 ? 0 : 3;\n\t\telse\n\t\t\tface = direction.y > 0.0 ? 1 : 4;\n\t}\n\telse {\n\t\tif(absDirection.z > absDirection.y )\n\t\t\tface = direction.z > 0.0 ? 2 : 5;\n\t\telse\n\t\t\tface = direction.y > 0.0 ? 1 : 4;\n\t}\n\treturn face;\n}\n#define cubeUV_maxLods1  (log2(cubeUV_textureSize*0.25) - 1.0)\n#define cubeUV_rangeClamp (exp2((6.0 - 1.0) * 2.0))\nvec2 MipLevelInfo( vec3 vec, float roughnessLevel, float roughness ) {\n\tfloat scale = exp2(cubeUV_maxLods1 - roughnessLevel);\n\tfloat dxRoughness = dFdx(roughness);\n\tfloat dyRoughness = dFdy(roughness);\n\tvec3 dx = dFdx( vec * scale * dxRoughness );\n\tvec3 dy = dFdy( vec * scale * dyRoughness );\n\tfloat d = max( dot( dx, dx ), dot( dy, dy ) );\n\td = clamp(d, 1.0, cubeUV_rangeClamp);\n\tfloat mipLevel = 0.5 * log2(d);\n\treturn vec2(floor(mipLevel), fract(mipLevel));\n}\n#define cubeUV_maxLods2 (log2(cubeUV_textureSize*0.25) - 2.0)\n#define cubeUV_rcpTextureSize (1.0 / cubeUV_textureSize)\nvec2 getCubeUV(vec3 direction, float roughnessLevel, float mipLevel) {\n\tmipLevel = roughnessLevel > cubeUV_maxLods2 - 3.0 ? 0.0 : mipLevel;\n\tfloat a = 16.0 * cubeUV_rcpTextureSize;\n\tvec2 exp2_packed = exp2( vec2( roughnessLevel, mipLevel ) );\n\tvec2 rcp_exp2_packed = vec2( 1.0 ) / exp2_packed;\n\tfloat powScale = exp2_packed.x * exp2_packed.y;\n\tfloat scale = rcp_exp2_packed.x * rcp_exp2_packed.y * 0.25;\n\tfloat mipOffset = 0.75*(1.0 - rcp_exp2_packed.y) * rcp_exp2_packed.x;\n\tbool bRes = mipLevel == 0.0;\n\tscale =  bRes && (scale < a) ? a : scale;\n\tvec3 r;\n\tvec2 offset;\n\tint face = getFaceFromDirection(direction);\n\tfloat rcpPowScale = 1.0 / powScale;\n\tif( face == 0) {\n\t\tr = vec3(direction.x, -direction.z, direction.y);\n\t\toffset = vec2(0.0+mipOffset,0.75 * rcpPowScale);\n\t\toffset.y = bRes && (offset.y < 2.0*a) ? a : offset.y;\n\t}\n\telse if( face == 1) {\n\t\tr = vec3(direction.y, direction.x, direction.z);\n\t\toffset = vec2(scale+mipOffset, 0.75 * rcpPowScale);\n\t\toffset.y = bRes && (offset.y < 2.0*a) ? a : offset.y;\n\t}\n\telse if( face == 2) {\n\t\tr = vec3(direction.z, direction.x, direction.y);\n\t\toffset = vec2(2.0*scale+mipOffset, 0.75 * rcpPowScale);\n\t\toffset.y = bRes && (offset.y < 2.0*a) ? a : offset.y;\n\t}\n\telse if( face == 3) {\n\t\tr = vec3(direction.x, direction.z, direction.y);\n\t\toffset = vec2(0.0+mipOffset,0.5 * rcpPowScale);\n\t\toffset.y = bRes && (offset.y < 2.0*a) ? 0.0 : offset.y;\n\t}\n\telse if( face == 4) {\n\t\tr = vec3(direction.y, direction.x, -direction.z);\n\t\toffset = vec2(scale+mipOffset, 0.5 * rcpPowScale);\n\t\toffset.y = bRes && (offset.y < 2.0*a) ? 0.0 : offset.y;\n\t}\n\telse {\n\t\tr = vec3(direction.z, -direction.x, direction.y);\n\t\toffset = vec2(2.0*scale+mipOffset, 0.5 * rcpPowScale);\n\t\toffset.y = bRes && (offset.y < 2.0*a) ? 0.0 : offset.y;\n\t}\n\tr = normalize(r);\n\tfloat texelOffset = 0.5 * cubeUV_rcpTextureSize;\n\tvec2 s = ( r.yz / abs( r.x ) + vec2( 1.0 ) ) * 0.5;\n\tvec2 base = offset + vec2( texelOffset );\n\treturn base + s * ( scale - 2.0 * texelOffset );\n}\n#define cubeUV_maxLods3 (log2(cubeUV_textureSize*0.25) - 3.0)\nvec4 textureCubeUV(vec3 reflectedDirection, float roughness ) {\n\tfloat roughnessVal = roughness* cubeUV_maxLods3;\n\tfloat r1 = floor(roughnessVal);\n\tfloat r2 = r1 + 1.0;\n\tfloat t = fract(roughnessVal);\n\tvec2 mipInfo = MipLevelInfo(reflectedDirection, r1, roughness);\n\tfloat s = mipInfo.y;\n\tfloat level0 = mipInfo.x;\n\tfloat level1 = level0 + 1.0;\n\tlevel1 = level1 > 5.0 ? 5.0 : level1;\n\tlevel0 += min( floor( s + 0.5 ), 5.0 );\n\tvec2 uv_10 = getCubeUV(reflectedDirection, r1, level0);\n\tvec4 color10 = envMapTexelToLinear(texture2D(envMap, uv_10));\n\tvec2 uv_20 = getCubeUV(reflectedDirection, r2, level0);\n\tvec4 color20 = envMapTexelToLinear(texture2D(envMap, uv_20));\n\tvec4 result = mix(color10, color20, t);\n\treturn vec4(result.rgb, 1.0);\n}\n#endif\n",
defaultnormal_vertex:"vec3 transformedNormal = normalMatrix * objectNormal;\n#ifdef FLIP_SIDED\n\ttransformedNormal = - transformedNormal;\n#endif\n",displacementmap_pars_vertex:"#ifdef USE_DISPLACEMENTMAP\n\tuniform sampler2D displacementMap;\n\tuniform float displacementScale;\n\tuniform float displacementBias;\n#endif\n",displacementmap_vertex:"#ifdef USE_DISPLACEMENTMAP\n\ttransformed += normalize( objectNormal ) * ( texture2D( displacementMap, uv ).x * displacementScale + displacementBias );\n#endif\n",
emissivemap_fragment:"#ifdef USE_EMISSIVEMAP\n\tvec4 emissiveColor = texture2D( emissiveMap, vUv );\n\temissiveColor.rgb = emissiveMapTexelToLinear( emissiveColor ).rgb;\n\ttotalEmissiveRadiance *= emissiveColor.rgb;\n#endif\n",emissivemap_pars_fragment:"#ifdef USE_EMISSIVEMAP\n\tuniform sampler2D emissiveMap;\n#endif\n",encodings_fragment:"  gl_FragColor = linearToOutputTexel( gl_FragColor );\n",encodings_pars_fragment:"\nvec4 LinearToLinear( in vec4 value ) {\n\treturn value;\n}\nvec4 GammaToLinear( in vec4 value, in float gammaFactor ) {\n\treturn vec4( pow( value.xyz, vec3( gammaFactor ) ), value.w );\n}\nvec4 LinearToGamma( in vec4 value, in float gammaFactor ) {\n\treturn vec4( pow( value.xyz, vec3( 1.0 / gammaFactor ) ), value.w );\n}\nvec4 sRGBToLinear( in vec4 value ) {\n\treturn vec4( mix( pow( value.rgb * 0.9478672986 + vec3( 0.0521327014 ), vec3( 2.4 ) ), value.rgb * 0.0773993808, vec3( lessThanEqual( value.rgb, vec3( 0.04045 ) ) ) ), value.w );\n}\nvec4 LinearTosRGB( in vec4 value ) {\n\treturn vec4( mix( pow( value.rgb, vec3( 0.41666 ) ) * 1.055 - vec3( 0.055 ), value.rgb * 12.92, vec3( lessThanEqual( value.rgb, vec3( 0.0031308 ) ) ) ), value.w );\n}\nvec4 RGBEToLinear( in vec4 value ) {\n\treturn vec4( value.rgb * exp2( value.a * 255.0 - 128.0 ), 1.0 );\n}\nvec4 LinearToRGBE( in vec4 value ) {\n\tfloat maxComponent = max( max( value.r, value.g ), value.b );\n\tfloat fExp = clamp( ceil( log2( maxComponent ) ), -128.0, 127.0 );\n\treturn vec4( value.rgb / exp2( fExp ), ( fExp + 128.0 ) / 255.0 );\n}\nvec4 RGBMToLinear( in vec4 value, in float maxRange ) {\n\treturn vec4( value.xyz * value.w * maxRange, 1.0 );\n}\nvec4 LinearToRGBM( in vec4 value, in float maxRange ) {\n\tfloat maxRGB = max( value.x, max( value.g, value.b ) );\n\tfloat M      = clamp( maxRGB / maxRange, 0.0, 1.0 );\n\tM            = ceil( M * 255.0 ) / 255.0;\n\treturn vec4( value.rgb / ( M * maxRange ), M );\n}\nvec4 RGBDToLinear( in vec4 value, in float maxRange ) {\n\treturn vec4( value.rgb * ( ( maxRange / 255.0 ) / value.a ), 1.0 );\n}\nvec4 LinearToRGBD( in vec4 value, in float maxRange ) {\n\tfloat maxRGB = max( value.x, max( value.g, value.b ) );\n\tfloat D      = max( maxRange / maxRGB, 1.0 );\n\tD            = min( floor( D ) / 255.0, 1.0 );\n\treturn vec4( value.rgb * ( D * ( 255.0 / maxRange ) ), D );\n}\nconst mat3 cLogLuvM = mat3( 0.2209, 0.3390, 0.4184, 0.1138, 0.6780, 0.7319, 0.0102, 0.1130, 0.2969 );\nvec4 LinearToLogLuv( in vec4 value )  {\n\tvec3 Xp_Y_XYZp = value.rgb * cLogLuvM;\n\tXp_Y_XYZp = max(Xp_Y_XYZp, vec3(1e-6, 1e-6, 1e-6));\n\tvec4 vResult;\n\tvResult.xy = Xp_Y_XYZp.xy / Xp_Y_XYZp.z;\n\tfloat Le = 2.0 * log2(Xp_Y_XYZp.y) + 127.0;\n\tvResult.w = fract(Le);\n\tvResult.z = (Le - (floor(vResult.w*255.0))/255.0)/255.0;\n\treturn vResult;\n}\nconst mat3 cLogLuvInverseM = mat3( 6.0014, -2.7008, -1.7996, -1.3320, 3.1029, -5.7721, 0.3008, -1.0882, 5.6268 );\nvec4 LogLuvToLinear( in vec4 value ) {\n\tfloat Le = value.z * 255.0 + value.w;\n\tvec3 Xp_Y_XYZp;\n\tXp_Y_XYZp.y = exp2((Le - 127.0) / 2.0);\n\tXp_Y_XYZp.z = Xp_Y_XYZp.y / value.y;\n\tXp_Y_XYZp.x = value.x * Xp_Y_XYZp.z;\n\tvec3 vRGB = Xp_Y_XYZp.rgb * cLogLuvInverseM;\n\treturn vec4( max(vRGB, 0.0), 1.0 );\n}\n",
envmap_fragment:"#ifdef USE_ENVMAP\n\t#if defined( USE_BUMPMAP ) || defined( USE_NORMALMAP ) || defined( PHONG )\n\t\tvec3 cameraToVertex = normalize( vWorldPosition - cameraPosition );\n\t\tvec3 worldNormal = inverseTransformDirection( normal, viewMatrix );\n\t\t#ifdef ENVMAP_MODE_REFLECTION\n\t\t\tvec3 reflectVec = reflect( cameraToVertex, worldNormal );\n\t\t#else\n\t\t\tvec3 reflectVec = refract( cameraToVertex, worldNormal, refractionRatio );\n\t\t#endif\n\t#else\n\t\tvec3 reflectVec = vReflect;\n\t#endif\n\t#ifdef ENVMAP_TYPE_CUBE\n\t\tvec4 envColor = textureCube( envMap, vec3( flipEnvMap * reflectVec.x, reflectVec.yz ) );\n\t#elif defined( ENVMAP_TYPE_EQUIREC )\n\t\tvec2 sampleUV;\n\t\treflectVec = normalize( reflectVec );\n\t\tsampleUV.y = asin( clamp( reflectVec.y, - 1.0, 1.0 ) ) * RECIPROCAL_PI + 0.5;\n\t\tsampleUV.x = atan( reflectVec.z, reflectVec.x ) * RECIPROCAL_PI2 + 0.5;\n\t\tvec4 envColor = texture2D( envMap, sampleUV );\n\t#elif defined( ENVMAP_TYPE_SPHERE )\n\t\treflectVec = normalize( reflectVec );\n\t\tvec3 reflectView = normalize( ( viewMatrix * vec4( reflectVec, 0.0 ) ).xyz + vec3( 0.0, 0.0, 1.0 ) );\n\t\tvec4 envColor = texture2D( envMap, reflectView.xy * 0.5 + 0.5 );\n\t#else\n\t\tvec4 envColor = vec4( 0.0 );\n\t#endif\n\tenvColor = envMapTexelToLinear( envColor );\n\t#ifdef ENVMAP_BLENDING_MULTIPLY\n\t\toutgoingLight = mix( outgoingLight, outgoingLight * envColor.xyz, specularStrength * reflectivity );\n\t#elif defined( ENVMAP_BLENDING_MIX )\n\t\toutgoingLight = mix( outgoingLight, envColor.xyz, specularStrength * reflectivity );\n\t#elif defined( ENVMAP_BLENDING_ADD )\n\t\toutgoingLight += envColor.xyz * specularStrength * reflectivity;\n\t#endif\n#endif\n",
envmap_pars_fragment:"#if defined( USE_ENVMAP ) || defined( PHYSICAL )\n\tuniform float reflectivity;\n\tuniform float envMapIntensity;\n#endif\n#ifdef USE_ENVMAP\n\t#if ! defined( PHYSICAL ) && ( defined( USE_BUMPMAP ) || defined( USE_NORMALMAP ) || defined( PHONG ) )\n\t\tvarying vec3 vWorldPosition;\n\t#endif\n\t#ifdef ENVMAP_TYPE_CUBE\n\t\tuniform samplerCube envMap;\n\t#else\n\t\tuniform sampler2D envMap;\n\t#endif\n\tuniform float flipEnvMap;\n\t#if defined( USE_BUMPMAP ) || defined( USE_NORMALMAP ) || defined( PHONG ) || defined( PHYSICAL )\n\t\tuniform float refractionRatio;\n\t#else\n\t\tvarying vec3 vReflect;\n\t#endif\n#endif\n",
envmap_pars_vertex:"#ifdef USE_ENVMAP\n\t#if defined( USE_BUMPMAP ) || defined( USE_NORMALMAP ) || defined( PHONG )\n\t\tvarying vec3 vWorldPosition;\n\t#else\n\t\tvarying vec3 vReflect;\n\t\tuniform float refractionRatio;\n\t#endif\n#endif\n",envmap_vertex:"#ifdef USE_ENVMAP\n\t#if defined( USE_BUMPMAP ) || defined( USE_NORMALMAP ) || defined( PHONG )\n\t\tvWorldPosition = worldPosition.xyz;\n\t#else\n\t\tvec3 cameraToVertex = normalize( worldPosition.xyz - cameraPosition );\n\t\tvec3 worldNormal = inverseTransformDirection( transformedNormal, viewMatrix );\n\t\t#ifdef ENVMAP_MODE_REFLECTION\n\t\t\tvReflect = reflect( cameraToVertex, worldNormal );\n\t\t#else\n\t\t\tvReflect = refract( cameraToVertex, worldNormal, refractionRatio );\n\t\t#endif\n\t#endif\n#endif\n",
fog_vertex:"\n#ifdef USE_FOG\nfogDepth = -mvPosition.z;\n#endif",fog_pars_vertex:"#ifdef USE_FOG\n  varying float fogDepth;\n#endif\n",fog_fragment:"#ifdef USE_FOG\n\t#ifdef FOG_EXP2\n\t\tfloat fogFactor = whiteCompliment( exp2( - fogDensity * fogDensity * fogDepth * fogDepth * LOG2 ) );\n\t#else\n\t\tfloat fogFactor = smoothstep( fogNear, fogFar, fogDepth );\n\t#endif\n\tgl_FragColor.rgb = mix( gl_FragColor.rgb, fogColor, fogFactor );\n#endif\n",fog_pars_fragment:"#ifdef USE_FOG\n\tuniform vec3 fogColor;\n\tvarying float fogDepth;\n\t#ifdef FOG_EXP2\n\t\tuniform float fogDensity;\n\t#else\n\t\tuniform float fogNear;\n\t\tuniform float fogFar;\n\t#endif\n#endif\n",
gradientmap_pars_fragment:"#ifdef TOON\n\tuniform sampler2D gradientMap;\n\tvec3 getGradientIrradiance( vec3 normal, vec3 lightDirection ) {\n\t\tfloat dotNL = dot( normal, lightDirection );\n\t\tvec2 coord = vec2( dotNL * 0.5 + 0.5, 0.0 );\n\t\t#ifdef USE_GRADIENTMAP\n\t\t\treturn texture2D( gradientMap, coord ).rgb;\n\t\t#else\n\t\t\treturn ( coord.x < 0.7 ) ? vec3( 0.7 ) : vec3( 1.0 );\n\t\t#endif\n\t}\n#endif\n",lightmap_fragment:"#ifdef USE_LIGHTMAP\n\treflectedLight.indirectDiffuse += PI * texture2D( lightMap, vUv2 ).xyz * lightMapIntensity;\n#endif\n",
lightmap_pars_fragment:"#ifdef USE_LIGHTMAP\n\tuniform sampler2D lightMap;\n\tuniform float lightMapIntensity;\n#endif",lights_lambert_vertex:"vec3 diffuse = vec3( 1.0 );\nGeometricContext geometry;\ngeometry.position = mvPosition.xyz;\ngeometry.normal = normalize( transformedNormal );\ngeometry.viewDir = normalize( -mvPosition.xyz );\nGeometricContext backGeometry;\nbackGeometry.position = geometry.position;\nbackGeometry.normal = -geometry.normal;\nbackGeometry.viewDir = geometry.viewDir;\nvLightFront = vec3( 0.0 );\n#ifdef DOUBLE_SIDED\n\tvLightBack = vec3( 0.0 );\n#endif\nIncidentLight directLight;\nfloat dotNL;\nvec3 directLightColor_Diffuse;\n#if NUM_POINT_LIGHTS > 0\n\tfor ( int i = 0; i < NUM_POINT_LIGHTS; i ++ ) {\n\t\tgetPointDirectLightIrradiance( pointLights[ i ], geometry, directLight );\n\t\tdotNL = dot( geometry.normal, directLight.direction );\n\t\tdirectLightColor_Diffuse = PI * directLight.color;\n\t\tvLightFront += saturate( dotNL ) * directLightColor_Diffuse;\n\t\t#ifdef DOUBLE_SIDED\n\t\t\tvLightBack += saturate( -dotNL ) * directLightColor_Diffuse;\n\t\t#endif\n\t}\n#endif\n#if NUM_SPOT_LIGHTS > 0\n\tfor ( int i = 0; i < NUM_SPOT_LIGHTS; i ++ ) {\n\t\tgetSpotDirectLightIrradiance( spotLights[ i ], geometry, directLight );\n\t\tdotNL = dot( geometry.normal, directLight.direction );\n\t\tdirectLightColor_Diffuse = PI * directLight.color;\n\t\tvLightFront += saturate( dotNL ) * directLightColor_Diffuse;\n\t\t#ifdef DOUBLE_SIDED\n\t\t\tvLightBack += saturate( -dotNL ) * directLightColor_Diffuse;\n\t\t#endif\n\t}\n#endif\n#if NUM_DIR_LIGHTS > 0\n\tfor ( int i = 0; i < NUM_DIR_LIGHTS; i ++ ) {\n\t\tgetDirectionalDirectLightIrradiance( directionalLights[ i ], geometry, directLight );\n\t\tdotNL = dot( geometry.normal, directLight.direction );\n\t\tdirectLightColor_Diffuse = PI * directLight.color;\n\t\tvLightFront += saturate( dotNL ) * directLightColor_Diffuse;\n\t\t#ifdef DOUBLE_SIDED\n\t\t\tvLightBack += saturate( -dotNL ) * directLightColor_Diffuse;\n\t\t#endif\n\t}\n#endif\n#if NUM_HEMI_LIGHTS > 0\n\tfor ( int i = 0; i < NUM_HEMI_LIGHTS; i ++ ) {\n\t\tvLightFront += getHemisphereLightIrradiance( hemisphereLights[ i ], geometry );\n\t\t#ifdef DOUBLE_SIDED\n\t\t\tvLightBack += getHemisphereLightIrradiance( hemisphereLights[ i ], backGeometry );\n\t\t#endif\n\t}\n#endif\n",
lights_pars:"uniform vec3 ambientLightColor;\nvec3 getAmbientLightIrradiance( const in vec3 ambientLightColor ) {\n\tvec3 irradiance = ambientLightColor;\n\t#ifndef PHYSICALLY_CORRECT_LIGHTS\n\t\tirradiance *= PI;\n\t#endif\n\treturn irradiance;\n}\n#if NUM_DIR_LIGHTS > 0\n\tstruct DirectionalLight {\n\t\tvec3 direction;\n\t\tvec3 color;\n\t\tint shadow;\n\t\tfloat shadowBias;\n\t\tfloat shadowRadius;\n\t\tvec2 shadowMapSize;\n\t};\n\tuniform DirectionalLight directionalLights[ NUM_DIR_LIGHTS ];\n\tvoid getDirectionalDirectLightIrradiance( const in DirectionalLight directionalLight, const in GeometricContext geometry, out IncidentLight directLight ) {\n\t\tdirectLight.color = directionalLight.color;\n\t\tdirectLight.direction = directionalLight.direction;\n\t\tdirectLight.visible = true;\n\t}\n#endif\n#if NUM_POINT_LIGHTS > 0\n\tstruct PointLight {\n\t\tvec3 position;\n\t\tvec3 color;\n\t\tfloat distance;\n\t\tfloat decay;\n\t\tint shadow;\n\t\tfloat shadowBias;\n\t\tfloat shadowRadius;\n\t\tvec2 shadowMapSize;\n\t\tfloat shadowCameraNear;\n\t\tfloat shadowCameraFar;\n\t};\n\tuniform PointLight pointLights[ NUM_POINT_LIGHTS ];\n\tvoid getPointDirectLightIrradiance( const in PointLight pointLight, const in GeometricContext geometry, out IncidentLight directLight ) {\n\t\tvec3 lVector = pointLight.position - geometry.position;\n\t\tdirectLight.direction = normalize( lVector );\n\t\tfloat lightDistance = length( lVector );\n\t\tdirectLight.color = pointLight.color;\n\t\tdirectLight.color *= punctualLightIntensityToIrradianceFactor( lightDistance, pointLight.distance, pointLight.decay );\n\t\tdirectLight.visible = ( directLight.color != vec3( 0.0 ) );\n\t}\n#endif\n#if NUM_SPOT_LIGHTS > 0\n\tstruct SpotLight {\n\t\tvec3 position;\n\t\tvec3 direction;\n\t\tvec3 color;\n\t\tfloat distance;\n\t\tfloat decay;\n\t\tfloat coneCos;\n\t\tfloat penumbraCos;\n\t\tint shadow;\n\t\tfloat shadowBias;\n\t\tfloat shadowRadius;\n\t\tvec2 shadowMapSize;\n\t};\n\tuniform SpotLight spotLights[ NUM_SPOT_LIGHTS ];\n\tvoid getSpotDirectLightIrradiance( const in SpotLight spotLight, const in GeometricContext geometry, out IncidentLight directLight  ) {\n\t\tvec3 lVector = spotLight.position - geometry.position;\n\t\tdirectLight.direction = normalize( lVector );\n\t\tfloat lightDistance = length( lVector );\n\t\tfloat angleCos = dot( directLight.direction, spotLight.direction );\n\t\tif ( angleCos > spotLight.coneCos ) {\n\t\t\tfloat spotEffect = smoothstep( spotLight.coneCos, spotLight.penumbraCos, angleCos );\n\t\t\tdirectLight.color = spotLight.color;\n\t\t\tdirectLight.color *= spotEffect * punctualLightIntensityToIrradianceFactor( lightDistance, spotLight.distance, spotLight.decay );\n\t\t\tdirectLight.visible = true;\n\t\t} else {\n\t\t\tdirectLight.color = vec3( 0.0 );\n\t\t\tdirectLight.visible = false;\n\t\t}\n\t}\n#endif\n#if NUM_RECT_AREA_LIGHTS > 0\n\tstruct RectAreaLight {\n\t\tvec3 color;\n\t\tvec3 position;\n\t\tvec3 halfWidth;\n\t\tvec3 halfHeight;\n\t};\n\tuniform sampler2D ltcMat;\tuniform sampler2D ltcMag;\n\tuniform RectAreaLight rectAreaLights[ NUM_RECT_AREA_LIGHTS ];\n#endif\n#if NUM_HEMI_LIGHTS > 0\n\tstruct HemisphereLight {\n\t\tvec3 direction;\n\t\tvec3 skyColor;\n\t\tvec3 groundColor;\n\t};\n\tuniform HemisphereLight hemisphereLights[ NUM_HEMI_LIGHTS ];\n\tvec3 getHemisphereLightIrradiance( const in HemisphereLight hemiLight, const in GeometricContext geometry ) {\n\t\tfloat dotNL = dot( geometry.normal, hemiLight.direction );\n\t\tfloat hemiDiffuseWeight = 0.5 * dotNL + 0.5;\n\t\tvec3 irradiance = mix( hemiLight.groundColor, hemiLight.skyColor, hemiDiffuseWeight );\n\t\t#ifndef PHYSICALLY_CORRECT_LIGHTS\n\t\t\tirradiance *= PI;\n\t\t#endif\n\t\treturn irradiance;\n\t}\n#endif\n#if defined( USE_ENVMAP ) && defined( PHYSICAL )\n\tvec3 getLightProbeIndirectIrradiance( const in GeometricContext geometry, const in int maxMIPLevel ) {\n\t\tvec3 worldNormal = inverseTransformDirection( geometry.normal, viewMatrix );\n\t\t#ifdef ENVMAP_TYPE_CUBE\n\t\t\tvec3 queryVec = vec3( flipEnvMap * worldNormal.x, worldNormal.yz );\n\t\t\t#ifdef TEXTURE_LOD_EXT\n\t\t\t\tvec4 envMapColor = textureCubeLodEXT( envMap, queryVec, float( maxMIPLevel ) );\n\t\t\t#else\n\t\t\t\tvec4 envMapColor = textureCube( envMap, queryVec, float( maxMIPLevel ) );\n\t\t\t#endif\n\t\t\tenvMapColor.rgb = envMapTexelToLinear( envMapColor ).rgb;\n\t\t#elif defined( ENVMAP_TYPE_CUBE_UV )\n\t\t\tvec3 queryVec = vec3( flipEnvMap * worldNormal.x, worldNormal.yz );\n\t\t\tvec4 envMapColor = textureCubeUV( queryVec, 1.0 );\n\t\t#else\n\t\t\tvec4 envMapColor = vec4( 0.0 );\n\t\t#endif\n\t\treturn PI * envMapColor.rgb * envMapIntensity;\n\t}\n\tfloat getSpecularMIPLevel( const in float blinnShininessExponent, const in int maxMIPLevel ) {\n\t\tfloat maxMIPLevelScalar = float( maxMIPLevel );\n\t\tfloat desiredMIPLevel = maxMIPLevelScalar - 0.79248 - 0.5 * log2( pow2( blinnShininessExponent ) + 1.0 );\n\t\treturn clamp( desiredMIPLevel, 0.0, maxMIPLevelScalar );\n\t}\n\tvec3 getLightProbeIndirectRadiance( const in GeometricContext geometry, const in float blinnShininessExponent, const in int maxMIPLevel ) {\n\t\t#ifdef ENVMAP_MODE_REFLECTION\n\t\t\tvec3 reflectVec = reflect( -geometry.viewDir, geometry.normal );\n\t\t#else\n\t\t\tvec3 reflectVec = refract( -geometry.viewDir, geometry.normal, refractionRatio );\n\t\t#endif\n\t\treflectVec = inverseTransformDirection( reflectVec, viewMatrix );\n\t\tfloat specularMIPLevel = getSpecularMIPLevel( blinnShininessExponent, maxMIPLevel );\n\t\t#ifdef ENVMAP_TYPE_CUBE\n\t\t\tvec3 queryReflectVec = vec3( flipEnvMap * reflectVec.x, reflectVec.yz );\n\t\t\t#ifdef TEXTURE_LOD_EXT\n\t\t\t\tvec4 envMapColor = textureCubeLodEXT( envMap, queryReflectVec, specularMIPLevel );\n\t\t\t#else\n\t\t\t\tvec4 envMapColor = textureCube( envMap, queryReflectVec, specularMIPLevel );\n\t\t\t#endif\n\t\t\tenvMapColor.rgb = envMapTexelToLinear( envMapColor ).rgb;\n\t\t#elif defined( ENVMAP_TYPE_CUBE_UV )\n\t\t\tvec3 queryReflectVec = vec3( flipEnvMap * reflectVec.x, reflectVec.yz );\n\t\t\tvec4 envMapColor = textureCubeUV(queryReflectVec, BlinnExponentToGGXRoughness(blinnShininessExponent));\n\t\t#elif defined( ENVMAP_TYPE_EQUIREC )\n\t\t\tvec2 sampleUV;\n\t\t\tsampleUV.y = asin( clamp( reflectVec.y, - 1.0, 1.0 ) ) * RECIPROCAL_PI + 0.5;\n\t\t\tsampleUV.x = atan( reflectVec.z, reflectVec.x ) * RECIPROCAL_PI2 + 0.5;\n\t\t\t#ifdef TEXTURE_LOD_EXT\n\t\t\t\tvec4 envMapColor = texture2DLodEXT( envMap, sampleUV, specularMIPLevel );\n\t\t\t#else\n\t\t\t\tvec4 envMapColor = texture2D( envMap, sampleUV, specularMIPLevel );\n\t\t\t#endif\n\t\t\tenvMapColor.rgb = envMapTexelToLinear( envMapColor ).rgb;\n\t\t#elif defined( ENVMAP_TYPE_SPHERE )\n\t\t\tvec3 reflectView = normalize( ( viewMatrix * vec4( reflectVec, 0.0 ) ).xyz + vec3( 0.0,0.0,1.0 ) );\n\t\t\t#ifdef TEXTURE_LOD_EXT\n\t\t\t\tvec4 envMapColor = texture2DLodEXT( envMap, reflectView.xy * 0.5 + 0.5, specularMIPLevel );\n\t\t\t#else\n\t\t\t\tvec4 envMapColor = texture2D( envMap, reflectView.xy * 0.5 + 0.5, specularMIPLevel );\n\t\t\t#endif\n\t\t\tenvMapColor.rgb = envMapTexelToLinear( envMapColor ).rgb;\n\t\t#endif\n\t\treturn envMapColor.rgb * envMapIntensity;\n\t}\n#endif\n",
lights_phong_fragment:"BlinnPhongMaterial material;\nmaterial.diffuseColor = diffuseColor.rgb;\nmaterial.specularColor = specular;\nmaterial.specularShininess = shininess;\nmaterial.specularStrength = specularStrength;\n",lights_phong_pars_fragment:"varying vec3 vViewPosition;\n#ifndef FLAT_SHADED\n\tvarying vec3 vNormal;\n#endif\nstruct BlinnPhongMaterial {\n\tvec3\tdiffuseColor;\n\tvec3\tspecularColor;\n\tfloat\tspecularShininess;\n\tfloat\tspecularStrength;\n};\nvoid RE_Direct_BlinnPhong( const in IncidentLight directLight, const in GeometricContext geometry, const in BlinnPhongMaterial material, inout ReflectedLight reflectedLight ) {\n\t#ifdef TOON\n\t\tvec3 irradiance = getGradientIrradiance( geometry.normal, directLight.direction ) * directLight.color;\n\t#else\n\t\tfloat dotNL = saturate( dot( geometry.normal, directLight.direction ) );\n\t\tvec3 irradiance = dotNL * directLight.color;\n\t#endif\n\t#ifndef PHYSICALLY_CORRECT_LIGHTS\n\t\tirradiance *= PI;\n\t#endif\n\treflectedLight.directDiffuse += irradiance * BRDF_Diffuse_Lambert( material.diffuseColor );\n\treflectedLight.directSpecular += irradiance * BRDF_Specular_BlinnPhong( directLight, geometry, material.specularColor, material.specularShininess ) * material.specularStrength;\n}\nvoid RE_IndirectDiffuse_BlinnPhong( const in vec3 irradiance, const in GeometricContext geometry, const in BlinnPhongMaterial material, inout ReflectedLight reflectedLight ) {\n\treflectedLight.indirectDiffuse += irradiance * BRDF_Diffuse_Lambert( material.diffuseColor );\n}\n#define RE_Direct\t\t\t\tRE_Direct_BlinnPhong\n#define RE_IndirectDiffuse\t\tRE_IndirectDiffuse_BlinnPhong\n#define Material_LightProbeLOD( material )\t(0)\n",
lights_physical_fragment:"PhysicalMaterial material;\nmaterial.diffuseColor = diffuseColor.rgb * ( 1.0 - metalnessFactor );\nmaterial.specularRoughness = clamp( roughnessFactor, 0.04, 1.0 );\n#ifdef STANDARD\n\tmaterial.specularColor = mix( vec3( DEFAULT_SPECULAR_COEFFICIENT ), diffuseColor.rgb, metalnessFactor );\n#else\n\tmaterial.specularColor = mix( vec3( MAXIMUM_SPECULAR_COEFFICIENT * pow2( reflectivity ) ), diffuseColor.rgb, metalnessFactor );\n\tmaterial.clearCoat = saturate( clearCoat );\tmaterial.clearCoatRoughness = clamp( clearCoatRoughness, 0.04, 1.0 );\n#endif\n",
lights_physical_pars_fragment:"struct PhysicalMaterial {\n\tvec3\tdiffuseColor;\n\tfloat\tspecularRoughness;\n\tvec3\tspecularColor;\n\t#ifndef STANDARD\n\t\tfloat clearCoat;\n\t\tfloat clearCoatRoughness;\n\t#endif\n};\n#define MAXIMUM_SPECULAR_COEFFICIENT 0.16\n#define DEFAULT_SPECULAR_COEFFICIENT 0.04\nfloat clearCoatDHRApprox( const in float roughness, const in float dotNL ) {\n\treturn DEFAULT_SPECULAR_COEFFICIENT + ( 1.0 - DEFAULT_SPECULAR_COEFFICIENT ) * ( pow( 1.0 - dotNL, 5.0 ) * pow( 1.0 - roughness, 2.0 ) );\n}\n#if NUM_RECT_AREA_LIGHTS > 0\n\tvoid RE_Direct_RectArea_Physical( const in RectAreaLight rectAreaLight, const in GeometricContext geometry, const in PhysicalMaterial material, inout ReflectedLight reflectedLight ) {\n\t\tvec3 normal = geometry.normal;\n\t\tvec3 viewDir = geometry.viewDir;\n\t\tvec3 position = geometry.position;\n\t\tvec3 lightPos = rectAreaLight.position;\n\t\tvec3 halfWidth = rectAreaLight.halfWidth;\n\t\tvec3 halfHeight = rectAreaLight.halfHeight;\n\t\tvec3 lightColor = rectAreaLight.color;\n\t\tfloat roughness = material.specularRoughness;\n\t\tvec3 rectCoords[ 4 ];\n\t\trectCoords[ 0 ] = lightPos - halfWidth - halfHeight;\t\trectCoords[ 1 ] = lightPos + halfWidth - halfHeight;\n\t\trectCoords[ 2 ] = lightPos + halfWidth + halfHeight;\n\t\trectCoords[ 3 ] = lightPos - halfWidth + halfHeight;\n\t\tvec2 uv = LTC_Uv( normal, viewDir, roughness );\n\t\tfloat norm = texture2D( ltcMag, uv ).a;\n\t\tvec4 t = texture2D( ltcMat, uv );\n\t\tmat3 mInv = mat3(\n\t\t\tvec3(   1,   0, t.y ),\n\t\t\tvec3(   0, t.z,   0 ),\n\t\t\tvec3( t.w,   0, t.x )\n\t\t);\n\t\treflectedLight.directSpecular += lightColor * material.specularColor * norm * LTC_Evaluate( normal, viewDir, position, mInv, rectCoords );\n\t\treflectedLight.directDiffuse += lightColor * material.diffuseColor * LTC_Evaluate( normal, viewDir, position, mat3( 1 ), rectCoords );\n\t}\n#endif\nvoid RE_Direct_Physical( const in IncidentLight directLight, const in GeometricContext geometry, const in PhysicalMaterial material, inout ReflectedLight reflectedLight ) {\n\tfloat dotNL = saturate( dot( geometry.normal, directLight.direction ) );\n\tvec3 irradiance = dotNL * directLight.color;\n\t#ifndef PHYSICALLY_CORRECT_LIGHTS\n\t\tirradiance *= PI;\n\t#endif\n\t#ifndef STANDARD\n\t\tfloat clearCoatDHR = material.clearCoat * clearCoatDHRApprox( material.clearCoatRoughness, dotNL );\n\t#else\n\t\tfloat clearCoatDHR = 0.0;\n\t#endif\n\treflectedLight.directSpecular += ( 1.0 - clearCoatDHR ) * irradiance * BRDF_Specular_GGX( directLight, geometry, material.specularColor, material.specularRoughness );\n\treflectedLight.directDiffuse += ( 1.0 - clearCoatDHR ) * irradiance * BRDF_Diffuse_Lambert( material.diffuseColor );\n\t#ifndef STANDARD\n\t\treflectedLight.directSpecular += irradiance * material.clearCoat * BRDF_Specular_GGX( directLight, geometry, vec3( DEFAULT_SPECULAR_COEFFICIENT ), material.clearCoatRoughness );\n\t#endif\n}\nvoid RE_IndirectDiffuse_Physical( const in vec3 irradiance, const in GeometricContext geometry, const in PhysicalMaterial material, inout ReflectedLight reflectedLight ) {\n\treflectedLight.indirectDiffuse += irradiance * BRDF_Diffuse_Lambert( material.diffuseColor );\n}\nvoid RE_IndirectSpecular_Physical( const in vec3 radiance, const in vec3 clearCoatRadiance, const in GeometricContext geometry, const in PhysicalMaterial material, inout ReflectedLight reflectedLight ) {\n\t#ifndef STANDARD\n\t\tfloat dotNV = saturate( dot( geometry.normal, geometry.viewDir ) );\n\t\tfloat dotNL = dotNV;\n\t\tfloat clearCoatDHR = material.clearCoat * clearCoatDHRApprox( material.clearCoatRoughness, dotNL );\n\t#else\n\t\tfloat clearCoatDHR = 0.0;\n\t#endif\n\treflectedLight.indirectSpecular += ( 1.0 - clearCoatDHR ) * radiance * BRDF_Specular_GGX_Environment( geometry, material.specularColor, material.specularRoughness );\n\t#ifndef STANDARD\n\t\treflectedLight.indirectSpecular += clearCoatRadiance * material.clearCoat * BRDF_Specular_GGX_Environment( geometry, vec3( DEFAULT_SPECULAR_COEFFICIENT ), material.clearCoatRoughness );\n\t#endif\n}\n#define RE_Direct\t\t\t\tRE_Direct_Physical\n#define RE_Direct_RectArea\t\tRE_Direct_RectArea_Physical\n#define RE_IndirectDiffuse\t\tRE_IndirectDiffuse_Physical\n#define RE_IndirectSpecular\t\tRE_IndirectSpecular_Physical\n#define Material_BlinnShininessExponent( material )   GGXRoughnessToBlinnExponent( material.specularRoughness )\n#define Material_ClearCoat_BlinnShininessExponent( material )   GGXRoughnessToBlinnExponent( material.clearCoatRoughness )\nfloat computeSpecularOcclusion( const in float dotNV, const in float ambientOcclusion, const in float roughness ) {\n\treturn saturate( pow( dotNV + ambientOcclusion, exp2( - 16.0 * roughness - 1.0 ) ) - 1.0 + ambientOcclusion );\n}\n",
lights_template:"\nGeometricContext geometry;\ngeometry.position = - vViewPosition;\ngeometry.normal = normal;\ngeometry.viewDir = normalize( vViewPosition );\nIncidentLight directLight;\n#if ( NUM_POINT_LIGHTS > 0 ) && defined( RE_Direct )\n\tPointLight pointLight;\n\tfor ( int i = 0; i < NUM_POINT_LIGHTS; i ++ ) {\n\t\tpointLight = pointLights[ i ];\n\t\tgetPointDirectLightIrradiance( pointLight, geometry, directLight );\n\t\t#ifdef USE_SHADOWMAP\n\t\tdirectLight.color *= all( bvec2( pointLight.shadow, directLight.visible ) ) ? getPointShadow( pointShadowMap[ i ], pointLight.shadowMapSize, pointLight.shadowBias, pointLight.shadowRadius, vPointShadowCoord[ i ], pointLight.shadowCameraNear, pointLight.shadowCameraFar ) : 1.0;\n\t\t#endif\n\t\tRE_Direct( directLight, geometry, material, reflectedLight );\n\t}\n#endif\n#if ( NUM_SPOT_LIGHTS > 0 ) && defined( RE_Direct )\n\tSpotLight spotLight;\n\tfor ( int i = 0; i < NUM_SPOT_LIGHTS; i ++ ) {\n\t\tspotLight = spotLights[ i ];\n\t\tgetSpotDirectLightIrradiance( spotLight, geometry, directLight );\n\t\t#ifdef USE_SHADOWMAP\n\t\tdirectLight.color *= all( bvec2( spotLight.shadow, directLight.visible ) ) ? getShadow( spotShadowMap[ i ], spotLight.shadowMapSize, spotLight.shadowBias, spotLight.shadowRadius, vSpotShadowCoord[ i ] ) : 1.0;\n\t\t#endif\n\t\tRE_Direct( directLight, geometry, material, reflectedLight );\n\t}\n#endif\n#if ( NUM_DIR_LIGHTS > 0 ) && defined( RE_Direct )\n\tDirectionalLight directionalLight;\n\tfor ( int i = 0; i < NUM_DIR_LIGHTS; i ++ ) {\n\t\tdirectionalLight = directionalLights[ i ];\n\t\tgetDirectionalDirectLightIrradiance( directionalLight, geometry, directLight );\n\t\t#ifdef USE_SHADOWMAP\n\t\tdirectLight.color *= all( bvec2( directionalLight.shadow, directLight.visible ) ) ? getShadow( directionalShadowMap[ i ], directionalLight.shadowMapSize, directionalLight.shadowBias, directionalLight.shadowRadius, vDirectionalShadowCoord[ i ] ) : 1.0;\n\t\t#endif\n\t\tRE_Direct( directLight, geometry, material, reflectedLight );\n\t}\n#endif\n#if ( NUM_RECT_AREA_LIGHTS > 0 ) && defined( RE_Direct_RectArea )\n\tRectAreaLight rectAreaLight;\n\tfor ( int i = 0; i < NUM_RECT_AREA_LIGHTS; i ++ ) {\n\t\trectAreaLight = rectAreaLights[ i ];\n\t\tRE_Direct_RectArea( rectAreaLight, geometry, material, reflectedLight );\n\t}\n#endif\n#if defined( RE_IndirectDiffuse )\n\tvec3 irradiance = getAmbientLightIrradiance( ambientLightColor );\n\t#ifdef USE_LIGHTMAP\n\t\tvec3 lightMapIrradiance = texture2D( lightMap, vUv2 ).xyz * lightMapIntensity;\n\t\t#ifndef PHYSICALLY_CORRECT_LIGHTS\n\t\t\tlightMapIrradiance *= PI;\n\t\t#endif\n\t\tirradiance += lightMapIrradiance;\n\t#endif\n\t#if ( NUM_HEMI_LIGHTS > 0 )\n\t\tfor ( int i = 0; i < NUM_HEMI_LIGHTS; i ++ ) {\n\t\t\tirradiance += getHemisphereLightIrradiance( hemisphereLights[ i ], geometry );\n\t\t}\n\t#endif\n\t#if defined( USE_ENVMAP ) && defined( PHYSICAL ) && defined( ENVMAP_TYPE_CUBE_UV )\n\t\tirradiance += getLightProbeIndirectIrradiance( geometry, 8 );\n\t#endif\n\tRE_IndirectDiffuse( irradiance, geometry, material, reflectedLight );\n#endif\n#if defined( USE_ENVMAP ) && defined( RE_IndirectSpecular )\n\tvec3 radiance = getLightProbeIndirectRadiance( geometry, Material_BlinnShininessExponent( material ), 8 );\n\t#ifndef STANDARD\n\t\tvec3 clearCoatRadiance = getLightProbeIndirectRadiance( geometry, Material_ClearCoat_BlinnShininessExponent( material ), 8 );\n\t#else\n\t\tvec3 clearCoatRadiance = vec3( 0.0 );\n\t#endif\n\tRE_IndirectSpecular( radiance, clearCoatRadiance, geometry, material, reflectedLight );\n#endif\n",
logdepthbuf_fragment:"#if defined(USE_LOGDEPTHBUF) && defined(USE_LOGDEPTHBUF_EXT)\n\tgl_FragDepthEXT = log2(vFragDepth) * logDepthBufFC * 0.5;\n#endif",logdepthbuf_pars_fragment:"#ifdef USE_LOGDEPTHBUF\n\tuniform float logDepthBufFC;\n\t#ifdef USE_LOGDEPTHBUF_EXT\n\t\tvarying float vFragDepth;\n\t#endif\n#endif\n",logdepthbuf_pars_vertex:"#ifdef USE_LOGDEPTHBUF\n\t#ifdef USE_LOGDEPTHBUF_EXT\n\t\tvarying float vFragDepth;\n\t#endif\n\tuniform float logDepthBufFC;\n#endif",logdepthbuf_vertex:"#ifdef USE_LOGDEPTHBUF\n\tgl_Position.z = log2(max( EPSILON, gl_Position.w + 1.0 )) * logDepthBufFC;\n\t#ifdef USE_LOGDEPTHBUF_EXT\n\t\tvFragDepth = 1.0 + gl_Position.w;\n\t#else\n\t\tgl_Position.z = (gl_Position.z - 1.0) * gl_Position.w;\n\t#endif\n#endif\n",
map_fragment:"#ifdef USE_MAP\n\tvec4 texelColor = texture2D( map, vUv );\n\ttexelColor = mapTexelToLinear( texelColor );\n\tdiffuseColor *= texelColor;\n#endif\n",map_pars_fragment:"#ifdef USE_MAP\n\tuniform sampler2D map;\n#endif\n",map_particle_fragment:"#ifdef USE_MAP\n\tvec4 mapTexel = texture2D( map, vec2( gl_PointCoord.x, 1.0 - gl_PointCoord.y ) * offsetRepeat.zw + offsetRepeat.xy );\n\tdiffuseColor *= mapTexelToLinear( mapTexel );\n#endif\n",map_particle_pars_fragment:"#ifdef USE_MAP\n\tuniform vec4 offsetRepeat;\n\tuniform sampler2D map;\n#endif\n",
metalnessmap_fragment:"float metalnessFactor = metalness;\n#ifdef USE_METALNESSMAP\n\tvec4 texelMetalness = texture2D( metalnessMap, vUv );\n\tmetalnessFactor *= texelMetalness.b;\n#endif\n",metalnessmap_pars_fragment:"#ifdef USE_METALNESSMAP\n\tuniform sampler2D metalnessMap;\n#endif",morphnormal_vertex:"#ifdef USE_MORPHNORMALS\n\tobjectNormal += ( morphNormal0 - normal ) * morphTargetInfluences[ 0 ];\n\tobjectNormal += ( morphNormal1 - normal ) * morphTargetInfluences[ 1 ];\n\tobjectNormal += ( morphNormal2 - normal ) * morphTargetInfluences[ 2 ];\n\tobjectNormal += ( morphNormal3 - normal ) * morphTargetInfluences[ 3 ];\n#endif\n",
morphtarget_pars_vertex:"#ifdef USE_MORPHTARGETS\n\t#ifndef USE_MORPHNORMALS\n\tuniform float morphTargetInfluences[ 8 ];\n\t#else\n\tuniform float morphTargetInfluences[ 4 ];\n\t#endif\n#endif",morphtarget_vertex:"#ifdef USE_MORPHTARGETS\n\ttransformed += ( morphTarget0 - position ) * morphTargetInfluences[ 0 ];\n\ttransformed += ( morphTarget1 - position ) * morphTargetInfluences[ 1 ];\n\ttransformed += ( morphTarget2 - position ) * morphTargetInfluences[ 2 ];\n\ttransformed += ( morphTarget3 - position ) * morphTargetInfluences[ 3 ];\n\t#ifndef USE_MORPHNORMALS\n\ttransformed += ( morphTarget4 - position ) * morphTargetInfluences[ 4 ];\n\ttransformed += ( morphTarget5 - position ) * morphTargetInfluences[ 5 ];\n\ttransformed += ( morphTarget6 - position ) * morphTargetInfluences[ 6 ];\n\ttransformed += ( morphTarget7 - position ) * morphTargetInfluences[ 7 ];\n\t#endif\n#endif\n",
normal_fragment:"#ifdef FLAT_SHADED\n\tvec3 fdx = vec3( dFdx( vViewPosition.x ), dFdx( vViewPosition.y ), dFdx( vViewPosition.z ) );\n\tvec3 fdy = vec3( dFdy( vViewPosition.x ), dFdy( vViewPosition.y ), dFdy( vViewPosition.z ) );\n\tvec3 normal = normalize( cross( fdx, fdy ) );\n#else\n\tvec3 normal = normalize( vNormal );\n\t#ifdef DOUBLE_SIDED\n\t\tnormal = normal * ( float( gl_FrontFacing ) * 2.0 - 1.0 );\n\t#endif\n#endif\n#ifdef USE_NORMALMAP\n\tnormal = perturbNormal2Arb( -vViewPosition, normal );\n#elif defined( USE_BUMPMAP )\n\tnormal = perturbNormalArb( -vViewPosition, normal, dHdxy_fwd() );\n#endif\n",
normalmap_pars_fragment:"#ifdef USE_NORMALMAP\n\tuniform sampler2D normalMap;\n\tuniform vec2 normalScale;\n\tvec3 perturbNormal2Arb( vec3 eye_pos, vec3 surf_norm ) {\n\t\tvec3 q0 = vec3( dFdx( eye_pos.x ), dFdx( eye_pos.y ), dFdx( eye_pos.z ) );\n\t\tvec3 q1 = vec3( dFdy( eye_pos.x ), dFdy( eye_pos.y ), dFdy( eye_pos.z ) );\n\t\tvec2 st0 = dFdx( vUv.st );\n\t\tvec2 st1 = dFdy( vUv.st );\n\t\tvec3 S = normalize( q0 * st1.t - q1 * st0.t );\n\t\tvec3 T = normalize( -q0 * st1.s + q1 * st0.s );\n\t\tvec3 N = normalize( surf_norm );\n\t\tvec3 mapN = texture2D( normalMap, vUv ).xyz * 2.0 - 1.0;\n\t\tmapN.xy = normalScale * mapN.xy;\n\t\tmat3 tsn = mat3( S, T, N );\n\t\treturn normalize( tsn * mapN );\n\t}\n#endif\n",
packing:"vec3 packNormalToRGB( const in vec3 normal ) {\n\treturn normalize( normal ) * 0.5 + 0.5;\n}\nvec3 unpackRGBToNormal( const in vec3 rgb ) {\n\treturn 1.0 - 2.0 * rgb.xyz;\n}\nconst float PackUpscale = 256. / 255.;const float UnpackDownscale = 255. / 256.;\nconst vec3 PackFactors = vec3( 256. * 256. * 256., 256. * 256.,  256. );\nconst vec4 UnpackFactors = UnpackDownscale / vec4( PackFactors, 1. );\nconst float ShiftRight8 = 1. / 256.;\nvec4 packDepthToRGBA( const in float v ) {\n\tvec4 r = vec4( fract( v * PackFactors ), v );\n\tr.yzw -= r.xyz * ShiftRight8;\treturn r * PackUpscale;\n}\nfloat unpackRGBAToDepth( const in vec4 v ) {\n\treturn dot( v, UnpackFactors );\n}\nfloat viewZToOrthographicDepth( const in float viewZ, const in float near, const in float far ) {\n\treturn ( viewZ + near ) / ( near - far );\n}\nfloat orthographicDepthToViewZ( const in float linearClipZ, const in float near, const in float far ) {\n\treturn linearClipZ * ( near - far ) - near;\n}\nfloat viewZToPerspectiveDepth( const in float viewZ, const in float near, const in float far ) {\n\treturn (( near + viewZ ) * far ) / (( far - near ) * viewZ );\n}\nfloat perspectiveDepthToViewZ( const in float invClipZ, const in float near, const in float far ) {\n\treturn ( near * far ) / ( ( far - near ) * invClipZ - far );\n}\n",
premultiplied_alpha_fragment:"#ifdef PREMULTIPLIED_ALPHA\n\tgl_FragColor.rgb *= gl_FragColor.a;\n#endif\n",project_vertex:"vec4 mvPosition = modelViewMatrix * vec4( transformed, 1.0 );\ngl_Position = projectionMatrix * mvPosition;\n",dithering_fragment:"#if defined( DITHERING )\n  gl_FragColor.rgb = dithering( gl_FragColor.rgb );\n#endif\n",dithering_pars_fragment:"#if defined( DITHERING )\n\tvec3 dithering( vec3 color ) {\n\t\tfloat grid_position = rand( gl_FragCoord.xy );\n\t\tvec3 dither_shift_RGB = vec3( 0.25 / 255.0, -0.25 / 255.0, 0.25 / 255.0 );\n\t\tdither_shift_RGB = mix( 2.0 * dither_shift_RGB, -2.0 * dither_shift_RGB, grid_position );\n\t\treturn color + dither_shift_RGB;\n\t}\n#endif\n",
roughnessmap_fragment:"float roughnessFactor = roughness;\n#ifdef USE_ROUGHNESSMAP\n\tvec4 texelRoughness = texture2D( roughnessMap, vUv );\n\troughnessFactor *= texelRoughness.g;\n#endif\n",roughnessmap_pars_fragment:"#ifdef USE_ROUGHNESSMAP\n\tuniform sampler2D roughnessMap;\n#endif",shadowmap_pars_fragment:"#ifdef USE_SHADOWMAP\n\t#if NUM_DIR_LIGHTS > 0\n\t\tuniform sampler2D directionalShadowMap[ NUM_DIR_LIGHTS ];\n\t\tvarying vec4 vDirectionalShadowCoord[ NUM_DIR_LIGHTS ];\n\t#endif\n\t#if NUM_SPOT_LIGHTS > 0\n\t\tuniform sampler2D spotShadowMap[ NUM_SPOT_LIGHTS ];\n\t\tvarying vec4 vSpotShadowCoord[ NUM_SPOT_LIGHTS ];\n\t#endif\n\t#if NUM_POINT_LIGHTS > 0\n\t\tuniform sampler2D pointShadowMap[ NUM_POINT_LIGHTS ];\n\t\tvarying vec4 vPointShadowCoord[ NUM_POINT_LIGHTS ];\n\t#endif\n\tfloat texture2DCompare( sampler2D depths, vec2 uv, float compare ) {\n\t\treturn step( compare, unpackRGBAToDepth( texture2D( depths, uv ) ) );\n\t}\n\tfloat texture2DShadowLerp( sampler2D depths, vec2 size, vec2 uv, float compare ) {\n\t\tconst vec2 offset = vec2( 0.0, 1.0 );\n\t\tvec2 texelSize = vec2( 1.0 ) / size;\n\t\tvec2 centroidUV = floor( uv * size + 0.5 ) / size;\n\t\tfloat lb = texture2DCompare( depths, centroidUV + texelSize * offset.xx, compare );\n\t\tfloat lt = texture2DCompare( depths, centroidUV + texelSize * offset.xy, compare );\n\t\tfloat rb = texture2DCompare( depths, centroidUV + texelSize * offset.yx, compare );\n\t\tfloat rt = texture2DCompare( depths, centroidUV + texelSize * offset.yy, compare );\n\t\tvec2 f = fract( uv * size + 0.5 );\n\t\tfloat a = mix( lb, lt, f.y );\n\t\tfloat b = mix( rb, rt, f.y );\n\t\tfloat c = mix( a, b, f.x );\n\t\treturn c;\n\t}\n\tfloat getShadow( sampler2D shadowMap, vec2 shadowMapSize, float shadowBias, float shadowRadius, vec4 shadowCoord ) {\n\t\tfloat shadow = 1.0;\n\t\tshadowCoord.xyz /= shadowCoord.w;\n\t\tshadowCoord.z += shadowBias;\n\t\tbvec4 inFrustumVec = bvec4 ( shadowCoord.x >= 0.0, shadowCoord.x <= 1.0, shadowCoord.y >= 0.0, shadowCoord.y <= 1.0 );\n\t\tbool inFrustum = all( inFrustumVec );\n\t\tbvec2 frustumTestVec = bvec2( inFrustum, shadowCoord.z <= 1.0 );\n\t\tbool frustumTest = all( frustumTestVec );\n\t\tif ( frustumTest ) {\n\t\t#if defined( SHADOWMAP_TYPE_PCF )\n\t\t\tvec2 texelSize = vec2( 1.0 ) / shadowMapSize;\n\t\t\tfloat dx0 = - texelSize.x * shadowRadius;\n\t\t\tfloat dy0 = - texelSize.y * shadowRadius;\n\t\t\tfloat dx1 = + texelSize.x * shadowRadius;\n\t\t\tfloat dy1 = + texelSize.y * shadowRadius;\n\t\t\tshadow = (\n\t\t\t\ttexture2DCompare( shadowMap, shadowCoord.xy + vec2( dx0, dy0 ), shadowCoord.z ) +\n\t\t\t\ttexture2DCompare( shadowMap, shadowCoord.xy + vec2( 0.0, dy0 ), shadowCoord.z ) +\n\t\t\t\ttexture2DCompare( shadowMap, shadowCoord.xy + vec2( dx1, dy0 ), shadowCoord.z ) +\n\t\t\t\ttexture2DCompare( shadowMap, shadowCoord.xy + vec2( dx0, 0.0 ), shadowCoord.z ) +\n\t\t\t\ttexture2DCompare( shadowMap, shadowCoord.xy, shadowCoord.z ) +\n\t\t\t\ttexture2DCompare( shadowMap, shadowCoord.xy + vec2( dx1, 0.0 ), shadowCoord.z ) +\n\t\t\t\ttexture2DCompare( shadowMap, shadowCoord.xy + vec2( dx0, dy1 ), shadowCoord.z ) +\n\t\t\t\ttexture2DCompare( shadowMap, shadowCoord.xy + vec2( 0.0, dy1 ), shadowCoord.z ) +\n\t\t\t\ttexture2DCompare( shadowMap, shadowCoord.xy + vec2( dx1, dy1 ), shadowCoord.z )\n\t\t\t) * ( 1.0 / 9.0 );\n\t\t#elif defined( SHADOWMAP_TYPE_PCF_SOFT )\n\t\t\tvec2 texelSize = vec2( 1.0 ) / shadowMapSize;\n\t\t\tfloat dx0 = - texelSize.x * shadowRadius;\n\t\t\tfloat dy0 = - texelSize.y * shadowRadius;\n\t\t\tfloat dx1 = + texelSize.x * shadowRadius;\n\t\t\tfloat dy1 = + texelSize.y * shadowRadius;\n\t\t\tshadow = (\n\t\t\t\ttexture2DShadowLerp( shadowMap, shadowMapSize, shadowCoord.xy + vec2( dx0, dy0 ), shadowCoord.z ) +\n\t\t\t\ttexture2DShadowLerp( shadowMap, shadowMapSize, shadowCoord.xy + vec2( 0.0, dy0 ), shadowCoord.z ) +\n\t\t\t\ttexture2DShadowLerp( shadowMap, shadowMapSize, shadowCoord.xy + vec2( dx1, dy0 ), shadowCoord.z ) +\n\t\t\t\ttexture2DShadowLerp( shadowMap, shadowMapSize, shadowCoord.xy + vec2( dx0, 0.0 ), shadowCoord.z ) +\n\t\t\t\ttexture2DShadowLerp( shadowMap, shadowMapSize, shadowCoord.xy, shadowCoord.z ) +\n\t\t\t\ttexture2DShadowLerp( shadowMap, shadowMapSize, shadowCoord.xy + vec2( dx1, 0.0 ), shadowCoord.z ) +\n\t\t\t\ttexture2DShadowLerp( shadowMap, shadowMapSize, shadowCoord.xy + vec2( dx0, dy1 ), shadowCoord.z ) +\n\t\t\t\ttexture2DShadowLerp( shadowMap, shadowMapSize, shadowCoord.xy + vec2( 0.0, dy1 ), shadowCoord.z ) +\n\t\t\t\ttexture2DShadowLerp( shadowMap, shadowMapSize, shadowCoord.xy + vec2( dx1, dy1 ), shadowCoord.z )\n\t\t\t) * ( 1.0 / 9.0 );\n\t\t#else\n\t\t\tshadow = texture2DCompare( shadowMap, shadowCoord.xy, shadowCoord.z );\n\t\t#endif\n\t\t}\n\t\treturn shadow;\n\t}\n\tvec2 cubeToUV( vec3 v, float texelSizeY ) {\n\t\tvec3 absV = abs( v );\n\t\tfloat scaleToCube = 1.0 / max( absV.x, max( absV.y, absV.z ) );\n\t\tabsV *= scaleToCube;\n\t\tv *= scaleToCube * ( 1.0 - 2.0 * texelSizeY );\n\t\tvec2 planar = v.xy;\n\t\tfloat almostATexel = 1.5 * texelSizeY;\n\t\tfloat almostOne = 1.0 - almostATexel;\n\t\tif ( absV.z >= almostOne ) {\n\t\t\tif ( v.z > 0.0 )\n\t\t\t\tplanar.x = 4.0 - v.x;\n\t\t} else if ( absV.x >= almostOne ) {\n\t\t\tfloat signX = sign( v.x );\n\t\t\tplanar.x = v.z * signX + 2.0 * signX;\n\t\t} else if ( absV.y >= almostOne ) {\n\t\t\tfloat signY = sign( v.y );\n\t\t\tplanar.x = v.x + 2.0 * signY + 2.0;\n\t\t\tplanar.y = v.z * signY - 2.0;\n\t\t}\n\t\treturn vec2( 0.125, 0.25 ) * planar + vec2( 0.375, 0.75 );\n\t}\n\tfloat getPointShadow( sampler2D shadowMap, vec2 shadowMapSize, float shadowBias, float shadowRadius, vec4 shadowCoord, float shadowCameraNear, float shadowCameraFar ) {\n\t\tvec2 texelSize = vec2( 1.0 ) / ( shadowMapSize * vec2( 4.0, 2.0 ) );\n\t\tvec3 lightToPosition = shadowCoord.xyz;\n\t\tfloat dp = ( length( lightToPosition ) - shadowCameraNear ) / ( shadowCameraFar - shadowCameraNear );\t\tdp += shadowBias;\n\t\tvec3 bd3D = normalize( lightToPosition );\n\t\t#if defined( SHADOWMAP_TYPE_PCF ) || defined( SHADOWMAP_TYPE_PCF_SOFT )\n\t\t\tvec2 offset = vec2( - 1, 1 ) * shadowRadius * texelSize.y;\n\t\t\treturn (\n\t\t\t\ttexture2DCompare( shadowMap, cubeToUV( bd3D + offset.xyy, texelSize.y ), dp ) +\n\t\t\t\ttexture2DCompare( shadowMap, cubeToUV( bd3D + offset.yyy, texelSize.y ), dp ) +\n\t\t\t\ttexture2DCompare( shadowMap, cubeToUV( bd3D + offset.xyx, texelSize.y ), dp ) +\n\t\t\t\ttexture2DCompare( shadowMap, cubeToUV( bd3D + offset.yyx, texelSize.y ), dp ) +\n\t\t\t\ttexture2DCompare( shadowMap, cubeToUV( bd3D, texelSize.y ), dp ) +\n\t\t\t\ttexture2DCompare( shadowMap, cubeToUV( bd3D + offset.xxy, texelSize.y ), dp ) +\n\t\t\t\ttexture2DCompare( shadowMap, cubeToUV( bd3D + offset.yxy, texelSize.y ), dp ) +\n\t\t\t\ttexture2DCompare( shadowMap, cubeToUV( bd3D + offset.xxx, texelSize.y ), dp ) +\n\t\t\t\ttexture2DCompare( shadowMap, cubeToUV( bd3D + offset.yxx, texelSize.y ), dp )\n\t\t\t) * ( 1.0 / 9.0 );\n\t\t#else\n\t\t\treturn texture2DCompare( shadowMap, cubeToUV( bd3D, texelSize.y ), dp );\n\t\t#endif\n\t}\n#endif\n",
shadowmap_pars_vertex:"#ifdef USE_SHADOWMAP\n\t#if NUM_DIR_LIGHTS > 0\n\t\tuniform mat4 directionalShadowMatrix[ NUM_DIR_LIGHTS ];\n\t\tvarying vec4 vDirectionalShadowCoord[ NUM_DIR_LIGHTS ];\n\t#endif\n\t#if NUM_SPOT_LIGHTS > 0\n\t\tuniform mat4 spotShadowMatrix[ NUM_SPOT_LIGHTS ];\n\t\tvarying vec4 vSpotShadowCoord[ NUM_SPOT_LIGHTS ];\n\t#endif\n\t#if NUM_POINT_LIGHTS > 0\n\t\tuniform mat4 pointShadowMatrix[ NUM_POINT_LIGHTS ];\n\t\tvarying vec4 vPointShadowCoord[ NUM_POINT_LIGHTS ];\n\t#endif\n#endif\n",
shadowmap_vertex:"#ifdef USE_SHADOWMAP\n\t#if NUM_DIR_LIGHTS > 0\n\tfor ( int i = 0; i < NUM_DIR_LIGHTS; i ++ ) {\n\t\tvDirectionalShadowCoord[ i ] = directionalShadowMatrix[ i ] * worldPosition;\n\t}\n\t#endif\n\t#if NUM_SPOT_LIGHTS > 0\n\tfor ( int i = 0; i < NUM_SPOT_LIGHTS; i ++ ) {\n\t\tvSpotShadowCoord[ i ] = spotShadowMatrix[ i ] * worldPosition;\n\t}\n\t#endif\n\t#if NUM_POINT_LIGHTS > 0\n\tfor ( int i = 0; i < NUM_POINT_LIGHTS; i ++ ) {\n\t\tvPointShadowCoord[ i ] = pointShadowMatrix[ i ] * worldPosition;\n\t}\n\t#endif\n#endif\n",
shadowmask_pars_fragment:"float getShadowMask() {\n\tfloat shadow = 1.0;\n\t#ifdef USE_SHADOWMAP\n\t#if NUM_DIR_LIGHTS > 0\n\tDirectionalLight directionalLight;\n\tfor ( int i = 0; i < NUM_DIR_LIGHTS; i ++ ) {\n\t\tdirectionalLight = directionalLights[ i ];\n\t\tshadow *= bool( directionalLight.shadow ) ? getShadow( directionalShadowMap[ i ], directionalLight.shadowMapSize, directionalLight.shadowBias, directionalLight.shadowRadius, vDirectionalShadowCoord[ i ] ) : 1.0;\n\t}\n\t#endif\n\t#if NUM_SPOT_LIGHTS > 0\n\tSpotLight spotLight;\n\tfor ( int i = 0; i < NUM_SPOT_LIGHTS; i ++ ) {\n\t\tspotLight = spotLights[ i ];\n\t\tshadow *= bool( spotLight.shadow ) ? getShadow( spotShadowMap[ i ], spotLight.shadowMapSize, spotLight.shadowBias, spotLight.shadowRadius, vSpotShadowCoord[ i ] ) : 1.0;\n\t}\n\t#endif\n\t#if NUM_POINT_LIGHTS > 0\n\tPointLight pointLight;\n\tfor ( int i = 0; i < NUM_POINT_LIGHTS; i ++ ) {\n\t\tpointLight = pointLights[ i ];\n\t\tshadow *= bool( pointLight.shadow ) ? getPointShadow( pointShadowMap[ i ], pointLight.shadowMapSize, pointLight.shadowBias, pointLight.shadowRadius, vPointShadowCoord[ i ], pointLight.shadowCameraNear, pointLight.shadowCameraFar ) : 1.0;\n\t}\n\t#endif\n\t#endif\n\treturn shadow;\n}\n",
skinbase_vertex:"#ifdef USE_SKINNING\n\tmat4 boneMatX = getBoneMatrix( skinIndex.x );\n\tmat4 boneMatY = getBoneMatrix( skinIndex.y );\n\tmat4 boneMatZ = getBoneMatrix( skinIndex.z );\n\tmat4 boneMatW = getBoneMatrix( skinIndex.w );\n#endif",skinning_pars_vertex:"#ifdef USE_SKINNING\n\tuniform mat4 bindMatrix;\n\tuniform mat4 bindMatrixInverse;\n\t#ifdef BONE_TEXTURE\n\t\tuniform sampler2D boneTexture;\n\t\tuniform int boneTextureSize;\n\t\tmat4 getBoneMatrix( const in float i ) {\n\t\t\tfloat j = i * 4.0;\n\t\t\tfloat x = mod( j, float( boneTextureSize ) );\n\t\t\tfloat y = floor( j / float( boneTextureSize ) );\n\t\t\tfloat dx = 1.0 / float( boneTextureSize );\n\t\t\tfloat dy = 1.0 / float( boneTextureSize );\n\t\t\ty = dy * ( y + 0.5 );\n\t\t\tvec4 v1 = texture2D( boneTexture, vec2( dx * ( x + 0.5 ), y ) );\n\t\t\tvec4 v2 = texture2D( boneTexture, vec2( dx * ( x + 1.5 ), y ) );\n\t\t\tvec4 v3 = texture2D( boneTexture, vec2( dx * ( x + 2.5 ), y ) );\n\t\t\tvec4 v4 = texture2D( boneTexture, vec2( dx * ( x + 3.5 ), y ) );\n\t\t\tmat4 bone = mat4( v1, v2, v3, v4 );\n\t\t\treturn bone;\n\t\t}\n\t#else\n\t\tuniform mat4 boneMatrices[ MAX_BONES ];\n\t\tmat4 getBoneMatrix( const in float i ) {\n\t\t\tmat4 bone = boneMatrices[ int(i) ];\n\t\t\treturn bone;\n\t\t}\n\t#endif\n#endif\n",
skinning_vertex:"#ifdef USE_SKINNING\n\tvec4 skinVertex = bindMatrix * vec4( transformed, 1.0 );\n\tvec4 skinned = vec4( 0.0 );\n\tskinned += boneMatX * skinVertex * skinWeight.x;\n\tskinned += boneMatY * skinVertex * skinWeight.y;\n\tskinned += boneMatZ * skinVertex * skinWeight.z;\n\tskinned += boneMatW * skinVertex * skinWeight.w;\n\ttransformed = ( bindMatrixInverse * skinned ).xyz;\n#endif\n",skinnormal_vertex:"#ifdef USE_SKINNING\n\tmat4 skinMatrix = mat4( 0.0 );\n\tskinMatrix += skinWeight.x * boneMatX;\n\tskinMatrix += skinWeight.y * boneMatY;\n\tskinMatrix += skinWeight.z * boneMatZ;\n\tskinMatrix += skinWeight.w * boneMatW;\n\tskinMatrix  = bindMatrixInverse * skinMatrix * bindMatrix;\n\tobjectNormal = vec4( skinMatrix * vec4( objectNormal, 0.0 ) ).xyz;\n#endif\n",
specularmap_fragment:"float specularStrength;\n#ifdef USE_SPECULARMAP\n\tvec4 texelSpecular = texture2D( specularMap, vUv );\n\tspecularStrength = texelSpecular.r;\n#else\n\tspecularStrength = 1.0;\n#endif",specularmap_pars_fragment:"#ifdef USE_SPECULARMAP\n\tuniform sampler2D specularMap;\n#endif",tonemapping_fragment:"#if defined( TONE_MAPPING )\n  gl_FragColor.rgb = toneMapping( gl_FragColor.rgb );\n#endif\n",tonemapping_pars_fragment:"#define saturate(a) clamp( a, 0.0, 1.0 )\nuniform float toneMappingExposure;\nuniform float toneMappingWhitePoint;\nvec3 LinearToneMapping( vec3 color ) {\n\treturn toneMappingExposure * color;\n}\nvec3 ReinhardToneMapping( vec3 color ) {\n\tcolor *= toneMappingExposure;\n\treturn saturate( color / ( vec3( 1.0 ) + color ) );\n}\n#define Uncharted2Helper( x ) max( ( ( x * ( 0.15 * x + 0.10 * 0.50 ) + 0.20 * 0.02 ) / ( x * ( 0.15 * x + 0.50 ) + 0.20 * 0.30 ) ) - 0.02 / 0.30, vec3( 0.0 ) )\nvec3 Uncharted2ToneMapping( vec3 color ) {\n\tcolor *= toneMappingExposure;\n\treturn saturate( Uncharted2Helper( color ) / Uncharted2Helper( vec3( toneMappingWhitePoint ) ) );\n}\nvec3 OptimizedCineonToneMapping( vec3 color ) {\n\tcolor *= toneMappingExposure;\n\tcolor = max( vec3( 0.0 ), color - 0.004 );\n\treturn pow( ( color * ( 6.2 * color + 0.5 ) ) / ( color * ( 6.2 * color + 1.7 ) + 0.06 ), vec3( 2.2 ) );\n}\n",
uv_pars_fragment:"#if defined( USE_MAP ) || defined( USE_BUMPMAP ) || defined( USE_NORMALMAP ) || defined( USE_SPECULARMAP ) || defined( USE_ALPHAMAP ) || defined( USE_EMISSIVEMAP ) || defined( USE_ROUGHNESSMAP ) || defined( USE_METALNESSMAP )\n\tvarying vec2 vUv;\n#endif",uv_pars_vertex:"#if defined( USE_MAP ) || defined( USE_BUMPMAP ) || defined( USE_NORMALMAP ) || defined( USE_SPECULARMAP ) || defined( USE_ALPHAMAP ) || defined( USE_EMISSIVEMAP ) || defined( USE_ROUGHNESSMAP ) || defined( USE_METALNESSMAP )\n\tvarying vec2 vUv;\n\tuniform vec4 offsetRepeat;\n#endif\n",
uv_vertex:"#if defined( USE_MAP ) || defined( USE_BUMPMAP ) || defined( USE_NORMALMAP ) || defined( USE_SPECULARMAP ) || defined( USE_ALPHAMAP ) || defined( USE_EMISSIVEMAP ) || defined( USE_ROUGHNESSMAP ) || defined( USE_METALNESSMAP )\n\tvUv = uv * offsetRepeat.zw + offsetRepeat.xy;\n#endif",uv2_pars_fragment:"#if defined( USE_LIGHTMAP ) || defined( USE_AOMAP )\n\tvarying vec2 vUv2;\n#endif",uv2_pars_vertex:"#if defined( USE_LIGHTMAP ) || defined( USE_AOMAP )\n\tattribute vec2 uv2;\n\tvarying vec2 vUv2;\n#endif",
uv2_vertex:"#if defined( USE_LIGHTMAP ) || defined( USE_AOMAP )\n\tvUv2 = uv2;\n#endif",worldpos_vertex:"#if defined( USE_ENVMAP ) || defined( PHONG ) || defined( PHYSICAL ) || defined( LAMBERT ) || defined( DISTANCE ) || defined ( USE_SHADOWMAP )\n\tvec4 worldPosition = modelMatrix * vec4( transformed, 1.0 );\n#endif\n",cube_frag:"uniform samplerCube tCube;\nuniform float tFlip;\nuniform float opacity;\nvarying vec3 vWorldPosition;\nvoid main() {\n\tgl_FragColor = textureCube( tCube, vec3( tFlip * vWorldPosition.x, vWorldPosition.yz ) );\n\tgl_FragColor.a *= opacity;\n}\n",
cube_vert:"varying vec3 vWorldPosition;\n#include <common>\nvoid main() {\n\tvWorldPosition = transformDirection( position, modelMatrix );\n\t#include <begin_vertex>\n\t#include <project_vertex>\n}\n",depth_frag:"#if DEPTH_PACKING == 3200\n\tuniform float opacity;\n#endif\n#include <common>\n#include <packing>\n#include <uv_pars_fragment>\n#include <map_pars_fragment>\n#include <alphamap_pars_fragment>\n#include <logdepthbuf_pars_fragment>\n#include <clipping_planes_pars_fragment>\nvoid main() {\n\t#include <clipping_planes_fragment>\n\tvec4 diffuseColor = vec4( 1.0 );\n\t#if DEPTH_PACKING == 3200\n\t\tdiffuseColor.a = opacity;\n\t#endif\n\t#include <map_fragment>\n\t#include <alphamap_fragment>\n\t#include <alphatest_fragment>\n\t#include <logdepthbuf_fragment>\n\t#if DEPTH_PACKING == 3200\n\t\tgl_FragColor = vec4( vec3( gl_FragCoord.z ), opacity );\n\t#elif DEPTH_PACKING == 3201\n\t\tgl_FragColor = packDepthToRGBA( gl_FragCoord.z );\n\t#endif\n}\n",
depth_vert:"#include <common>\n#include <uv_pars_vertex>\n#include <displacementmap_pars_vertex>\n#include <morphtarget_pars_vertex>\n#include <skinning_pars_vertex>\n#include <logdepthbuf_pars_vertex>\n#include <clipping_planes_pars_vertex>\nvoid main() {\n\t#include <uv_vertex>\n\t#include <skinbase_vertex>\n\t#ifdef USE_DISPLACEMENTMAP\n\t\t#include <beginnormal_vertex>\n\t\t#include <morphnormal_vertex>\n\t\t#include <skinnormal_vertex>\n\t#endif\n\t#include <begin_vertex>\n\t#include <morphtarget_vertex>\n\t#include <skinning_vertex>\n\t#include <displacementmap_vertex>\n\t#include <project_vertex>\n\t#include <logdepthbuf_vertex>\n\t#include <clipping_planes_vertex>\n}\n",
distanceRGBA_frag:"#define DISTANCE\nuniform vec3 referencePosition;\nuniform float nearDistance;\nuniform float farDistance;\nvarying vec3 vWorldPosition;\n#include <common>\n#include <packing>\n#include <uv_pars_fragment>\n#include <map_pars_fragment>\n#include <alphamap_pars_fragment>\n#include <clipping_planes_pars_fragment>\nvoid main () {\n\t#include <clipping_planes_fragment>\n\tvec4 diffuseColor = vec4( 1.0 );\n\t#include <map_fragment>\n\t#include <alphamap_fragment>\n\t#include <alphatest_fragment>\n\tfloat dist = length( vWorldPosition - referencePosition );\n\tdist = ( dist - nearDistance ) / ( farDistance - nearDistance );\n\tdist = saturate( dist );\n\tgl_FragColor = packDepthToRGBA( dist );\n}\n",
distanceRGBA_vert:"#define DISTANCE\nvarying vec3 vWorldPosition;\n#include <common>\n#include <uv_pars_vertex>\n#include <displacementmap_pars_vertex>\n#include <morphtarget_pars_vertex>\n#include <skinning_pars_vertex>\n#include <clipping_planes_pars_vertex>\nvoid main() {\n\t#include <uv_vertex>\n\t#include <skinbase_vertex>\n\t#ifdef USE_DISPLACEMENTMAP\n\t\t#include <beginnormal_vertex>\n\t\t#include <morphnormal_vertex>\n\t\t#include <skinnormal_vertex>\n\t#endif\n\t#include <begin_vertex>\n\t#include <morphtarget_vertex>\n\t#include <skinning_vertex>\n\t#include <displacementmap_vertex>\n\t#include <project_vertex>\n\t#include <worldpos_vertex>\n\t#include <clipping_planes_vertex>\n\tvWorldPosition = worldPosition.xyz;\n}\n",
equirect_frag:"uniform sampler2D tEquirect;\nvarying vec3 vWorldPosition;\n#include <common>\nvoid main() {\n\tvec3 direction = normalize( vWorldPosition );\n\tvec2 sampleUV;\n\tsampleUV.y = asin( clamp( direction.y, - 1.0, 1.0 ) ) * RECIPROCAL_PI + 0.5;\n\tsampleUV.x = atan( direction.z, direction.x ) * RECIPROCAL_PI2 + 0.5;\n\tgl_FragColor = texture2D( tEquirect, sampleUV );\n}\n",equirect_vert:"varying vec3 vWorldPosition;\n#include <common>\nvoid main() {\n\tvWorldPosition = transformDirection( position, modelMatrix );\n\t#include <begin_vertex>\n\t#include <project_vertex>\n}\n",
linedashed_frag:"uniform vec3 diffuse;\nuniform float opacity;\nuniform float dashSize;\nuniform float totalSize;\nvarying float vLineDistance;\n#include <common>\n#include <color_pars_fragment>\n#include <fog_pars_fragment>\n#include <logdepthbuf_pars_fragment>\n#include <clipping_planes_pars_fragment>\nvoid main() {\n\t#include <clipping_planes_fragment>\n\tif ( mod( vLineDistance, totalSize ) > dashSize ) {\n\t\tdiscard;\n\t}\n\tvec3 outgoingLight = vec3( 0.0 );\n\tvec4 diffuseColor = vec4( diffuse, opacity );\n\t#include <logdepthbuf_fragment>\n\t#include <color_fragment>\n\toutgoingLight = diffuseColor.rgb;\n\tgl_FragColor = vec4( outgoingLight, diffuseColor.a );\n\t#include <premultiplied_alpha_fragment>\n\t#include <tonemapping_fragment>\n\t#include <encodings_fragment>\n\t#include <fog_fragment>\n}\n",
linedashed_vert:"uniform float scale;\nattribute float lineDistance;\nvarying float vLineDistance;\n#include <common>\n#include <color_pars_vertex>\n#include <fog_pars_vertex>\n#include <logdepthbuf_pars_vertex>\n#include <clipping_planes_pars_vertex>\nvoid main() {\n\t#include <color_vertex>\n\tvLineDistance = scale * lineDistance;\n\tvec4 mvPosition = modelViewMatrix * vec4( position, 1.0 );\n\tgl_Position = projectionMatrix * mvPosition;\n\t#include <logdepthbuf_vertex>\n\t#include <clipping_planes_vertex>\n\t#include <fog_vertex>\n}\n",
meshbasic_frag:"uniform vec3 diffuse;\nuniform float opacity;\n#ifndef FLAT_SHADED\n\tvarying vec3 vNormal;\n#endif\n#include <common>\n#include <color_pars_fragment>\n#include <uv_pars_fragment>\n#include <uv2_pars_fragment>\n#include <map_pars_fragment>\n#include <alphamap_pars_fragment>\n#include <aomap_pars_fragment>\n#include <lightmap_pars_fragment>\n#include <envmap_pars_fragment>\n#include <fog_pars_fragment>\n#include <specularmap_pars_fragment>\n#include <logdepthbuf_pars_fragment>\n#include <clipping_planes_pars_fragment>\nvoid main() {\n\t#include <clipping_planes_fragment>\n\tvec4 diffuseColor = vec4( diffuse, opacity );\n\t#include <logdepthbuf_fragment>\n\t#include <map_fragment>\n\t#include <color_fragment>\n\t#include <alphamap_fragment>\n\t#include <alphatest_fragment>\n\t#include <specularmap_fragment>\n\tReflectedLight reflectedLight = ReflectedLight( vec3( 0.0 ), vec3( 0.0 ), vec3( 0.0 ), vec3( 0.0 ) );\n\t#ifdef USE_LIGHTMAP\n\t\treflectedLight.indirectDiffuse += texture2D( lightMap, vUv2 ).xyz * lightMapIntensity;\n\t#else\n\t\treflectedLight.indirectDiffuse += vec3( 1.0 );\n\t#endif\n\t#include <aomap_fragment>\n\treflectedLight.indirectDiffuse *= diffuseColor.rgb;\n\tvec3 outgoingLight = reflectedLight.indirectDiffuse;\n\t#include <envmap_fragment>\n\tgl_FragColor = vec4( outgoingLight, diffuseColor.a );\n\t#include <premultiplied_alpha_fragment>\n\t#include <tonemapping_fragment>\n\t#include <encodings_fragment>\n\t#include <fog_fragment>\n}\n",
meshbasic_vert:"#include <common>\n#include <uv_pars_vertex>\n#include <uv2_pars_vertex>\n#include <envmap_pars_vertex>\n#include <color_pars_vertex>\n#include <fog_pars_vertex>\n#include <morphtarget_pars_vertex>\n#include <skinning_pars_vertex>\n#include <logdepthbuf_pars_vertex>\n#include <clipping_planes_pars_vertex>\nvoid main() {\n\t#include <uv_vertex>\n\t#include <uv2_vertex>\n\t#include <color_vertex>\n\t#include <skinbase_vertex>\n\t#ifdef USE_ENVMAP\n\t#include <beginnormal_vertex>\n\t#include <morphnormal_vertex>\n\t#include <skinnormal_vertex>\n\t#include <defaultnormal_vertex>\n\t#endif\n\t#include <begin_vertex>\n\t#include <morphtarget_vertex>\n\t#include <skinning_vertex>\n\t#include <project_vertex>\n\t#include <logdepthbuf_vertex>\n\t#include <worldpos_vertex>\n\t#include <clipping_planes_vertex>\n\t#include <envmap_vertex>\n\t#include <fog_vertex>\n}\n",
meshlambert_frag:"uniform vec3 diffuse;\nuniform vec3 emissive;\nuniform float opacity;\nvarying vec3 vLightFront;\n#ifdef DOUBLE_SIDED\n\tvarying vec3 vLightBack;\n#endif\n#include <common>\n#include <packing>\n#include <dithering_pars_fragment>\n#include <color_pars_fragment>\n#include <uv_pars_fragment>\n#include <uv2_pars_fragment>\n#include <map_pars_fragment>\n#include <alphamap_pars_fragment>\n#include <aomap_pars_fragment>\n#include <lightmap_pars_fragment>\n#include <emissivemap_pars_fragment>\n#include <envmap_pars_fragment>\n#include <bsdfs>\n#include <lights_pars>\n#include <fog_pars_fragment>\n#include <shadowmap_pars_fragment>\n#include <shadowmask_pars_fragment>\n#include <specularmap_pars_fragment>\n#include <logdepthbuf_pars_fragment>\n#include <clipping_planes_pars_fragment>\nvoid main() {\n\t#include <clipping_planes_fragment>\n\tvec4 diffuseColor = vec4( diffuse, opacity );\n\tReflectedLight reflectedLight = ReflectedLight( vec3( 0.0 ), vec3( 0.0 ), vec3( 0.0 ), vec3( 0.0 ) );\n\tvec3 totalEmissiveRadiance = emissive;\n\t#include <logdepthbuf_fragment>\n\t#include <map_fragment>\n\t#include <color_fragment>\n\t#include <alphamap_fragment>\n\t#include <alphatest_fragment>\n\t#include <specularmap_fragment>\n\t#include <emissivemap_fragment>\n\treflectedLight.indirectDiffuse = getAmbientLightIrradiance( ambientLightColor );\n\t#include <lightmap_fragment>\n\treflectedLight.indirectDiffuse *= BRDF_Diffuse_Lambert( diffuseColor.rgb );\n\t#ifdef DOUBLE_SIDED\n\t\treflectedLight.directDiffuse = ( gl_FrontFacing ) ? vLightFront : vLightBack;\n\t#else\n\t\treflectedLight.directDiffuse = vLightFront;\n\t#endif\n\treflectedLight.directDiffuse *= BRDF_Diffuse_Lambert( diffuseColor.rgb ) * getShadowMask();\n\t#include <aomap_fragment>\n\tvec3 outgoingLight = reflectedLight.directDiffuse + reflectedLight.indirectDiffuse + totalEmissiveRadiance;\n\t#include <envmap_fragment>\n\tgl_FragColor = vec4( outgoingLight, diffuseColor.a );\n\t#include <tonemapping_fragment>\n\t#include <encodings_fragment>\n\t#include <fog_fragment>\n\t#include <premultiplied_alpha_fragment>\n\t#include <dithering_fragment>\n}\n",
meshlambert_vert:"#define LAMBERT\nvarying vec3 vLightFront;\n#ifdef DOUBLE_SIDED\n\tvarying vec3 vLightBack;\n#endif\n#include <common>\n#include <uv_pars_vertex>\n#include <uv2_pars_vertex>\n#include <envmap_pars_vertex>\n#include <bsdfs>\n#include <lights_pars>\n#include <color_pars_vertex>\n#include <fog_pars_vertex>\n#include <morphtarget_pars_vertex>\n#include <skinning_pars_vertex>\n#include <shadowmap_pars_vertex>\n#include <logdepthbuf_pars_vertex>\n#include <clipping_planes_pars_vertex>\nvoid main() {\n\t#include <uv_vertex>\n\t#include <uv2_vertex>\n\t#include <color_vertex>\n\t#include <beginnormal_vertex>\n\t#include <morphnormal_vertex>\n\t#include <skinbase_vertex>\n\t#include <skinnormal_vertex>\n\t#include <defaultnormal_vertex>\n\t#include <begin_vertex>\n\t#include <morphtarget_vertex>\n\t#include <skinning_vertex>\n\t#include <project_vertex>\n\t#include <logdepthbuf_vertex>\n\t#include <clipping_planes_vertex>\n\t#include <worldpos_vertex>\n\t#include <envmap_vertex>\n\t#include <lights_lambert_vertex>\n\t#include <shadowmap_vertex>\n\t#include <fog_vertex>\n}\n",
meshphong_frag:"#define PHONG\nuniform vec3 diffuse;\nuniform vec3 emissive;\nuniform vec3 specular;\nuniform float shininess;\nuniform float opacity;\n#include <common>\n#include <packing>\n#include <dithering_pars_fragment>\n#include <color_pars_fragment>\n#include <uv_pars_fragment>\n#include <uv2_pars_fragment>\n#include <map_pars_fragment>\n#include <alphamap_pars_fragment>\n#include <aomap_pars_fragment>\n#include <lightmap_pars_fragment>\n#include <emissivemap_pars_fragment>\n#include <envmap_pars_fragment>\n#include <gradientmap_pars_fragment>\n#include <fog_pars_fragment>\n#include <bsdfs>\n#include <lights_pars>\n#include <lights_phong_pars_fragment>\n#include <shadowmap_pars_fragment>\n#include <bumpmap_pars_fragment>\n#include <normalmap_pars_fragment>\n#include <specularmap_pars_fragment>\n#include <logdepthbuf_pars_fragment>\n#include <clipping_planes_pars_fragment>\nvoid main() {\n\t#include <clipping_planes_fragment>\n\tvec4 diffuseColor = vec4( diffuse, opacity );\n\tReflectedLight reflectedLight = ReflectedLight( vec3( 0.0 ), vec3( 0.0 ), vec3( 0.0 ), vec3( 0.0 ) );\n\tvec3 totalEmissiveRadiance = emissive;\n\t#include <logdepthbuf_fragment>\n\t#include <map_fragment>\n\t#include <color_fragment>\n\t#include <alphamap_fragment>\n\t#include <alphatest_fragment>\n\t#include <specularmap_fragment>\n\t#include <normal_fragment>\n\t#include <emissivemap_fragment>\n\t#include <lights_phong_fragment>\n\t#include <lights_template>\n\t#include <aomap_fragment>\n\tvec3 outgoingLight = reflectedLight.directDiffuse + reflectedLight.indirectDiffuse + reflectedLight.directSpecular + reflectedLight.indirectSpecular + totalEmissiveRadiance;\n\t#include <envmap_fragment>\n\tgl_FragColor = vec4( outgoingLight, diffuseColor.a );\n\t#include <tonemapping_fragment>\n\t#include <encodings_fragment>\n\t#include <fog_fragment>\n\t#include <premultiplied_alpha_fragment>\n\t#include <dithering_fragment>\n}\n",
meshphong_vert:"#define PHONG\nvarying vec3 vViewPosition;\n#ifndef FLAT_SHADED\n\tvarying vec3 vNormal;\n#endif\n#include <common>\n#include <uv_pars_vertex>\n#include <uv2_pars_vertex>\n#include <displacementmap_pars_vertex>\n#include <envmap_pars_vertex>\n#include <color_pars_vertex>\n#include <fog_pars_vertex>\n#include <morphtarget_pars_vertex>\n#include <skinning_pars_vertex>\n#include <shadowmap_pars_vertex>\n#include <logdepthbuf_pars_vertex>\n#include <clipping_planes_pars_vertex>\nvoid main() {\n\t#include <uv_vertex>\n\t#include <uv2_vertex>\n\t#include <color_vertex>\n\t#include <beginnormal_vertex>\n\t#include <morphnormal_vertex>\n\t#include <skinbase_vertex>\n\t#include <skinnormal_vertex>\n\t#include <defaultnormal_vertex>\n#ifndef FLAT_SHADED\n\tvNormal = normalize( transformedNormal );\n#endif\n\t#include <begin_vertex>\n\t#include <morphtarget_vertex>\n\t#include <skinning_vertex>\n\t#include <displacementmap_vertex>\n\t#include <project_vertex>\n\t#include <logdepthbuf_vertex>\n\t#include <clipping_planes_vertex>\n\tvViewPosition = - mvPosition.xyz;\n\t#include <worldpos_vertex>\n\t#include <envmap_vertex>\n\t#include <shadowmap_vertex>\n\t#include <fog_vertex>\n}\n",
meshphysical_frag:"#define PHYSICAL\nuniform vec3 diffuse;\nuniform vec3 emissive;\nuniform float roughness;\nuniform float metalness;\nuniform float opacity;\n#ifndef STANDARD\n\tuniform float clearCoat;\n\tuniform float clearCoatRoughness;\n#endif\nvarying vec3 vViewPosition;\n#ifndef FLAT_SHADED\n\tvarying vec3 vNormal;\n#endif\n#include <common>\n#include <packing>\n#include <dithering_pars_fragment>\n#include <color_pars_fragment>\n#include <uv_pars_fragment>\n#include <uv2_pars_fragment>\n#include <map_pars_fragment>\n#include <alphamap_pars_fragment>\n#include <aomap_pars_fragment>\n#include <lightmap_pars_fragment>\n#include <emissivemap_pars_fragment>\n#include <envmap_pars_fragment>\n#include <fog_pars_fragment>\n#include <bsdfs>\n#include <cube_uv_reflection_fragment>\n#include <lights_pars>\n#include <lights_physical_pars_fragment>\n#include <shadowmap_pars_fragment>\n#include <bumpmap_pars_fragment>\n#include <normalmap_pars_fragment>\n#include <roughnessmap_pars_fragment>\n#include <metalnessmap_pars_fragment>\n#include <logdepthbuf_pars_fragment>\n#include <clipping_planes_pars_fragment>\nvoid main() {\n\t#include <clipping_planes_fragment>\n\tvec4 diffuseColor = vec4( diffuse, opacity );\n\tReflectedLight reflectedLight = ReflectedLight( vec3( 0.0 ), vec3( 0.0 ), vec3( 0.0 ), vec3( 0.0 ) );\n\tvec3 totalEmissiveRadiance = emissive;\n\t#include <logdepthbuf_fragment>\n\t#include <map_fragment>\n\t#include <color_fragment>\n\t#include <alphamap_fragment>\n\t#include <alphatest_fragment>\n\t#include <roughnessmap_fragment>\n\t#include <metalnessmap_fragment>\n\t#include <normal_fragment>\n\t#include <emissivemap_fragment>\n\t#include <lights_physical_fragment>\n\t#include <lights_template>\n\t#include <aomap_fragment>\n\tvec3 outgoingLight = reflectedLight.directDiffuse + reflectedLight.indirectDiffuse + reflectedLight.directSpecular + reflectedLight.indirectSpecular + totalEmissiveRadiance;\n\tgl_FragColor = vec4( outgoingLight, diffuseColor.a );\n\t#include <tonemapping_fragment>\n\t#include <encodings_fragment>\n\t#include <fog_fragment>\n\t#include <premultiplied_alpha_fragment>\n\t#include <dithering_fragment>\n}\n",
meshphysical_vert:"#define PHYSICAL\nvarying vec3 vViewPosition;\n#ifndef FLAT_SHADED\n\tvarying vec3 vNormal;\n#endif\n#include <common>\n#include <uv_pars_vertex>\n#include <uv2_pars_vertex>\n#include <displacementmap_pars_vertex>\n#include <color_pars_vertex>\n#include <fog_pars_vertex>\n#include <morphtarget_pars_vertex>\n#include <skinning_pars_vertex>\n#include <shadowmap_pars_vertex>\n#include <logdepthbuf_pars_vertex>\n#include <clipping_planes_pars_vertex>\nvoid main() {\n\t#include <uv_vertex>\n\t#include <uv2_vertex>\n\t#include <color_vertex>\n\t#include <beginnormal_vertex>\n\t#include <morphnormal_vertex>\n\t#include <skinbase_vertex>\n\t#include <skinnormal_vertex>\n\t#include <defaultnormal_vertex>\n#ifndef FLAT_SHADED\n\tvNormal = normalize( transformedNormal );\n#endif\n\t#include <begin_vertex>\n\t#include <morphtarget_vertex>\n\t#include <skinning_vertex>\n\t#include <displacementmap_vertex>\n\t#include <project_vertex>\n\t#include <logdepthbuf_vertex>\n\t#include <clipping_planes_vertex>\n\tvViewPosition = - mvPosition.xyz;\n\t#include <worldpos_vertex>\n\t#include <shadowmap_vertex>\n\t#include <fog_vertex>\n}\n",
normal_frag:"#define NORMAL\nuniform float opacity;\n#if defined( FLAT_SHADED ) || defined( USE_BUMPMAP ) || defined( USE_NORMALMAP )\n\tvarying vec3 vViewPosition;\n#endif\n#ifndef FLAT_SHADED\n\tvarying vec3 vNormal;\n#endif\n#include <packing>\n#include <uv_pars_fragment>\n#include <bumpmap_pars_fragment>\n#include <normalmap_pars_fragment>\n#include <logdepthbuf_pars_fragment>\nvoid main() {\n\t#include <logdepthbuf_fragment>\n\t#include <normal_fragment>\n\tgl_FragColor = vec4( packNormalToRGB( normal ), opacity );\n}\n",
normal_vert:"#define NORMAL\n#if defined( FLAT_SHADED ) || defined( USE_BUMPMAP ) || defined( USE_NORMALMAP )\n\tvarying vec3 vViewPosition;\n#endif\n#ifndef FLAT_SHADED\n\tvarying vec3 vNormal;\n#endif\n#include <uv_pars_vertex>\n#include <displacementmap_pars_vertex>\n#include <morphtarget_pars_vertex>\n#include <skinning_pars_vertex>\n#include <logdepthbuf_pars_vertex>\nvoid main() {\n\t#include <uv_vertex>\n\t#include <beginnormal_vertex>\n\t#include <morphnormal_vertex>\n\t#include <skinbase_vertex>\n\t#include <skinnormal_vertex>\n\t#include <defaultnormal_vertex>\n#ifndef FLAT_SHADED\n\tvNormal = normalize( transformedNormal );\n#endif\n\t#include <begin_vertex>\n\t#include <morphtarget_vertex>\n\t#include <skinning_vertex>\n\t#include <displacementmap_vertex>\n\t#include <project_vertex>\n\t#include <logdepthbuf_vertex>\n#if defined( FLAT_SHADED ) || defined( USE_BUMPMAP ) || defined( USE_NORMALMAP )\n\tvViewPosition = - mvPosition.xyz;\n#endif\n}\n",
points_frag:"uniform vec3 diffuse;\nuniform float opacity;\n#include <common>\n#include <packing>\n#include <color_pars_fragment>\n#include <map_particle_pars_fragment>\n#include <fog_pars_fragment>\n#include <shadowmap_pars_fragment>\n#include <logdepthbuf_pars_fragment>\n#include <clipping_planes_pars_fragment>\nvoid main() {\n\t#include <clipping_planes_fragment>\n\tvec3 outgoingLight = vec3( 0.0 );\n\tvec4 diffuseColor = vec4( diffuse, opacity );\n\t#include <logdepthbuf_fragment>\n\t#include <map_particle_fragment>\n\t#include <color_fragment>\n\t#include <alphatest_fragment>\n\toutgoingLight = diffuseColor.rgb;\n\tgl_FragColor = vec4( outgoingLight, diffuseColor.a );\n\t#include <premultiplied_alpha_fragment>\n\t#include <tonemapping_fragment>\n\t#include <encodings_fragment>\n\t#include <fog_fragment>\n}\n",
points_vert:"uniform float size;\nuniform float scale;\n#include <common>\n#include <color_pars_vertex>\n#include <fog_pars_vertex>\n#include <shadowmap_pars_vertex>\n#include <logdepthbuf_pars_vertex>\n#include <clipping_planes_pars_vertex>\nvoid main() {\n\t#include <color_vertex>\n\t#include <begin_vertex>\n\t#include <project_vertex>\n\t#ifdef USE_SIZEATTENUATION\n\t\tgl_PointSize = size * ( scale / - mvPosition.z );\n\t#else\n\t\tgl_PointSize = size;\n\t#endif\n\t#include <logdepthbuf_vertex>\n\t#include <clipping_planes_vertex>\n\t#include <worldpos_vertex>\n\t#include <shadowmap_vertex>\n\t#include <fog_vertex>\n}\n",
shadow_frag:"uniform vec3 color;\nuniform float opacity;\n#include <common>\n#include <packing>\n#include <bsdfs>\n#include <lights_pars>\n#include <shadowmap_pars_fragment>\n#include <shadowmask_pars_fragment>\nvoid main() {\n\tgl_FragColor = vec4( color, opacity * ( 1.0 - getShadowMask() ) );\n}\n",shadow_vert:"#include <shadowmap_pars_vertex>\nvoid main() {\n\t#include <begin_vertex>\n\t#include <project_vertex>\n\t#include <worldpos_vertex>\n\t#include <shadowmap_vertex>\n}\n"},ib={basic:{uniforms:Da.merge([L.common,
L.specularmap,L.envmap,L.aomap,L.lightmap,L.fog]),vertexShader:V.meshbasic_vert,fragmentShader:V.meshbasic_frag},lambert:{uniforms:Da.merge([L.common,L.specularmap,L.envmap,L.aomap,L.lightmap,L.emissivemap,L.fog,L.lights,{emissive:{value:new C(0)}}]),vertexShader:V.meshlambert_vert,fragmentShader:V.meshlambert_frag},phong:{uniforms:Da.merge([L.common,L.specularmap,L.envmap,L.aomap,L.lightmap,L.emissivemap,L.bumpmap,L.normalmap,L.displacementmap,L.gradientmap,L.fog,L.lights,{emissive:{value:new C(0)},
specular:{value:new C(1118481)},shininess:{value:30}}]),vertexShader:V.meshphong_vert,fragmentShader:V.meshphong_frag},standard:{uniforms:Da.merge([L.common,L.envmap,L.aomap,L.lightmap,L.emissivemap,L.bumpmap,L.normalmap,L.displacementmap,L.roughnessmap,L.metalnessmap,L.fog,L.lights,{emissive:{value:new C(0)},roughness:{value:.5},metalness:{value:.5},envMapIntensity:{value:1}}]),vertexShader:V.meshphysical_vert,fragmentShader:V.meshphysical_frag},points:{uniforms:Da.merge([L.points,L.fog]),vertexShader:V.points_vert,
fragmentShader:V.points_frag},dashed:{uniforms:Da.merge([L.common,L.fog,{scale:{value:1},dashSize:{value:1},totalSize:{value:2}}]),vertexShader:V.linedashed_vert,fragmentShader:V.linedashed_frag},depth:{uniforms:Da.merge([L.common,L.displacementmap]),vertexShader:V.depth_vert,fragmentShader:V.depth_frag},normal:{uniforms:Da.merge([L.common,L.bumpmap,L.normalmap,L.displacementmap,{opacity:{value:1}}]),vertexShader:V.normal_vert,fragmentShader:V.normal_frag},cube:{uniforms:{tCube:{value:null},tFlip:{value:-1},
opacity:{value:1}},vertexShader:V.cube_vert,fragmentShader:V.cube_frag},equirect:{uniforms:{tEquirect:{value:null}},vertexShader:V.equirect_vert,fragmentShader:V.equirect_frag},distanceRGBA:{uniforms:Da.merge([L.common,L.displacementmap,{referencePosition:{value:new n},nearDistance:{value:1},farDistance:{value:1E3}}]),vertexShader:V.distanceRGBA_vert,fragmentShader:V.distanceRGBA_frag},shadow:{uniforms:Da.merge([L.lights,{color:{value:new C(0)},opacity:{value:1}}]),vertexShader:V.shadow_vert,fragmentShader:V.shadow_frag}};
ib.physical={uniforms:Da.merge([ib.standard.uniforms,{clearCoat:{value:0},clearCoatRoughness:{value:0}}]),vertexShader:V.meshphysical_vert,fragmentShader:V.meshphysical_frag};Object.assign(id.prototype,{set:function(a,b){this.min.copy(a);this.max.copy(b);return this},setFromPoints:function(a){this.makeEmpty();for(var b=0,c=a.length;b<c;b++)this.expandByPoint(a[b]);return this},setFromCenterAndSize:function(){var a=new D;return function(b,c){c=a.copy(c).multiplyScalar(.5);this.min.copy(b).sub(c);this.max.copy(b).add(c);
return this}}(),clone:function(){return(new this.constructor).copy(this)},copy:function(a){this.min.copy(a.min);this.max.copy(a.max);return this},makeEmpty:function(){this.min.x=this.min.y=Infinity;this.max.x=this.max.y=-Infinity;return this},isEmpty:function(){return this.max.x<this.min.x||this.max.y<this.min.y},getCenter:function(a){a=a||new D;return this.isEmpty()?a.set(0,0):a.addVectors(this.min,this.max).multiplyScalar(.5)},getSize:function(a){a=a||new D;return this.isEmpty()?a.set(0,0):a.subVectors(this.max,
this.min)},expandByPoint:function(a){this.min.min(a);this.max.max(a);return this},expandByVector:function(a){this.min.sub(a);this.max.add(a);return this},expandByScalar:function(a){this.min.addScalar(-a);this.max.addScalar(a);return this},containsPoint:function(a){return a.x<this.min.x||a.x>this.max.x||a.y<this.min.y||a.y>this.max.y?!1:!0},containsBox:function(a){return this.min.x<=a.min.x&&a.max.x<=this.max.x&&this.min.y<=a.min.y&&a.max.y<=this.max.y},getParameter:function(a,b){return(b||new D).set((a.x-
this.min.x)/(this.max.x-this.min.x),(a.y-this.min.y)/(this.max.y-this.min.y))},intersectsBox:function(a){return a.max.x<this.min.x||a.min.x>this.max.x||a.max.y<this.min.y||a.min.y>this.max.y?!1:!0},clampPoint:function(a,b){return(b||new D).copy(a).clamp(this.min,this.max)},distanceToPoint:function(){var a=new D;return function(b){return a.copy(b).clamp(this.min,this.max).sub(b).length()}}(),intersect:function(a){this.min.max(a.min);this.max.min(a.max);return this},union:function(a){this.min.min(a.min);
this.max.max(a.max);return this},translate:function(a){this.min.add(a);this.max.add(a);return this},equals:function(a){return a.min.equals(this.min)&&a.max.equals(this.max)}});oc.prototype=Object.create(N.prototype);oc.prototype.constructor=oc;var Mf=0;Object.assign(P.prototype,na.prototype,{isMaterial:!0,onBeforeCompile:function(){},setValues:function(a){if(void 0!==a)for(var b in a){var c=a[b];if(void 0===c)console.warn("THREE.Material: '"+b+"' parameter is undefined.");else if("shading"===b)console.warn("THREE."+
this.type+": .shading has been removed. Use the boolean .flatShading instead."),this.flatShading=1===c?!0:!1;else{var d=this[b];void 0===d?console.warn("THREE."+this.type+": '"+b+"' is not a property of this material."):d&&d.isColor?d.set(c):d&&d.isVector3&&c&&c.isVector3?d.copy(c):this[b]="overdraw"===b?Number(c):c}}},toJSON:function(a){function b(a){var b=[],c;for(c in a){var d=a[c];delete d.metadata;b.push(d)}return b}var c=void 0===a;c&&(a={textures:{},images:{}});var d={metadata:{version:4.5,
type:"Material",generator:"Material.toJSON"}};d.uuid=this.uuid;d.type=this.type;""!==this.name&&(d.name=this.name);this.color&&this.color.isColor&&(d.color=this.color.getHex());void 0!==this.roughness&&(d.roughness=this.roughness);void 0!==this.metalness&&(d.metalness=this.metalness);this.emissive&&this.emissive.isColor&&(d.emissive=this.emissive.getHex());this.specular&&this.specular.isColor&&(d.specular=this.specular.getHex());void 0!==this.shininess&&(d.shininess=this.shininess);void 0!==this.clearCoat&&
(d.clearCoat=this.clearCoat);void 0!==this.clearCoatRoughness&&(d.clearCoatRoughness=this.clearCoatRoughness);this.map&&this.map.isTexture&&(d.map=this.map.toJSON(a).uuid);this.alphaMap&&this.alphaMap.isTexture&&(d.alphaMap=this.alphaMap.toJSON(a).uuid);this.lightMap&&this.lightMap.isTexture&&(d.lightMap=this.lightMap.toJSON(a).uuid);this.bumpMap&&this.bumpMap.isTexture&&(d.bumpMap=this.bumpMap.toJSON(a).uuid,d.bumpScale=this.bumpScale);this.normalMap&&this.normalMap.isTexture&&(d.normalMap=this.normalMap.toJSON(a).uuid,
d.normalScale=this.normalScale.toArray());this.displacementMap&&this.displacementMap.isTexture&&(d.displacementMap=this.displacementMap.toJSON(a).uuid,d.displacementScale=this.displacementScale,d.displacementBias=this.displacementBias);this.roughnessMap&&this.roughnessMap.isTexture&&(d.roughnessMap=this.roughnessMap.toJSON(a).uuid);this.metalnessMap&&this.metalnessMap.isTexture&&(d.metalnessMap=this.metalnessMap.toJSON(a).uuid);this.emissiveMap&&this.emissiveMap.isTexture&&(d.emissiveMap=this.emissiveMap.toJSON(a).uuid);
this.specularMap&&this.specularMap.isTexture&&(d.specularMap=this.specularMap.toJSON(a).uuid);this.envMap&&this.envMap.isTexture&&(d.envMap=this.envMap.toJSON(a).uuid,d.reflectivity=this.reflectivity);this.gradientMap&&this.gradientMap.isTexture&&(d.gradientMap=this.gradientMap.toJSON(a).uuid);void 0!==this.size&&(d.size=this.size);void 0!==this.sizeAttenuation&&(d.sizeAttenuation=this.sizeAttenuation);1!==this.blending&&(d.blending=this.blending);!0===this.flatShading&&(d.flatShading=this.flatShading);
0!==this.side&&(d.side=this.side);0!==this.vertexColors&&(d.vertexColors=this.vertexColors);1>this.opacity&&(d.opacity=this.opacity);!0===this.transparent&&(d.transparent=this.transparent);d.depthFunc=this.depthFunc;d.depthTest=this.depthTest;d.depthWrite=this.depthWrite;!0===this.dithering&&(d.dithering=!0);0<this.alphaTest&&(d.alphaTest=this.alphaTest);!0===this.premultipliedAlpha&&(d.premultipliedAlpha=this.premultipliedAlpha);!0===this.wireframe&&(d.wireframe=this.wireframe);1<this.wireframeLinewidth&&
(d.wireframeLinewidth=this.wireframeLinewidth);"round"!==this.wireframeLinecap&&(d.wireframeLinecap=this.wireframeLinecap);"round"!==this.wireframeLinejoin&&(d.wireframeLinejoin=this.wireframeLinejoin);!0===this.morphTargets&&(d.morphTargets=!0);!0===this.skinning&&(d.skinning=!0);!1===this.visible&&(d.visible=!1);"{}"!==JSON.stringify(this.userData)&&(d.userData=this.userData);c&&(c=b(a.textures),a=b(a.images),0<c.length&&(d.textures=c),0<a.length&&(d.images=a));return d},clone:function(){return(new this.constructor).copy(this)},
copy:function(a){this.name=a.name;this.fog=a.fog;this.lights=a.lights;this.blending=a.blending;this.side=a.side;this.flatShading=a.flatShading;this.vertexColors=a.vertexColors;this.opacity=a.opacity;this.transparent=a.transparent;this.blendSrc=a.blendSrc;this.blendDst=a.blendDst;this.blendEquation=a.blendEquation;this.blendSrcAlpha=a.blendSrcAlpha;this.blendDstAlpha=a.blendDstAlpha;this.blendEquationAlpha=a.blendEquationAlpha;this.depthFunc=a.depthFunc;this.depthTest=a.depthTest;this.depthWrite=a.depthWrite;
this.colorWrite=a.colorWrite;this.precision=a.precision;this.polygonOffset=a.polygonOffset;this.polygonOffsetFactor=a.polygonOffsetFactor;this.polygonOffsetUnits=a.polygonOffsetUnits;this.dithering=a.dithering;this.alphaTest=a.alphaTest;this.premultipliedAlpha=a.premultipliedAlpha;this.overdraw=a.overdraw;this.visible=a.visible;this.userData=JSON.parse(JSON.stringify(a.userData));this.clipShadows=a.clipShadows;this.clipIntersection=a.clipIntersection;a=a.clippingPlanes;var b=null;if(null!==a)for(var c=
a.length,b=Array(c),d=0;d!==c;++d)b[d]=a[d].clone();this.clippingPlanes=b;return this},dispose:function(){this.dispatchEvent({type:"dispose"})}});ya.prototype=Object.create(P.prototype);ya.prototype.constructor=ya;ya.prototype.isShaderMaterial=!0;ya.prototype.copy=function(a){P.prototype.copy.call(this,a);this.fragmentShader=a.fragmentShader;this.vertexShader=a.vertexShader;this.uniforms=Da.clone(a.uniforms);this.defines=a.defines;this.wireframe=a.wireframe;this.wireframeLinewidth=a.wireframeLinewidth;
this.lights=a.lights;this.clipping=a.clipping;this.skinning=a.skinning;this.morphTargets=a.morphTargets;this.morphNormals=a.morphNormals;this.extensions=a.extensions;return this};ya.prototype.toJSON=function(a){a=P.prototype.toJSON.call(this,a);a.uniforms=this.uniforms;a.vertexShader=this.vertexShader;a.fragmentShader=this.fragmentShader;return a};Wa.prototype=Object.create(P.prototype);Wa.prototype.constructor=Wa;Wa.prototype.isMeshDepthMaterial=!0;Wa.prototype.copy=function(a){P.prototype.copy.call(this,
a);this.depthPacking=a.depthPacking;this.skinning=a.skinning;this.morphTargets=a.morphTargets;this.map=a.map;this.alphaMap=a.alphaMap;this.displacementMap=a.displacementMap;this.displacementScale=a.displacementScale;this.displacementBias=a.displacementBias;this.wireframe=a.wireframe;this.wireframeLinewidth=a.wireframeLinewidth;return this};Xa.prototype=Object.create(P.prototype);Xa.prototype.constructor=Xa;Xa.prototype.isMeshDistanceMaterial=!0;Xa.prototype.copy=function(a){P.prototype.copy.call(this,
a);this.referencePosition.copy(a.referencePosition);this.nearDistance=a.nearDistance;this.farDistance=a.farDistance;this.skinning=a.skinning;this.morphTargets=a.morphTargets;this.map=a.map;this.alphaMap=a.alphaMap;this.displacementMap=a.displacementMap;this.displacementScale=a.displacementScale;this.displacementBias=a.displacementBias;return this};Object.assign(Pa.prototype,{isBox3:!0,set:function(a,b){this.min.copy(a);this.max.copy(b);return this},setFromArray:function(a){for(var b=Infinity,c=Infinity,
d=Infinity,e=-Infinity,f=-Infinity,g=-Infinity,h=0,k=a.length;h<k;h+=3){var l=a[h],q=a[h+1],p=a[h+2];l<b&&(b=l);q<c&&(c=q);p<d&&(d=p);l>e&&(e=l);q>f&&(f=q);p>g&&(g=p)}this.min.set(b,c,d);this.max.set(e,f,g);return this},setFromBufferAttribute:function(a){for(var b=Infinity,c=Infinity,d=Infinity,e=-Infinity,f=-Infinity,g=-Infinity,h=0,k=a.count;h<k;h++){var l=a.getX(h),q=a.getY(h),p=a.getZ(h);l<b&&(b=l);q<c&&(c=q);p<d&&(d=p);l>e&&(e=l);q>f&&(f=q);p>g&&(g=p)}this.min.set(b,c,d);this.max.set(e,f,g);
return this},setFromPoints:function(a){this.makeEmpty();for(var b=0,c=a.length;b<c;b++)this.expandByPoint(a[b]);return this},setFromCenterAndSize:function(){var a=new n;return function(b,c){c=a.copy(c).multiplyScalar(.5);this.min.copy(b).sub(c);this.max.copy(b).add(c);return this}}(),setFromObject:function(a){this.makeEmpty();return this.expandByObject(a)},clone:function(){return(new this.constructor).copy(this)},copy:function(a){this.min.copy(a.min);this.max.copy(a.max);return this},makeEmpty:function(){this.min.x=
this.min.y=this.min.z=Infinity;this.max.x=this.max.y=this.max.z=-Infinity;return this},isEmpty:function(){return this.max.x<this.min.x||this.max.y<this.min.y||this.max.z<this.min.z},getCenter:function(a){a=a||new n;return this.isEmpty()?a.set(0,0,0):a.addVectors(this.min,this.max).multiplyScalar(.5)},getSize:function(a){a=a||new n;return this.isEmpty()?a.set(0,0,0):a.subVectors(this.max,this.min)},expandByPoint:function(a){this.min.min(a);this.max.max(a);return this},expandByVector:function(a){this.min.sub(a);
this.max.add(a);return this},expandByScalar:function(a){this.min.addScalar(-a);this.max.addScalar(a);return this},expandByObject:function(){var a=new n;return function(b){var c=this;b.updateMatrixWorld(!0);b.traverse(function(b){var d;var f=b.geometry;if(void 0!==f)if(f.isGeometry){var g=f.vertices;f=0;for(d=g.length;f<d;f++)a.copy(g[f]),a.applyMatrix4(b.matrixWorld),c.expandByPoint(a)}else if(f.isBufferGeometry&&(g=f.attributes.position,void 0!==g))for(f=0,d=g.count;f<d;f++)a.fromBufferAttribute(g,
f).applyMatrix4(b.matrixWorld),c.expandByPoint(a)});return this}}(),containsPoint:function(a){return a.x<this.min.x||a.x>this.max.x||a.y<this.min.y||a.y>this.max.y||a.z<this.min.z||a.z>this.max.z?!1:!0},containsBox:function(a){return this.min.x<=a.min.x&&a.max.x<=this.max.x&&this.min.y<=a.min.y&&a.max.y<=this.max.y&&this.min.z<=a.min.z&&a.max.z<=this.max.z},getParameter:function(a,b){return(b||new n).set((a.x-this.min.x)/(this.max.x-this.min.x),(a.y-this.min.y)/(this.max.y-this.min.y),(a.z-this.min.z)/
(this.max.z-this.min.z))},intersectsBox:function(a){return a.max.x<this.min.x||a.min.x>this.max.x||a.max.y<this.min.y||a.min.y>this.max.y||a.max.z<this.min.z||a.min.z>this.max.z?!1:!0},intersectsSphere:function(){var a=new n;return function(b){this.clampPoint(b.center,a);return a.distanceToSquared(b.center)<=b.radius*b.radius}}(),intersectsPlane:function(a){if(0<a.normal.x){var b=a.normal.x*this.min.x;var c=a.normal.x*this.max.x}else b=a.normal.x*this.max.x,c=a.normal.x*this.min.x;0<a.normal.y?(b+=
a.normal.y*this.min.y,c+=a.normal.y*this.max.y):(b+=a.normal.y*this.max.y,c+=a.normal.y*this.min.y);0<a.normal.z?(b+=a.normal.z*this.min.z,c+=a.normal.z*this.max.z):(b+=a.normal.z*this.max.z,c+=a.normal.z*this.min.z);return b<=a.constant&&c>=a.constant},clampPoint:function(a,b){return(b||new n).copy(a).clamp(this.min,this.max)},distanceToPoint:function(){var a=new n;return function(b){return a.copy(b).clamp(this.min,this.max).sub(b).length()}}(),getBoundingSphere:function(){var a=new n;return function(b){b=
b||new Ca;this.getCenter(b.center);b.radius=.5*this.getSize(a).length();return b}}(),intersect:function(a){this.min.max(a.min);this.max.min(a.max);this.isEmpty()&&this.makeEmpty();return this},union:function(a){this.min.min(a.min);this.max.max(a.max);return this},applyMatrix4:function(){var a=[new n,new n,new n,new n,new n,new n,new n,new n];return function(b){if(this.isEmpty())return this;a[0].set(this.min.x,this.min.y,this.min.z).applyMatrix4(b);a[1].set(this.min.x,this.min.y,this.max.z).applyMatrix4(b);
a[2].set(this.min.x,this.max.y,this.min.z).applyMatrix4(b);a[3].set(this.min.x,this.max.y,this.max.z).applyMatrix4(b);a[4].set(this.max.x,this.min.y,this.min.z).applyMatrix4(b);a[5].set(this.max.x,this.min.y,this.max.z).applyMatrix4(b);a[6].set(this.max.x,this.max.y,this.min.z).applyMatrix4(b);a[7].set(this.max.x,this.max.y,this.max.z).applyMatrix4(b);this.setFromPoints(a);return this}}(),translate:function(a){this.min.add(a);this.max.add(a);return this},equals:function(a){return a.min.equals(this.min)&&
a.max.equals(this.max)}});Object.assign(Ca.prototype,{set:function(a,b){this.center.copy(a);this.radius=b;return this},setFromPoints:function(){var a=new Pa;return function(b,c){var d=this.center;void 0!==c?d.copy(c):a.setFromPoints(b).getCenter(d);for(var e=c=0,f=b.length;e<f;e++)c=Math.max(c,d.distanceToSquared(b[e]));this.radius=Math.sqrt(c);return this}}(),clone:function(){return(new this.constructor).copy(this)},copy:function(a){this.center.copy(a.center);this.radius=a.radius;return this},empty:function(){return 0>=
this.radius},containsPoint:function(a){return a.distanceToSquared(this.center)<=this.radius*this.radius},distanceToPoint:function(a){return a.distanceTo(this.center)-this.radius},intersectsSphere:function(a){var b=this.radius+a.radius;return a.center.distanceToSquared(this.center)<=b*b},intersectsBox:function(a){return a.intersectsSphere(this)},intersectsPlane:function(a){return Math.abs(a.distanceToPoint(this.center))<=this.radius},clampPoint:function(a,b){var c=this.center.distanceToSquared(a);
b=b||new n;b.copy(a);c>this.radius*this.radius&&(b.sub(this.center).normalize(),b.multiplyScalar(this.radius).add(this.center));return b},getBoundingBox:function(a){a=a||new Pa;a.set(this.center,this.center);a.expandByScalar(this.radius);return a},applyMatrix4:function(a){this.center.applyMatrix4(a);this.radius*=a.getMaxScaleOnAxis();return this},translate:function(a){this.center.add(a);return this},equals:function(a){return a.center.equals(this.center)&&a.radius===this.radius}});Object.assign(qa.prototype,
{isMatrix3:!0,set:function(a,b,c,d,e,f,g,h,k){var l=this.elements;l[0]=a;l[1]=d;l[2]=g;l[3]=b;l[4]=e;l[5]=h;l[6]=c;l[7]=f;l[8]=k;return this},identity:function(){this.set(1,0,0,0,1,0,0,0,1);return this},clone:function(){return(new this.constructor).fromArray(this.elements)},copy:function(a){var b=this.elements;a=a.elements;b[0]=a[0];b[1]=a[1];b[2]=a[2];b[3]=a[3];b[4]=a[4];b[5]=a[5];b[6]=a[6];b[7]=a[7];b[8]=a[8];return this},setFromMatrix4:function(a){a=a.elements;this.set(a[0],a[4],a[8],a[1],a[5],
a[9],a[2],a[6],a[10]);return this},applyToBufferAttribute:function(){var a=new n;return function(b){for(var c=0,d=b.count;c<d;c++)a.x=b.getX(c),a.y=b.getY(c),a.z=b.getZ(c),a.applyMatrix3(this),b.setXYZ(c,a.x,a.y,a.z);return b}}(),multiply:function(a){return this.multiplyMatrices(this,a)},premultiply:function(a){return this.multiplyMatrices(a,this)},multiplyMatrices:function(a,b){var c=a.elements,d=b.elements;b=this.elements;a=c[0];var e=c[3],f=c[6],g=c[1],h=c[4],k=c[7],l=c[2],q=c[5],c=c[8],p=d[0],
m=d[3],r=d[6],n=d[1],u=d[4],x=d[7],y=d[2],A=d[5],d=d[8];b[0]=a*p+e*n+f*y;b[3]=a*m+e*u+f*A;b[6]=a*r+e*x+f*d;b[1]=g*p+h*n+k*y;b[4]=g*m+h*u+k*A;b[7]=g*r+h*x+k*d;b[2]=l*p+q*n+c*y;b[5]=l*m+q*u+c*A;b[8]=l*r+q*x+c*d;return this},multiplyScalar:function(a){var b=this.elements;b[0]*=a;b[3]*=a;b[6]*=a;b[1]*=a;b[4]*=a;b[7]*=a;b[2]*=a;b[5]*=a;b[8]*=a;return this},determinant:function(){var a=this.elements,b=a[0],c=a[1],d=a[2],e=a[3],f=a[4],g=a[5],h=a[6],k=a[7],a=a[8];return b*f*a-b*g*k-c*e*a+c*g*h+d*e*k-d*f*
h},getInverse:function(a,b){a&&a.isMatrix4&&console.error("THREE.Matrix3: .getInverse() no longer takes a Matrix4 argument.");var c=a.elements;a=this.elements;var d=c[0],e=c[1],f=c[2],g=c[3],h=c[4],k=c[5],l=c[6],q=c[7],c=c[8],p=c*h-k*q,m=k*l-c*g,r=q*g-h*l,n=d*p+e*m+f*r;if(0===n){if(!0===b)throw Error("THREE.Matrix3: .getInverse() can't invert matrix, determinant is 0");console.warn("THREE.Matrix3: .getInverse() can't invert matrix, determinant is 0");return this.identity()}b=1/n;a[0]=p*b;a[1]=(f*
q-c*e)*b;a[2]=(k*e-f*h)*b;a[3]=m*b;a[4]=(c*d-f*l)*b;a[5]=(f*g-k*d)*b;a[6]=r*b;a[7]=(e*l-q*d)*b;a[8]=(h*d-e*g)*b;return this},transpose:function(){var a=this.elements;var b=a[1];a[1]=a[3];a[3]=b;b=a[2];a[2]=a[6];a[6]=b;b=a[5];a[5]=a[7];a[7]=b;return this},getNormalMatrix:function(a){return this.setFromMatrix4(a).getInverse(this).transpose()},transposeIntoArray:function(a){var b=this.elements;a[0]=b[0];a[1]=b[3];a[2]=b[6];a[3]=b[1];a[4]=b[4];a[5]=b[7];a[6]=b[2];a[7]=b[5];a[8]=b[8];return this},equals:function(a){var b=
this.elements;a=a.elements;for(var c=0;9>c;c++)if(b[c]!==a[c])return!1;return!0},fromArray:function(a,b){void 0===b&&(b=0);for(var c=0;9>c;c++)this.elements[c]=a[c+b];return this},toArray:function(a,b){void 0===a&&(a=[]);void 0===b&&(b=0);var c=this.elements;a[b]=c[0];a[b+1]=c[1];a[b+2]=c[2];a[b+3]=c[3];a[b+4]=c[4];a[b+5]=c[5];a[b+6]=c[6];a[b+7]=c[7];a[b+8]=c[8];return a}});Object.assign(za.prototype,{set:function(a,b){this.normal.copy(a);this.constant=b;return this},setComponents:function(a,b,c,
d){this.normal.set(a,b,c);this.constant=d;return this},setFromNormalAndCoplanarPoint:function(a,b){this.normal.copy(a);this.constant=-b.dot(this.normal);return this},setFromCoplanarPoints:function(){var a=new n,b=new n;return function(c,d,e){d=a.subVectors(e,d).cross(b.subVectors(c,d)).normalize();this.setFromNormalAndCoplanarPoint(d,c);return this}}(),clone:function(){return(new this.constructor).copy(this)},copy:function(a){this.normal.copy(a.normal);this.constant=a.constant;return this},normalize:function(){var a=
1/this.normal.length();this.normal.multiplyScalar(a);this.constant*=a;return this},negate:function(){this.constant*=-1;this.normal.negate();return this},distanceToPoint:function(a){return this.normal.dot(a)+this.constant},distanceToSphere:function(a){return this.distanceToPoint(a.center)-a.radius},projectPoint:function(a,b){return(b||new n).copy(this.normal).multiplyScalar(-this.distanceToPoint(a)).add(a)},intersectLine:function(){var a=new n;return function(b,c){c=c||new n;var d=b.delta(a),e=this.normal.dot(d);
if(0===e){if(0===this.distanceToPoint(b.start))return c.copy(b.start)}else if(e=-(b.start.dot(this.normal)+this.constant)/e,!(0>e||1<e))return c.copy(d).multiplyScalar(e).add(b.start)}}(),intersectsLine:function(a){var b=this.distanceToPoint(a.start);a=this.distanceToPoint(a.end);return 0>b&&0<a||0>a&&0<b},intersectsBox:function(a){return a.intersectsPlane(this)},intersectsSphere:function(a){return a.intersectsPlane(this)},coplanarPoint:function(a){return(a||new n).copy(this.normal).multiplyScalar(-this.constant)},
applyMatrix4:function(){var a=new n,b=new qa;return function(c,d){d=d||b.getNormalMatrix(c);c=this.coplanarPoint(a).applyMatrix4(c);d=this.normal.applyMatrix3(d).normalize();this.constant=-c.dot(d);return this}}(),translate:function(a){this.constant-=a.dot(this.normal);return this},equals:function(a){return a.normal.equals(this.normal)&&a.constant===this.constant}});Object.assign(kd.prototype,{set:function(a,b,c,d,e,f){var g=this.planes;g[0].copy(a);g[1].copy(b);g[2].copy(c);g[3].copy(d);g[4].copy(e);
g[5].copy(f);return this},clone:function(){return(new this.constructor).copy(this)},copy:function(a){for(var b=this.planes,c=0;6>c;c++)b[c].copy(a.planes[c]);return this},setFromMatrix:function(a){var b=this.planes,c=a.elements;a=c[0];var d=c[1],e=c[2],f=c[3],g=c[4],h=c[5],k=c[6],l=c[7],q=c[8],p=c[9],m=c[10],r=c[11],n=c[12],u=c[13],x=c[14],c=c[15];b[0].setComponents(f-a,l-g,r-q,c-n).normalize();b[1].setComponents(f+a,l+g,r+q,c+n).normalize();b[2].setComponents(f+d,l+h,r+p,c+u).normalize();b[3].setComponents(f-
d,l-h,r-p,c-u).normalize();b[4].setComponents(f-e,l-k,r-m,c-x).normalize();b[5].setComponents(f+e,l+k,r+m,c+x).normalize();return this},intersectsObject:function(){var a=new Ca;return function(b){var c=b.geometry;null===c.boundingSphere&&c.computeBoundingSphere();a.copy(c.boundingSphere).applyMatrix4(b.matrixWorld);return this.intersectsSphere(a)}}(),intersectsSprite:function(){var a=new Ca;return function(b){a.center.set(0,0,0);a.radius=.7071067811865476;a.applyMatrix4(b.matrixWorld);return this.intersectsSphere(a)}}(),
intersectsSphere:function(a){var b=this.planes,c=a.center;a=-a.radius;for(var d=0;6>d;d++)if(b[d].distanceToPoint(c)<a)return!1;return!0},intersectsBox:function(){var a=new n,b=new n;return function(c){for(var d=this.planes,e=0;6>e;e++){var f=d[e];a.x=0<f.normal.x?c.min.x:c.max.x;b.x=0<f.normal.x?c.max.x:c.min.x;a.y=0<f.normal.y?c.min.y:c.max.y;b.y=0<f.normal.y?c.max.y:c.min.y;a.z=0<f.normal.z?c.min.z:c.max.z;b.z=0<f.normal.z?c.max.z:c.min.z;var g=f.distanceToPoint(a),f=f.distanceToPoint(b);if(0>
g&&0>f)return!1}return!0}}(),containsPoint:function(a){for(var b=this.planes,c=0;6>c;c++)if(0>b[c].distanceToPoint(a))return!1;return!0}});Ya.RotationOrders="XYZ YZX ZXY XZY YXZ ZYX".split(" ");Ya.DefaultOrder="XYZ";Object.defineProperties(Ya.prototype,{x:{get:function(){return this._x},set:function(a){this._x=a;this.onChangeCallback()}},y:{get:function(){return this._y},set:function(a){this._y=a;this.onChangeCallback()}},z:{get:function(){return this._z},set:function(a){this._z=a;this.onChangeCallback()}},
order:{get:function(){return this._order},set:function(a){this._order=a;this.onChangeCallback()}}});Object.assign(Ya.prototype,{isEuler:!0,set:function(a,b,c,d){this._x=a;this._y=b;this._z=c;this._order=d||this._order;this.onChangeCallback();return this},clone:function(){return new this.constructor(this._x,this._y,this._z,this._order)},copy:function(a){this._x=a._x;this._y=a._y;this._z=a._z;this._order=a._order;this.onChangeCallback();return this},setFromRotationMatrix:function(a,b,c){var d=R.clamp,
e=a.elements;a=e[0];var f=e[4],g=e[8],h=e[1],k=e[5],l=e[9],q=e[2],p=e[6],e=e[10];b=b||this._order;"XYZ"===b?(this._y=Math.asin(d(g,-1,1)),.99999>Math.abs(g)?(this._x=Math.atan2(-l,e),this._z=Math.atan2(-f,a)):(this._x=Math.atan2(p,k),this._z=0)):"YXZ"===b?(this._x=Math.asin(-d(l,-1,1)),.99999>Math.abs(l)?(this._y=Math.atan2(g,e),this._z=Math.atan2(h,k)):(this._y=Math.atan2(-q,a),this._z=0)):"ZXY"===b?(this._x=Math.asin(d(p,-1,1)),.99999>Math.abs(p)?(this._y=Math.atan2(-q,e),this._z=Math.atan2(-f,
k)):(this._y=0,this._z=Math.atan2(h,a))):"ZYX"===b?(this._y=Math.asin(-d(q,-1,1)),.99999>Math.abs(q)?(this._x=Math.atan2(p,e),this._z=Math.atan2(h,a)):(this._x=0,this._z=Math.atan2(-f,k))):"YZX"===b?(this._z=Math.asin(d(h,-1,1)),.99999>Math.abs(h)?(this._x=Math.atan2(-l,k),this._y=Math.atan2(-q,a)):(this._x=0,this._y=Math.atan2(g,e))):"XZY"===b?(this._z=Math.asin(-d(f,-1,1)),.99999>Math.abs(f)?(this._x=Math.atan2(p,k),this._y=Math.atan2(g,a)):(this._x=Math.atan2(-l,e),this._y=0)):console.warn("THREE.Euler: .setFromRotationMatrix() given unsupported order: "+
b);this._order=b;if(!1!==c)this.onChangeCallback();return this},setFromQuaternion:function(){var a=new O;return function(b,c,d){a.makeRotationFromQuaternion(b);return this.setFromRotationMatrix(a,c,d)}}(),setFromVector3:function(a,b){return this.set(a.x,a.y,a.z,b||this._order)},reorder:function(){var a=new ia;return function(b){a.setFromEuler(this);return this.setFromQuaternion(a,b)}}(),equals:function(a){return a._x===this._x&&a._y===this._y&&a._z===this._z&&a._order===this._order},fromArray:function(a){this._x=
a[0];this._y=a[1];this._z=a[2];void 0!==a[3]&&(this._order=a[3]);this.onChangeCallback();return this},toArray:function(a,b){void 0===a&&(a=[]);void 0===b&&(b=0);a[b]=this._x;a[b+1]=this._y;a[b+2]=this._z;a[b+3]=this._order;return a},toVector3:function(a){return a?a.set(this._x,this._y,this._z):new n(this._x,this._y,this._z)},onChange:function(a){this.onChangeCallback=a;return this},onChangeCallback:function(){}});Object.assign(Qd.prototype,{set:function(a){this.mask=1<<a|0},enable:function(a){this.mask=
this.mask|1<<a|0},toggle:function(a){this.mask^=1<<a|0},disable:function(a){this.mask&=~(1<<a|0)},test:function(a){return 0!==(this.mask&a.mask)}});var Of=0;w.DefaultUp=new n(0,1,0);w.DefaultMatrixAutoUpdate=!0;Object.assign(w.prototype,na.prototype,{isObject3D:!0,onBeforeRender:function(){},onAfterRender:function(){},applyMatrix:function(a){this.matrix.multiplyMatrices(a,this.matrix);this.matrix.decompose(this.position,this.quaternion,this.scale)},applyQuaternion:function(a){this.quaternion.premultiply(a);
return this},setRotationFromAxisAngle:function(a,b){this.quaternion.setFromAxisAngle(a,b)},setRotationFromEuler:function(a){this.quaternion.setFromEuler(a,!0)},setRotationFromMatrix:function(a){this.quaternion.setFromRotationMatrix(a)},setRotationFromQuaternion:function(a){this.quaternion.copy(a)},rotateOnAxis:function(){var a=new ia;return function(b,c){a.setFromAxisAngle(b,c);this.quaternion.multiply(a);return this}}(),rotateX:function(){var a=new n(1,0,0);return function(b){return this.rotateOnAxis(a,
b)}}(),rotateY:function(){var a=new n(0,1,0);return function(b){return this.rotateOnAxis(a,b)}}(),rotateZ:function(){var a=new n(0,0,1);return function(b){return this.rotateOnAxis(a,b)}}(),translateOnAxis:function(){var a=new n;return function(b,c){a.copy(b).applyQuaternion(this.quaternion);this.position.add(a.multiplyScalar(c));return this}}(),translateX:function(){var a=new n(1,0,0);return function(b){return this.translateOnAxis(a,b)}}(),translateY:function(){var a=new n(0,1,0);return function(b){return this.translateOnAxis(a,
b)}}(),translateZ:function(){var a=new n(0,0,1);return function(b){return this.translateOnAxis(a,b)}}(),localToWorld:function(a){return a.applyMatrix4(this.matrixWorld)},worldToLocal:function(){var a=new O;return function(b){return b.applyMatrix4(a.getInverse(this.matrixWorld))}}(),lookAt:function(){var a=new O;return function(b){this.isCamera?a.lookAt(this.position,b,this.up):a.lookAt(b,this.position,this.up);this.quaternion.setFromRotationMatrix(a)}}(),add:function(a){if(1<arguments.length){for(var b=
0;b<arguments.length;b++)this.add(arguments[b]);return this}if(a===this)return console.error("THREE.Object3D.add: object can't be added as a child of itself.",a),this;a&&a.isObject3D?(null!==a.parent&&a.parent.remove(a),a.parent=this,a.dispatchEvent({type:"added"}),this.children.push(a)):console.error("THREE.Object3D.add: object not an instance of THREE.Object3D.",a);return this},remove:function(a){if(1<arguments.length){for(var b=0;b<arguments.length;b++)this.remove(arguments[b]);return this}b=this.children.indexOf(a);
-1!==b&&(a.parent=null,a.dispatchEvent({type:"removed"}),this.children.splice(b,1));return this},getObjectById:function(a){return this.getObjectByProperty("id",a)},getObjectByName:function(a){return this.getObjectByProperty("name",a)},getObjectByProperty:function(a,b){if(this[a]===b)return this;for(var c=0,d=this.children.length;c<d;c++){var e=this.children[c].getObjectByProperty(a,b);if(void 0!==e)return e}},getWorldPosition:function(a){a=a||new n;this.updateMatrixWorld(!0);return a.setFromMatrixPosition(this.matrixWorld)},
getWorldQuaternion:function(){var a=new n,b=new n;return function(c){c=c||new ia;this.updateMatrixWorld(!0);this.matrixWorld.decompose(a,c,b);return c}}(),getWorldRotation:function(){var a=new ia;return function(b){b=b||new Ya;this.getWorldQuaternion(a);return b.setFromQuaternion(a,this.rotation.order,!1)}}(),getWorldScale:function(){var a=new n,b=new ia;return function(c){c=c||new n;this.updateMatrixWorld(!0);this.matrixWorld.decompose(a,b,c);return c}}(),getWorldDirection:function(){var a=new ia;
return function(b){b=b||new n;this.getWorldQuaternion(a);return b.set(0,0,1).applyQuaternion(a)}}(),raycast:function(){},traverse:function(a){a(this);for(var b=this.children,c=0,d=b.length;c<d;c++)b[c].traverse(a)},traverseVisible:function(a){if(!1!==this.visible){a(this);for(var b=this.children,c=0,d=b.length;c<d;c++)b[c].traverseVisible(a)}},traverseAncestors:function(a){var b=this.parent;null!==b&&(a(b),b.traverseAncestors(a))},updateMatrix:function(){this.matrix.compose(this.position,this.quaternion,
this.scale);this.matrixWorldNeedsUpdate=!0},updateMatrixWorld:function(a){this.matrixAutoUpdate&&this.updateMatrix();if(this.matrixWorldNeedsUpdate||a)null===this.parent?this.matrixWorld.copy(this.matrix):this.matrixWorld.multiplyMatrices(this.parent.matrixWorld,this.matrix),this.matrixWorldNeedsUpdate=!1,a=!0;for(var b=this.children,c=0,d=b.length;c<d;c++)b[c].updateMatrixWorld(a)},toJSON:function(a){function b(b,c){void 0===b[c.uuid]&&(b[c.uuid]=c.toJSON(a));return c.uuid}function c(a){var b=[],
c;for(c in a){var d=a[c];delete d.metadata;b.push(d)}return b}var d=void 0===a||""===a,e={};d&&(a={geometries:{},materials:{},textures:{},images:{}},e.metadata={version:4.5,type:"Object",generator:"Object3D.toJSON"});var f={};f.uuid=this.uuid;f.type=this.type;""!==this.name&&(f.name=this.name);!0===this.castShadow&&(f.castShadow=!0);!0===this.receiveShadow&&(f.receiveShadow=!0);!1===this.visible&&(f.visible=!1);"{}"!==JSON.stringify(this.userData)&&(f.userData=this.userData);f.matrix=this.matrix.toArray();
void 0!==this.geometry&&(f.geometry=b(a.geometries,this.geometry));if(void 0!==this.material)if(Array.isArray(this.material)){for(var g=[],h=0,k=this.material.length;h<k;h++)g.push(b(a.materials,this.material[h]));f.material=g}else f.material=b(a.materials,this.material);if(0<this.children.length)for(f.children=[],h=0;h<this.children.length;h++)f.children.push(this.children[h].toJSON(a).object);d&&(d=c(a.geometries),g=c(a.materials),h=c(a.textures),k=c(a.images),0<d.length&&(e.geometries=d),0<g.length&&
(e.materials=g),0<h.length&&(e.textures=h),0<k.length&&(e.images=k));e.object=f;return e},clone:function(a){return(new this.constructor).copy(this,a)},copy:function(a,b){void 0===b&&(b=!0);this.name=a.name;this.up.copy(a.up);this.position.copy(a.position);this.quaternion.copy(a.quaternion);this.scale.copy(a.scale);this.matrix.copy(a.matrix);this.matrixWorld.copy(a.matrixWorld);this.matrixAutoUpdate=a.matrixAutoUpdate;this.matrixWorldNeedsUpdate=a.matrixWorldNeedsUpdate;this.layers.mask=a.layers.mask;
this.visible=a.visible;this.castShadow=a.castShadow;this.receiveShadow=a.receiveShadow;this.frustumCulled=a.frustumCulled;this.renderOrder=a.renderOrder;this.userData=JSON.parse(JSON.stringify(a.userData));if(!0===b)for(b=0;b<a.children.length;b++)this.add(a.children[b].clone());return this}});Ma.prototype=Object.assign(Object.create(w.prototype),{constructor:Ma,isCamera:!0,copy:function(a,b){w.prototype.copy.call(this,a,b);this.matrixWorldInverse.copy(a.matrixWorldInverse);this.projectionMatrix.copy(a.projectionMatrix);
return this},getWorldDirection:function(){var a=new ia;return function(b){b=b||new n;this.getWorldQuaternion(a);return b.set(0,0,-1).applyQuaternion(a)}}(),updateMatrixWorld:function(a){w.prototype.updateMatrixWorld.call(this,a);this.matrixWorldInverse.getInverse(this.matrixWorld)},clone:function(){return(new this.constructor).copy(this)}});Db.prototype=Object.assign(Object.create(Ma.prototype),{constructor:Db,isOrthographicCamera:!0,copy:function(a,b){Ma.prototype.copy.call(this,a,b);this.left=a.left;
this.right=a.right;this.top=a.top;this.bottom=a.bottom;this.near=a.near;this.far=a.far;this.zoom=a.zoom;this.view=null===a.view?null:Object.assign({},a.view);return this},setViewOffset:function(a,b,c,d,e,f){this.view={fullWidth:a,fullHeight:b,offsetX:c,offsetY:d,width:e,height:f};this.updateProjectionMatrix()},clearViewOffset:function(){this.view=null;this.updateProjectionMatrix()},updateProjectionMatrix:function(){var a=(this.right-this.left)/(2*this.zoom),b=(this.top-this.bottom)/(2*this.zoom),
c=(this.right+this.left)/2,d=(this.top+this.bottom)/2,e=c-a,c=c+a,a=d+b,b=d-b;if(null!==this.view)var c=this.zoom/(this.view.width/this.view.fullWidth),b=this.zoom/(this.view.height/this.view.fullHeight),f=(this.right-this.left)/this.view.width,d=(this.top-this.bottom)/this.view.height,e=e+this.view.offsetX/c*f,c=e+this.view.width/c*f,a=a-this.view.offsetY/b*d,b=a-this.view.height/b*d;this.projectionMatrix.makeOrthographic(e,c,a,b,this.near,this.far)},toJSON:function(a){a=w.prototype.toJSON.call(this,
a);a.object.zoom=this.zoom;a.object.left=this.left;a.object.right=this.right;a.object.top=this.top;a.object.bottom=this.bottom;a.object.near=this.near;a.object.far=this.far;null!==this.view&&(a.object.view=Object.assign({},this.view));return a}});ja.prototype=Object.assign(Object.create(Ma.prototype),{constructor:ja,isPerspectiveCamera:!0,copy:function(a,b){Ma.prototype.copy.call(this,a,b);this.fov=a.fov;this.zoom=a.zoom;this.near=a.near;this.far=a.far;this.focus=a.focus;this.aspect=a.aspect;this.view=
null===a.view?null:Object.assign({},a.view);this.filmGauge=a.filmGauge;this.filmOffset=a.filmOffset;return this},setFocalLength:function(a){a=.5*this.getFilmHeight()/a;this.fov=2*R.RAD2DEG*Math.atan(a);this.updateProjectionMatrix()},getFocalLength:function(){var a=Math.tan(.5*R.DEG2RAD*this.fov);return.5*this.getFilmHeight()/a},getEffectiveFOV:function(){return 2*R.RAD2DEG*Math.atan(Math.tan(.5*R.DEG2RAD*this.fov)/this.zoom)},getFilmWidth:function(){return this.filmGauge*Math.min(this.aspect,1)},
getFilmHeight:function(){return this.filmGauge/Math.max(this.aspect,1)},setViewOffset:function(a,b,c,d,e,f){this.aspect=a/b;this.view={fullWidth:a,fullHeight:b,offsetX:c,offsetY:d,width:e,height:f};this.updateProjectionMatrix()},clearViewOffset:function(){this.view=null;this.updateProjectionMatrix()},updateProjectionMatrix:function(){var a=this.near,b=a*Math.tan(.5*R.DEG2RAD*this.fov)/this.zoom,c=2*b,d=this.aspect*c,e=-.5*d,f=this.view;if(null!==f)var g=f.fullWidth,h=f.fullHeight,e=e+f.offsetX*d/
g,b=b-f.offsetY*c/h,d=f.width/g*d,c=f.height/h*c;f=this.filmOffset;0!==f&&(e+=a*f/this.getFilmWidth());this.projectionMatrix.makePerspective(e,e+d,b,b-c,a,this.far)},toJSON:function(a){a=w.prototype.toJSON.call(this,a);a.object.fov=this.fov;a.object.zoom=this.zoom;a.object.near=this.near;a.object.far=this.far;a.object.focus=this.focus;a.object.aspect=this.aspect;null!==this.view&&(a.object.view=Object.assign({},this.view));a.object.filmGauge=this.filmGauge;a.object.filmOffset=this.filmOffset;return a}});
Object.assign(Qa.prototype,{clone:function(){return(new this.constructor).copy(this)},copy:function(a){this.a=a.a;this.b=a.b;this.c=a.c;this.normal.copy(a.normal);this.color.copy(a.color);this.materialIndex=a.materialIndex;for(var b=0,c=a.vertexNormals.length;b<c;b++)this.vertexNormals[b]=a.vertexNormals[b].clone();b=0;for(c=a.vertexColors.length;b<c;b++)this.vertexColors[b]=a.vertexColors[b].clone();return this}});var Rd=0;Object.assign(Q.prototype,na.prototype,{isGeometry:!0,applyMatrix:function(a){for(var b=
(new qa).getNormalMatrix(a),c=0,d=this.vertices.length;c<d;c++)this.vertices[c].applyMatrix4(a);c=0;for(d=this.faces.length;c<d;c++){a=this.faces[c];a.normal.applyMatrix3(b).normalize();for(var e=0,f=a.vertexNormals.length;e<f;e++)a.vertexNormals[e].applyMatrix3(b).normalize()}null!==this.boundingBox&&this.computeBoundingBox();null!==this.boundingSphere&&this.computeBoundingSphere();this.normalsNeedUpdate=this.verticesNeedUpdate=!0;return this},rotateX:function(){var a=new O;return function(b){a.makeRotationX(b);
this.applyMatrix(a);return this}}(),rotateY:function(){var a=new O;return function(b){a.makeRotationY(b);this.applyMatrix(a);return this}}(),rotateZ:function(){var a=new O;return function(b){a.makeRotationZ(b);this.applyMatrix(a);return this}}(),translate:function(){var a=new O;return function(b,c,d){a.makeTranslation(b,c,d);this.applyMatrix(a);return this}}(),scale:function(){var a=new O;return function(b,c,d){a.makeScale(b,c,d);this.applyMatrix(a);return this}}(),lookAt:function(){var a=new w;return function(b){a.lookAt(b);
a.updateMatrix();this.applyMatrix(a.matrix)}}(),fromBufferGeometry:function(a){function b(a,b,d,e){var f=void 0!==g?[q[a].clone(),q[b].clone(),q[d].clone()]:[],t=void 0!==h?[c.colors[a].clone(),c.colors[b].clone(),c.colors[d].clone()]:[];e=new Qa(a,b,d,f,t,e);c.faces.push(e);void 0!==k&&c.faceVertexUvs[0].push([p[a].clone(),p[b].clone(),p[d].clone()]);void 0!==l&&c.faceVertexUvs[1].push([m[a].clone(),m[b].clone(),m[d].clone()])}var c=this,d=null!==a.index?a.index.array:void 0,e=a.attributes,f=e.position.array,
g=void 0!==e.normal?e.normal.array:void 0,h=void 0!==e.color?e.color.array:void 0,k=void 0!==e.uv?e.uv.array:void 0,l=void 0!==e.uv2?e.uv2.array:void 0;void 0!==l&&(this.faceVertexUvs[1]=[]);for(var q=[],p=[],m=[],r=e=0;e<f.length;e+=3,r+=2)c.vertices.push(new n(f[e],f[e+1],f[e+2])),void 0!==g&&q.push(new n(g[e],g[e+1],g[e+2])),void 0!==h&&c.colors.push(new C(h[e],h[e+1],h[e+2])),void 0!==k&&p.push(new D(k[r],k[r+1])),void 0!==l&&m.push(new D(l[r],l[r+1]));var v=a.groups;if(0<v.length)for(e=0;e<v.length;e++)for(var f=
v[e],u=f.start,x=f.count,r=u,u=u+x;r<u;r+=3)void 0!==d?b(d[r],d[r+1],d[r+2],f.materialIndex):b(r,r+1,r+2,f.materialIndex);else if(void 0!==d)for(e=0;e<d.length;e+=3)b(d[e],d[e+1],d[e+2]);else for(e=0;e<f.length/3;e+=3)b(e,e+1,e+2);this.computeFaceNormals();null!==a.boundingBox&&(this.boundingBox=a.boundingBox.clone());null!==a.boundingSphere&&(this.boundingSphere=a.boundingSphere.clone());return this},center:function(){this.computeBoundingBox();var a=this.boundingBox.getCenter().negate();this.translate(a.x,
a.y,a.z);return a},normalize:function(){this.computeBoundingSphere();var a=this.boundingSphere.center,b=this.boundingSphere.radius,b=0===b?1:1/b,c=new O;c.set(b,0,0,-b*a.x,0,b,0,-b*a.y,0,0,b,-b*a.z,0,0,0,1);this.applyMatrix(c);return this},computeFaceNormals:function(){for(var a=new n,b=new n,c=0,d=this.faces.length;c<d;c++){var e=this.faces[c],f=this.vertices[e.a],g=this.vertices[e.b];a.subVectors(this.vertices[e.c],g);b.subVectors(f,g);a.cross(b);a.normalize();e.normal.copy(a)}},computeVertexNormals:function(a){void 0===
a&&(a=!0);var b;var c=Array(this.vertices.length);var d=0;for(b=this.vertices.length;d<b;d++)c[d]=new n;if(a){var e=new n,f=new n;a=0;for(d=this.faces.length;a<d;a++){b=this.faces[a];var g=this.vertices[b.a];var h=this.vertices[b.b];var k=this.vertices[b.c];e.subVectors(k,h);f.subVectors(g,h);e.cross(f);c[b.a].add(e);c[b.b].add(e);c[b.c].add(e)}}else for(this.computeFaceNormals(),a=0,d=this.faces.length;a<d;a++)b=this.faces[a],c[b.a].add(b.normal),c[b.b].add(b.normal),c[b.c].add(b.normal);d=0;for(b=
this.vertices.length;d<b;d++)c[d].normalize();a=0;for(d=this.faces.length;a<d;a++)b=this.faces[a],g=b.vertexNormals,3===g.length?(g[0].copy(c[b.a]),g[1].copy(c[b.b]),g[2].copy(c[b.c])):(g[0]=c[b.a].clone(),g[1]=c[b.b].clone(),g[2]=c[b.c].clone());0<this.faces.length&&(this.normalsNeedUpdate=!0)},computeFlatVertexNormals:function(){var a;this.computeFaceNormals();var b=0;for(a=this.faces.length;b<a;b++){var c=this.faces[b];var d=c.vertexNormals;3===d.length?(d[0].copy(c.normal),d[1].copy(c.normal),
d[2].copy(c.normal)):(d[0]=c.normal.clone(),d[1]=c.normal.clone(),d[2]=c.normal.clone())}0<this.faces.length&&(this.normalsNeedUpdate=!0)},computeMorphNormals:function(){var a,b;var c=0;for(b=this.faces.length;c<b;c++){var d=this.faces[c];d.__originalFaceNormal?d.__originalFaceNormal.copy(d.normal):d.__originalFaceNormal=d.normal.clone();d.__originalVertexNormals||(d.__originalVertexNormals=[]);var e=0;for(a=d.vertexNormals.length;e<a;e++)d.__originalVertexNormals[e]?d.__originalVertexNormals[e].copy(d.vertexNormals[e]):
d.__originalVertexNormals[e]=d.vertexNormals[e].clone()}var f=new Q;f.faces=this.faces;e=0;for(a=this.morphTargets.length;e<a;e++){if(!this.morphNormals[e]){this.morphNormals[e]={};this.morphNormals[e].faceNormals=[];this.morphNormals[e].vertexNormals=[];d=this.morphNormals[e].faceNormals;var g=this.morphNormals[e].vertexNormals;c=0;for(b=this.faces.length;c<b;c++){var h=new n;var k={a:new n,b:new n,c:new n};d.push(h);g.push(k)}}g=this.morphNormals[e];f.vertices=this.morphTargets[e].vertices;f.computeFaceNormals();
f.computeVertexNormals();c=0;for(b=this.faces.length;c<b;c++)d=this.faces[c],h=g.faceNormals[c],k=g.vertexNormals[c],h.copy(d.normal),k.a.copy(d.vertexNormals[0]),k.b.copy(d.vertexNormals[1]),k.c.copy(d.vertexNormals[2])}c=0;for(b=this.faces.length;c<b;c++)d=this.faces[c],d.normal=d.__originalFaceNormal,d.vertexNormals=d.__originalVertexNormals},computeLineDistances:function(){for(var a=0,b=this.vertices,c=0,d=b.length;c<d;c++)0<c&&(a+=b[c].distanceTo(b[c-1])),this.lineDistances[c]=a},computeBoundingBox:function(){null===
this.boundingBox&&(this.boundingBox=new Pa);this.boundingBox.setFromPoints(this.vertices)},computeBoundingSphere:function(){null===this.boundingSphere&&(this.boundingSphere=new Ca);this.boundingSphere.setFromPoints(this.vertices)},merge:function(a,b,c){if(a&&a.isGeometry){var d,e=this.vertices.length,f=this.vertices,g=a.vertices,h=this.faces,k=a.faces,l=this.faceVertexUvs[0],q=a.faceVertexUvs[0],p=this.colors,m=a.colors;void 0===c&&(c=0);void 0!==b&&(d=(new qa).getNormalMatrix(b));a=0;for(var r=g.length;a<
r;a++){var n=g[a].clone();void 0!==b&&n.applyMatrix4(b);f.push(n)}a=0;for(r=m.length;a<r;a++)p.push(m[a].clone());a=0;for(r=k.length;a<r;a++){var g=k[a],u=g.vertexNormals,m=g.vertexColors,p=new Qa(g.a+e,g.b+e,g.c+e);p.normal.copy(g.normal);void 0!==d&&p.normal.applyMatrix3(d).normalize();b=0;for(f=u.length;b<f;b++)n=u[b].clone(),void 0!==d&&n.applyMatrix3(d).normalize(),p.vertexNormals.push(n);p.color.copy(g.color);b=0;for(f=m.length;b<f;b++)n=m[b],p.vertexColors.push(n.clone());p.materialIndex=g.materialIndex+
c;h.push(p)}a=0;for(r=q.length;a<r;a++)if(c=q[a],d=[],void 0!==c){b=0;for(f=c.length;b<f;b++)d.push(c[b].clone());l.push(d)}}else console.error("THREE.Geometry.merge(): geometry not an instance of THREE.Geometry.",a)},mergeMesh:function(a){a&&a.isMesh?(a.matrixAutoUpdate&&a.updateMatrix(),this.merge(a.geometry,a.matrix)):console.error("THREE.Geometry.mergeMesh(): mesh not an instance of THREE.Mesh.",a)},mergeVertices:function(){var a={},b=[],c=[],d=Math.pow(10,4),e;var f=0;for(e=this.vertices.length;f<
e;f++){var g=this.vertices[f];g=Math.round(g.x*d)+"_"+Math.round(g.y*d)+"_"+Math.round(g.z*d);void 0===a[g]?(a[g]=f,b.push(this.vertices[f]),c[f]=b.length-1):c[f]=c[a[g]]}a=[];f=0;for(e=this.faces.length;f<e;f++)for(d=this.faces[f],d.a=c[d.a],d.b=c[d.b],d.c=c[d.c],d=[d.a,d.b,d.c],g=0;3>g;g++)if(d[g]===d[(g+1)%3]){a.push(f);break}for(f=a.length-1;0<=f;f--)for(d=a[f],this.faces.splice(d,1),c=0,e=this.faceVertexUvs.length;c<e;c++)this.faceVertexUvs[c].splice(d,1);f=this.vertices.length-b.length;this.vertices=
b;return f},sortFacesByMaterialIndex:function(){for(var a=this.faces,b=a.length,c=0;c<b;c++)a[c]._id=c;a.sort(function(a,b){return a.materialIndex-b.materialIndex});var d=this.faceVertexUvs[0],e=this.faceVertexUvs[1],f,g;d&&d.length===b&&(f=[]);e&&e.length===b&&(g=[]);for(c=0;c<b;c++){var h=a[c]._id;f&&f.push(d[h]);g&&g.push(e[h])}f&&(this.faceVertexUvs[0]=f);g&&(this.faceVertexUvs[1]=g)},toJSON:function(){function a(a,b,c){return c?a|1<<b:a&~(1<<b)}function b(a){var b=a.x.toString()+a.y.toString()+
a.z.toString();if(void 0!==l[b])return l[b];l[b]=k.length/3;k.push(a.x,a.y,a.z);return l[b]}function c(a){var b=a.r.toString()+a.g.toString()+a.b.toString();if(void 0!==p[b])return p[b];p[b]=q.length;q.push(a.getHex());return p[b]}function d(a){var b=a.x.toString()+a.y.toString();if(void 0!==r[b])return r[b];r[b]=m.length/2;m.push(a.x,a.y);return r[b]}var e={metadata:{version:4.5,type:"Geometry",generator:"Geometry.toJSON"}};e.uuid=this.uuid;e.type=this.type;""!==this.name&&(e.name=this.name);if(void 0!==
this.parameters){var f=this.parameters,g;for(g in f)void 0!==f[g]&&(e[g]=f[g]);return e}f=[];for(g=0;g<this.vertices.length;g++){var h=this.vertices[g];f.push(h.x,h.y,h.z)}var h=[],k=[],l={},q=[],p={},m=[],r={};for(g=0;g<this.faces.length;g++){var n=this.faces[g],u=void 0!==this.faceVertexUvs[0][g],x=0<n.normal.length(),y=0<n.vertexNormals.length,A=1!==n.color.r||1!==n.color.g||1!==n.color.b,I=0<n.vertexColors.length,B=0,B=a(B,0,0),B=a(B,1,!0),B=a(B,2,!1),B=a(B,3,u),B=a(B,4,x),B=a(B,5,y),B=a(B,6,
A),B=a(B,7,I);h.push(B);h.push(n.a,n.b,n.c);h.push(n.materialIndex);u&&(u=this.faceVertexUvs[0][g],h.push(d(u[0]),d(u[1]),d(u[2])));x&&h.push(b(n.normal));y&&(x=n.vertexNormals,h.push(b(x[0]),b(x[1]),b(x[2])));A&&h.push(c(n.color));I&&(n=n.vertexColors,h.push(c(n[0]),c(n[1]),c(n[2])))}e.data={};e.data.vertices=f;e.data.normals=k;0<q.length&&(e.data.colors=q);0<m.length&&(e.data.uvs=[m]);e.data.faces=h;return e},clone:function(){return(new Q).copy(this)},copy:function(a){var b,c,d;this.vertices=[];
this.colors=[];this.faces=[];this.faceVertexUvs=[[]];this.morphTargets=[];this.morphNormals=[];this.skinWeights=[];this.skinIndices=[];this.lineDistances=[];this.boundingSphere=this.boundingBox=null;this.name=a.name;var e=a.vertices;var f=0;for(b=e.length;f<b;f++)this.vertices.push(e[f].clone());e=a.colors;f=0;for(b=e.length;f<b;f++)this.colors.push(e[f].clone());e=a.faces;f=0;for(b=e.length;f<b;f++)this.faces.push(e[f].clone());f=0;for(b=a.faceVertexUvs.length;f<b;f++){var g=a.faceVertexUvs[f];void 0===
this.faceVertexUvs[f]&&(this.faceVertexUvs[f]=[]);e=0;for(c=g.length;e<c;e++){var h=g[e],k=[];var l=0;for(d=h.length;l<d;l++)k.push(h[l].clone());this.faceVertexUvs[f].push(k)}}l=a.morphTargets;f=0;for(b=l.length;f<b;f++){d={};d.name=l[f].name;if(void 0!==l[f].vertices)for(d.vertices=[],e=0,c=l[f].vertices.length;e<c;e++)d.vertices.push(l[f].vertices[e].clone());if(void 0!==l[f].normals)for(d.normals=[],e=0,c=l[f].normals.length;e<c;e++)d.normals.push(l[f].normals[e].clone());this.morphTargets.push(d)}l=
a.morphNormals;f=0;for(b=l.length;f<b;f++){d={};if(void 0!==l[f].vertexNormals)for(d.vertexNormals=[],e=0,c=l[f].vertexNormals.length;e<c;e++)g=l[f].vertexNormals[e],h={},h.a=g.a.clone(),h.b=g.b.clone(),h.c=g.c.clone(),d.vertexNormals.push(h);if(void 0!==l[f].faceNormals)for(d.faceNormals=[],e=0,c=l[f].faceNormals.length;e<c;e++)d.faceNormals.push(l[f].faceNormals[e].clone());this.morphNormals.push(d)}e=a.skinWeights;f=0;for(b=e.length;f<b;f++)this.skinWeights.push(e[f].clone());e=a.skinIndices;f=
0;for(b=e.length;f<b;f++)this.skinIndices.push(e[f].clone());e=a.lineDistances;f=0;for(b=e.length;f<b;f++)this.lineDistances.push(e[f]);f=a.boundingBox;null!==f&&(this.boundingBox=f.clone());f=a.boundingSphere;null!==f&&(this.boundingSphere=f.clone());this.elementsNeedUpdate=a.elementsNeedUpdate;this.verticesNeedUpdate=a.verticesNeedUpdate;this.uvsNeedUpdate=a.uvsNeedUpdate;this.normalsNeedUpdate=a.normalsNeedUpdate;this.colorsNeedUpdate=a.colorsNeedUpdate;this.lineDistancesNeedUpdate=a.lineDistancesNeedUpdate;
this.groupsNeedUpdate=a.groupsNeedUpdate;return this},dispose:function(){this.dispatchEvent({type:"dispose"})}});Object.defineProperty(K.prototype,"needsUpdate",{set:function(a){!0===a&&this.version++}});Object.assign(K.prototype,{isBufferAttribute:!0,setArray:function(a){if(Array.isArray(a))throw new TypeError("THREE.BufferAttribute: array should be a Typed Array.");this.count=void 0!==a?a.length/this.itemSize:0;this.array=a},setDynamic:function(a){this.dynamic=a;return this},copy:function(a){this.array=
new a.array.constructor(a.array);this.itemSize=a.itemSize;this.count=a.count;this.normalized=a.normalized;this.dynamic=a.dynamic;return this},copyAt:function(a,b,c){a*=this.itemSize;c*=b.itemSize;for(var d=0,e=this.itemSize;d<e;d++)this.array[a+d]=b.array[c+d];return this},copyArray:function(a){this.array.set(a);return this},copyColorsArray:function(a){for(var b=this.array,c=0,d=0,e=a.length;d<e;d++){var f=a[d];void 0===f&&(console.warn("THREE.BufferAttribute.copyColorsArray(): color is undefined",
d),f=new C);b[c++]=f.r;b[c++]=f.g;b[c++]=f.b}return this},copyIndicesArray:function(a){for(var b=this.array,c=0,d=0,e=a.length;d<e;d++){var f=a[d];b[c++]=f.a;b[c++]=f.b;b[c++]=f.c}return this},copyVector2sArray:function(a){for(var b=this.array,c=0,d=0,e=a.length;d<e;d++){var f=a[d];void 0===f&&(console.warn("THREE.BufferAttribute.copyVector2sArray(): vector is undefined",d),f=new D);b[c++]=f.x;b[c++]=f.y}return this},copyVector3sArray:function(a){for(var b=this.array,c=0,d=0,e=a.length;d<e;d++){var f=
a[d];void 0===f&&(console.warn("THREE.BufferAttribute.copyVector3sArray(): vector is undefined",d),f=new n);b[c++]=f.x;b[c++]=f.y;b[c++]=f.z}return this},copyVector4sArray:function(a){for(var b=this.array,c=0,d=0,e=a.length;d<e;d++){var f=a[d];void 0===f&&(console.warn("THREE.BufferAttribute.copyVector4sArray(): vector is undefined",d),f=new S);b[c++]=f.x;b[c++]=f.y;b[c++]=f.z;b[c++]=f.w}return this},set:function(a,b){void 0===b&&(b=0);this.array.set(a,b);return this},getX:function(a){return this.array[a*
this.itemSize]},setX:function(a,b){this.array[a*this.itemSize]=b;return this},getY:function(a){return this.array[a*this.itemSize+1]},setY:function(a,b){this.array[a*this.itemSize+1]=b;return this},getZ:function(a){return this.array[a*this.itemSize+2]},setZ:function(a,b){this.array[a*this.itemSize+2]=b;return this},getW:function(a){return this.array[a*this.itemSize+3]},setW:function(a,b){this.array[a*this.itemSize+3]=b;return this},setXY:function(a,b,c){a*=this.itemSize;this.array[a+0]=b;this.array[a+
1]=c;return this},setXYZ:function(a,b,c,d){a*=this.itemSize;this.array[a+0]=b;this.array[a+1]=c;this.array[a+2]=d;return this},setXYZW:function(a,b,c,d,e){a*=this.itemSize;this.array[a+0]=b;this.array[a+1]=c;this.array[a+2]=d;this.array[a+3]=e;return this},onUpload:function(a){this.onUploadCallback=a;return this},clone:function(){return(new this.constructor(this.array,this.itemSize)).copy(this)}});pc.prototype=Object.create(K.prototype);pc.prototype.constructor=pc;qc.prototype=Object.create(K.prototype);
qc.prototype.constructor=qc;rc.prototype=Object.create(K.prototype);rc.prototype.constructor=rc;sc.prototype=Object.create(K.prototype);sc.prototype.constructor=sc;db.prototype=Object.create(K.prototype);db.prototype.constructor=db;tc.prototype=Object.create(K.prototype);tc.prototype.constructor=tc;eb.prototype=Object.create(K.prototype);eb.prototype.constructor=eb;z.prototype=Object.create(K.prototype);z.prototype.constructor=z;uc.prototype=Object.create(K.prototype);uc.prototype.constructor=uc;
Object.assign(Le.prototype,{computeGroups:function(a){var b=[],c=void 0;a=a.faces;for(var d=0;d<a.length;d++){var e=a[d];if(e.materialIndex!==c){c=e.materialIndex;void 0!==f&&(f.count=3*d-f.start,b.push(f));var f={start:3*d,materialIndex:c}}}void 0!==f&&(f.count=3*d-f.start,b.push(f));this.groups=b},fromGeometry:function(a){var b=a.faces,c=a.vertices,d=a.faceVertexUvs,e=d[0]&&0<d[0].length,f=d[1]&&0<d[1].length,g=a.morphTargets,h=g.length;if(0<h){var k=[];for(var l=0;l<h;l++)k[l]=[];this.morphTargets.position=
k}var q=a.morphNormals,p=q.length;if(0<p){var m=[];for(l=0;l<p;l++)m[l]=[];this.morphTargets.normal=m}for(var n=a.skinIndices,v=a.skinWeights,u=n.length===c.length,x=v.length===c.length,l=0;l<b.length;l++){var y=b[l];this.vertices.push(c[y.a],c[y.b],c[y.c]);var A=y.vertexNormals;3===A.length?this.normals.push(A[0],A[1],A[2]):(A=y.normal,this.normals.push(A,A,A));A=y.vertexColors;3===A.length?this.colors.push(A[0],A[1],A[2]):(A=y.color,this.colors.push(A,A,A));!0===e&&(A=d[0][l],void 0!==A?this.uvs.push(A[0],
A[1],A[2]):(console.warn("THREE.DirectGeometry.fromGeometry(): Undefined vertexUv ",l),this.uvs.push(new D,new D,new D)));!0===f&&(A=d[1][l],void 0!==A?this.uvs2.push(A[0],A[1],A[2]):(console.warn("THREE.DirectGeometry.fromGeometry(): Undefined vertexUv2 ",l),this.uvs2.push(new D,new D,new D)));for(A=0;A<h;A++){var I=g[A].vertices;k[A].push(I[y.a],I[y.b],I[y.c])}for(A=0;A<p;A++)I=q[A].vertexNormals[l],m[A].push(I.a,I.b,I.c);u&&this.skinIndices.push(n[y.a],n[y.b],n[y.c]);x&&this.skinWeights.push(v[y.a],
v[y.b],v[y.c])}this.computeGroups(a);this.verticesNeedUpdate=a.verticesNeedUpdate;this.normalsNeedUpdate=a.normalsNeedUpdate;this.colorsNeedUpdate=a.colorsNeedUpdate;this.uvsNeedUpdate=a.uvsNeedUpdate;this.groupsNeedUpdate=a.groupsNeedUpdate;return this}});F.MaxIndex=65535;Object.assign(F.prototype,na.prototype,{isBufferGeometry:!0,getIndex:function(){return this.index},setIndex:function(a){Array.isArray(a)?this.index=new (65535<Sd(a)?eb:db)(a,1):this.index=a},addAttribute:function(a,b,c){if(b&&b.isBufferAttribute||
b&&b.isInterleavedBufferAttribute)if("index"===a)console.warn("THREE.BufferGeometry.addAttribute: Use .setIndex() for index attribute."),this.setIndex(b);else return this.attributes[a]=b,this;else console.warn("THREE.BufferGeometry: .addAttribute() now expects ( name, attribute )."),this.addAttribute(a,new K(b,c))},getAttribute:function(a){return this.attributes[a]},removeAttribute:function(a){delete this.attributes[a];return this},addGroup:function(a,b,c){this.groups.push({start:a,count:b,materialIndex:void 0!==
c?c:0})},clearGroups:function(){this.groups=[]},setDrawRange:function(a,b){this.drawRange.start=a;this.drawRange.count=b},applyMatrix:function(a){var b=this.attributes.position;void 0!==b&&(a.applyToBufferAttribute(b),b.needsUpdate=!0);b=this.attributes.normal;void 0!==b&&((new qa).getNormalMatrix(a).applyToBufferAttribute(b),b.needsUpdate=!0);null!==this.boundingBox&&this.computeBoundingBox();null!==this.boundingSphere&&this.computeBoundingSphere();return this},rotateX:function(){var a=new O;return function(b){a.makeRotationX(b);
this.applyMatrix(a);return this}}(),rotateY:function(){var a=new O;return function(b){a.makeRotationY(b);this.applyMatrix(a);return this}}(),rotateZ:function(){var a=new O;return function(b){a.makeRotationZ(b);this.applyMatrix(a);return this}}(),translate:function(){var a=new O;return function(b,c,d){a.makeTranslation(b,c,d);this.applyMatrix(a);return this}}(),scale:function(){var a=new O;return function(b,c,d){a.makeScale(b,c,d);this.applyMatrix(a);return this}}(),lookAt:function(){var a=new w;return function(b){a.lookAt(b);
a.updateMatrix();this.applyMatrix(a.matrix)}}(),center:function(){this.computeBoundingBox();var a=this.boundingBox.getCenter().negate();this.translate(a.x,a.y,a.z);return a},setFromObject:function(a){var b=a.geometry;if(a.isPoints||a.isLine){a=new z(3*b.vertices.length,3);var c=new z(3*b.colors.length,3);this.addAttribute("position",a.copyVector3sArray(b.vertices));this.addAttribute("color",c.copyColorsArray(b.colors));b.lineDistances&&b.lineDistances.length===b.vertices.length&&(a=new z(b.lineDistances.length,
1),this.addAttribute("lineDistance",a.copyArray(b.lineDistances)));null!==b.boundingSphere&&(this.boundingSphere=b.boundingSphere.clone());null!==b.boundingBox&&(this.boundingBox=b.boundingBox.clone())}else a.isMesh&&b&&b.isGeometry&&this.fromGeometry(b);return this},updateFromObject:function(a){var b=a.geometry;if(a.isMesh){var c=b.__directGeometry;!0===b.elementsNeedUpdate&&(c=void 0,b.elementsNeedUpdate=!1);if(void 0===c)return this.fromGeometry(b);c.verticesNeedUpdate=b.verticesNeedUpdate;c.normalsNeedUpdate=
b.normalsNeedUpdate;c.colorsNeedUpdate=b.colorsNeedUpdate;c.uvsNeedUpdate=b.uvsNeedUpdate;c.groupsNeedUpdate=b.groupsNeedUpdate;b.verticesNeedUpdate=!1;b.normalsNeedUpdate=!1;b.colorsNeedUpdate=!1;b.uvsNeedUpdate=!1;b.groupsNeedUpdate=!1;b=c}!0===b.verticesNeedUpdate&&(c=this.attributes.position,void 0!==c&&(c.copyVector3sArray(b.vertices),c.needsUpdate=!0),b.verticesNeedUpdate=!1);!0===b.normalsNeedUpdate&&(c=this.attributes.normal,void 0!==c&&(c.copyVector3sArray(b.normals),c.needsUpdate=!0),b.normalsNeedUpdate=
!1);!0===b.colorsNeedUpdate&&(c=this.attributes.color,void 0!==c&&(c.copyColorsArray(b.colors),c.needsUpdate=!0),b.colorsNeedUpdate=!1);b.uvsNeedUpdate&&(c=this.attributes.uv,void 0!==c&&(c.copyVector2sArray(b.uvs),c.needsUpdate=!0),b.uvsNeedUpdate=!1);b.lineDistancesNeedUpdate&&(c=this.attributes.lineDistance,void 0!==c&&(c.copyArray(b.lineDistances),c.needsUpdate=!0),b.lineDistancesNeedUpdate=!1);b.groupsNeedUpdate&&(b.computeGroups(a.geometry),this.groups=b.groups,b.groupsNeedUpdate=!1);return this},
fromGeometry:function(a){a.__directGeometry=(new Le).fromGeometry(a);return this.fromDirectGeometry(a.__directGeometry)},fromDirectGeometry:function(a){var b=new Float32Array(3*a.vertices.length);this.addAttribute("position",(new K(b,3)).copyVector3sArray(a.vertices));0<a.normals.length&&(b=new Float32Array(3*a.normals.length),this.addAttribute("normal",(new K(b,3)).copyVector3sArray(a.normals)));0<a.colors.length&&(b=new Float32Array(3*a.colors.length),this.addAttribute("color",(new K(b,3)).copyColorsArray(a.colors)));
0<a.uvs.length&&(b=new Float32Array(2*a.uvs.length),this.addAttribute("uv",(new K(b,2)).copyVector2sArray(a.uvs)));0<a.uvs2.length&&(b=new Float32Array(2*a.uvs2.length),this.addAttribute("uv2",(new K(b,2)).copyVector2sArray(a.uvs2)));0<a.indices.length&&(b=new (65535<Sd(a.indices)?Uint32Array:Uint16Array)(3*a.indices.length),this.setIndex((new K(b,1)).copyIndicesArray(a.indices)));this.groups=a.groups;for(var c in a.morphTargets){for(var b=[],d=a.morphTargets[c],e=0,f=d.length;e<f;e++){var g=d[e],
h=new z(3*g.length,3);b.push(h.copyVector3sArray(g))}this.morphAttributes[c]=b}0<a.skinIndices.length&&(c=new z(4*a.skinIndices.length,4),this.addAttribute("skinIndex",c.copyVector4sArray(a.skinIndices)));0<a.skinWeights.length&&(c=new z(4*a.skinWeights.length,4),this.addAttribute("skinWeight",c.copyVector4sArray(a.skinWeights)));null!==a.boundingSphere&&(this.boundingSphere=a.boundingSphere.clone());null!==a.boundingBox&&(this.boundingBox=a.boundingBox.clone());return this},computeBoundingBox:function(){null===
this.boundingBox&&(this.boundingBox=new Pa);var a=this.attributes.position;void 0!==a?this.boundingBox.setFromBufferAttribute(a):this.boundingBox.makeEmpty();(isNaN(this.boundingBox.min.x)||isNaN(this.boundingBox.min.y)||isNaN(this.boundingBox.min.z))&&console.error('THREE.BufferGeometry.computeBoundingBox: Computed min/max have NaN values. The "position" attribute is likely to have NaN values.',this)},computeBoundingSphere:function(){var a=new Pa,b=new n;return function(){null===this.boundingSphere&&
(this.boundingSphere=new Ca);var c=this.attributes.position;if(c){var d=this.boundingSphere.center;a.setFromBufferAttribute(c);a.getCenter(d);for(var e=0,f=0,g=c.count;f<g;f++)b.x=c.getX(f),b.y=c.getY(f),b.z=c.getZ(f),e=Math.max(e,d.distanceToSquared(b));this.boundingSphere.radius=Math.sqrt(e);isNaN(this.boundingSphere.radius)&&console.error('THREE.BufferGeometry.computeBoundingSphere(): Computed radius is NaN. The "position" attribute is likely to have NaN values.',this)}}}(),computeFaceNormals:function(){},
computeVertexNormals:function(){var a=this.index,b=this.attributes,c=this.groups;if(b.position){var d=b.position.array;if(void 0===b.normal)this.addAttribute("normal",new K(new Float32Array(d.length),3));else for(var e=b.normal.array,f=0,g=e.length;f<g;f++)e[f]=0;var e=b.normal.array,h=new n,k=new n,l=new n,q=new n,p=new n;if(a){a=a.array;0===c.length&&this.addGroup(0,a.length);for(var m=0,r=c.length;m<r;++m){f=c[m];g=f.start;var v=f.count;f=g;for(g+=v;f<g;f+=3){v=3*a[f+0];var u=3*a[f+1];var x=3*
a[f+2];h.fromArray(d,v);k.fromArray(d,u);l.fromArray(d,x);q.subVectors(l,k);p.subVectors(h,k);q.cross(p);e[v]+=q.x;e[v+1]+=q.y;e[v+2]+=q.z;e[u]+=q.x;e[u+1]+=q.y;e[u+2]+=q.z;e[x]+=q.x;e[x+1]+=q.y;e[x+2]+=q.z}}}else for(f=0,g=d.length;f<g;f+=9)h.fromArray(d,f),k.fromArray(d,f+3),l.fromArray(d,f+6),q.subVectors(l,k),p.subVectors(h,k),q.cross(p),e[f]=q.x,e[f+1]=q.y,e[f+2]=q.z,e[f+3]=q.x,e[f+4]=q.y,e[f+5]=q.z,e[f+6]=q.x,e[f+7]=q.y,e[f+8]=q.z;this.normalizeNormals();b.normal.needsUpdate=!0}},merge:function(a,
b){if(a&&a.isBufferGeometry){void 0===b&&(b=0);var c=this.attributes,d;for(d in c)if(void 0!==a.attributes[d])for(var e=c[d].array,f=a.attributes[d],g=f.array,h=0,f=f.itemSize*b;h<g.length;h++,f++)e[f]=g[h];return this}console.error("THREE.BufferGeometry.merge(): geometry not an instance of THREE.BufferGeometry.",a)},normalizeNormals:function(){var a=new n;return function(){for(var b=this.attributes.normal,c=0,d=b.count;c<d;c++)a.x=b.getX(c),a.y=b.getY(c),a.z=b.getZ(c),a.normalize(),b.setXYZ(c,a.x,
a.y,a.z)}}(),toNonIndexed:function(){if(null===this.index)return console.warn("THREE.BufferGeometry.toNonIndexed(): Geometry is already non-indexed."),this;var a=new F,b=this.index.array,c=this.attributes,d;for(d in c){for(var e=c[d],f=e.array,e=e.itemSize,g=new f.constructor(b.length*e),h,k=0,l=0,q=b.length;l<q;l++){h=b[l]*e;for(var m=0;m<e;m++)g[k++]=f[h++]}a.addAttribute(d,new K(g,e))}return a},toJSON:function(){var a={metadata:{version:4.5,type:"BufferGeometry",generator:"BufferGeometry.toJSON"}};
a.uuid=this.uuid;a.type=this.type;""!==this.name&&(a.name=this.name);if(void 0!==this.parameters){var b=this.parameters;for(var c in b)void 0!==b[c]&&(a[c]=b[c]);return a}a.data={attributes:{}};var d=this.index;null!==d&&(b=Array.prototype.slice.call(d.array),a.data.index={type:d.array.constructor.name,array:b});d=this.attributes;for(c in d){var e=d[c];b=Array.prototype.slice.call(e.array);a.data.attributes[c]={itemSize:e.itemSize,type:e.array.constructor.name,array:b,normalized:e.normalized}}c=this.groups;
0<c.length&&(a.data.groups=JSON.parse(JSON.stringify(c)));c=this.boundingSphere;null!==c&&(a.data.boundingSphere={center:c.center.toArray(),radius:c.radius});return a},clone:function(){return(new F).copy(this)},copy:function(a){var b;this.index=null;this.attributes={};this.morphAttributes={};this.groups=[];this.boundingSphere=this.boundingBox=null;this.name=a.name;var c=a.index;null!==c&&this.setIndex(c.clone());c=a.attributes;for(g in c)this.addAttribute(g,c[g].clone());var d=a.morphAttributes;for(g in d){var e=
[],f=d[g];c=0;for(b=f.length;c<b;c++)e.push(f[c].clone());this.morphAttributes[g]=e}var g=a.groups;c=0;for(b=g.length;c<b;c++)d=g[c],this.addGroup(d.start,d.count,d.materialIndex);g=a.boundingBox;null!==g&&(this.boundingBox=g.clone());g=a.boundingSphere;null!==g&&(this.boundingSphere=g.clone());this.drawRange.start=a.drawRange.start;this.drawRange.count=a.drawRange.count;return this},dispose:function(){this.dispatchEvent({type:"dispose"})}});Eb.prototype=Object.create(Q.prototype);Eb.prototype.constructor=
Eb;fb.prototype=Object.create(F.prototype);fb.prototype.constructor=fb;vc.prototype=Object.create(Q.prototype);vc.prototype.constructor=vc;gb.prototype=Object.create(F.prototype);gb.prototype.constructor=gb;sa.prototype=Object.create(P.prototype);sa.prototype.constructor=sa;sa.prototype.isMeshBasicMaterial=!0;sa.prototype.copy=function(a){P.prototype.copy.call(this,a);this.color.copy(a.color);this.map=a.map;this.lightMap=a.lightMap;this.lightMapIntensity=a.lightMapIntensity;this.aoMap=a.aoMap;this.aoMapIntensity=
a.aoMapIntensity;this.specularMap=a.specularMap;this.alphaMap=a.alphaMap;this.envMap=a.envMap;this.combine=a.combine;this.reflectivity=a.reflectivity;this.refractionRatio=a.refractionRatio;this.wireframe=a.wireframe;this.wireframeLinewidth=a.wireframeLinewidth;this.wireframeLinecap=a.wireframeLinecap;this.wireframeLinejoin=a.wireframeLinejoin;this.skinning=a.skinning;this.morphTargets=a.morphTargets;return this};Object.assign(hb.prototype,{set:function(a,b){this.origin.copy(a);this.direction.copy(b);
return this},clone:function(){return(new this.constructor).copy(this)},copy:function(a){this.origin.copy(a.origin);this.direction.copy(a.direction);return this},at:function(a,b){return(b||new n).copy(this.direction).multiplyScalar(a).add(this.origin)},lookAt:function(a){this.direction.copy(a).sub(this.origin).normalize();return this},recast:function(){var a=new n;return function(b){this.origin.copy(this.at(b,a));return this}}(),closestPointToPoint:function(a,b){b=b||new n;b.subVectors(a,this.origin);
a=b.dot(this.direction);return 0>a?b.copy(this.origin):b.copy(this.direction).multiplyScalar(a).add(this.origin)},distanceToPoint:function(a){return Math.sqrt(this.distanceSqToPoint(a))},distanceSqToPoint:function(){var a=new n;return function(b){var c=a.subVectors(b,this.origin).dot(this.direction);if(0>c)return this.origin.distanceToSquared(b);a.copy(this.direction).multiplyScalar(c).add(this.origin);return a.distanceToSquared(b)}}(),distanceSqToSegment:function(){var a=new n,b=new n,c=new n;return function(d,
e,f,g){a.copy(d).add(e).multiplyScalar(.5);b.copy(e).sub(d).normalize();c.copy(this.origin).sub(a);var h=.5*d.distanceTo(e),k=-this.direction.dot(b),l=c.dot(this.direction),q=-c.dot(b),m=c.lengthSq(),t=Math.abs(1-k*k);if(0<t){d=k*q-l;e=k*l-q;var n=h*t;0<=d?e>=-n?e<=n?(h=1/t,d*=h,e*=h,k=d*(d+k*e+2*l)+e*(k*d+e+2*q)+m):(e=h,d=Math.max(0,-(k*e+l)),k=-d*d+e*(e+2*q)+m):(e=-h,d=Math.max(0,-(k*e+l)),k=-d*d+e*(e+2*q)+m):e<=-n?(d=Math.max(0,-(-k*h+l)),e=0<d?-h:Math.min(Math.max(-h,-q),h),k=-d*d+e*(e+2*q)+m):
e<=n?(d=0,e=Math.min(Math.max(-h,-q),h),k=e*(e+2*q)+m):(d=Math.max(0,-(k*h+l)),e=0<d?h:Math.min(Math.max(-h,-q),h),k=-d*d+e*(e+2*q)+m)}else e=0<k?-h:h,d=Math.max(0,-(k*e+l)),k=-d*d+e*(e+2*q)+m;f&&f.copy(this.direction).multiplyScalar(d).add(this.origin);g&&g.copy(b).multiplyScalar(e).add(a);return k}}(),intersectSphere:function(){var a=new n;return function(b,c){a.subVectors(b.center,this.origin);var d=a.dot(this.direction),e=a.dot(a)-d*d;b=b.radius*b.radius;if(e>b)return null;b=Math.sqrt(b-e);e=
d-b;d+=b;return 0>e&&0>d?null:0>e?this.at(d,c):this.at(e,c)}}(),intersectsSphere:function(a){return this.distanceToPoint(a.center)<=a.radius},distanceToPlane:function(a){var b=a.normal.dot(this.direction);if(0===b)return 0===a.distanceToPoint(this.origin)?0:null;a=-(this.origin.dot(a.normal)+a.constant)/b;return 0<=a?a:null},intersectPlane:function(a,b){a=this.distanceToPlane(a);return null===a?null:this.at(a,b)},intersectsPlane:function(a){var b=a.distanceToPoint(this.origin);return 0===b||0>a.normal.dot(this.direction)*
b?!0:!1},intersectBox:function(a,b){var c=1/this.direction.x;var d=1/this.direction.y;var e=1/this.direction.z,f=this.origin;if(0<=c){var g=(a.min.x-f.x)*c;c*=a.max.x-f.x}else g=(a.max.x-f.x)*c,c*=a.min.x-f.x;if(0<=d){var h=(a.min.y-f.y)*d;d*=a.max.y-f.y}else h=(a.max.y-f.y)*d,d*=a.min.y-f.y;if(g>d||h>c)return null;if(h>g||g!==g)g=h;if(d<c||c!==c)c=d;0<=e?(h=(a.min.z-f.z)*e,a=(a.max.z-f.z)*e):(h=(a.max.z-f.z)*e,a=(a.min.z-f.z)*e);if(g>a||h>c)return null;if(h>g||g!==g)g=h;if(a<c||c!==c)c=a;return 0>
c?null:this.at(0<=g?g:c,b)},intersectsBox:function(){var a=new n;return function(b){return null!==this.intersectBox(b,a)}}(),intersectTriangle:function(){var a=new n,b=new n,c=new n,d=new n;return function(e,f,g,h,k){b.subVectors(f,e);c.subVectors(g,e);d.crossVectors(b,c);f=this.direction.dot(d);if(0<f){if(h)return null;h=1}else if(0>f)h=-1,f=-f;else return null;a.subVectors(this.origin,e);e=h*this.direction.dot(c.crossVectors(a,c));if(0>e)return null;g=h*this.direction.dot(b.cross(a));if(0>g||e+
g>f)return null;e=-h*a.dot(d);return 0>e?null:this.at(e/f,k)}}(),applyMatrix4:function(a){this.origin.applyMatrix4(a);this.direction.transformDirection(a);return this},equals:function(a){return a.origin.equals(this.origin)&&a.direction.equals(this.direction)}});Object.assign(Fb.prototype,{set:function(a,b){this.start.copy(a);this.end.copy(b);return this},clone:function(){return(new this.constructor).copy(this)},copy:function(a){this.start.copy(a.start);this.end.copy(a.end);return this},getCenter:function(a){return(a||
new n).addVectors(this.start,this.end).multiplyScalar(.5)},delta:function(a){return(a||new n).subVectors(this.end,this.start)},distanceSq:function(){return this.start.distanceToSquared(this.end)},distance:function(){return this.start.distanceTo(this.end)},at:function(a,b){b=b||new n;return this.delta(b).multiplyScalar(a).add(this.start)},closestPointToPointParameter:function(){var a=new n,b=new n;return function(c,d){a.subVectors(c,this.start);b.subVectors(this.end,this.start);c=b.dot(b);c=b.dot(a)/
c;d&&(c=R.clamp(c,0,1));return c}}(),closestPointToPoint:function(a,b,c){a=this.closestPointToPointParameter(a,b);c=c||new n;return this.delta(c).multiplyScalar(a).add(this.start)},applyMatrix4:function(a){this.start.applyMatrix4(a);this.end.applyMatrix4(a);return this},equals:function(a){return a.start.equals(this.start)&&a.end.equals(this.end)}});Object.assign(Ra,{normal:function(){var a=new n;return function(b,c,d,e){e=e||new n;e.subVectors(d,c);a.subVectors(b,c);e.cross(a);b=e.lengthSq();return 0<
b?e.multiplyScalar(1/Math.sqrt(b)):e.set(0,0,0)}}(),barycoordFromPoint:function(){var a=new n,b=new n,c=new n;return function(d,e,f,g,h){a.subVectors(g,e);b.subVectors(f,e);c.subVectors(d,e);d=a.dot(a);e=a.dot(b);f=a.dot(c);var k=b.dot(b);g=b.dot(c);var l=d*k-e*e;h=h||new n;if(0===l)return h.set(-2,-1,-1);l=1/l;k=(k*f-e*g)*l;d=(d*g-e*f)*l;return h.set(1-k-d,d,k)}}(),containsPoint:function(){var a=new n;return function(b,c,d,e){b=Ra.barycoordFromPoint(b,c,d,e,a);return 0<=b.x&&0<=b.y&&1>=b.x+b.y}}()});
Object.assign(Ra.prototype,{set:function(a,b,c){this.a.copy(a);this.b.copy(b);this.c.copy(c);return this},setFromPointsAndIndices:function(a,b,c,d){this.a.copy(a[b]);this.b.copy(a[c]);this.c.copy(a[d]);return this},clone:function(){return(new this.constructor).copy(this)},copy:function(a){this.a.copy(a.a);this.b.copy(a.b);this.c.copy(a.c);return this},area:function(){var a=new n,b=new n;return function(){a.subVectors(this.c,this.b);b.subVectors(this.a,this.b);return.5*a.cross(b).length()}}(),midpoint:function(a){return(a||
new n).addVectors(this.a,this.b).add(this.c).multiplyScalar(1/3)},normal:function(a){return Ra.normal(this.a,this.b,this.c,a)},plane:function(a){return(a||new za).setFromCoplanarPoints(this.a,this.b,this.c)},barycoordFromPoint:function(a,b){return Ra.barycoordFromPoint(a,this.a,this.b,this.c,b)},containsPoint:function(a){return Ra.containsPoint(a,this.a,this.b,this.c)},closestPointToPoint:function(){var a=new za,b=[new Fb,new Fb,new Fb],c=new n,d=new n;return function(e,f){f=f||new n;var g=Infinity;
a.setFromCoplanarPoints(this.a,this.b,this.c);a.projectPoint(e,c);if(!0===this.containsPoint(c))f.copy(c);else for(b[0].set(this.a,this.b),b[1].set(this.b,this.c),b[2].set(this.c,this.a),e=0;e<b.length;e++){b[e].closestPointToPoint(c,!0,d);var h=c.distanceToSquared(d);h<g&&(g=h,f.copy(d))}return f}}(),equals:function(a){return a.a.equals(this.a)&&a.b.equals(this.b)&&a.c.equals(this.c)}});fa.prototype=Object.assign(Object.create(w.prototype),{constructor:fa,isMesh:!0,setDrawMode:function(a){this.drawMode=
a},copy:function(a){w.prototype.copy.call(this,a);this.drawMode=a.drawMode;return this},updateMorphTargets:function(){var a=this.geometry;if(a.isBufferGeometry){a=a.morphAttributes;var b=Object.keys(a);if(0<b.length){var c=a[b[0]];if(void 0!==c)for(this.morphTargetInfluences=[],this.morphTargetDictionary={},a=0,b=c.length;a<b;a++){var d=c[a].name||String(a);this.morphTargetInfluences.push(0);this.morphTargetDictionary[d]=a}}}else if(c=a.morphTargets,void 0!==c&&0<c.length)for(this.morphTargetInfluences=
[],this.morphTargetDictionary={},a=0,b=c.length;a<b;a++)d=c[a].name||String(a),this.morphTargetInfluences.push(0),this.morphTargetDictionary[d]=a},raycast:function(){function a(a,b,c,d,e,f,g){Ra.barycoordFromPoint(a,b,c,d,u);e.multiplyScalar(u.x);f.multiplyScalar(u.y);g.multiplyScalar(u.z);e.add(f).add(g);return e.clone()}function b(a,b,c,d,e,f,g,h){if(null===(1===b.side?d.intersectTriangle(g,f,e,!0,h):d.intersectTriangle(e,f,g,2!==b.side,h)))return null;y.copy(h);y.applyMatrix4(a.matrixWorld);b=
c.ray.origin.distanceTo(y);return b<c.near||b>c.far?null:{distance:b,point:y.clone(),object:a}}function c(c,d,e,f,l,q,m,p){g.fromBufferAttribute(f,q);h.fromBufferAttribute(f,m);k.fromBufferAttribute(f,p);if(c=b(c,c.material,d,e,g,h,k,x))l&&(t.fromBufferAttribute(l,q),r.fromBufferAttribute(l,m),v.fromBufferAttribute(l,p),c.uv=a(x,g,h,k,t,r,v)),c.face=new Qa(q,m,p,Ra.normal(g,h,k)),c.faceIndex=q;return c}var d=new O,e=new hb,f=new Ca,g=new n,h=new n,k=new n,l=new n,q=new n,m=new n,t=new D,r=new D,v=
new D,u=new n,x=new n,y=new n;return function(p,n){var u=this.geometry,y=this.material,A=this.matrixWorld;if(void 0!==y&&(null===u.boundingSphere&&u.computeBoundingSphere(),f.copy(u.boundingSphere),f.applyMatrix4(A),!1!==p.ray.intersectsSphere(f)&&(d.getInverse(A),e.copy(p.ray).applyMatrix4(d),null===u.boundingBox||!1!==e.intersectsBox(u.boundingBox)))){var w;if(u.isBufferGeometry){var y=u.index,I=u.attributes.position,A=u.attributes.uv,z;if(null!==y){var D=0;for(z=y.count;D<z;D+=3){u=y.getX(D);var C=
y.getX(D+1);var J=y.getX(D+2);if(w=c(this,p,e,I,A,u,C,J))w.faceIndex=Math.floor(D/3),n.push(w)}}else for(D=0,z=I.count;D<z;D+=3)if(u=D,C=D+1,J=D+2,w=c(this,p,e,I,A,u,C,J))w.index=u,n.push(w)}else if(u.isGeometry){var A=Array.isArray(y);D=u.vertices;z=u.faces;C=u.faceVertexUvs[0];0<C.length&&(I=C);for(var F=0,L=z.length;F<L;F++){var M=z[F];w=A?y[M.materialIndex]:y;if(void 0!==w){C=D[M.a];J=D[M.b];var T=D[M.c];if(!0===w.morphTargets){var K=u.morphTargets,Q=this.morphTargetInfluences;g.set(0,0,0);h.set(0,
0,0);k.set(0,0,0);for(var O=0,P=K.length;O<P;O++){var R=Q[O];if(0!==R){var N=K[O].vertices;g.addScaledVector(l.subVectors(N[M.a],C),R);h.addScaledVector(q.subVectors(N[M.b],J),R);k.addScaledVector(m.subVectors(N[M.c],T),R)}}g.add(C);h.add(J);k.add(T);C=g;J=h;T=k}if(w=b(this,w,p,e,C,J,T,x))I&&I[F]&&(K=I[F],t.copy(K[0]),r.copy(K[1]),v.copy(K[2]),w.uv=a(x,C,J,T,t,r,v)),w.face=M,w.faceIndex=F,n.push(w)}}}}}}(),clone:function(){return(new this.constructor(this.geometry,this.material)).copy(this)}});var hg=
0;md.prototype=Object.assign(Object.create(ja.prototype),{constructor:md,isArrayCamera:!0});Hb.prototype.isFogExp2=!0;Hb.prototype.clone=function(){return new Hb(this.color.getHex(),this.density)};Hb.prototype.toJSON=function(a){return{type:"FogExp2",color:this.color.getHex(),density:this.density}};Ib.prototype.isFog=!0;Ib.prototype.clone=function(){return new Ib(this.color.getHex(),this.near,this.far)};Ib.prototype.toJSON=function(a){return{type:"Fog",color:this.color.getHex(),near:this.near,far:this.far}};
nd.prototype=Object.assign(Object.create(w.prototype),{constructor:nd,copy:function(a,b){w.prototype.copy.call(this,a,b);null!==a.background&&(this.background=a.background.clone());null!==a.fog&&(this.fog=a.fog.clone());null!==a.overrideMaterial&&(this.overrideMaterial=a.overrideMaterial.clone());this.autoUpdate=a.autoUpdate;this.matrixAutoUpdate=a.matrixAutoUpdate;return this},toJSON:function(a){var b=w.prototype.toJSON.call(this,a);null!==this.background&&(b.object.background=this.background.toJSON(a));
null!==this.fog&&(b.object.fog=this.fog.toJSON());return b}});Zd.prototype=Object.assign(Object.create(w.prototype),{constructor:Zd,isLensFlare:!0,copy:function(a){w.prototype.copy.call(this,a);this.positionScreen.copy(a.positionScreen);this.customUpdateCallback=a.customUpdateCallback;for(var b=0,c=a.lensFlares.length;b<c;b++)this.lensFlares.push(a.lensFlares[b]);return this},add:function(a,b,c,d,e,f){void 0===b&&(b=-1);void 0===c&&(c=0);void 0===f&&(f=1);void 0===e&&(e=new C(16777215));void 0===
d&&(d=1);c=Math.min(c,Math.max(0,c));this.lensFlares.push({texture:a,size:b,distance:c,x:0,y:0,z:0,scale:1,rotation:0,opacity:f,color:e,blending:d})},updateLensFlares:function(){var a,b=this.lensFlares.length,c=2*-this.positionScreen.x,d=2*-this.positionScreen.y;for(a=0;a<b;a++){var e=this.lensFlares[a];e.x=this.positionScreen.x+c*e.distance;e.y=this.positionScreen.y+d*e.distance;e.wantedRotation=e.x*Math.PI*.25;e.rotation+=.25*(e.wantedRotation-e.rotation)}}});Za.prototype=Object.create(P.prototype);
Za.prototype.constructor=Za;Za.prototype.isSpriteMaterial=!0;Za.prototype.copy=function(a){P.prototype.copy.call(this,a);this.color.copy(a.color);this.map=a.map;this.rotation=a.rotation;return this};xc.prototype=Object.assign(Object.create(w.prototype),{constructor:xc,isSprite:!0,raycast:function(){var a=new n,b=new n,c=new n;return function(d,e){b.setFromMatrixPosition(this.matrixWorld);d.ray.closestPointToPoint(b,a);c.setFromMatrixScale(this.matrixWorld);var f=c.x*c.y/4;b.distanceToSquared(a)>f||
(f=d.ray.origin.distanceTo(a),f<d.near||f>d.far||e.push({distance:f,point:a.clone(),face:null,object:this}))}}(),clone:function(){return(new this.constructor(this.material)).copy(this)}});yc.prototype=Object.assign(Object.create(w.prototype),{constructor:yc,copy:function(a){w.prototype.copy.call(this,a,!1);a=a.levels;for(var b=0,c=a.length;b<c;b++){var d=a[b];this.addLevel(d.object.clone(),d.distance)}return this},addLevel:function(a,b){void 0===b&&(b=0);b=Math.abs(b);for(var c=this.levels,d=0;d<
c.length&&!(b<c[d].distance);d++);c.splice(d,0,{distance:b,object:a});this.add(a)},getObjectForDistance:function(a){for(var b=this.levels,c=1,d=b.length;c<d&&!(a<b[c].distance);c++);return b[c-1].object},raycast:function(){var a=new n;return function(b,c){a.setFromMatrixPosition(this.matrixWorld);var d=b.ray.origin.distanceTo(a);this.getObjectForDistance(d).raycast(b,c)}}(),update:function(){var a=new n,b=new n;return function(c){var d=this.levels;if(1<d.length){a.setFromMatrixPosition(c.matrixWorld);
b.setFromMatrixPosition(this.matrixWorld);c=a.distanceTo(b);d[0].object.visible=!0;for(var e=1,f=d.length;e<f;e++)if(c>=d[e].distance)d[e-1].object.visible=!1,d[e].object.visible=!0;else break;for(;e<f;e++)d[e].object.visible=!1}}}(),toJSON:function(a){a=w.prototype.toJSON.call(this,a);a.object.levels=[];for(var b=this.levels,c=0,d=b.length;c<d;c++){var e=b[c];a.object.levels.push({object:e.object.uuid,distance:e.distance})}return a}});Object.assign(zc.prototype,{calculateInverses:function(){this.boneInverses=
[];for(var a=0,b=this.bones.length;a<b;a++){var c=new O;this.bones[a]&&c.getInverse(this.bones[a].matrixWorld);this.boneInverses.push(c)}},pose:function(){var a,b;var c=0;for(b=this.bones.length;c<b;c++)(a=this.bones[c])&&a.matrixWorld.getInverse(this.boneInverses[c]);c=0;for(b=this.bones.length;c<b;c++)if(a=this.bones[c])a.parent&&a.parent.isBone?(a.matrix.getInverse(a.parent.matrixWorld),a.matrix.multiply(a.matrixWorld)):a.matrix.copy(a.matrixWorld),a.matrix.decompose(a.position,a.quaternion,a.scale)},
update:function(){var a=new O,b=new O;return function(){for(var c=this.bones,d=this.boneInverses,e=this.boneMatrices,f=this.boneTexture,g=0,h=c.length;g<h;g++)a.multiplyMatrices(c[g]?c[g].matrixWorld:b,d[g]),a.toArray(e,16*g);void 0!==f&&(f.needsUpdate=!0)}}(),clone:function(){return new zc(this.bones,this.boneInverses)}});od.prototype=Object.assign(Object.create(w.prototype),{constructor:od,isBone:!0});pd.prototype=Object.assign(Object.create(fa.prototype),{constructor:pd,isSkinnedMesh:!0,initBones:function(){var a=
[],b;if(this.geometry&&void 0!==this.geometry.bones){var c=0;for(b=this.geometry.bones.length;c<b;c++){var d=this.geometry.bones[c];var e=new od;a.push(e);e.name=d.name;e.position.fromArray(d.pos);e.quaternion.fromArray(d.rotq);void 0!==d.scl&&e.scale.fromArray(d.scl)}c=0;for(b=this.geometry.bones.length;c<b;c++)d=this.geometry.bones[c],-1!==d.parent&&null!==d.parent&&void 0!==a[d.parent]?a[d.parent].add(a[c]):this.add(a[c])}this.updateMatrixWorld(!0);return a},bind:function(a,b){this.skeleton=a;
void 0===b&&(this.updateMatrixWorld(!0),this.skeleton.calculateInverses(),b=this.matrixWorld);this.bindMatrix.copy(b);this.bindMatrixInverse.getInverse(b)},pose:function(){this.skeleton.pose()},normalizeSkinWeights:function(){var a;if(this.geometry&&this.geometry.isGeometry)for(a=0;a<this.geometry.skinWeights.length;a++){var b=this.geometry.skinWeights[a];var c=1/b.lengthManhattan();Infinity!==c?b.multiplyScalar(c):b.set(1,0,0,0)}else if(this.geometry&&this.geometry.isBufferGeometry){var b=new S,
d=this.geometry.attributes.skinWeight;for(a=0;a<d.count;a++)b.x=d.getX(a),b.y=d.getY(a),b.z=d.getZ(a),b.w=d.getW(a),c=1/b.lengthManhattan(),Infinity!==c?b.multiplyScalar(c):b.set(1,0,0,0),d.setXYZW(a,b.x,b.y,b.z,b.w)}},updateMatrixWorld:function(a){fa.prototype.updateMatrixWorld.call(this,a);"attached"===this.bindMode?this.bindMatrixInverse.getInverse(this.matrixWorld):"detached"===this.bindMode?this.bindMatrixInverse.getInverse(this.bindMatrix):console.warn("THREE.SkinnedMesh: Unrecognized bindMode: "+
this.bindMode)},clone:function(){return(new this.constructor(this.geometry,this.material)).copy(this)}});W.prototype=Object.create(P.prototype);W.prototype.constructor=W;W.prototype.isLineBasicMaterial=!0;W.prototype.copy=function(a){P.prototype.copy.call(this,a);this.color.copy(a.color);this.linewidth=a.linewidth;this.linecap=a.linecap;this.linejoin=a.linejoin;return this};ra.prototype=Object.assign(Object.create(w.prototype),{constructor:ra,isLine:!0,raycast:function(){var a=new O,b=new hb,c=new Ca;
return function(d,e){var f=d.linePrecision,f=f*f,g=this.geometry,h=this.matrixWorld;null===g.boundingSphere&&g.computeBoundingSphere();c.copy(g.boundingSphere);c.applyMatrix4(h);if(!1!==d.ray.intersectsSphere(c)){a.getInverse(h);b.copy(d.ray).applyMatrix4(a);var k=new n,l=new n,h=new n,q=new n,m=this&&this.isLineSegments?2:1;if(g.isBufferGeometry){var t=g.index;var r=g.attributes.position.array;if(null!==t)for(var v=t.array,g=0,u=v.length-1;g<u;g+=m)t=v[g+1],k.fromArray(r,3*v[g]),l.fromArray(r,3*
t),t=b.distanceSqToSegment(k,l,q,h),t>f||(q.applyMatrix4(this.matrixWorld),t=d.ray.origin.distanceTo(q),t<d.near||t>d.far||e.push({distance:t,point:h.clone().applyMatrix4(this.matrixWorld),index:g,face:null,faceIndex:null,object:this}));else for(g=0,u=r.length/3-1;g<u;g+=m)k.fromArray(r,3*g),l.fromArray(r,3*g+3),t=b.distanceSqToSegment(k,l,q,h),t>f||(q.applyMatrix4(this.matrixWorld),t=d.ray.origin.distanceTo(q),t<d.near||t>d.far||e.push({distance:t,point:h.clone().applyMatrix4(this.matrixWorld),index:g,
face:null,faceIndex:null,object:this}))}else if(g.isGeometry)for(k=g.vertices,l=k.length,g=0;g<l-1;g+=m)t=b.distanceSqToSegment(k[g],k[g+1],q,h),t>f||(q.applyMatrix4(this.matrixWorld),t=d.ray.origin.distanceTo(q),t<d.near||t>d.far||e.push({distance:t,point:h.clone().applyMatrix4(this.matrixWorld),index:g,face:null,faceIndex:null,object:this}))}}}(),clone:function(){return(new this.constructor(this.geometry,this.material)).copy(this)}});X.prototype=Object.assign(Object.create(ra.prototype),{constructor:X,
isLineSegments:!0});qd.prototype=Object.assign(Object.create(ra.prototype),{constructor:qd,isLineLoop:!0});ma.prototype=Object.create(P.prototype);ma.prototype.constructor=ma;ma.prototype.isPointsMaterial=!0;ma.prototype.copy=function(a){P.prototype.copy.call(this,a);this.color.copy(a.color);this.map=a.map;this.size=a.size;this.sizeAttenuation=a.sizeAttenuation;return this};Jb.prototype=Object.assign(Object.create(w.prototype),{constructor:Jb,isPoints:!0,raycast:function(){var a=new O,b=new hb,c=
new Ca;return function(d,e){function f(a,c){var f=b.distanceSqToPoint(a);if(f<q){a=b.closestPointToPoint(a);a.applyMatrix4(k);var h=d.ray.origin.distanceTo(a);h<d.near||h>d.far||e.push({distance:h,distanceToRay:Math.sqrt(f),point:a.clone(),index:c,face:null,object:g})}}var g=this,h=this.geometry,k=this.matrixWorld,l=d.params.Points.threshold;null===h.boundingSphere&&h.computeBoundingSphere();c.copy(h.boundingSphere);c.applyMatrix4(k);c.radius+=l;if(!1!==d.ray.intersectsSphere(c)){a.getInverse(k);
b.copy(d.ray).applyMatrix4(a);var l=l/((this.scale.x+this.scale.y+this.scale.z)/3),q=l*l,l=new n;if(h.isBufferGeometry){var m=h.index,h=h.attributes.position.array;if(null!==m)for(var t=m.array,m=0,r=t.length;m<r;m++){var v=t[m];l.fromArray(h,3*v);f(l,v)}else for(m=0,t=h.length/3;m<t;m++)l.fromArray(h,3*m),f(l,m)}else for(l=h.vertices,m=0,t=l.length;m<t;m++)f(l[m],m)}}}(),clone:function(){return(new this.constructor(this.geometry,this.material)).copy(this)}});Ac.prototype=Object.assign(Object.create(w.prototype),
{constructor:Ac});rd.prototype=Object.create(N.prototype);rd.prototype.constructor=rd;Kb.prototype=Object.create(N.prototype);Kb.prototype.constructor=Kb;Kb.prototype.isCompressedTexture=!0;Bc.prototype=Object.create(N.prototype);Bc.prototype.constructor=Bc;Bc.prototype.isDepthTexture=!0;Lb.prototype=Object.create(F.prototype);Lb.prototype.constructor=Lb;Cc.prototype=Object.create(Q.prototype);Cc.prototype.constructor=Cc;Mb.prototype=Object.create(F.prototype);Mb.prototype.constructor=Mb;Dc.prototype=
Object.create(Q.prototype);Dc.prototype.constructor=Dc;ua.prototype=Object.create(F.prototype);ua.prototype.constructor=ua;Ec.prototype=Object.create(Q.prototype);Ec.prototype.constructor=Ec;Nb.prototype=Object.create(ua.prototype);Nb.prototype.constructor=Nb;Fc.prototype=Object.create(Q.prototype);Fc.prototype.constructor=Fc;jb.prototype=Object.create(ua.prototype);jb.prototype.constructor=jb;Gc.prototype=Object.create(Q.prototype);Gc.prototype.constructor=Gc;Ob.prototype=Object.create(ua.prototype);
Ob.prototype.constructor=Ob;Hc.prototype=Object.create(Q.prototype);Hc.prototype.constructor=Hc;Pb.prototype=Object.create(ua.prototype);Pb.prototype.constructor=Pb;Ic.prototype=Object.create(Q.prototype);Ic.prototype.constructor=Ic;Qb.prototype=Object.create(F.prototype);Qb.prototype.constructor=Qb;Jc.prototype=Object.create(Q.prototype);Jc.prototype.constructor=Jc;Rb.prototype=Object.create(F.prototype);Rb.prototype.constructor=Rb;Kc.prototype=Object.create(Q.prototype);Kc.prototype.constructor=
Kc;Sb.prototype=Object.create(F.prototype);Sb.prototype.constructor=Sb;var Fa={area:function(a){for(var b=a.length,c=0,d=b-1,e=0;e<b;d=e++)c+=a[d].x*a[e].y-a[e].x*a[d].y;return.5*c},triangulate:function(){return function(a,b){var c=a.length;if(3>c)return null;var d=[],e=[],f=[],g;if(0<Fa.area(a))for(g=0;g<c;g++)e[g]=g;else for(g=0;g<c;g++)e[g]=c-1-g;var h=2*c;for(g=c-1;2<c;){if(0>=h--){console.warn("THREE.ShapeUtils: Unable to triangulate polygon! in triangulate()");break}var k=g;c<=k&&(k=0);g=k+
1;c<=g&&(g=0);var l=g+1;c<=l&&(l=0);a:{var m;var p=a[e[k]].x;var t=a[e[k]].y;var n=a[e[g]].x;var v=a[e[g]].y;var u=a[e[l]].x;var x=a[e[l]].y;if(0>=(n-p)*(x-t)-(v-t)*(u-p))var y=!1;else{var A=u-n;var w=x-v;var B=p-u;var z=t-x;var D=n-p;y=v-t;for(m=0;m<c;m++){var C=a[e[m]].x;var F=a[e[m]].y;if(!(C===p&&F===t||C===n&&F===v||C===u&&F===x)){var K=C-p;var L=F-t;var O=C-n;var J=F-v;C-=u;F-=x;J=A*J-w*O;L=D*L-y*K;C=B*F-z*C;if(J>=-Number.EPSILON&&C>=-Number.EPSILON&&L>=-Number.EPSILON){y=!1;break a}}}y=!0}}if(y){d.push([a[e[k]],
a[e[g]],a[e[l]]]);f.push([e[k],e[g],e[l]]);k=g;for(l=g+1;l<c;k++,l++)e[k]=e[l];c--;h=2*c}}return b?f:d}}(),triangulateShape:function(a,b){function c(a){var b=a.length;2<b&&a[b-1].equals(a[0])&&a.pop()}function d(a,b,c){return a.x!==b.x?a.x<b.x?a.x<=c.x&&c.x<=b.x:b.x<=c.x&&c.x<=a.x:a.y<b.y?a.y<=c.y&&c.y<=b.y:b.y<=c.y&&c.y<=a.y}function e(a,b,c,e,f){var g=b.x-a.x,h=b.y-a.y,k=e.x-c.x,l=e.y-c.y,m=a.x-c.x,q=a.y-c.y,p=h*k-g*l,n=h*m-g*q;if(Math.abs(p)>Number.EPSILON){if(0<p){if(0>n||n>p)return[];k=l*m-k*
q;if(0>k||k>p)return[]}else{if(0<n||n<p)return[];k=l*m-k*q;if(0<k||k<p)return[]}if(0===k)return!f||0!==n&&n!==p?[a]:[];if(k===p)return!f||0!==n&&n!==p?[b]:[];if(0===n)return[c];if(n===p)return[e];f=k/p;return[{x:a.x+f*g,y:a.y+f*h}]}if(0!==n||l*m!==k*q)return[];h=0===g&&0===h;k=0===k&&0===l;if(h&&k)return a.x!==c.x||a.y!==c.y?[]:[a];if(h)return d(c,e,a)?[a]:[];if(k)return d(a,b,c)?[c]:[];0!==g?(a.x<b.x?(g=a,k=a.x,h=b,a=b.x):(g=b,k=b.x,h=a,a=a.x),c.x<e.x?(b=c,p=c.x,l=e,c=e.x):(b=e,p=e.x,l=c,c=c.x)):
(a.y<b.y?(g=a,k=a.y,h=b,a=b.y):(g=b,k=b.y,h=a,a=a.y),c.y<e.y?(b=c,p=c.y,l=e,c=e.y):(b=e,p=e.y,l=c,c=c.y));return k<=p?a<p?[]:a===p?f?[]:[b]:a<=c?[b,h]:[b,l]:k>c?[]:k===c?f?[]:[g]:a<=c?[g,h]:[g,l]}function f(a,b,c,d){var e=b.x-a.x,f=b.y-a.y;b=c.x-a.x;c=c.y-a.y;var g=d.x-a.x;d=d.y-a.y;a=e*c-f*b;e=e*d-f*g;return Math.abs(a)>Number.EPSILON?(b=g*c-d*b,0<a?0<=e&&0<=b:0<=e||0<=b):0<e}c(a);b.forEach(c);var g,h={},k=a.concat();var l=0;for(g=b.length;l<g;l++)Array.prototype.push.apply(k,b[l]);l=0;for(g=k.length;l<
g;l++){var m=k[l].x+":"+k[l].y;void 0!==h[m]&&console.warn("THREE.ShapeUtils: Duplicate point",m,l);h[m]=l}l=function(a,b){function c(a,b){var c=h.length-1,d=a-1;0>d&&(d=c);var e=a+1;e>c&&(e=0);c=f(h[a],h[d],h[e],D[b]);if(!c)return!1;c=D.length-1;d=b-1;0>d&&(d=c);e=b+1;e>c&&(e=0);return(c=f(D[b],D[d],D[e],h[a]))?!0:!1}function d(a,b){var c;for(c=0;c<h.length;c++){var d=c+1;d%=h.length;d=e(a,b,h[c],h[d],!0);if(0<d.length)return!0}return!1}function g(a,c){var d,f;for(d=0;d<k.length;d++){var g=b[k[d]];
for(f=0;f<g.length;f++){var h=f+1;h%=g.length;h=e(a,c,g[f],g[h],!0);if(0<h.length)return!0}}return!1}var h=a.concat(),k=[],l,m;a=[];var q,p=0;for(l=b.length;p<l;p++)k.push(p);var n=0;for(var t=2*k.length;0<k.length;){t--;if(0>t){console.log('THREE.ShapeUtils: Infinite Loop! Holes left:" + indepHoles.length + ", Probably Hole outside Shape!');break}for(m=n;m<h.length;m++){var w=h[m];l=-1;for(p=0;p<k.length;p++){var z=k[p];var C=w.x+":"+w.y+":"+z;if(void 0===a[C]){var D=b[z];for(q=0;q<D.length;q++)if(z=
D[q],c(m,q)&&!d(w,z)&&!g(w,z)){l=q;k.splice(p,1);n=h.slice(0,m+1);z=h.slice(m);q=D.slice(l);var F=D.slice(0,l+1);h=n.concat(q).concat(F).concat(z);n=m;break}if(0<=l)break;a[C]=!0}}if(0<=l)break}}return h}(a,b);k=Fa.triangulate(l,!1);l=0;for(g=k.length;l<g;l++)for(b=k[l],a=0;3>a;a++)m=b[a].x+":"+b[a].y,m=h[m],void 0!==m&&(b[a]=m);return k.concat()},isClockWise:function(a){return 0>Fa.area(a)}};$a.prototype=Object.create(Q.prototype);$a.prototype.constructor=$a;Ea.prototype=Object.create(F.prototype);
Ea.prototype.constructor=Ea;Ea.prototype.getArrays=function(){var a=this.getAttribute("position"),a=a?Array.prototype.slice.call(a.array):[],b=this.getAttribute("uv"),b=b?Array.prototype.slice.call(b.array):[],c=this.index,c=c?Array.prototype.slice.call(c.array):[];return{position:a,uv:b,index:c}};Ea.prototype.addShapeList=function(a,b){var c=a.length;b.arrays=this.getArrays();for(var d=0;d<c;d++)this.addShape(a[d],b);this.setIndex(b.arrays.index);this.addAttribute("position",new z(b.arrays.position,
3));this.addAttribute("uv",new z(b.arrays.uv,2))};Ea.prototype.addShape=function(a,b){function c(a,b,c){b||console.error("THREE.ExtrudeGeometry: vec does not exist");return b.clone().multiplyScalar(c).add(a)}function d(a,b,c){var d=a.x-b.x;var e=a.y-b.y;var f=c.x-a.x;var g=c.y-a.y,h=d*d+e*e;if(Math.abs(d*g-e*f)>Number.EPSILON){var k=Math.sqrt(h),l=Math.sqrt(f*f+g*g),h=b.x-e/k;b=b.y+d/k;g=((c.x-g/l-h)*g-(c.y+f/l-b)*f)/(d*g-e*f);f=h+d*g-a.x;d=b+e*g-a.y;e=f*f+d*d;if(2>=e)return new D(f,d);e=Math.sqrt(e/
2)}else a=!1,d>Number.EPSILON?f>Number.EPSILON&&(a=!0):d<-Number.EPSILON?f<-Number.EPSILON&&(a=!0):Math.sign(e)===Math.sign(g)&&(a=!0),a?(f=-e,e=Math.sqrt(h)):(f=d,d=e,e=Math.sqrt(h/2));return new D(f/e,d/e)}function e(a,b){for(G=a.length;0<=--G;){var c=G;var d=G-1;0>d&&(d=a.length-1);var e,f=w+2*x;for(e=0;e<f;e++){var g=X*e,l=X*(e+1),q=b+d+g,p=b+d+l,l=b+c+l;h(b+c+g);h(q);h(l);h(q);h(p);h(l);g=m.length/3;g=F.generateSideWallUV(R,m,g-6,g-3,g-2,g-1);k(g[0]);k(g[1]);k(g[3]);k(g[1]);k(g[2]);k(g[3])}}}
function f(a,b,c){r.push(a);r.push(b);r.push(c)}function g(a,b,c){h(a);h(b);h(c);a=m.length/3;a=F.generateTopUV(R,m,a-3,a-2,a-1);k(a[0]);k(a[1]);k(a[2])}function h(a){p.push(m.length/3);m.push(r[3*a+0]);m.push(r[3*a+1]);m.push(r[3*a+2])}function k(a){t.push(a.x);t.push(a.y)}var l=b.arrays?b.arrays:this.getArrays(),m=l.position,p=l.index,t=l.uv,r=[],l=void 0!==b.amount?b.amount:100,v=void 0!==b.bevelThickness?b.bevelThickness:6,u=void 0!==b.bevelSize?b.bevelSize:v-2,x=void 0!==b.bevelSegments?b.bevelSegments:
3,y=void 0!==b.bevelEnabled?b.bevelEnabled:!0,A=void 0!==b.curveSegments?b.curveSegments:12,w=void 0!==b.steps?b.steps:1,B=b.extrudePath,C=!1,F=void 0!==b.UVGenerator?b.UVGenerator:$a.WorldUVGenerator;if(B){var K=B.getSpacedPoints(w);C=!0;y=!1;var L=void 0!==b.frames?b.frames:B.computeFrenetFrames(w,!1);var O=new n;var Q=new n;var P=new n}y||(u=v=x=0);var J,R=this,A=a.extractPoints(A);a=A.shape;var N=A.holes;if(!Fa.isClockWise(a)){a=a.reverse();var M=0;for(J=N.length;M<J;M++){var T=N[M];Fa.isClockWise(T)&&
(N[M]=T.reverse())}}var V=Fa.triangulateShape(a,N),W=a;M=0;for(J=N.length;M<J;M++)T=N[M],a=a.concat(T);var Y,X=a.length,S,da=V.length,A=[],G=0;var U=W.length;var ca=U-1;for(Y=G+1;G<U;G++,ca++,Y++)ca===U&&(ca=0),Y===U&&(Y=0),A[G]=d(W[G],W[ca],W[Y]);var B=[],ea=A.concat();M=0;for(J=N.length;M<J;M++){T=N[M];var aa=[];G=0;U=T.length;ca=U-1;for(Y=G+1;G<U;G++,ca++,Y++)ca===U&&(ca=0),Y===U&&(Y=0),aa[G]=d(T[G],T[ca],T[Y]);B.push(aa);ea=ea.concat(aa)}for(ca=0;ca<x;ca++){U=ca/x;var fa=v*Math.cos(U*Math.PI/
2);Y=u*Math.sin(U*Math.PI/2);G=0;for(U=W.length;G<U;G++){var ha=c(W[G],A[G],Y);f(ha.x,ha.y,-fa)}M=0;for(J=N.length;M<J;M++)for(T=N[M],aa=B[M],G=0,U=T.length;G<U;G++)ha=c(T[G],aa[G],Y),f(ha.x,ha.y,-fa)}Y=u;for(G=0;G<X;G++)ha=y?c(a[G],ea[G],Y):a[G],C?(Q.copy(L.normals[0]).multiplyScalar(ha.x),O.copy(L.binormals[0]).multiplyScalar(ha.y),P.copy(K[0]).add(Q).add(O),f(P.x,P.y,P.z)):f(ha.x,ha.y,0);for(U=1;U<=w;U++)for(G=0;G<X;G++)ha=y?c(a[G],ea[G],Y):a[G],C?(Q.copy(L.normals[U]).multiplyScalar(ha.x),O.copy(L.binormals[U]).multiplyScalar(ha.y),
P.copy(K[U]).add(Q).add(O),f(P.x,P.y,P.z)):f(ha.x,ha.y,l/w*U);for(ca=x-1;0<=ca;ca--){U=ca/x;fa=v*Math.cos(U*Math.PI/2);Y=u*Math.sin(U*Math.PI/2);G=0;for(U=W.length;G<U;G++)ha=c(W[G],A[G],Y),f(ha.x,ha.y,l+fa);M=0;for(J=N.length;M<J;M++)for(T=N[M],aa=B[M],G=0,U=T.length;G<U;G++)ha=c(T[G],aa[G],Y),C?f(ha.x,ha.y+K[w-1].y,K[w-1].x+fa):f(ha.x,ha.y,l+fa)}(function(){var a=m.length/3;if(y){var c=0*X;for(G=0;G<da;G++)S=V[G],g(S[2]+c,S[1]+c,S[0]+c);c=X*(w+2*x);for(G=0;G<da;G++)S=V[G],g(S[0]+c,S[1]+c,S[2]+c)}else{for(G=
0;G<da;G++)S=V[G],g(S[2],S[1],S[0]);for(G=0;G<da;G++)S=V[G],g(S[0]+X*w,S[1]+X*w,S[2]+X*w)}R.addGroup(a,m.length/3-a,void 0!==b.material?b.material:0)})();(function(){var a=m.length/3,c=0;e(W,c);c+=W.length;M=0;for(J=N.length;M<J;M++)T=N[M],e(T,c),c+=T.length;R.addGroup(a,m.length/3-a,void 0!==b.extrudeMaterial?b.extrudeMaterial:1)})();b.arrays||(this.setIndex(p),this.addAttribute("position",new z(m,3)),this.addAttribute("uv",new z(b.arrays.uv,2)))};$a.WorldUVGenerator={generateTopUV:function(a,b,
c,d,e){a=b[3*d];d=b[3*d+1];var f=b[3*e];e=b[3*e+1];return[new D(b[3*c],b[3*c+1]),new D(a,d),new D(f,e)]},generateSideWallUV:function(a,b,c,d,e,f){a=b[3*c];var g=b[3*c+1];c=b[3*c+2];var h=b[3*d],k=b[3*d+1];d=b[3*d+2];var l=b[3*e],m=b[3*e+1];e=b[3*e+2];var p=b[3*f],n=b[3*f+1];b=b[3*f+2];return.01>Math.abs(g-k)?[new D(a,1-c),new D(h,1-d),new D(l,1-e),new D(p,1-b)]:[new D(g,1-c),new D(k,1-d),new D(m,1-e),new D(n,1-b)]}};Lc.prototype=Object.create(Q.prototype);Lc.prototype.constructor=Lc;Tb.prototype=
Object.create(Ea.prototype);Tb.prototype.constructor=Tb;Mc.prototype=Object.create(Q.prototype);Mc.prototype.constructor=Mc;kb.prototype=Object.create(F.prototype);kb.prototype.constructor=kb;Nc.prototype=Object.create(Q.prototype);Nc.prototype.constructor=Nc;Ub.prototype=Object.create(F.prototype);Ub.prototype.constructor=Ub;Oc.prototype=Object.create(Q.prototype);Oc.prototype.constructor=Oc;Vb.prototype=Object.create(F.prototype);Vb.prototype.constructor=Vb;Wb.prototype=Object.create(Q.prototype);
Wb.prototype.constructor=Wb;Xb.prototype=Object.create(F.prototype);Xb.prototype.constructor=Xb;Yb.prototype=Object.create(F.prototype);Yb.prototype.constructor=Yb;lb.prototype=Object.create(Q.prototype);lb.prototype.constructor=lb;Ta.prototype=Object.create(F.prototype);Ta.prototype.constructor=Ta;Pc.prototype=Object.create(lb.prototype);Pc.prototype.constructor=Pc;Qc.prototype=Object.create(Ta.prototype);Qc.prototype.constructor=Qc;Rc.prototype=Object.create(Q.prototype);Rc.prototype.constructor=
Rc;Zb.prototype=Object.create(F.prototype);Zb.prototype.constructor=Zb;var Ka=Object.freeze({WireframeGeometry:Lb,ParametricGeometry:Cc,ParametricBufferGeometry:Mb,TetrahedronGeometry:Ec,TetrahedronBufferGeometry:Nb,OctahedronGeometry:Fc,OctahedronBufferGeometry:jb,IcosahedronGeometry:Gc,IcosahedronBufferGeometry:Ob,DodecahedronGeometry:Hc,DodecahedronBufferGeometry:Pb,PolyhedronGeometry:Dc,PolyhedronBufferGeometry:ua,TubeGeometry:Ic,TubeBufferGeometry:Qb,TorusKnotGeometry:Jc,TorusKnotBufferGeometry:Rb,
TorusGeometry:Kc,TorusBufferGeometry:Sb,TextGeometry:Lc,TextBufferGeometry:Tb,SphereGeometry:Mc,SphereBufferGeometry:kb,RingGeometry:Nc,RingBufferGeometry:Ub,PlaneGeometry:vc,PlaneBufferGeometry:gb,LatheGeometry:Oc,LatheBufferGeometry:Vb,ShapeGeometry:Wb,ShapeBufferGeometry:Xb,ExtrudeGeometry:$a,ExtrudeBufferGeometry:Ea,EdgesGeometry:Yb,ConeGeometry:Pc,ConeBufferGeometry:Qc,CylinderGeometry:lb,CylinderBufferGeometry:Ta,CircleGeometry:Rc,CircleBufferGeometry:Zb,BoxGeometry:Eb,BoxBufferGeometry:fb});
$b.prototype=Object.create(P.prototype);$b.prototype.constructor=$b;$b.prototype.isShadowMaterial=!0;ac.prototype=Object.create(ya.prototype);ac.prototype.constructor=ac;ac.prototype.isRawShaderMaterial=!0;Na.prototype=Object.create(P.prototype);Na.prototype.constructor=Na;Na.prototype.isMeshStandardMaterial=!0;Na.prototype.copy=function(a){P.prototype.copy.call(this,a);this.defines={STANDARD:""};this.color.copy(a.color);this.roughness=a.roughness;this.metalness=a.metalness;this.map=a.map;this.lightMap=
a.lightMap;this.lightMapIntensity=a.lightMapIntensity;this.aoMap=a.aoMap;this.aoMapIntensity=a.aoMapIntensity;this.emissive.copy(a.emissive);this.emissiveMap=a.emissiveMap;this.emissiveIntensity=a.emissiveIntensity;this.bumpMap=a.bumpMap;this.bumpScale=a.bumpScale;this.normalMap=a.normalMap;this.normalScale.copy(a.normalScale);this.displacementMap=a.displacementMap;this.displacementScale=a.displacementScale;this.displacementBias=a.displacementBias;this.roughnessMap=a.roughnessMap;this.metalnessMap=
a.metalnessMap;this.alphaMap=a.alphaMap;this.envMap=a.envMap;this.envMapIntensity=a.envMapIntensity;this.refractionRatio=a.refractionRatio;this.wireframe=a.wireframe;this.wireframeLinewidth=a.wireframeLinewidth;this.wireframeLinecap=a.wireframeLinecap;this.wireframeLinejoin=a.wireframeLinejoin;this.skinning=a.skinning;this.morphTargets=a.morphTargets;this.morphNormals=a.morphNormals;return this};mb.prototype=Object.create(Na.prototype);mb.prototype.constructor=mb;mb.prototype.isMeshPhysicalMaterial=
!0;mb.prototype.copy=function(a){Na.prototype.copy.call(this,a);this.defines={PHYSICAL:""};this.reflectivity=a.reflectivity;this.clearCoat=a.clearCoat;this.clearCoatRoughness=a.clearCoatRoughness;return this};Aa.prototype=Object.create(P.prototype);Aa.prototype.constructor=Aa;Aa.prototype.isMeshPhongMaterial=!0;Aa.prototype.copy=function(a){P.prototype.copy.call(this,a);this.color.copy(a.color);this.specular.copy(a.specular);this.shininess=a.shininess;this.map=a.map;this.lightMap=a.lightMap;this.lightMapIntensity=
a.lightMapIntensity;this.aoMap=a.aoMap;this.aoMapIntensity=a.aoMapIntensity;this.emissive.copy(a.emissive);this.emissiveMap=a.emissiveMap;this.emissiveIntensity=a.emissiveIntensity;this.bumpMap=a.bumpMap;this.bumpScale=a.bumpScale;this.normalMap=a.normalMap;this.normalScale.copy(a.normalScale);this.displacementMap=a.displacementMap;this.displacementScale=a.displacementScale;this.displacementBias=a.displacementBias;this.specularMap=a.specularMap;this.alphaMap=a.alphaMap;this.envMap=a.envMap;this.combine=
a.combine;this.reflectivity=a.reflectivity;this.refractionRatio=a.refractionRatio;this.wireframe=a.wireframe;this.wireframeLinewidth=a.wireframeLinewidth;this.wireframeLinecap=a.wireframeLinecap;this.wireframeLinejoin=a.wireframeLinejoin;this.skinning=a.skinning;this.morphTargets=a.morphTargets;this.morphNormals=a.morphNormals;return this};nb.prototype=Object.create(Aa.prototype);nb.prototype.constructor=nb;nb.prototype.isMeshToonMaterial=!0;nb.prototype.copy=function(a){Aa.prototype.copy.call(this,
a);this.gradientMap=a.gradientMap;return this};ob.prototype=Object.create(P.prototype);ob.prototype.constructor=ob;ob.prototype.isMeshNormalMaterial=!0;ob.prototype.copy=function(a){P.prototype.copy.call(this,a);this.bumpMap=a.bumpMap;this.bumpScale=a.bumpScale;this.normalMap=a.normalMap;this.normalScale.copy(a.normalScale);this.displacementMap=a.displacementMap;this.displacementScale=a.displacementScale;this.displacementBias=a.displacementBias;this.wireframe=a.wireframe;this.wireframeLinewidth=a.wireframeLinewidth;
this.skinning=a.skinning;this.morphTargets=a.morphTargets;this.morphNormals=a.morphNormals;return this};pb.prototype=Object.create(P.prototype);pb.prototype.constructor=pb;pb.prototype.isMeshLambertMaterial=!0;pb.prototype.copy=function(a){P.prototype.copy.call(this,a);this.color.copy(a.color);this.map=a.map;this.lightMap=a.lightMap;this.lightMapIntensity=a.lightMapIntensity;this.aoMap=a.aoMap;this.aoMapIntensity=a.aoMapIntensity;this.emissive.copy(a.emissive);this.emissiveMap=a.emissiveMap;this.emissiveIntensity=
a.emissiveIntensity;this.specularMap=a.specularMap;this.alphaMap=a.alphaMap;this.envMap=a.envMap;this.combine=a.combine;this.reflectivity=a.reflectivity;this.refractionRatio=a.refractionRatio;this.wireframe=a.wireframe;this.wireframeLinewidth=a.wireframeLinewidth;this.wireframeLinecap=a.wireframeLinecap;this.wireframeLinejoin=a.wireframeLinejoin;this.skinning=a.skinning;this.morphTargets=a.morphTargets;this.morphNormals=a.morphNormals;return this};qb.prototype=Object.create(W.prototype);qb.prototype.constructor=
qb;qb.prototype.isLineDashedMaterial=!0;qb.prototype.copy=function(a){W.prototype.copy.call(this,a);this.scale=a.scale;this.dashSize=a.dashSize;this.gapSize=a.gapSize;return this};var sg=Object.freeze({ShadowMaterial:$b,SpriteMaterial:Za,RawShaderMaterial:ac,ShaderMaterial:ya,PointsMaterial:ma,MeshPhysicalMaterial:mb,MeshStandardMaterial:Na,MeshPhongMaterial:Aa,MeshToonMaterial:nb,MeshNormalMaterial:ob,MeshLambertMaterial:pb,MeshDepthMaterial:Wa,MeshDistanceMaterial:Xa,MeshBasicMaterial:sa,LineDashedMaterial:qb,
LineBasicMaterial:W,Material:P}),hd={enabled:!1,files:{},add:function(a,b){!1!==this.enabled&&(this.files[a]=b)},get:function(a){if(!1!==this.enabled)return this.files[a]},remove:function(a){delete this.files[a]},clear:function(){this.files={}}},oa=new $d;Object.assign(Ia.prototype,{load:function(a,b,c,d){void 0===a&&(a="");void 0!==this.path&&(a=this.path+a);var e=this,f=hd.get(a);if(void 0!==f)return e.manager.itemStart(a),setTimeout(function(){b&&b(f);e.manager.itemEnd(a)},0),f;var g=a.match(/^data:(.*?)(;base64)?,(.*)$/);
if(g){var h=g[1],k=!!g[2],g=g[3],g=window.decodeURIComponent(g);k&&(g=window.atob(g));try{var l=(this.responseType||"").toLowerCase();switch(l){case "arraybuffer":case "blob":var m=new ArrayBuffer(g.length);for(var p=new Uint8Array(m),k=0;k<g.length;k++)p[k]=g.charCodeAt(k);"blob"===l&&(m=new Blob([m],{type:h}));break;case "document":m=(new DOMParser).parseFromString(g,h);break;case "json":m=JSON.parse(g);break;default:m=g}window.setTimeout(function(){b&&b(m);e.manager.itemEnd(a)},0)}catch(r){window.setTimeout(function(){d&&
d(r);e.manager.itemEnd(a);e.manager.itemError(a)},0)}}else{var n=new XMLHttpRequest;n.open("GET",a,!0);n.addEventListener("load",function(c){var f=c.target.response;hd.add(a,f);200===this.status?(b&&b(f),e.manager.itemEnd(a)):0===this.status?(console.warn("THREE.FileLoader: HTTP Status 0 received."),b&&b(f),e.manager.itemEnd(a)):(d&&d(c),e.manager.itemEnd(a),e.manager.itemError(a))},!1);void 0!==c&&n.addEventListener("progress",function(a){c(a)},!1);n.addEventListener("error",function(b){d&&d(b);
e.manager.itemEnd(a);e.manager.itemError(a)},!1);void 0!==this.responseType&&(n.responseType=this.responseType);void 0!==this.withCredentials&&(n.withCredentials=this.withCredentials);n.overrideMimeType&&n.overrideMimeType(void 0!==this.mimeType?this.mimeType:"text/plain");for(h in this.requestHeader)n.setRequestHeader(h,this.requestHeader[h]);n.send(null)}e.manager.itemStart(a);return n},setPath:function(a){this.path=a;return this},setResponseType:function(a){this.responseType=a;return this},setWithCredentials:function(a){this.withCredentials=
a;return this},setMimeType:function(a){this.mimeType=a;return this},setRequestHeader:function(a){this.requestHeader=a;return this}});Object.assign(Re.prototype,{load:function(a,b,c,d){function e(e){l.load(a[e],function(a){a=g._parser(a,!0);h[e]={width:a.width,height:a.height,format:a.format,mipmaps:a.mipmaps};f+=1;6===f&&(1===a.mipmapCount&&(k.minFilter=1006),k.format=a.format,k.needsUpdate=!0,b&&b(k))},c,d)}var f,g=this,h=[],k=new Kb;k.image=h;var l=new Ia(this.manager);l.setPath(this.path);l.setResponseType("arraybuffer");
if(Array.isArray(a))for(var m=f=0,p=a.length;m<p;++m)e(m);else l.load(a,function(a){a=g._parser(a,!0);if(a.isCubemap)for(var c=a.mipmaps.length/a.mipmapCount,d=0;d<c;d++){h[d]={mipmaps:[]};for(var e=0;e<a.mipmapCount;e++)h[d].mipmaps.push(a.mipmaps[d*a.mipmapCount+e]),h[d].format=a.format,h[d].width=a.width,h[d].height=a.height}else k.image.width=a.width,k.image.height=a.height,k.mipmaps=a.mipmaps;1===a.mipmapCount&&(k.minFilter=1006);k.format=a.format;k.needsUpdate=!0;b&&b(k)},c,d);return k},setPath:function(a){this.path=
a;return this}});Object.assign(ae.prototype,{load:function(a,b,c,d){var e=this,f=new bb,g=new Ia(this.manager);g.setResponseType("arraybuffer");g.load(a,function(a){if(a=e._parser(a))void 0!==a.image?f.image=a.image:void 0!==a.data&&(f.image.width=a.width,f.image.height=a.height,f.image.data=a.data),f.wrapS=void 0!==a.wrapS?a.wrapS:1001,f.wrapT=void 0!==a.wrapT?a.wrapT:1001,f.magFilter=void 0!==a.magFilter?a.magFilter:1006,f.minFilter=void 0!==a.minFilter?a.minFilter:1008,f.anisotropy=void 0!==a.anisotropy?
a.anisotropy:1,void 0!==a.format&&(f.format=a.format),void 0!==a.type&&(f.type=a.type),void 0!==a.mipmaps&&(f.mipmaps=a.mipmaps),1===a.mipmapCount&&(f.minFilter=1006),f.needsUpdate=!0,b&&b(f,a)},c,d);return f}});Object.assign(Sc.prototype,{crossOrigin:"Anonymous",load:function(a,b,c,d){void 0===a&&(a="");void 0!==this.path&&(a=this.path+a);var e=this,f=hd.get(a);if(void 0!==f)return e.manager.itemStart(a),setTimeout(function(){b&&b(f);e.manager.itemEnd(a)},0),f;c=document.createElementNS("http://www.w3.org/1999/xhtml",
"img");c.addEventListener("load",function(){hd.add(a,this);b&&b(this);e.manager.itemEnd(a)},!1);c.addEventListener("error",function(b){d&&d(b);e.manager.itemEnd(a);e.manager.itemError(a)},!1);"data:"!==a.substr(0,5)&&void 0!==this.crossOrigin&&(c.crossOrigin=this.crossOrigin);e.manager.itemStart(a);c.src=a;return c},setCrossOrigin:function(a){this.crossOrigin=a;return this},setPath:function(a){this.path=a;return this}});Object.assign(be.prototype,{crossOrigin:"Anonymous",load:function(a,b,c,d){function e(c){g.load(a[c],
function(a){f.images[c]=a;h++;6===h&&(f.needsUpdate=!0,b&&b(f))},void 0,d)}var f=new Va,g=new Sc(this.manager);g.setCrossOrigin(this.crossOrigin);g.setPath(this.path);var h=0;for(c=0;c<a.length;++c)e(c);return f},setCrossOrigin:function(a){this.crossOrigin=a;return this},setPath:function(a){this.path=a;return this}});Object.assign(sd.prototype,{crossOrigin:"Anonymous",load:function(a,b,c,d){var e=new Sc(this.manager);e.setCrossOrigin(this.crossOrigin);e.setPath(this.path);var f=new N;f.image=e.load(a,
function(){var c=0<a.search(/\.(jpg|jpeg)$/)||0===a.search(/^data\:image\/jpeg/);f.format=c?1022:1023;f.needsUpdate=!0;void 0!==b&&b(f)},c,d);return f},setCrossOrigin:function(a){this.crossOrigin=a;return this},setPath:function(a){this.path=a;return this}});aa.prototype=Object.assign(Object.create(w.prototype),{constructor:aa,isLight:!0,copy:function(a){w.prototype.copy.call(this,a);this.color.copy(a.color);this.intensity=a.intensity;return this},toJSON:function(a){a=w.prototype.toJSON.call(this,
a);a.object.color=this.color.getHex();a.object.intensity=this.intensity;void 0!==this.groundColor&&(a.object.groundColor=this.groundColor.getHex());void 0!==this.distance&&(a.object.distance=this.distance);void 0!==this.angle&&(a.object.angle=this.angle);void 0!==this.decay&&(a.object.decay=this.decay);void 0!==this.penumbra&&(a.object.penumbra=this.penumbra);void 0!==this.shadow&&(a.object.shadow=this.shadow.toJSON());return a}});td.prototype=Object.assign(Object.create(aa.prototype),{constructor:td,
isHemisphereLight:!0,copy:function(a){aa.prototype.copy.call(this,a);this.groundColor.copy(a.groundColor);return this}});Object.assign(rb.prototype,{copy:function(a){this.camera=a.camera.clone();this.bias=a.bias;this.radius=a.radius;this.mapSize.copy(a.mapSize);return this},clone:function(){return(new this.constructor).copy(this)},toJSON:function(){var a={};0!==this.bias&&(a.bias=this.bias);1!==this.radius&&(a.radius=this.radius);if(512!==this.mapSize.x||512!==this.mapSize.y)a.mapSize=this.mapSize.toArray();
a.camera=this.camera.toJSON(!1).object;delete a.camera.matrix;return a}});ud.prototype=Object.assign(Object.create(rb.prototype),{constructor:ud,isSpotLightShadow:!0,update:function(a){var b=this.camera,c=2*R.RAD2DEG*a.angle,d=this.mapSize.width/this.mapSize.height;a=a.distance||b.far;if(c!==b.fov||d!==b.aspect||a!==b.far)b.fov=c,b.aspect=d,b.far=a,b.updateProjectionMatrix()}});vd.prototype=Object.assign(Object.create(aa.prototype),{constructor:vd,isSpotLight:!0,copy:function(a){aa.prototype.copy.call(this,
a);this.distance=a.distance;this.angle=a.angle;this.penumbra=a.penumbra;this.decay=a.decay;this.target=a.target.clone();this.shadow=a.shadow.clone();return this}});wd.prototype=Object.assign(Object.create(aa.prototype),{constructor:wd,isPointLight:!0,copy:function(a){aa.prototype.copy.call(this,a);this.distance=a.distance;this.decay=a.decay;this.shadow=a.shadow.clone();return this}});xd.prototype=Object.assign(Object.create(rb.prototype),{constructor:xd});yd.prototype=Object.assign(Object.create(aa.prototype),
{constructor:yd,isDirectionalLight:!0,copy:function(a){aa.prototype.copy.call(this,a);this.target=a.target.clone();this.shadow=a.shadow.clone();return this}});zd.prototype=Object.assign(Object.create(aa.prototype),{constructor:zd,isAmbientLight:!0});Ad.prototype=Object.assign(Object.create(aa.prototype),{constructor:Ad,isRectAreaLight:!0,copy:function(a){aa.prototype.copy.call(this,a);this.width=a.width;this.height=a.height;return this},toJSON:function(a){a=aa.prototype.toJSON.call(this,a);a.object.width=
this.width;a.object.height=this.height;return a}});var ea={arraySlice:function(a,b,c){return ea.isTypedArray(a)?new a.constructor(a.subarray(b,void 0!==c?c:a.length)):a.slice(b,c)},convertArray:function(a,b,c){return!a||!c&&a.constructor===b?a:"number"===typeof b.BYTES_PER_ELEMENT?new b(a):Array.prototype.slice.call(a)},isTypedArray:function(a){return ArrayBuffer.isView(a)&&!(a instanceof DataView)},getKeyframeOrder:function(a){for(var b=a.length,c=Array(b),d=0;d!==b;++d)c[d]=d;c.sort(function(b,
c){return a[b]-a[c]});return c},sortedArray:function(a,b,c){for(var d=a.length,e=new a.constructor(d),f=0,g=0;g!==d;++f)for(var h=c[f]*b,k=0;k!==b;++k)e[g++]=a[h+k];return e},flattenJSON:function(a,b,c,d){for(var e=1,f=a[0];void 0!==f&&void 0===f[d];)f=a[e++];if(void 0!==f){var g=f[d];if(void 0!==g)if(Array.isArray(g)){do g=f[d],void 0!==g&&(b.push(f.time),c.push.apply(c,g)),f=a[e++];while(void 0!==f)}else if(void 0!==g.toArray){do g=f[d],void 0!==g&&(b.push(f.time),g.toArray(c,c.length)),f=a[e++];
while(void 0!==f)}else{do g=f[d],void 0!==g&&(b.push(f.time),c.push(g)),f=a[e++];while(void 0!==f)}}}};Object.assign(wa.prototype,{evaluate:function(a){var b=this.parameterPositions,c=this._cachedIndex,d=b[c],e=b[c-1];a:{b:{c:{d:if(!(a<d)){for(var f=c+2;;){if(void 0===d){if(a<e)break d;this._cachedIndex=c=b.length;return this.afterEnd_(c-1,a,e)}if(c===f)break;e=d;d=b[++c];if(a<d)break b}d=b.length;break c}if(a>=e)break a;else{f=b[1];a<f&&(c=2,e=f);for(f=c-2;;){if(void 0===e)return this._cachedIndex=
0,this.beforeStart_(0,a,d);if(c===f)break;d=e;e=b[--c-1];if(a>=e)break b}d=c;c=0}}for(;c<d;)e=c+d>>>1,a<b[e]?d=e:c=e+1;d=b[c];e=b[c-1];if(void 0===e)return this._cachedIndex=0,this.beforeStart_(0,a,d);if(void 0===d)return this._cachedIndex=c=b.length,this.afterEnd_(c-1,e,a)}this._cachedIndex=c;this.intervalChanged_(c,e,d)}return this.interpolate_(c,e,a,d)},settings:null,DefaultSettings_:{},getSettings_:function(){return this.settings||this.DefaultSettings_},copySampleValue_:function(a){var b=this.resultBuffer,
c=this.sampleValues,d=this.valueSize;a*=d;for(var e=0;e!==d;++e)b[e]=c[a+e];return b},interpolate_:function(a,b,c,d){throw Error("call to abstract method");},intervalChanged_:function(a,b,c){}});Object.assign(wa.prototype,{beforeStart_:wa.prototype.copySampleValue_,afterEnd_:wa.prototype.copySampleValue_});Bd.prototype=Object.assign(Object.create(wa.prototype),{constructor:Bd,DefaultSettings_:{endingStart:2400,endingEnd:2400},intervalChanged_:function(a,b,c){var d=this.parameterPositions,e=a-2,f=
a+1,g=d[e],h=d[f];if(void 0===g)switch(this.getSettings_().endingStart){case 2401:e=a;g=2*b-c;break;case 2402:e=d.length-2;g=b+d[e]-d[e+1];break;default:e=a,g=c}if(void 0===h)switch(this.getSettings_().endingEnd){case 2401:f=a;h=2*c-b;break;case 2402:f=1;h=c+d[1]-d[0];break;default:f=a-1,h=b}a=.5*(c-b);d=this.valueSize;this._weightPrev=a/(b-g);this._weightNext=a/(h-c);this._offsetPrev=e*d;this._offsetNext=f*d},interpolate_:function(a,b,c,d){var e=this.resultBuffer,f=this.sampleValues,g=this.valueSize;
a*=g;var h=a-g,k=this._offsetPrev,l=this._offsetNext,m=this._weightPrev,p=this._weightNext,n=(c-b)/(d-b);c=n*n;d=c*n;b=-m*d+2*m*c-m*n;m=(1+m)*d+(-1.5-2*m)*c+(-.5+m)*n+1;n=(-1-p)*d+(1.5+p)*c+.5*n;p=p*d-p*c;for(c=0;c!==g;++c)e[c]=b*f[k+c]+m*f[h+c]+n*f[a+c]+p*f[l+c];return e}});Tc.prototype=Object.assign(Object.create(wa.prototype),{constructor:Tc,interpolate_:function(a,b,c,d){var e=this.resultBuffer,f=this.sampleValues,g=this.valueSize;a*=g;var h=a-g;b=(c-b)/(d-b);c=1-b;for(d=0;d!==g;++d)e[d]=f[h+
d]*c+f[a+d]*b;return e}});Cd.prototype=Object.assign(Object.create(wa.prototype),{constructor:Cd,interpolate_:function(a,b,c,d){return this.copySampleValue_(a-1)}});var ab={TimeBufferType:Float32Array,ValueBufferType:Float32Array,DefaultInterpolation:2301,InterpolantFactoryMethodDiscrete:function(a){return new Cd(this.times,this.values,this.getValueSize(),a)},InterpolantFactoryMethodLinear:function(a){return new Tc(this.times,this.values,this.getValueSize(),a)},InterpolantFactoryMethodSmooth:function(a){return new Bd(this.times,
this.values,this.getValueSize(),a)},setInterpolation:function(a){switch(a){case 2300:var b=this.InterpolantFactoryMethodDiscrete;break;case 2301:b=this.InterpolantFactoryMethodLinear;break;case 2302:b=this.InterpolantFactoryMethodSmooth}if(void 0===b){b="unsupported interpolation for "+this.ValueTypeName+" keyframe track named "+this.name;if(void 0===this.createInterpolant)if(a!==this.DefaultInterpolation)this.setInterpolation(this.DefaultInterpolation);else throw Error(b);console.warn("THREE.KeyframeTrackPrototype:",
b)}else this.createInterpolant=b},getInterpolation:function(){switch(this.createInterpolant){case this.InterpolantFactoryMethodDiscrete:return 2300;case this.InterpolantFactoryMethodLinear:return 2301;case this.InterpolantFactoryMethodSmooth:return 2302}},getValueSize:function(){return this.values.length/this.times.length},shift:function(a){if(0!==a)for(var b=this.times,c=0,d=b.length;c!==d;++c)b[c]+=a;return this},scale:function(a){if(1!==a)for(var b=this.times,c=0,d=b.length;c!==d;++c)b[c]*=a;return this},
trim:function(a,b){for(var c=this.times,d=c.length,e=0,f=d-1;e!==d&&c[e]<a;)++e;for(;-1!==f&&c[f]>b;)--f;++f;if(0!==e||f!==d)e>=f&&(f=Math.max(f,1),e=f-1),a=this.getValueSize(),this.times=ea.arraySlice(c,e,f),this.values=ea.arraySlice(this.values,e*a,f*a);return this},validate:function(){var a=!0,b=this.getValueSize();0!==b-Math.floor(b)&&(console.error("THREE.KeyframeTrackPrototype: Invalid value size in track.",this),a=!1);var c=this.times,b=this.values,d=c.length;0===d&&(console.error("THREE.KeyframeTrackPrototype: Track is empty.",
this),a=!1);for(var e=null,f=0;f!==d;f++){var g=c[f];if("number"===typeof g&&isNaN(g)){console.error("THREE.KeyframeTrackPrototype: Time is not a valid number.",this,f,g);a=!1;break}if(null!==e&&e>g){console.error("THREE.KeyframeTrackPrototype: Out of order keys.",this,f,g,e);a=!1;break}e=g}if(void 0!==b&&ea.isTypedArray(b))for(f=0,c=b.length;f!==c;++f)if(d=b[f],isNaN(d)){console.error("THREE.KeyframeTrackPrototype: Value is not a valid number.",this,f,d);a=!1;break}return a},optimize:function(){for(var a,
b,c=this.times,d=this.values,e=this.getValueSize(),f=2302===this.getInterpolation(),g=1,h=c.length-1,k=1;k<h;++k){a=!1;var l=c[k];if(l!==c[k+1]&&(1!==k||l!==l[0]))if(f)a=!0;else{b=k*e;for(var m=b-e,p=b+e,l=0;l!==e;++l){var n=d[b+l];if(n!==d[m+l]||n!==d[p+l]){a=!0;break}}}if(a){if(k!==g)for(c[g]=c[k],b=k*e,a=g*e,l=0;l!==e;++l)d[a+l]=d[b+l];++g}}if(0<h){c[g]=c[h];b=h*e;a=g*e;for(l=0;l!==e;++l)d[a+l]=d[b+l];++g}g!==c.length&&(this.times=ea.arraySlice(c,0,g),this.values=ea.arraySlice(d,0,g*e));return this}};
bc.prototype=Object.assign(Object.create(ab),{constructor:bc,ValueTypeName:"vector"});Dd.prototype=Object.assign(Object.create(wa.prototype),{constructor:Dd,interpolate_:function(a,b,c,d){var e=this.resultBuffer,f=this.sampleValues,g=this.valueSize;a*=g;b=(c-b)/(d-b);for(c=a+g;a!==c;a+=4)ia.slerpFlat(e,0,f,a-g,f,a,b);return e}});Uc.prototype=Object.assign(Object.create(ab),{constructor:Uc,ValueTypeName:"quaternion",DefaultInterpolation:2301,InterpolantFactoryMethodLinear:function(a){return new Dd(this.times,
this.values,this.getValueSize(),a)},InterpolantFactoryMethodSmooth:void 0});cc.prototype=Object.assign(Object.create(ab),{constructor:cc,ValueTypeName:"number"});Ed.prototype=Object.assign(Object.create(ab),{constructor:Ed,ValueTypeName:"string",ValueBufferType:Array,DefaultInterpolation:2300,InterpolantFactoryMethodLinear:void 0,InterpolantFactoryMethodSmooth:void 0});Fd.prototype=Object.assign(Object.create(ab),{constructor:Fd,ValueTypeName:"bool",ValueBufferType:Array,DefaultInterpolation:2300,
InterpolantFactoryMethodLinear:void 0,InterpolantFactoryMethodSmooth:void 0});Gd.prototype=Object.assign(Object.create(ab),{constructor:Gd,ValueTypeName:"color"});tb.prototype=ab;ab.constructor=tb;Object.assign(tb,{parse:function(a){if(void 0===a.type)throw Error("track type undefined, can not parse");var b=tb._getTrackTypeForValueTypeName(a.type);if(void 0===a.times){var c=[],d=[];ea.flattenJSON(a.keys,c,d,"value");a.times=c;a.values=d}return void 0!==b.parse?b.parse(a):new b(a.name,a.times,a.values,
a.interpolation)},toJSON:function(a){var b=a.constructor;if(void 0!==b.toJSON)b=b.toJSON(a);else{var b={name:a.name,times:ea.convertArray(a.times,Array),values:ea.convertArray(a.values,Array)},c=a.getInterpolation();c!==a.DefaultInterpolation&&(b.interpolation=c)}b.type=a.ValueTypeName;return b},_getTrackTypeForValueTypeName:function(a){switch(a.toLowerCase()){case "scalar":case "double":case "float":case "number":case "integer":return cc;case "vector":case "vector2":case "vector3":case "vector4":return bc;
case "color":return Gd;case "quaternion":return Uc;case "bool":case "boolean":return Fd;case "string":return Ed}throw Error("Unsupported typeName: "+a);}});Object.assign(Ba,{parse:function(a){for(var b=[],c=a.tracks,d=1/(a.fps||1),e=0,f=c.length;e!==f;++e)b.push(tb.parse(c[e]).scale(d));return new Ba(a.name,a.duration,b)},toJSON:function(a){var b=[],c=a.tracks;a={name:a.name,duration:a.duration,tracks:b};for(var d=0,e=c.length;d!==e;++d)b.push(tb.toJSON(c[d]));return a},CreateFromMorphTargetSequence:function(a,
b,c,d){for(var e=b.length,f=[],g=0;g<e;g++){var h=[],k=[];h.push((g+e-1)%e,g,(g+1)%e);k.push(0,1,0);var l=ea.getKeyframeOrder(h),h=ea.sortedArray(h,1,l),k=ea.sortedArray(k,1,l);d||0!==h[0]||(h.push(e),k.push(k[0]));f.push((new cc(".morphTargetInfluences["+b[g].name+"]",h,k)).scale(1/c))}return new Ba(a,-1,f)},findByName:function(a,b){var c=a;Array.isArray(a)||(c=a.geometry&&a.geometry.animations||a.animations);for(a=0;a<c.length;a++)if(c[a].name===b)return c[a];return null},CreateClipsFromMorphTargetSequences:function(a,
b,c){for(var d,e={},f=/^([\w-]*?)([\d]+)$/,g=0,h=a.length;g<h;g++){var k=a[g],l=k.name.match(f);l&&1<l.length&&(d=l[1],(l=e[d])||(e[d]=l=[]),l.push(k))}a=[];for(d in e)a.push(Ba.CreateFromMorphTargetSequence(d,e[d],b,c));return a},parseAnimation:function(a,b){if(!a)return console.error("THREE.AnimationClip: No animation in JSONLoader data."),null;var c=function(a,b,c,d,e){if(0!==c.length){var f=[],g=[];ea.flattenJSON(c,f,g,d);0!==f.length&&e.push(new a(b,f,g))}},d=[],e=a.name||"default",f=a.length||
-1,g=a.fps||30;a=a.hierarchy||[];for(var h=0;h<a.length;h++){var k=a[h].keys;if(k&&0!==k.length)if(k[0].morphTargets){for(var f={},l=0;l<k.length;l++)if(k[l].morphTargets)for(var m=0;m<k[l].morphTargets.length;m++)f[k[l].morphTargets[m]]=-1;for(var p in f){for(var n=[],r=[],m=0;m!==k[l].morphTargets.length;++m){var v=k[l];n.push(v.time);r.push(v.morphTarget===p?1:0)}d.push(new cc(".morphTargetInfluence["+p+"]",n,r))}f=f.length*(g||1)}else l=".bones["+b[h].name+"]",c(bc,l+".position",k,"pos",d),c(Uc,
l+".quaternion",k,"rot",d),c(bc,l+".scale",k,"scl",d)}return 0===d.length?null:new Ba(e,f,d)}});Object.assign(Ba.prototype,{resetDuration:function(){for(var a=0,b=0,c=this.tracks.length;b!==c;++b)var d=this.tracks[b],a=Math.max(a,d.times[d.times.length-1]);this.duration=a},trim:function(){for(var a=0;a<this.tracks.length;a++)this.tracks[a].trim(0,this.duration);return this},optimize:function(){for(var a=0;a<this.tracks.length;a++)this.tracks[a].optimize();return this}});Object.assign(Hd.prototype,
{load:function(a,b,c,d){var e=this;(new Ia(e.manager)).load(a,function(a){b(e.parse(JSON.parse(a)))},c,d)},setTextures:function(a){this.textures=a},parse:function(a){function b(a){void 0===c[a]&&console.warn("THREE.MaterialLoader: Undefined texture",a);return c[a]}var c=this.textures,d=new sg[a.type];void 0!==a.uuid&&(d.uuid=a.uuid);void 0!==a.name&&(d.name=a.name);void 0!==a.color&&d.color.setHex(a.color);void 0!==a.roughness&&(d.roughness=a.roughness);void 0!==a.metalness&&(d.metalness=a.metalness);
void 0!==a.emissive&&d.emissive.setHex(a.emissive);void 0!==a.specular&&d.specular.setHex(a.specular);void 0!==a.shininess&&(d.shininess=a.shininess);void 0!==a.clearCoat&&(d.clearCoat=a.clearCoat);void 0!==a.clearCoatRoughness&&(d.clearCoatRoughness=a.clearCoatRoughness);void 0!==a.uniforms&&(d.uniforms=a.uniforms);void 0!==a.vertexShader&&(d.vertexShader=a.vertexShader);void 0!==a.fragmentShader&&(d.fragmentShader=a.fragmentShader);void 0!==a.vertexColors&&(d.vertexColors=a.vertexColors);void 0!==
a.fog&&(d.fog=a.fog);void 0!==a.flatShading&&(d.flatShading=a.flatShading);void 0!==a.blending&&(d.blending=a.blending);void 0!==a.side&&(d.side=a.side);void 0!==a.opacity&&(d.opacity=a.opacity);void 0!==a.transparent&&(d.transparent=a.transparent);void 0!==a.alphaTest&&(d.alphaTest=a.alphaTest);void 0!==a.depthTest&&(d.depthTest=a.depthTest);void 0!==a.depthWrite&&(d.depthWrite=a.depthWrite);void 0!==a.colorWrite&&(d.colorWrite=a.colorWrite);void 0!==a.wireframe&&(d.wireframe=a.wireframe);void 0!==
a.wireframeLinewidth&&(d.wireframeLinewidth=a.wireframeLinewidth);void 0!==a.wireframeLinecap&&(d.wireframeLinecap=a.wireframeLinecap);void 0!==a.wireframeLinejoin&&(d.wireframeLinejoin=a.wireframeLinejoin);void 0!==a.skinning&&(d.skinning=a.skinning);void 0!==a.morphTargets&&(d.morphTargets=a.morphTargets);void 0!==a.dithering&&(d.dithering=a.dithering);void 0!==a.visible&&(d.visible=a.visible);void 0!==a.userData&&(d.userData=a.userData);void 0!==a.shading&&(d.flatShading=1===a.shading);void 0!==
a.size&&(d.size=a.size);void 0!==a.sizeAttenuation&&(d.sizeAttenuation=a.sizeAttenuation);void 0!==a.map&&(d.map=b(a.map));void 0!==a.alphaMap&&(d.alphaMap=b(a.alphaMap),d.transparent=!0);void 0!==a.bumpMap&&(d.bumpMap=b(a.bumpMap));void 0!==a.bumpScale&&(d.bumpScale=a.bumpScale);void 0!==a.normalMap&&(d.normalMap=b(a.normalMap));if(void 0!==a.normalScale){var e=a.normalScale;!1===Array.isArray(e)&&(e=[e,e]);d.normalScale=(new D).fromArray(e)}void 0!==a.displacementMap&&(d.displacementMap=b(a.displacementMap));
void 0!==a.displacementScale&&(d.displacementScale=a.displacementScale);void 0!==a.displacementBias&&(d.displacementBias=a.displacementBias);void 0!==a.roughnessMap&&(d.roughnessMap=b(a.roughnessMap));void 0!==a.metalnessMap&&(d.metalnessMap=b(a.metalnessMap));void 0!==a.emissiveMap&&(d.emissiveMap=b(a.emissiveMap));void 0!==a.emissiveIntensity&&(d.emissiveIntensity=a.emissiveIntensity);void 0!==a.specularMap&&(d.specularMap=b(a.specularMap));void 0!==a.envMap&&(d.envMap=b(a.envMap));void 0!==a.reflectivity&&
(d.reflectivity=a.reflectivity);void 0!==a.lightMap&&(d.lightMap=b(a.lightMap));void 0!==a.lightMapIntensity&&(d.lightMapIntensity=a.lightMapIntensity);void 0!==a.aoMap&&(d.aoMap=b(a.aoMap));void 0!==a.aoMapIntensity&&(d.aoMapIntensity=a.aoMapIntensity);void 0!==a.gradientMap&&(d.gradientMap=b(a.gradientMap));return d}});Object.assign(ce.prototype,{load:function(a,b,c,d){var e=this;(new Ia(e.manager)).load(a,function(a){b(e.parse(JSON.parse(a)))},c,d)},parse:function(a){var b=new F;var c=a.data.index;
void 0!==c&&(c=new hf[c.type](c.array),b.setIndex(new K(c,1)));var d=a.data.attributes;for(f in d){var e=d[f];c=new hf[e.type](e.array);b.addAttribute(f,new K(c,e.itemSize,e.normalized))}var f=a.data.groups||a.data.drawcalls||a.data.offsets;if(void 0!==f)for(c=0,d=f.length;c!==d;++c)e=f[c],b.addGroup(e.start,e.count,e.materialIndex);a=a.data.boundingSphere;void 0!==a&&(f=new n,void 0!==a.center&&f.fromArray(a.center),b.boundingSphere=new Ca(f,a.radius));return b}});var hf={Int8Array:Int8Array,Uint8Array:Uint8Array,
Uint8ClampedArray:"undefined"!==typeof Uint8ClampedArray?Uint8ClampedArray:Uint8Array,Int16Array:Int16Array,Uint16Array:Uint16Array,Int32Array:Int32Array,Uint32Array:Uint32Array,Float32Array:Float32Array,Float64Array:Float64Array};dc.Handlers={handlers:[],add:function(a,b){this.handlers.push(a,b)},get:function(a){for(var b=this.handlers,c=0,d=b.length;c<d;c+=2){var e=b[c+1];if(b[c].test(a))return e}return null}};Object.assign(dc.prototype,{crossOrigin:void 0,extractUrlBase:function(a){a=a.split("/");
if(1===a.length)return"./";a.pop();return a.join("/")+"/"},initMaterials:function(a,b,c){for(var d=[],e=0;e<a.length;++e)d[e]=this.createMaterial(a[e],b,c);return d},createMaterial:function(){var a={NoBlending:0,NormalBlending:1,AdditiveBlending:2,SubtractiveBlending:3,MultiplyBlending:4,CustomBlending:5},b=new C,c=new sd,d=new Hd;return function(e,f,g){function h(a,b,d,e,h){a=f+a;var l=dc.Handlers.get(a);null!==l?a=l.load(a):(c.setCrossOrigin(g),a=c.load(a));void 0!==b&&(a.repeat.fromArray(b),1!==
b[0]&&(a.wrapS=1E3),1!==b[1]&&(a.wrapT=1E3));void 0!==d&&a.offset.fromArray(d);void 0!==e&&("repeat"===e[0]&&(a.wrapS=1E3),"mirror"===e[0]&&(a.wrapS=1002),"repeat"===e[1]&&(a.wrapT=1E3),"mirror"===e[1]&&(a.wrapT=1002));void 0!==h&&(a.anisotropy=h);b=R.generateUUID();k[b]=a;return b}var k={},l={uuid:R.generateUUID(),type:"MeshLambertMaterial"},m;for(m in e){var p=e[m];switch(m){case "DbgColor":case "DbgIndex":case "opticalDensity":case "illumination":break;case "DbgName":l.name=p;break;case "blending":l.blending=
a[p];break;case "colorAmbient":case "mapAmbient":console.warn("THREE.Loader.createMaterial:",m,"is no longer supported.");break;case "colorDiffuse":l.color=b.fromArray(p).getHex();break;case "colorSpecular":l.specular=b.fromArray(p).getHex();break;case "colorEmissive":l.emissive=b.fromArray(p).getHex();break;case "specularCoef":l.shininess=p;break;case "shading":"basic"===p.toLowerCase()&&(l.type="MeshBasicMaterial");"phong"===p.toLowerCase()&&(l.type="MeshPhongMaterial");"standard"===p.toLowerCase()&&
(l.type="MeshStandardMaterial");break;case "mapDiffuse":l.map=h(p,e.mapDiffuseRepeat,e.mapDiffuseOffset,e.mapDiffuseWrap,e.mapDiffuseAnisotropy);break;case "mapDiffuseRepeat":case "mapDiffuseOffset":case "mapDiffuseWrap":case "mapDiffuseAnisotropy":break;case "mapEmissive":l.emissiveMap=h(p,e.mapEmissiveRepeat,e.mapEmissiveOffset,e.mapEmissiveWrap,e.mapEmissiveAnisotropy);break;case "mapEmissiveRepeat":case "mapEmissiveOffset":case "mapEmissiveWrap":case "mapEmissiveAnisotropy":break;case "mapLight":l.lightMap=
h(p,e.mapLightRepeat,e.mapLightOffset,e.mapLightWrap,e.mapLightAnisotropy);break;case "mapLightRepeat":case "mapLightOffset":case "mapLightWrap":case "mapLightAnisotropy":break;case "mapAO":l.aoMap=h(p,e.mapAORepeat,e.mapAOOffset,e.mapAOWrap,e.mapAOAnisotropy);break;case "mapAORepeat":case "mapAOOffset":case "mapAOWrap":case "mapAOAnisotropy":break;case "mapBump":l.bumpMap=h(p,e.mapBumpRepeat,e.mapBumpOffset,e.mapBumpWrap,e.mapBumpAnisotropy);break;case "mapBumpScale":l.bumpScale=p;break;case "mapBumpRepeat":case "mapBumpOffset":case "mapBumpWrap":case "mapBumpAnisotropy":break;
case "mapNormal":l.normalMap=h(p,e.mapNormalRepeat,e.mapNormalOffset,e.mapNormalWrap,e.mapNormalAnisotropy);break;case "mapNormalFactor":l.normalScale=[p,p];break;case "mapNormalRepeat":case "mapNormalOffset":case "mapNormalWrap":case "mapNormalAnisotropy":break;case "mapSpecular":l.specularMap=h(p,e.mapSpecularRepeat,e.mapSpecularOffset,e.mapSpecularWrap,e.mapSpecularAnisotropy);break;case "mapSpecularRepeat":case "mapSpecularOffset":case "mapSpecularWrap":case "mapSpecularAnisotropy":break;case "mapMetalness":l.metalnessMap=
h(p,e.mapMetalnessRepeat,e.mapMetalnessOffset,e.mapMetalnessWrap,e.mapMetalnessAnisotropy);break;case "mapMetalnessRepeat":case "mapMetalnessOffset":case "mapMetalnessWrap":case "mapMetalnessAnisotropy":break;case "mapRoughness":l.roughnessMap=h(p,e.mapRoughnessRepeat,e.mapRoughnessOffset,e.mapRoughnessWrap,e.mapRoughnessAnisotropy);break;case "mapRoughnessRepeat":case "mapRoughnessOffset":case "mapRoughnessWrap":case "mapRoughnessAnisotropy":break;case "mapAlpha":l.alphaMap=h(p,e.mapAlphaRepeat,
e.mapAlphaOffset,e.mapAlphaWrap,e.mapAlphaAnisotropy);break;case "mapAlphaRepeat":case "mapAlphaOffset":case "mapAlphaWrap":case "mapAlphaAnisotropy":break;case "flipSided":l.side=1;break;case "doubleSided":l.side=2;break;case "transparency":console.warn("THREE.Loader.createMaterial: transparency has been renamed to opacity");l.opacity=p;break;case "depthTest":case "depthWrite":case "colorWrite":case "opacity":case "reflectivity":case "transparent":case "visible":case "wireframe":l[m]=p;break;case "vertexColors":!0===
p&&(l.vertexColors=2);"face"===p&&(l.vertexColors=1);break;default:console.error("THREE.Loader.createMaterial: Unsupported",m,p)}}"MeshBasicMaterial"===l.type&&delete l.emissive;"MeshPhongMaterial"!==l.type&&delete l.specular;1>l.opacity&&(l.transparent=!0);d.setTextures(k);return d.parse(l)}}()});Object.assign(de.prototype,{load:function(a,b,c,d){var e=this,f=this.texturePath&&"string"===typeof this.texturePath?this.texturePath:dc.prototype.extractUrlBase(a),g=new Ia(this.manager);g.setWithCredentials(this.withCredentials);
g.load(a,function(c){c=JSON.parse(c);var d=c.metadata;if(void 0!==d&&(d=d.type,void 0!==d)){if("object"===d.toLowerCase()){console.error("THREE.JSONLoader: "+a+" should be loaded with THREE.ObjectLoader instead.");return}if("scene"===d.toLowerCase()){console.error("THREE.JSONLoader: "+a+" should be loaded with THREE.SceneLoader instead.");return}}c=e.parse(c,f);b(c.geometry,c.materials)},c,d)},setTexturePath:function(a){this.texturePath=a},parse:function(){return function(a,b){void 0!==a.data&&(a=
a.data);a.scale=void 0!==a.scale?1/a.scale:1;var c=new Q,d=a,e,f,g,h=d.faces;var k=d.vertices;var l=d.normals,m=d.colors;var p=d.scale;var t=0;if(void 0!==d.uvs){for(e=0;e<d.uvs.length;e++)d.uvs[e].length&&t++;for(e=0;e<t;e++)c.faceVertexUvs[e]=[]}var r=0;for(g=k.length;r<g;)e=new n,e.x=k[r++]*p,e.y=k[r++]*p,e.z=k[r++]*p,c.vertices.push(e);r=0;for(g=h.length;r<g;){k=h[r++];var v=k&1;var u=k&2;e=k&8;var x=k&16;var y=k&32;p=k&64;k&=128;if(v){v=new Qa;v.a=h[r];v.b=h[r+1];v.c=h[r+3];var w=new Qa;w.a=
h[r+1];w.b=h[r+2];w.c=h[r+3];r+=4;u&&(u=h[r++],v.materialIndex=u,w.materialIndex=u);u=c.faces.length;if(e)for(e=0;e<t;e++){var z=d.uvs[e];c.faceVertexUvs[e][u]=[];c.faceVertexUvs[e][u+1]=[];for(f=0;4>f;f++){var B=h[r++];var H=z[2*B];B=z[2*B+1];H=new D(H,B);2!==f&&c.faceVertexUvs[e][u].push(H);0!==f&&c.faceVertexUvs[e][u+1].push(H)}}x&&(x=3*h[r++],v.normal.set(l[x++],l[x++],l[x]),w.normal.copy(v.normal));if(y)for(e=0;4>e;e++)x=3*h[r++],y=new n(l[x++],l[x++],l[x]),2!==e&&v.vertexNormals.push(y),0!==
e&&w.vertexNormals.push(y);p&&(p=h[r++],p=m[p],v.color.setHex(p),w.color.setHex(p));if(k)for(e=0;4>e;e++)p=h[r++],p=m[p],2!==e&&v.vertexColors.push(new C(p)),0!==e&&w.vertexColors.push(new C(p));c.faces.push(v);c.faces.push(w)}else{v=new Qa;v.a=h[r++];v.b=h[r++];v.c=h[r++];u&&(u=h[r++],v.materialIndex=u);u=c.faces.length;if(e)for(e=0;e<t;e++)for(z=d.uvs[e],c.faceVertexUvs[e][u]=[],f=0;3>f;f++)B=h[r++],H=z[2*B],B=z[2*B+1],H=new D(H,B),c.faceVertexUvs[e][u].push(H);x&&(x=3*h[r++],v.normal.set(l[x++],
l[x++],l[x]));if(y)for(e=0;3>e;e++)x=3*h[r++],y=new n(l[x++],l[x++],l[x]),v.vertexNormals.push(y);p&&(p=h[r++],v.color.setHex(m[p]));if(k)for(e=0;3>e;e++)p=h[r++],v.vertexColors.push(new C(m[p]));c.faces.push(v)}}d=a;r=void 0!==d.influencesPerVertex?d.influencesPerVertex:2;if(d.skinWeights)for(g=0,h=d.skinWeights.length;g<h;g+=r)c.skinWeights.push(new S(d.skinWeights[g],1<r?d.skinWeights[g+1]:0,2<r?d.skinWeights[g+2]:0,3<r?d.skinWeights[g+3]:0));if(d.skinIndices)for(g=0,h=d.skinIndices.length;g<h;g+=
r)c.skinIndices.push(new S(d.skinIndices[g],1<r?d.skinIndices[g+1]:0,2<r?d.skinIndices[g+2]:0,3<r?d.skinIndices[g+3]:0));c.bones=d.bones;c.bones&&0<c.bones.length&&(c.skinWeights.length!==c.skinIndices.length||c.skinIndices.length!==c.vertices.length)&&console.warn("When skinning, number of vertices ("+c.vertices.length+"), skinIndices ("+c.skinIndices.length+"), and skinWeights ("+c.skinWeights.length+") should match.");g=a;h=g.scale;if(void 0!==g.morphTargets)for(d=0,r=g.morphTargets.length;d<r;d++)for(c.morphTargets[d]=
{},c.morphTargets[d].name=g.morphTargets[d].name,c.morphTargets[d].vertices=[],l=c.morphTargets[d].vertices,m=g.morphTargets[d].vertices,t=0,k=m.length;t<k;t+=3)p=new n,p.x=m[t]*h,p.y=m[t+1]*h,p.z=m[t+2]*h,l.push(p);if(void 0!==g.morphColors&&0<g.morphColors.length)for(console.warn('THREE.JSONLoader: "morphColors" no longer supported. Using them as face colors.'),h=c.faces,g=g.morphColors[0].colors,d=0,r=h.length;d<r;d++)h[d].color.fromArray(g,3*d);g=a;d=[];r=[];void 0!==g.animation&&r.push(g.animation);
void 0!==g.animations&&(g.animations.length?r=r.concat(g.animations):r.push(g.animations));for(g=0;g<r.length;g++)(h=Ba.parseAnimation(r[g],c.bones))&&d.push(h);c.morphTargets&&(r=Ba.CreateClipsFromMorphTargetSequences(c.morphTargets,10),d=d.concat(r));0<d.length&&(c.animations=d);c.computeFaceNormals();c.computeBoundingSphere();if(void 0===a.materials||0===a.materials.length)return{geometry:c};a=dc.prototype.initMaterials(a.materials,b,this.crossOrigin);return{geometry:c,materials:a}}}()});Object.assign(Se.prototype,
{load:function(a,b,c,d){""===this.texturePath&&(this.texturePath=a.substring(0,a.lastIndexOf("/")+1));var e=this;(new Ia(e.manager)).load(a,function(c){var f=null;try{f=JSON.parse(c)}catch(h){void 0!==d&&d(h);console.error("THREE:ObjectLoader: Can't parse "+a+".",h.message);return}c=f.metadata;void 0===c||void 0===c.type||"geometry"===c.type.toLowerCase()?console.error("THREE.ObjectLoader: Can't load "+a+". Use THREE.JSONLoader instead."):e.parse(f,b)},c,d)},setTexturePath:function(a){this.texturePath=
a},setCrossOrigin:function(a){this.crossOrigin=a},parse:function(a,b){var c=this.parseGeometries(a.geometries),d=this.parseImages(a.images,function(){void 0!==b&&b(e)}),d=this.parseTextures(a.textures,d),d=this.parseMaterials(a.materials,d),e=this.parseObject(a.object,c,d);a.animations&&(e.animations=this.parseAnimations(a.animations));void 0!==a.images&&0!==a.images.length||void 0===b||b(e);return e},parseGeometries:function(a){var b={};if(void 0!==a)for(var c=new de,d=new ce,e=0,f=a.length;e<f;e++){var g=
a[e];switch(g.type){case "PlaneGeometry":case "PlaneBufferGeometry":var h=new Ka[g.type](g.width,g.height,g.widthSegments,g.heightSegments);break;case "BoxGeometry":case "BoxBufferGeometry":case "CubeGeometry":h=new Ka[g.type](g.width,g.height,g.depth,g.widthSegments,g.heightSegments,g.depthSegments);break;case "CircleGeometry":case "CircleBufferGeometry":h=new Ka[g.type](g.radius,g.segments,g.thetaStart,g.thetaLength);break;case "CylinderGeometry":case "CylinderBufferGeometry":h=new Ka[g.type](g.radiusTop,
g.radiusBottom,g.height,g.radialSegments,g.heightSegments,g.openEnded,g.thetaStart,g.thetaLength);break;case "ConeGeometry":case "ConeBufferGeometry":h=new Ka[g.type](g.radius,g.height,g.radialSegments,g.heightSegments,g.openEnded,g.thetaStart,g.thetaLength);break;case "SphereGeometry":case "SphereBufferGeometry":h=new Ka[g.type](g.radius,g.widthSegments,g.heightSegments,g.phiStart,g.phiLength,g.thetaStart,g.thetaLength);break;case "DodecahedronGeometry":case "IcosahedronGeometry":case "OctahedronGeometry":case "TetrahedronGeometry":h=
new Ka[g.type](g.radius,g.detail);break;case "RingGeometry":case "RingBufferGeometry":h=new Ka[g.type](g.innerRadius,g.outerRadius,g.thetaSegments,g.phiSegments,g.thetaStart,g.thetaLength);break;case "TorusGeometry":case "TorusBufferGeometry":h=new Ka[g.type](g.radius,g.tube,g.radialSegments,g.tubularSegments,g.arc);break;case "TorusKnotGeometry":case "TorusKnotBufferGeometry":h=new Ka[g.type](g.radius,g.tube,g.tubularSegments,g.radialSegments,g.p,g.q);break;case "LatheGeometry":case "LatheBufferGeometry":h=
new Ka[g.type](g.points,g.segments,g.phiStart,g.phiLength);break;case "BufferGeometry":h=d.parse(g);break;case "Geometry":h=c.parse(g,this.texturePath).geometry;break;default:console.warn('THREE.ObjectLoader: Unsupported geometry type "'+g.type+'"');continue}h.uuid=g.uuid;void 0!==g.name&&(h.name=g.name);b[g.uuid]=h}return b},parseMaterials:function(a,b){var c={};if(void 0!==a){var d=new Hd;d.setTextures(b);b=0;for(var e=a.length;b<e;b++){var f=a[b];if("MultiMaterial"===f.type){for(var g=[],h=0;h<
f.materials.length;h++)g.push(d.parse(f.materials[h]));c[f.uuid]=g}else c[f.uuid]=d.parse(f)}}return c},parseAnimations:function(a){for(var b=[],c=0;c<a.length;c++){var d=Ba.parse(a[c]);b.push(d)}return b},parseImages:function(a,b){function c(a){d.manager.itemStart(a);return f.load(a,function(){d.manager.itemEnd(a)},void 0,function(){d.manager.itemEnd(a);d.manager.itemError(a)})}var d=this,e={};if(void 0!==a&&0<a.length){b=new $d(b);var f=new Sc(b);f.setCrossOrigin(this.crossOrigin);b=0;for(var g=
a.length;b<g;b++){var h=a[b],k=/^(\/\/)|([a-z]+:(\/\/)?)/i.test(h.url)?h.url:d.texturePath+h.url;e[h.uuid]=c(k)}}return e},parseTextures:function(a,b){function c(a,b){if("number"===typeof a)return a;console.warn("THREE.ObjectLoader.parseTexture: Constant should be in numeric form.",a);return b[a]}var d={};if(void 0!==a)for(var e=0,f=a.length;e<f;e++){var g=a[e];void 0===g.image&&console.warn('THREE.ObjectLoader: No "image" specified for',g.uuid);void 0===b[g.image]&&console.warn("THREE.ObjectLoader: Undefined image",
g.image);var h=new N(b[g.image]);h.needsUpdate=!0;h.uuid=g.uuid;void 0!==g.name&&(h.name=g.name);void 0!==g.mapping&&(h.mapping=c(g.mapping,tg));void 0!==g.offset&&h.offset.fromArray(g.offset);void 0!==g.repeat&&h.repeat.fromArray(g.repeat);void 0!==g.wrap&&(h.wrapS=c(g.wrap[0],jf),h.wrapT=c(g.wrap[1],jf));void 0!==g.minFilter&&(h.minFilter=c(g.minFilter,kf));void 0!==g.magFilter&&(h.magFilter=c(g.magFilter,kf));void 0!==g.anisotropy&&(h.anisotropy=g.anisotropy);void 0!==g.flipY&&(h.flipY=g.flipY);
d[g.uuid]=h}return d},parseObject:function(){var a=new O;return function(b,c,d){function e(a){void 0===c[a]&&console.warn("THREE.ObjectLoader: Undefined geometry",a);return c[a]}function f(a){if(void 0!==a){if(Array.isArray(a)){for(var b=[],c=0,e=a.length;c<e;c++){var f=a[c];void 0===d[f]&&console.warn("THREE.ObjectLoader: Undefined material",f);b.push(d[f])}return b}void 0===d[a]&&console.warn("THREE.ObjectLoader: Undefined material",a);return d[a]}}switch(b.type){case "Scene":var g=new nd;void 0!==
b.background&&Number.isInteger(b.background)&&(g.background=new C(b.background));void 0!==b.fog&&("Fog"===b.fog.type?g.fog=new Ib(b.fog.color,b.fog.near,b.fog.far):"FogExp2"===b.fog.type&&(g.fog=new Hb(b.fog.color,b.fog.density)));break;case "PerspectiveCamera":g=new ja(b.fov,b.aspect,b.near,b.far);void 0!==b.focus&&(g.focus=b.focus);void 0!==b.zoom&&(g.zoom=b.zoom);void 0!==b.filmGauge&&(g.filmGauge=b.filmGauge);void 0!==b.filmOffset&&(g.filmOffset=b.filmOffset);void 0!==b.view&&(g.view=Object.assign({},
b.view));break;case "OrthographicCamera":g=new Db(b.left,b.right,b.top,b.bottom,b.near,b.far);break;case "AmbientLight":g=new zd(b.color,b.intensity);break;case "DirectionalLight":g=new yd(b.color,b.intensity);break;case "PointLight":g=new wd(b.color,b.intensity,b.distance,b.decay);break;case "RectAreaLight":g=new Ad(b.color,b.intensity,b.width,b.height);break;case "SpotLight":g=new vd(b.color,b.intensity,b.distance,b.angle,b.penumbra,b.decay);break;case "HemisphereLight":g=new td(b.color,b.groundColor,
b.intensity);break;case "SkinnedMesh":console.warn("THREE.ObjectLoader.parseObject() does not support SkinnedMesh yet.");case "Mesh":g=e(b.geometry);var h=f(b.material);g=g.bones&&0<g.bones.length?new pd(g,h):new fa(g,h);break;case "LOD":g=new yc;break;case "Line":g=new ra(e(b.geometry),f(b.material),b.mode);break;case "LineLoop":g=new qd(e(b.geometry),f(b.material));break;case "LineSegments":g=new X(e(b.geometry),f(b.material));break;case "PointCloud":case "Points":g=new Jb(e(b.geometry),f(b.material));
break;case "Sprite":g=new xc(f(b.material));break;case "Group":g=new Ac;break;default:g=new w}g.uuid=b.uuid;void 0!==b.name&&(g.name=b.name);void 0!==b.matrix?(a.fromArray(b.matrix),a.decompose(g.position,g.quaternion,g.scale)):(void 0!==b.position&&g.position.fromArray(b.position),void 0!==b.rotation&&g.rotation.fromArray(b.rotation),void 0!==b.quaternion&&g.quaternion.fromArray(b.quaternion),void 0!==b.scale&&g.scale.fromArray(b.scale));void 0!==b.castShadow&&(g.castShadow=b.castShadow);void 0!==
b.receiveShadow&&(g.receiveShadow=b.receiveShadow);b.shadow&&(void 0!==b.shadow.bias&&(g.shadow.bias=b.shadow.bias),void 0!==b.shadow.radius&&(g.shadow.radius=b.shadow.radius),void 0!==b.shadow.mapSize&&g.shadow.mapSize.fromArray(b.shadow.mapSize),void 0!==b.shadow.camera&&(g.shadow.camera=this.parseObject(b.shadow.camera)));void 0!==b.visible&&(g.visible=b.visible);void 0!==b.userData&&(g.userData=b.userData);if(void 0!==b.children)for(var h=b.children,k=0;k<h.length;k++)g.add(this.parseObject(h[k],
c,d));if("LOD"===b.type)for(b=b.levels,h=0;h<b.length;h++){var k=b[h],l=g.getObjectByProperty("uuid",k.object);void 0!==l&&g.addLevel(l,k.distance)}return g}}()});var tg={UVMapping:300,CubeReflectionMapping:301,CubeRefractionMapping:302,EquirectangularReflectionMapping:303,EquirectangularRefractionMapping:304,SphericalReflectionMapping:305,CubeUVReflectionMapping:306,CubeUVRefractionMapping:307},jf={RepeatWrapping:1E3,ClampToEdgeWrapping:1001,MirroredRepeatWrapping:1002},kf={NearestFilter:1003,NearestMipMapNearestFilter:1004,
NearestMipMapLinearFilter:1005,LinearFilter:1006,LinearMipMapNearestFilter:1007,LinearMipMapLinearFilter:1008};Object.assign(pa.prototype,{getPoint:function(){console.warn("THREE.Curve: .getPoint() not implemented.");return null},getPointAt:function(a){a=this.getUtoTmapping(a);return this.getPoint(a)},getPoints:function(a){void 0===a&&(a=5);for(var b=[],c=0;c<=a;c++)b.push(this.getPoint(c/a));return b},getSpacedPoints:function(a){void 0===a&&(a=5);for(var b=[],c=0;c<=a;c++)b.push(this.getPointAt(c/
a));return b},getLength:function(){var a=this.getLengths();return a[a.length-1]},getLengths:function(a){void 0===a&&(a=this.arcLengthDivisions);if(this.cacheArcLengths&&this.cacheArcLengths.length===a+1&&!this.needsUpdate)return this.cacheArcLengths;this.needsUpdate=!1;var b=[],c=this.getPoint(0),d,e=0;b.push(0);for(d=1;d<=a;d++){var f=this.getPoint(d/a);e+=f.distanceTo(c);b.push(e);c=f}return this.cacheArcLengths=b},updateArcLengths:function(){this.needsUpdate=!0;this.getLengths()},getUtoTmapping:function(a,
b){var c=this.getLengths(),d=c.length;b=b?b:a*c[d-1];for(var e=0,f=d-1,g;e<=f;)if(a=Math.floor(e+(f-e)/2),g=c[a]-b,0>g)e=a+1;else if(0<g)f=a-1;else{f=a;break}a=f;if(c[a]===b)return a/(d-1);e=c[a];return(a+(b-e)/(c[a+1]-e))/(d-1)},getTangent:function(a){var b=a-1E-4;a+=1E-4;0>b&&(b=0);1<a&&(a=1);b=this.getPoint(b);return this.getPoint(a).clone().sub(b).normalize()},getTangentAt:function(a){a=this.getUtoTmapping(a);return this.getTangent(a)},computeFrenetFrames:function(a,b){var c=new n,d=[],e=[],f=
[],g=new n,h=new O,k;for(k=0;k<=a;k++){var l=k/a;d[k]=this.getTangentAt(l);d[k].normalize()}e[0]=new n;f[0]=new n;k=Number.MAX_VALUE;l=Math.abs(d[0].x);var m=Math.abs(d[0].y),p=Math.abs(d[0].z);l<=k&&(k=l,c.set(1,0,0));m<=k&&(k=m,c.set(0,1,0));p<=k&&c.set(0,0,1);g.crossVectors(d[0],c).normalize();e[0].crossVectors(d[0],g);f[0].crossVectors(d[0],e[0]);for(k=1;k<=a;k++)e[k]=e[k-1].clone(),f[k]=f[k-1].clone(),g.crossVectors(d[k-1],d[k]),g.length()>Number.EPSILON&&(g.normalize(),c=Math.acos(R.clamp(d[k-
1].dot(d[k]),-1,1)),e[k].applyMatrix4(h.makeRotationAxis(g,c))),f[k].crossVectors(d[k],e[k]);if(!0===b)for(c=Math.acos(R.clamp(e[0].dot(e[a]),-1,1)),c/=a,0<d[0].dot(g.crossVectors(e[0],e[a]))&&(c=-c),k=1;k<=a;k++)e[k].applyMatrix4(h.makeRotationAxis(d[k],c*k)),f[k].crossVectors(d[k],e[k]);return{tangents:d,normals:e,binormals:f}}});Oa.prototype=Object.create(pa.prototype);Oa.prototype.constructor=Oa;Oa.prototype.isLineCurve=!0;Oa.prototype.getPoint=function(a){if(1===a)return this.v2.clone();var b=
this.v2.clone().sub(this.v1);b.multiplyScalar(a).add(this.v1);return b};Oa.prototype.getPointAt=function(a){return this.getPoint(a)};Oa.prototype.getTangent=function(a){return this.v2.clone().sub(this.v1).normalize()};Vc.prototype=Object.assign(Object.create(pa.prototype),{constructor:Vc,add:function(a){this.curves.push(a)},closePath:function(){var a=this.curves[0].getPoint(0),b=this.curves[this.curves.length-1].getPoint(1);a.equals(b)||this.curves.push(new Oa(b,a))},getPoint:function(a){var b=a*
this.getLength(),c=this.getCurveLengths();for(a=0;a<c.length;){if(c[a]>=b)return b=c[a]-b,a=this.curves[a],c=a.getLength(),a.getPointAt(0===c?0:1-b/c);a++}return null},getLength:function(){var a=this.getCurveLengths();return a[a.length-1]},updateArcLengths:function(){this.needsUpdate=!0;this.cacheLengths=null;this.getCurveLengths()},getCurveLengths:function(){if(this.cacheLengths&&this.cacheLengths.length===this.curves.length)return this.cacheLengths;for(var a=[],b=0,c=0,d=this.curves.length;c<d;c++)b+=
this.curves[c].getLength(),a.push(b);return this.cacheLengths=a},getSpacedPoints:function(a){void 0===a&&(a=40);for(var b=[],c=0;c<=a;c++)b.push(this.getPoint(c/a));this.autoClose&&b.push(b[0]);return b},getPoints:function(a){a=a||12;for(var b=[],c,d=0,e=this.curves;d<e.length;d++)for(var f=e[d],f=f.getPoints(f&&f.isEllipseCurve?2*a:f&&f.isLineCurve?1:f&&f.isSplineCurve?a*f.points.length:a),g=0;g<f.length;g++){var h=f[g];c&&c.equals(h)||(b.push(h),c=h)}this.autoClose&&1<b.length&&!b[b.length-1].equals(b[0])&&
b.push(b[0]);return b},createPointsGeometry:function(a){a=this.getPoints(a);return this.createGeometry(a)},createSpacedPointsGeometry:function(a){a=this.getSpacedPoints(a);return this.createGeometry(a)},createGeometry:function(a){for(var b=new Q,c=0,d=a.length;c<d;c++){var e=a[c];b.vertices.push(new n(e.x,e.y,e.z||0))}return b}});Ua.prototype=Object.create(pa.prototype);Ua.prototype.constructor=Ua;Ua.prototype.isEllipseCurve=!0;Ua.prototype.getPoint=function(a){for(var b=2*Math.PI,c=this.aEndAngle-
this.aStartAngle,d=Math.abs(c)<Number.EPSILON;0>c;)c+=b;for(;c>b;)c-=b;c<Number.EPSILON&&(c=d?0:b);!0!==this.aClockwise||d||(c=c===b?-b:c-b);b=this.aStartAngle+a*c;a=this.aX+this.xRadius*Math.cos(b);var e=this.aY+this.yRadius*Math.sin(b);0!==this.aRotation&&(b=Math.cos(this.aRotation),c=Math.sin(this.aRotation),d=a-this.aX,e-=this.aY,a=d*b-e*c+this.aX,e=d*c+e*b+this.aY);return new D(a,e)};wb.prototype=Object.create(pa.prototype);wb.prototype.constructor=wb;wb.prototype.isSplineCurve=!0;wb.prototype.getPoint=
function(a){var b=this.points,c=(b.length-1)*a;a=Math.floor(c);var c=c-a,d=b[0===a?a:a-1],e=b[a],f=b[a>b.length-2?b.length-1:a+1],b=b[a>b.length-3?b.length-1:a+2];return new D(Te(c,d.x,e.x,f.x,b.x),Te(c,d.y,e.y,f.y,b.y))};ec.prototype=Object.create(pa.prototype);ec.prototype.constructor=ec;ec.prototype.getPoint=function(a){var b=this.v0,c=this.v1,d=this.v2,e=this.v3;return new D(vb(a,b.x,c.x,d.x,e.x),vb(a,b.y,c.y,d.y,e.y))};fc.prototype=Object.create(pa.prototype);fc.prototype.constructor=fc;fc.prototype.getPoint=
function(a){var b=this.v0,c=this.v1,d=this.v2;return new D(ub(a,b.x,c.x,d.x),ub(a,b.y,c.y,d.y))};var ue=Object.assign(Object.create(Vc.prototype),{fromPoints:function(a){this.moveTo(a[0].x,a[0].y);for(var b=1,c=a.length;b<c;b++)this.lineTo(a[b].x,a[b].y)},moveTo:function(a,b){this.currentPoint.set(a,b)},lineTo:function(a,b){var c=new Oa(this.currentPoint.clone(),new D(a,b));this.curves.push(c);this.currentPoint.set(a,b)},quadraticCurveTo:function(a,b,c,d){a=new fc(this.currentPoint.clone(),new D(a,
b),new D(c,d));this.curves.push(a);this.currentPoint.set(c,d)},bezierCurveTo:function(a,b,c,d,e,f){a=new ec(this.currentPoint.clone(),new D(a,b),new D(c,d),new D(e,f));this.curves.push(a);this.currentPoint.set(e,f)},splineThru:function(a){var b=[this.currentPoint.clone()].concat(a),b=new wb(b);this.curves.push(b);this.currentPoint.copy(a[a.length-1])},arc:function(a,b,c,d,e,f){this.absarc(a+this.currentPoint.x,b+this.currentPoint.y,c,d,e,f)},absarc:function(a,b,c,d,e,f){this.absellipse(a,b,c,c,d,
e,f)},ellipse:function(a,b,c,d,e,f,g,h){this.absellipse(a+this.currentPoint.x,b+this.currentPoint.y,c,d,e,f,g,h)},absellipse:function(a,b,c,d,e,f,g,h){a=new Ua(a,b,c,d,e,f,g,h);0<this.curves.length&&(b=a.getPoint(0),b.equals(this.currentPoint)||this.lineTo(b.x,b.y));this.curves.push(a);a=a.getPoint(1);this.currentPoint.copy(a)}});Wc.prototype=ue;ue.constructor=Wc;xb.prototype=Object.assign(Object.create(ue),{constructor:xb,getPointsHoles:function(a){for(var b=[],c=0,d=this.holes.length;c<d;c++)b[c]=
this.holes[c].getPoints(a);return b},extractAllPoints:function(a){return{shape:this.getPoints(a),holes:this.getPointsHoles(a)}},extractPoints:function(a){return this.extractAllPoints(a)}});Object.assign(ee.prototype,{moveTo:function(a,b){this.currentPath=new Wc;this.subPaths.push(this.currentPath);this.currentPath.moveTo(a,b)},lineTo:function(a,b){this.currentPath.lineTo(a,b)},quadraticCurveTo:function(a,b,c,d){this.currentPath.quadraticCurveTo(a,b,c,d)},bezierCurveTo:function(a,b,c,d,e,f){this.currentPath.bezierCurveTo(a,
b,c,d,e,f)},splineThru:function(a){this.currentPath.splineThru(a)},toShapes:function(a,b){function c(a){for(var b=[],c=0,d=a.length;c<d;c++){var e=a[c],f=new xb;f.curves=e.curves;b.push(f)}return b}function d(a,b){for(var c=b.length,d=!1,e=c-1,f=0;f<c;e=f++){var g=b[e],h=b[f],k=h.x-g.x,l=h.y-g.y;if(Math.abs(l)>Number.EPSILON){if(0>l&&(g=b[f],k=-k,h=b[e],l=-l),!(a.y<g.y||a.y>h.y))if(a.y===g.y){if(a.x===g.x)return!0}else{e=l*(a.x-g.x)-k*(a.y-g.y);if(0===e)return!0;0>e||(d=!d)}}else if(a.y===g.y&&(h.x<=
a.x&&a.x<=g.x||g.x<=a.x&&a.x<=h.x))return!0}return d}var e=Fa.isClockWise,f=this.subPaths;if(0===f.length)return[];if(!0===b)return c(f);b=[];if(1===f.length){var g=f[0];var h=new xb;h.curves=g.curves;b.push(h);return b}var k=!e(f[0].getPoints()),k=a?!k:k;h=[];var l=[],m=[],p=0;l[p]=void 0;m[p]=[];for(var n=0,r=f.length;n<r;n++){g=f[n];var v=g.getPoints();var u=e(v);(u=a?!u:u)?(!k&&l[p]&&p++,l[p]={s:new xb,p:v},l[p].s.curves=g.curves,k&&p++,m[p]=[]):m[p].push({h:g,p:v[0]})}if(!l[0])return c(f);if(1<
l.length){n=!1;a=[];e=0;for(f=l.length;e<f;e++)h[e]=[];e=0;for(f=l.length;e<f;e++)for(g=m[e],u=0;u<g.length;u++){k=g[u];p=!0;for(v=0;v<l.length;v++)d(k.p,l[v].p)&&(e!==v&&a.push({froms:e,tos:v,hole:u}),p?(p=!1,h[v].push(k)):n=!0);p&&h[e].push(k)}0<a.length&&(n||(m=h))}n=0;for(e=l.length;n<e;n++)for(h=l[n].s,b.push(h),a=m[n],f=0,g=a.length;f<g;f++)h.holes.push(a[f].h);return b}});Object.assign(fe.prototype,{isFont:!0,generateShapes:function(a,b,c){void 0===b&&(b=100);void 0===c&&(c=4);var d=this.data;
a=String(a).split("");var e=b/d.resolution,f=(d.boundingBox.yMax-d.boundingBox.yMin+d.underlineThickness)*e,g=0,h=0;b=[];for(var k=0;k<a.length;k++){var l=a[k];if("\n"===l)g=0,h-=f;else{var m;var p=e;var n=g,r=h;if(l=d.glyphs[l]||d.glyphs["?"]){var v=new ee,u=[];if(l.o)for(var x=l._cachedOutline||(l._cachedOutline=l.o.split(" ")),w=0,z=x.length;w<z;)switch(x[w++]){case "m":var C=x[w++]*p+n;var B=x[w++]*p+r;v.moveTo(C,B);break;case "l":C=x[w++]*p+n;B=x[w++]*p+r;v.lineTo(C,B);break;case "q":var D=x[w++]*
p+n;var F=x[w++]*p+r;var K=x[w++]*p+n;var L=x[w++]*p+r;v.quadraticCurveTo(K,L,D,F);if(m=u[u.length-1]){var O=m.x;m=m.y;for(var N=1;N<=c;N++){var P=N/c;ub(P,O,K,D);ub(P,m,L,F)}}break;case "b":if(D=x[w++]*p+n,F=x[w++]*p+r,K=x[w++]*p+n,L=x[w++]*p+r,C=x[w++]*p+n,B=x[w++]*p+r,v.bezierCurveTo(K,L,C,B,D,F),m=u[u.length-1])for(O=m.x,m=m.y,N=1;N<=c;N++)P=N/c,vb(P,O,K,C,D),vb(P,m,L,B,F)}p={offsetX:l.ha*p,path:v}}else p=void 0;g+=p.offsetX;b.push(p.path)}}c=[];d=0;for(a=b.length;d<a;d++)Array.prototype.push.apply(c,
b[d].toShapes());return c}});Object.assign(Ue.prototype,{load:function(a,b,c,d){var e=this;(new Ia(this.manager)).load(a,function(a){try{var c=JSON.parse(a)}catch(h){console.warn("THREE.FontLoader: typeface.js support is being deprecated. Use typeface.json instead."),c=JSON.parse(a.substring(65,a.length-2))}a=e.parse(c);b&&b(a)},c,d)},parse:function(a){return new fe(a)}});var Nd,ie={getContext:function(){void 0===Nd&&(Nd=new (window.AudioContext||window.webkitAudioContext));return Nd},setContext:function(a){Nd=
a}};Object.assign(ge.prototype,{load:function(a,b,c,d){var e=new Ia(this.manager);e.setResponseType("arraybuffer");e.load(a,function(a){ie.getContext().decodeAudioData(a,function(a){b(a)})},c,d)}});Object.assign(Ve.prototype,{update:function(){var a,b,c,d,e,f,g,h,k=new O,l=new O;return function(m){if(a!==this||b!==m.focus||c!==m.fov||d!==m.aspect*this.aspect||e!==m.near||f!==m.far||g!==m.zoom||h!==this.eyeSep){a=this;b=m.focus;c=m.fov;d=m.aspect*this.aspect;e=m.near;f=m.far;g=m.zoom;var p=m.projectionMatrix.clone();
h=this.eyeSep/2;var q=h*e/b,n=e*Math.tan(R.DEG2RAD*c*.5)/g;l.elements[12]=-h;k.elements[12]=h;var v=-n*d+q;var u=n*d+q;p.elements[0]=2*e/(u-v);p.elements[8]=(u+v)/(u-v);this.cameraL.projectionMatrix.copy(p);v=-n*d-q;u=n*d-q;p.elements[0]=2*e/(u-v);p.elements[8]=(u+v)/(u-v);this.cameraR.projectionMatrix.copy(p)}this.cameraL.matrixWorld.copy(m.matrixWorld).multiply(l);this.cameraR.matrixWorld.copy(m.matrixWorld).multiply(k)}}()});Xc.prototype=Object.create(w.prototype);Xc.prototype.constructor=Xc;he.prototype=
Object.assign(Object.create(w.prototype),{constructor:he,getInput:function(){return this.gain},removeFilter:function(){null!==this.filter&&(this.gain.disconnect(this.filter),this.filter.disconnect(this.context.destination),this.gain.connect(this.context.destination),this.filter=null)},getFilter:function(){return this.filter},setFilter:function(a){null!==this.filter?(this.gain.disconnect(this.filter),this.filter.disconnect(this.context.destination)):this.gain.disconnect(this.context.destination);this.filter=
a;this.gain.connect(this.filter);this.filter.connect(this.context.destination)},getMasterVolume:function(){return this.gain.gain.value},setMasterVolume:function(a){this.gain.gain.value=a},updateMatrixWorld:function(){var a=new n,b=new ia,c=new n,d=new n;return function(e){w.prototype.updateMatrixWorld.call(this,e);e=this.context.listener;var f=this.up;this.matrixWorld.decompose(a,b,c);d.set(0,0,-1).applyQuaternion(b);e.positionX?(e.positionX.setValueAtTime(a.x,this.context.currentTime),e.positionY.setValueAtTime(a.y,
this.context.currentTime),e.positionZ.setValueAtTime(a.z,this.context.currentTime),e.forwardX.setValueAtTime(d.x,this.context.currentTime),e.forwardY.setValueAtTime(d.y,this.context.currentTime),e.forwardZ.setValueAtTime(d.z,this.context.currentTime),e.upX.setValueAtTime(f.x,this.context.currentTime),e.upY.setValueAtTime(f.y,this.context.currentTime),e.upZ.setValueAtTime(f.z,this.context.currentTime)):(e.setPosition(a.x,a.y,a.z),e.setOrientation(d.x,d.y,d.z,f.x,f.y,f.z))}}()});gc.prototype=Object.assign(Object.create(w.prototype),
{constructor:gc,getOutput:function(){return this.gain},setNodeSource:function(a){this.hasPlaybackControl=!1;this.sourceType="audioNode";this.source=a;this.connect();return this},setBuffer:function(a){this.buffer=a;this.sourceType="buffer";this.autoplay&&this.play();return this},play:function(){if(!0===this.isPlaying)console.warn("THREE.Audio: Audio is already playing.");else if(!1===this.hasPlaybackControl)console.warn("THREE.Audio: this Audio has no playback control.");else{var a=this.context.createBufferSource();
a.buffer=this.buffer;a.loop=this.loop;a.onended=this.onEnded.bind(this);a.playbackRate.setValueAtTime(this.playbackRate,this.startTime);a.start(0,this.startTime);this.isPlaying=!0;this.source=a;return this.connect()}},pause:function(){if(!1===this.hasPlaybackControl)console.warn("THREE.Audio: this Audio has no playback control.");else return this.source.stop(),this.startTime=this.context.currentTime,this.isPlaying=!1,this},stop:function(){if(!1===this.hasPlaybackControl)console.warn("THREE.Audio: this Audio has no playback control.");
else return this.source.stop(),this.startTime=0,this.isPlaying=!1,this},connect:function(){if(0<this.filters.length){this.source.connect(this.filters[0]);for(var a=1,b=this.filters.length;a<b;a++)this.filters[a-1].connect(this.filters[a]);this.filters[this.filters.length-1].connect(this.getOutput())}else this.source.connect(this.getOutput());return this},disconnect:function(){if(0<this.filters.length){this.source.disconnect(this.filters[0]);for(var a=1,b=this.filters.length;a<b;a++)this.filters[a-
1].disconnect(this.filters[a]);this.filters[this.filters.length-1].disconnect(this.getOutput())}else this.source.disconnect(this.getOutput());return this},getFilters:function(){return this.filters},setFilters:function(a){a||(a=[]);!0===this.isPlaying?(this.disconnect(),this.filters=a,this.connect()):this.filters=a;return this},getFilter:function(){return this.getFilters()[0]},setFilter:function(a){return this.setFilters(a?[a]:[])},setPlaybackRate:function(a){if(!1===this.hasPlaybackControl)console.warn("THREE.Audio: this Audio has no playback control.");
else return this.playbackRate=a,!0===this.isPlaying&&this.source.playbackRate.setValueAtTime(this.playbackRate,this.context.currentTime),this},getPlaybackRate:function(){return this.playbackRate},onEnded:function(){this.isPlaying=!1},getLoop:function(){return!1===this.hasPlaybackControl?(console.warn("THREE.Audio: this Audio has no playback control."),!1):this.loop},setLoop:function(a){if(!1===this.hasPlaybackControl)console.warn("THREE.Audio: this Audio has no playback control.");else return this.loop=
a,!0===this.isPlaying&&(this.source.loop=this.loop),this},getVolume:function(){return this.gain.gain.value},setVolume:function(a){this.gain.gain.value=a;return this}});je.prototype=Object.assign(Object.create(gc.prototype),{constructor:je,getOutput:function(){return this.panner},getRefDistance:function(){return this.panner.refDistance},setRefDistance:function(a){this.panner.refDistance=a},getRolloffFactor:function(){return this.panner.rolloffFactor},setRolloffFactor:function(a){this.panner.rolloffFactor=
a},getDistanceModel:function(){return this.panner.distanceModel},setDistanceModel:function(a){this.panner.distanceModel=a},getMaxDistance:function(){return this.panner.maxDistance},setMaxDistance:function(a){this.panner.maxDistance=a},updateMatrixWorld:function(){var a=new n;return function(b){w.prototype.updateMatrixWorld.call(this,b);a.setFromMatrixPosition(this.matrixWorld);this.panner.setPosition(a.x,a.y,a.z)}}()});Object.assign(ke.prototype,{getFrequencyData:function(){this.analyser.getByteFrequencyData(this.data);
return this.data},getAverageFrequency:function(){for(var a=0,b=this.getFrequencyData(),c=0;c<b.length;c++)a+=b[c];return a/b.length}});Object.assign(le.prototype,{accumulate:function(a,b){var c=this.buffer,d=this.valueSize;a=a*d+d;var e=this.cumulativeWeight;if(0===e){for(e=0;e!==d;++e)c[a+e]=c[e];e=b}else e+=b,this._mixBufferRegion(c,a,0,b/e,d);this.cumulativeWeight=e},apply:function(a){var b=this.valueSize,c=this.buffer;a=a*b+b;var d=this.cumulativeWeight,e=this.binding;this.cumulativeWeight=0;
1>d&&this._mixBufferRegion(c,a,3*b,1-d,b);for(var d=b,f=b+b;d!==f;++d)if(c[d]!==c[d+b]){e.setValue(c,a);break}},saveOriginalState:function(){var a=this.buffer,b=this.valueSize,c=3*b;this.binding.getValue(a,c);for(var d=b;d!==c;++d)a[d]=a[c+d%b];this.cumulativeWeight=0},restoreOriginalState:function(){this.binding.setValue(this.buffer,3*this.valueSize)},_select:function(a,b,c,d,e){if(.5<=d)for(d=0;d!==e;++d)a[b+d]=a[c+d]},_slerp:function(a,b,c,d){ia.slerpFlat(a,b,a,b,a,c,d)},_lerp:function(a,b,c,d,
e){for(var f=1-d,g=0;g!==e;++g){var h=b+g;a[h]=a[h]*f+a[c+g]*d}}});Object.assign(We.prototype,{getValue:function(a,b){this.bind();var c=this._bindings[this._targetGroup.nCachedObjects_];void 0!==c&&c.getValue(a,b)},setValue:function(a,b){for(var c=this._bindings,d=this._targetGroup.nCachedObjects_,e=c.length;d!==e;++d)c[d].setValue(a,b)},bind:function(){for(var a=this._bindings,b=this._targetGroup.nCachedObjects_,c=a.length;b!==c;++b)a[b].bind()},unbind:function(){for(var a=this._bindings,b=this._targetGroup.nCachedObjects_,
c=a.length;b!==c;++b)a[b].unbind()}});Object.assign(da,{Composite:We,create:function(a,b,c){return a&&a.isAnimationObjectGroup?new da.Composite(a,b,c):new da(a,b,c)},sanitizeNodeName:function(a){return a.replace(/\s/g,"_").replace(/[^\w-]/g,"")},parseTrackName:function(){var a=new RegExp("^"+/((?:[\w-]+[\/:])*)/.source+/([\w-\.]+)?/.source+/(?:\.([\w-]+)(?:\[(.+)\])?)?/.source+/\.([\w-]+)(?:\[(.+)\])?/.source+"$"),b=["material","materials","bones"];return function(c){var d=a.exec(c);if(!d)throw Error("PropertyBinding: Cannot parse trackName: "+
c);var d={nodeName:d[2],objectName:d[3],objectIndex:d[4],propertyName:d[5],propertyIndex:d[6]},e=d.nodeName&&d.nodeName.lastIndexOf(".");if(void 0!==e&&-1!==e){var f=d.nodeName.substring(e+1);-1!==b.indexOf(f)&&(d.nodeName=d.nodeName.substring(0,e),d.objectName=f)}if(null===d.propertyName||0===d.propertyName.length)throw Error("PropertyBinding: can not parse propertyName from trackName: "+c);return d}}(),findNode:function(a,b){if(!b||""===b||"root"===b||"."===b||-1===b||b===a.name||b===a.uuid)return a;
if(a.skeleton){var c=function(a){for(var c=0;c<a.bones.length;c++){var d=a.bones[c];if(d.name===b)return d}return null}(a.skeleton);if(c)return c}if(a.children){var d=function(a){for(var c=0;c<a.length;c++){var e=a[c];if(e.name===b||e.uuid===b||(e=d(e.children)))return e}return null};if(a=d(a.children))return a}return null}});Object.assign(da.prototype,{_getValue_unavailable:function(){},_setValue_unavailable:function(){},BindingType:{Direct:0,EntireArray:1,ArrayElement:2,HasFromToArray:3},Versioning:{None:0,
NeedsUpdate:1,MatrixWorldNeedsUpdate:2},GetterByBindingType:[function(a,b){a[b]=this.node[this.propertyName]},function(a,b){for(var c=this.resolvedProperty,d=0,e=c.length;d!==e;++d)a[b++]=c[d]},function(a,b){a[b]=this.resolvedProperty[this.propertyIndex]},function(a,b){this.resolvedProperty.toArray(a,b)}],SetterByBindingTypeAndVersioning:[[function(a,b){this.node[this.propertyName]=a[b]},function(a,b){this.node[this.propertyName]=a[b];this.targetObject.needsUpdate=!0},function(a,b){this.node[this.propertyName]=
a[b];this.targetObject.matrixWorldNeedsUpdate=!0}],[function(a,b){for(var c=this.resolvedProperty,d=0,e=c.length;d!==e;++d)c[d]=a[b++]},function(a,b){for(var c=this.resolvedProperty,d=0,e=c.length;d!==e;++d)c[d]=a[b++];this.targetObject.needsUpdate=!0},function(a,b){for(var c=this.resolvedProperty,d=0,e=c.length;d!==e;++d)c[d]=a[b++];this.targetObject.matrixWorldNeedsUpdate=!0}],[function(a,b){this.resolvedProperty[this.propertyIndex]=a[b]},function(a,b){this.resolvedProperty[this.propertyIndex]=
a[b];this.targetObject.needsUpdate=!0},function(a,b){this.resolvedProperty[this.propertyIndex]=a[b];this.targetObject.matrixWorldNeedsUpdate=!0}],[function(a,b){this.resolvedProperty.fromArray(a,b)},function(a,b){this.resolvedProperty.fromArray(a,b);this.targetObject.needsUpdate=!0},function(a,b){this.resolvedProperty.fromArray(a,b);this.targetObject.matrixWorldNeedsUpdate=!0}]],getValue:function(a,b){this.bind();this.getValue(a,b)},setValue:function(a,b){this.bind();this.setValue(a,b)},bind:function(){var a=
this.node,b=this.parsedPath,c=b.objectName,d=b.propertyName,e=b.propertyIndex;a||(this.node=a=da.findNode(this.rootNode,b.nodeName)||this.rootNode);this.getValue=this._getValue_unavailable;this.setValue=this._setValue_unavailable;if(a){if(c){var f=b.objectIndex;switch(c){case "materials":if(!a.material){console.error("THREE.PropertyBinding: Can not bind to material as node does not have a material.",this);return}if(!a.material.materials){console.error("THREE.PropertyBinding: Can not bind to material.materials as node.material does not have a materials array.",
this);return}a=a.material.materials;break;case "bones":if(!a.skeleton){console.error("THREE.PropertyBinding: Can not bind to bones as node does not have a skeleton.",this);return}a=a.skeleton.bones;for(c=0;c<a.length;c++)if(a[c].name===f){f=c;break}break;default:if(void 0===a[c]){console.error("THREE.PropertyBinding: Can not bind to objectName of node undefined.",this);return}a=a[c]}if(void 0!==f){if(void 0===a[f]){console.error("THREE.PropertyBinding: Trying to bind to objectIndex of objectName, but is undefined.",
this,a);return}a=a[f]}}f=a[d];if(void 0===f)console.error("THREE.PropertyBinding: Trying to update property for track: "+b.nodeName+"."+d+" but it wasn't found.",a);else{b=this.Versioning.None;void 0!==a.needsUpdate?(b=this.Versioning.NeedsUpdate,this.targetObject=a):void 0!==a.matrixWorldNeedsUpdate&&(b=this.Versioning.MatrixWorldNeedsUpdate,this.targetObject=a);c=this.BindingType.Direct;if(void 0!==e){if("morphTargetInfluences"===d){if(!a.geometry){console.error("THREE.PropertyBinding: Can not bind to morphTargetInfluences because node does not have a geometry.",
this);return}if(a.geometry.isBufferGeometry){if(!a.geometry.morphAttributes){console.error("THREE.PropertyBinding: Can not bind to morphTargetInfluences because node does not have a geometry.morphAttributes.",this);return}for(c=0;c<this.node.geometry.morphAttributes.position.length;c++)if(a.geometry.morphAttributes.position[c].name===e){e=c;break}}else{if(!a.geometry.morphTargets){console.error("THREE.PropertyBinding: Can not bind to morphTargetInfluences because node does not have a geometry.morphTargets.",
this);return}for(c=0;c<this.node.geometry.morphTargets.length;c++)if(a.geometry.morphTargets[c].name===e){e=c;break}}}c=this.BindingType.ArrayElement;this.resolvedProperty=f;this.propertyIndex=e}else void 0!==f.fromArray&&void 0!==f.toArray?(c=this.BindingType.HasFromToArray,this.resolvedProperty=f):Array.isArray(f)?(c=this.BindingType.EntireArray,this.resolvedProperty=f):this.propertyName=d;this.getValue=this.GetterByBindingType[c];this.setValue=this.SetterByBindingTypeAndVersioning[c][b]}}else console.error("THREE.PropertyBinding: Trying to update node for track: "+
this.path+" but it wasn't found.")},unbind:function(){this.node=null;this.getValue=this._getValue_unbound;this.setValue=this._setValue_unbound}});Object.assign(da.prototype,{_getValue_unbound:da.prototype.getValue,_setValue_unbound:da.prototype.setValue});Object.assign(Xe.prototype,{isAnimationObjectGroup:!0,add:function(a){for(var b=this._objects,c=b.length,d=this.nCachedObjects_,e=this._indicesByUUID,f=this._paths,g=this._parsedPaths,h=this._bindings,k=h.length,l=0,m=arguments.length;l!==m;++l){var p=
arguments[l],n=p.uuid,r=e[n];if(void 0===r){r=c++;e[n]=r;b.push(p);for(var n=0,v=k;n!==v;++n)h[n].push(new da(p,f[n],g[n]))}else if(r<d){var u=--d,v=b[u];e[v.uuid]=r;b[r]=v;e[n]=u;b[u]=p;n=0;for(v=k;n!==v;++n){var w=h[n],y=w[r];w[r]=w[u];void 0===y&&(y=new da(p,f[n],g[n]));w[u]=y}}else void 0!==b[r]&&console.error("THREE.AnimationObjectGroup: Different objects with the same UUID detected. Clean the caches or recreate your infrastructure when reloading scenes.")}this.nCachedObjects_=d},remove:function(a){for(var b=
this._objects,c=this.nCachedObjects_,d=this._indicesByUUID,e=this._bindings,f=e.length,g=0,h=arguments.length;g!==h;++g){var k=arguments[g],l=k.uuid,m=d[l];if(void 0!==m&&m>=c){var p=c++,n=b[p];d[n.uuid]=m;b[m]=n;d[l]=p;b[p]=k;k=0;for(l=f;k!==l;++k){var n=e[k],r=n[m];n[m]=n[p];n[p]=r}}}this.nCachedObjects_=c},uncache:function(a){for(var b,c,d=this._objects,e=d.length,f=this.nCachedObjects_,g=this._indicesByUUID,h=this._bindings,k=h.length,l=0,m=arguments.length;l!==m;++l){c=arguments[l].uuid;var p=
g[c];if(void 0!==p)if(delete g[c],p<f){var n=--f,r=d[n];c=--e;b=d[c];g[r.uuid]=p;d[p]=r;g[b.uuid]=n;d[n]=b;d.pop();for(var r=0,v=k;r!==v;++r){b=h[r];var u=b[c];b[p]=b[n];b[n]=u;b.pop()}}else for(c=--e,b=d[c],g[b.uuid]=p,d[p]=b,d.pop(),r=0,v=k;r!==v;++r)b=h[r],b[p]=b[c],b.pop()}this.nCachedObjects_=f},subscribe_:function(a,b){var c=this._bindingsIndicesByPath,d=c[a],e=this._bindings;if(void 0!==d)return e[d];var f=this._paths,g=this._parsedPaths,h=this._objects,k=this.nCachedObjects_,l=Array(h.length),
d=e.length;c[a]=d;f.push(a);g.push(b);e.push(l);c=k;for(d=h.length;c!==d;++c)l[c]=new da(h[c],a,b);return l},unsubscribe_:function(a){var b=this._bindingsIndicesByPath,c=b[a];if(void 0!==c){var d=this._paths,e=this._parsedPaths,f=this._bindings,g=f.length-1,h=f[g];b[a[g]]=c;f[c]=h;f.pop();e[c]=e[g];e.pop();d[c]=d[g];d.pop()}}});Object.assign(Ye.prototype,{play:function(){this._mixer._activateAction(this);return this},stop:function(){this._mixer._deactivateAction(this);return this.reset()},reset:function(){this.paused=
!1;this.enabled=!0;this.time=0;this._loopCount=-1;this._startTime=null;return this.stopFading().stopWarping()},isRunning:function(){return this.enabled&&!this.paused&&0!==this.timeScale&&null===this._startTime&&this._mixer._isActiveAction(this)},isScheduled:function(){return this._mixer._isActiveAction(this)},startAt:function(a){this._startTime=a;return this},setLoop:function(a,b){this.loop=a;this.repetitions=b;return this},setEffectiveWeight:function(a){this.weight=a;this._effectiveWeight=this.enabled?
a:0;return this.stopFading()},getEffectiveWeight:function(){return this._effectiveWeight},fadeIn:function(a){return this._scheduleFading(a,0,1)},fadeOut:function(a){return this._scheduleFading(a,1,0)},crossFadeFrom:function(a,b,c){a.fadeOut(b);this.fadeIn(b);if(c){c=this._clip.duration;var d=a._clip.duration,e=c/d;a.warp(1,d/c,b);this.warp(e,1,b)}return this},crossFadeTo:function(a,b,c){return a.crossFadeFrom(this,b,c)},stopFading:function(){var a=this._weightInterpolant;null!==a&&(this._weightInterpolant=
null,this._mixer._takeBackControlInterpolant(a));return this},setEffectiveTimeScale:function(a){this.timeScale=a;this._effectiveTimeScale=this.paused?0:a;return this.stopWarping()},getEffectiveTimeScale:function(){return this._effectiveTimeScale},setDuration:function(a){this.timeScale=this._clip.duration/a;return this.stopWarping()},syncWith:function(a){this.time=a.time;this.timeScale=a.timeScale;return this.stopWarping()},halt:function(a){return this.warp(this._effectiveTimeScale,0,a)},warp:function(a,
b,c){var d=this._mixer,e=d.time,f=this._timeScaleInterpolant,g=this.timeScale;null===f&&(this._timeScaleInterpolant=f=d._lendControlInterpolant());d=f.parameterPositions;f=f.sampleValues;d[0]=e;d[1]=e+c;f[0]=a/g;f[1]=b/g;return this},stopWarping:function(){var a=this._timeScaleInterpolant;null!==a&&(this._timeScaleInterpolant=null,this._mixer._takeBackControlInterpolant(a));return this},getMixer:function(){return this._mixer},getClip:function(){return this._clip},getRoot:function(){return this._localRoot||
this._mixer._root},_update:function(a,b,c,d){if(this.enabled){var e=this._startTime;if(null!==e){b=(a-e)*c;if(0>b||0===c)return;this._startTime=null;b*=c}b*=this._updateTimeScale(a);c=this._updateTime(b);a=this._updateWeight(a);if(0<a){b=this._interpolants;for(var e=this._propertyBindings,f=0,g=b.length;f!==g;++f)b[f].evaluate(c),e[f].accumulate(d,a)}}else this._updateWeight(a)},_updateWeight:function(a){var b=0;if(this.enabled){var b=this.weight,c=this._weightInterpolant;if(null!==c){var d=c.evaluate(a)[0],
b=b*d;a>c.parameterPositions[1]&&(this.stopFading(),0===d&&(this.enabled=!1))}}return this._effectiveWeight=b},_updateTimeScale:function(a){var b=0;if(!this.paused){var b=this.timeScale,c=this._timeScaleInterpolant;if(null!==c){var d=c.evaluate(a)[0],b=b*d;a>c.parameterPositions[1]&&(this.stopWarping(),0===b?this.paused=!0:this.timeScale=b)}}return this._effectiveTimeScale=b},_updateTime:function(a){var b=this.time+a;if(0===a)return b;var c=this._clip.duration,d=this.loop,e=this._loopCount;if(2200===
d)a:{if(-1===e&&(this._loopCount=0,this._setEndings(!0,!0,!1)),b>=c)b=c;else if(0>b)b=0;else break a;this.clampWhenFinished?this.paused=!0:this.enabled=!1;this._mixer.dispatchEvent({type:"finished",action:this,direction:0>a?-1:1})}else{d=2202===d;-1===e&&(0<=a?(e=0,this._setEndings(!0,0===this.repetitions,d)):this._setEndings(0===this.repetitions,!0,d));if(b>=c||0>b){var f=Math.floor(b/c),b=b-c*f,e=e+Math.abs(f),g=this.repetitions-e;0>g?(this.clampWhenFinished?this.paused=!0:this.enabled=!1,b=0<a?
c:0,this._mixer.dispatchEvent({type:"finished",action:this,direction:0<a?1:-1})):(0===g?(a=0>a,this._setEndings(a,!a,d)):this._setEndings(!1,!1,d),this._loopCount=e,this._mixer.dispatchEvent({type:"loop",action:this,loopDelta:f}))}if(d&&1===(e&1))return this.time=b,c-b}return this.time=b},_setEndings:function(a,b,c){var d=this._interpolantSettings;c?(d.endingStart=2401,d.endingEnd=2401):(d.endingStart=a?this.zeroSlopeAtStart?2401:2400:2402,d.endingEnd=b?this.zeroSlopeAtEnd?2401:2400:2402)},_scheduleFading:function(a,
b,c){var d=this._mixer,e=d.time,f=this._weightInterpolant;null===f&&(this._weightInterpolant=f=d._lendControlInterpolant());d=f.parameterPositions;f=f.sampleValues;d[0]=e;f[0]=b;d[1]=e+a;f[1]=c;return this}});Object.assign(Ze.prototype,na.prototype,{_bindAction:function(a,b){var c=a._localRoot||this._root,d=a._clip.tracks,e=d.length,f=a._propertyBindings;a=a._interpolants;var g=c.uuid,h=this._bindingsByRootAndName,k=h[g];void 0===k&&(k={},h[g]=k);for(h=0;h!==e;++h){var l=d[h],m=l.name,n=k[m];if(void 0===
n){n=f[h];if(void 0!==n){null===n._cacheIndex&&(++n.referenceCount,this._addInactiveBinding(n,g,m));continue}n=new le(da.create(c,m,b&&b._propertyBindings[h].binding.parsedPath),l.ValueTypeName,l.getValueSize());++n.referenceCount;this._addInactiveBinding(n,g,m)}f[h]=n;a[h].resultBuffer=n.buffer}},_activateAction:function(a){if(!this._isActiveAction(a)){if(null===a._cacheIndex){var b=(a._localRoot||this._root).uuid,c=a._clip.uuid,d=this._actionsByClip[c];this._bindAction(a,d&&d.knownActions[0]);this._addInactiveAction(a,
c,b)}b=a._propertyBindings;c=0;for(d=b.length;c!==d;++c){var e=b[c];0===e.useCount++&&(this._lendBinding(e),e.saveOriginalState())}this._lendAction(a)}},_deactivateAction:function(a){if(this._isActiveAction(a)){for(var b=a._propertyBindings,c=0,d=b.length;c!==d;++c){var e=b[c];0===--e.useCount&&(e.restoreOriginalState(),this._takeBackBinding(e))}this._takeBackAction(a)}},_initMemoryManager:function(){this._actions=[];this._nActiveActions=0;this._actionsByClip={};this._bindings=[];this._nActiveBindings=
0;this._bindingsByRootAndName={};this._controlInterpolants=[];this._nActiveControlInterpolants=0;var a=this;this.stats={actions:{get total(){return a._actions.length},get inUse(){return a._nActiveActions}},bindings:{get total(){return a._bindings.length},get inUse(){return a._nActiveBindings}},controlInterpolants:{get total(){return a._controlInterpolants.length},get inUse(){return a._nActiveControlInterpolants}}}},_isActiveAction:function(a){a=a._cacheIndex;return null!==a&&a<this._nActiveActions},
_addInactiveAction:function(a,b,c){var d=this._actions,e=this._actionsByClip,f=e[b];void 0===f?(f={knownActions:[a],actionByRoot:{}},a._byClipCacheIndex=0,e[b]=f):(b=f.knownActions,a._byClipCacheIndex=b.length,b.push(a));a._cacheIndex=d.length;d.push(a);f.actionByRoot[c]=a},_removeInactiveAction:function(a){var b=this._actions,c=b[b.length-1],d=a._cacheIndex;c._cacheIndex=d;b[d]=c;b.pop();a._cacheIndex=null;var b=a._clip.uuid,c=this._actionsByClip,d=c[b],e=d.knownActions,f=e[e.length-1],g=a._byClipCacheIndex;
f._byClipCacheIndex=g;e[g]=f;e.pop();a._byClipCacheIndex=null;delete d.actionByRoot[(a._localRoot||this._root).uuid];0===e.length&&delete c[b];this._removeInactiveBindingsForAction(a)},_removeInactiveBindingsForAction:function(a){a=a._propertyBindings;for(var b=0,c=a.length;b!==c;++b){var d=a[b];0===--d.referenceCount&&this._removeInactiveBinding(d)}},_lendAction:function(a){var b=this._actions,c=a._cacheIndex,d=this._nActiveActions++,e=b[d];a._cacheIndex=d;b[d]=a;e._cacheIndex=c;b[c]=e},_takeBackAction:function(a){var b=
this._actions,c=a._cacheIndex,d=--this._nActiveActions,e=b[d];a._cacheIndex=d;b[d]=a;e._cacheIndex=c;b[c]=e},_addInactiveBinding:function(a,b,c){var d=this._bindingsByRootAndName,e=d[b],f=this._bindings;void 0===e&&(e={},d[b]=e);e[c]=a;a._cacheIndex=f.length;f.push(a)},_removeInactiveBinding:function(a){var b=this._bindings,c=a.binding,d=c.rootNode.uuid,c=c.path,e=this._bindingsByRootAndName,f=e[d],g=b[b.length-1];a=a._cacheIndex;g._cacheIndex=a;b[a]=g;b.pop();delete f[c];a:{for(var h in f)break a;
delete e[d]}},_lendBinding:function(a){var b=this._bindings,c=a._cacheIndex,d=this._nActiveBindings++,e=b[d];a._cacheIndex=d;b[d]=a;e._cacheIndex=c;b[c]=e},_takeBackBinding:function(a){var b=this._bindings,c=a._cacheIndex,d=--this._nActiveBindings,e=b[d];a._cacheIndex=d;b[d]=a;e._cacheIndex=c;b[c]=e},_lendControlInterpolant:function(){var a=this._controlInterpolants,b=this._nActiveControlInterpolants++,c=a[b];void 0===c&&(c=new Tc(new Float32Array(2),new Float32Array(2),1,this._controlInterpolantsResultBuffer),
c.__cacheIndex=b,a[b]=c);return c},_takeBackControlInterpolant:function(a){var b=this._controlInterpolants,c=a.__cacheIndex,d=--this._nActiveControlInterpolants,e=b[d];a.__cacheIndex=d;b[d]=a;e.__cacheIndex=c;b[c]=e},_controlInterpolantsResultBuffer:new Float32Array(1),clipAction:function(a,b){var c=b||this._root,d=c.uuid,c="string"===typeof a?Ba.findByName(c,a):a;a=null!==c?c.uuid:a;var e=this._actionsByClip[a],f=null;if(void 0!==e){f=e.actionByRoot[d];if(void 0!==f)return f;f=e.knownActions[0];
null===c&&(c=f._clip)}if(null===c)return null;b=new Ye(this,c,b);this._bindAction(b,f);this._addInactiveAction(b,a,d);return b},existingAction:function(a,b){var c=b||this._root;b=c.uuid;c="string"===typeof a?Ba.findByName(c,a):a;a=this._actionsByClip[c?c.uuid:a];return void 0!==a?a.actionByRoot[b]||null:null},stopAllAction:function(){for(var a=this._actions,b=this._nActiveActions,c=this._bindings,d=this._nActiveBindings,e=this._nActiveBindings=this._nActiveActions=0;e!==b;++e)a[e].reset();for(e=0;e!==
d;++e)c[e].useCount=0;return this},update:function(a){a*=this.timeScale;for(var b=this._actions,c=this._nActiveActions,d=this.time+=a,e=Math.sign(a),f=this._accuIndex^=1,g=0;g!==c;++g)b[g]._update(d,a,e,f);a=this._bindings;b=this._nActiveBindings;for(g=0;g!==b;++g)a[g].apply(f);return this},getRoot:function(){return this._root},uncacheClip:function(a){var b=this._actions;a=a.uuid;var c=this._actionsByClip,d=c[a];if(void 0!==d){for(var d=d.knownActions,e=0,f=d.length;e!==f;++e){var g=d[e];this._deactivateAction(g);
var h=g._cacheIndex,k=b[b.length-1];g._cacheIndex=null;g._byClipCacheIndex=null;k._cacheIndex=h;b[h]=k;b.pop();this._removeInactiveBindingsForAction(g)}delete c[a]}},uncacheRoot:function(a){a=a.uuid;var b=this._actionsByClip;for(d in b){var c=b[d].actionByRoot[a];void 0!==c&&(this._deactivateAction(c),this._removeInactiveAction(c))}var d=this._bindingsByRootAndName[a];if(void 0!==d)for(var e in d)a=d[e],a.restoreOriginalState(),this._removeInactiveBinding(a)},uncacheAction:function(a,b){a=this.existingAction(a,
b);null!==a&&(this._deactivateAction(a),this._removeInactiveAction(a))}});Id.prototype.clone=function(){return new Id(void 0===this.value.clone?this.value:this.value.clone())};me.prototype=Object.assign(Object.create(F.prototype),{constructor:me,isInstancedBufferGeometry:!0,addGroup:function(a,b,c){this.groups.push({start:a,count:b,materialIndex:c})},copy:function(a){var b=a.index;null!==b&&this.setIndex(b.clone());var b=a.attributes;for(c in b)this.addAttribute(c,b[c].clone());a=a.groups;var c=0;
for(b=a.length;c<b;c++){var d=a[c];this.addGroup(d.start,d.count,d.materialIndex)}return this}});Object.defineProperties(ne.prototype,{count:{get:function(){return this.data.count}},array:{get:function(){return this.data.array}}});Object.assign(ne.prototype,{isInterleavedBufferAttribute:!0,setX:function(a,b){this.data.array[a*this.data.stride+this.offset]=b;return this},setY:function(a,b){this.data.array[a*this.data.stride+this.offset+1]=b;return this},setZ:function(a,b){this.data.array[a*this.data.stride+
this.offset+2]=b;return this},setW:function(a,b){this.data.array[a*this.data.stride+this.offset+3]=b;return this},getX:function(a){return this.data.array[a*this.data.stride+this.offset]},getY:function(a){return this.data.array[a*this.data.stride+this.offset+1]},getZ:function(a){return this.data.array[a*this.data.stride+this.offset+2]},getW:function(a){return this.data.array[a*this.data.stride+this.offset+3]},setXY:function(a,b,c){a=a*this.data.stride+this.offset;this.data.array[a+0]=b;this.data.array[a+
1]=c;return this},setXYZ:function(a,b,c,d){a=a*this.data.stride+this.offset;this.data.array[a+0]=b;this.data.array[a+1]=c;this.data.array[a+2]=d;return this},setXYZW:function(a,b,c,d,e){a=a*this.data.stride+this.offset;this.data.array[a+0]=b;this.data.array[a+1]=c;this.data.array[a+2]=d;this.data.array[a+3]=e;return this}});Object.defineProperty(hc.prototype,"needsUpdate",{set:function(a){!0===a&&this.version++}});Object.assign(hc.prototype,{isInterleavedBuffer:!0,setArray:function(a){if(Array.isArray(a))throw new TypeError("THREE.BufferAttribute: array should be a Typed Array.");
this.count=void 0!==a?a.length/this.stride:0;this.array=a},setDynamic:function(a){this.dynamic=a;return this},copy:function(a){this.array=new a.array.constructor(a.array);this.count=a.count;this.stride=a.stride;this.dynamic=a.dynamic;return this},copyAt:function(a,b,c){a*=this.stride;c*=b.stride;for(var d=0,e=this.stride;d<e;d++)this.array[a+d]=b.array[c+d];return this},set:function(a,b){void 0===b&&(b=0);this.array.set(a,b);return this},clone:function(){return(new this.constructor).copy(this)},onUpload:function(a){this.onUploadCallback=
a;return this}});oe.prototype=Object.assign(Object.create(hc.prototype),{constructor:oe,isInstancedInterleavedBuffer:!0,copy:function(a){hc.prototype.copy.call(this,a);this.meshPerAttribute=a.meshPerAttribute;return this}});pe.prototype=Object.assign(Object.create(K.prototype),{constructor:pe,isInstancedBufferAttribute:!0,copy:function(a){K.prototype.copy.call(this,a);this.meshPerAttribute=a.meshPerAttribute;return this}});Object.assign($e.prototype,{linePrecision:1,set:function(a,b){this.ray.set(a,
b)},setFromCamera:function(a,b){b&&b.isPerspectiveCamera?(this.ray.origin.setFromMatrixPosition(b.matrixWorld),this.ray.direction.set(a.x,a.y,.5).unproject(b).sub(this.ray.origin).normalize()):b&&b.isOrthographicCamera?(this.ray.origin.set(a.x,a.y,(b.near+b.far)/(b.near-b.far)).unproject(b),this.ray.direction.set(0,0,-1).transformDirection(b.matrixWorld)):console.error("THREE.Raycaster: Unsupported camera type.")},intersectObject:function(a,b){var c=[];qe(a,this,c,b);c.sort(af);return c},intersectObjects:function(a,
b){var c=[];if(!1===Array.isArray(a))return console.warn("THREE.Raycaster.intersectObjects: objects is not an Array."),c;for(var d=0,e=a.length;d<e;d++)qe(a[d],this,c,b);c.sort(af);return c}});Object.assign(bf.prototype,{start:function(){this.oldTime=this.startTime=("undefined"===typeof performance?Date:performance).now();this.elapsedTime=0;this.running=!0},stop:function(){this.getElapsedTime();this.autoStart=this.running=!1},getElapsedTime:function(){this.getDelta();return this.elapsedTime},getDelta:function(){var a=
0;if(this.autoStart&&!this.running)return this.start(),0;if(this.running){var b=("undefined"===typeof performance?Date:performance).now(),a=(b-this.oldTime)/1E3;this.oldTime=b;this.elapsedTime+=a}return a}});Object.assign(cf.prototype,{set:function(a,b,c){this.radius=a;this.phi=b;this.theta=c;return this},clone:function(){return(new this.constructor).copy(this)},copy:function(a){this.radius=a.radius;this.phi=a.phi;this.theta=a.theta;return this},makeSafe:function(){this.phi=Math.max(1E-6,Math.min(Math.PI-
1E-6,this.phi));return this},setFromVector3:function(a){this.radius=a.length();0===this.radius?this.phi=this.theta=0:(this.theta=Math.atan2(a.x,a.z),this.phi=Math.acos(R.clamp(a.y/this.radius,-1,1)));return this}});Object.assign(df.prototype,{set:function(a,b,c){this.radius=a;this.theta=b;this.y=c;return this},clone:function(){return(new this.constructor).copy(this)},copy:function(a){this.radius=a.radius;this.theta=a.theta;this.y=a.y;return this},setFromVector3:function(a){this.radius=Math.sqrt(a.x*
a.x+a.z*a.z);this.theta=Math.atan2(a.x,a.z);this.y=a.y;return this}});Yc.prototype=Object.create(w.prototype);Yc.prototype.constructor=Yc;Yc.prototype.isImmediateRenderObject=!0;Zc.prototype=Object.create(X.prototype);Zc.prototype.constructor=Zc;Zc.prototype.update=function(){var a=new n,b=new n,c=new qa;return function(){var d,e=["a","b","c"];this.object.updateMatrixWorld(!0);c.getNormalMatrix(this.object.matrixWorld);var f=this.object.matrixWorld,g=this.geometry.attributes.position;if((d=this.object.geometry)&&
d.isGeometry)for(var h=d.vertices,k=d.faces,l=d=0,m=k.length;l<m;l++)for(var n=k[l],t=0,r=n.vertexNormals.length;t<r;t++){var v=n.vertexNormals[t];a.copy(h[n[e[t]]]).applyMatrix4(f);b.copy(v).applyMatrix3(c).normalize().multiplyScalar(this.size).add(a);g.setXYZ(d,a.x,a.y,a.z);d+=1;g.setXYZ(d,b.x,b.y,b.z);d+=1}else if(d&&d.isBufferGeometry)for(e=d.attributes.position,h=d.attributes.normal,t=d=0,r=e.count;t<r;t++)a.set(e.getX(t),e.getY(t),e.getZ(t)).applyMatrix4(f),b.set(h.getX(t),h.getY(t),h.getZ(t)),
b.applyMatrix3(c).normalize().multiplyScalar(this.size).add(a),g.setXYZ(d,a.x,a.y,a.z),d+=1,g.setXYZ(d,b.x,b.y,b.z),d+=1;g.needsUpdate=!0}}();ic.prototype=Object.create(w.prototype);ic.prototype.constructor=ic;ic.prototype.dispose=function(){this.cone.geometry.dispose();this.cone.material.dispose()};ic.prototype.update=function(){var a=new n,b=new n;return function(){this.light.updateMatrixWorld();var c=this.light.distance?this.light.distance:1E3,d=c*Math.tan(this.light.angle);this.cone.scale.set(d,
d,c);a.setFromMatrixPosition(this.light.matrixWorld);b.setFromMatrixPosition(this.light.target.matrixWorld);this.cone.lookAt(b.sub(a));void 0!==this.color?this.cone.material.color.set(this.color):this.cone.material.color.copy(this.light.color)}}();jc.prototype=Object.create(X.prototype);jc.prototype.constructor=jc;jc.prototype.onBeforeRender=function(){var a=new n,b=new O,c=new O;return function(){var d=this.bones,e=this.geometry,f=e.getAttribute("position");c.getInverse(this.root.matrixWorld);for(var g=
0,h=0;g<d.length;g++){var k=d[g];k.parent&&k.parent.isBone&&(b.multiplyMatrices(c,k.matrixWorld),a.setFromMatrixPosition(b),f.setXYZ(h,a.x,a.y,a.z),b.multiplyMatrices(c,k.parent.matrixWorld),a.setFromMatrixPosition(b),f.setXYZ(h+1,a.x,a.y,a.z),h+=2)}e.getAttribute("position").needsUpdate=!0}}();kc.prototype=Object.create(fa.prototype);kc.prototype.constructor=kc;kc.prototype.dispose=function(){this.geometry.dispose();this.material.dispose()};kc.prototype.update=function(){void 0!==this.color?this.material.color.set(this.color):
this.material.color.copy(this.light.color)};lc.prototype=Object.create(w.prototype);lc.prototype.constructor=lc;lc.prototype.dispose=function(){this.children[0].geometry.dispose();this.children[0].material.dispose()};lc.prototype.update=function(){var a=.5*this.light.width,b=.5*this.light.height,c=this.line.geometry.attributes.position,d=c.array;d[0]=a;d[1]=-b;d[2]=0;d[3]=a;d[4]=b;d[5]=0;d[6]=-a;d[7]=b;d[8]=0;d[9]=-a;d[10]=-b;d[11]=0;d[12]=a;d[13]=-b;d[14]=0;c.needsUpdate=!0;void 0!==this.color?this.line.material.color.set(this.color):
this.line.material.color.copy(this.light.color)};mc.prototype=Object.create(w.prototype);mc.prototype.constructor=mc;mc.prototype.dispose=function(){this.children[0].geometry.dispose();this.children[0].material.dispose()};mc.prototype.update=function(){var a=new n,b=new C,c=new C;return function(){var d=this.children[0];if(void 0!==this.color)this.material.color.set(this.color);else{var e=d.geometry.getAttribute("color");b.copy(this.light.color);c.copy(this.light.groundColor);for(var f=0,g=e.count;f<
g;f++){var h=f<g/2?b:c;e.setXYZ(f,h.r,h.g,h.b)}e.needsUpdate=!0}d.lookAt(a.setFromMatrixPosition(this.light.matrixWorld).negate())}}();$c.prototype=Object.create(X.prototype);$c.prototype.constructor=$c;Jd.prototype=Object.create(X.prototype);Jd.prototype.constructor=Jd;ad.prototype=Object.create(X.prototype);ad.prototype.constructor=ad;ad.prototype.update=function(){var a=new n,b=new n,c=new qa;return function(){this.object.updateMatrixWorld(!0);c.getNormalMatrix(this.object.matrixWorld);for(var d=
this.object.matrixWorld,e=this.geometry.attributes.position,f=this.object.geometry,g=f.vertices,f=f.faces,h=0,k=0,l=f.length;k<l;k++){var m=f[k],n=m.normal;a.copy(g[m.a]).add(g[m.b]).add(g[m.c]).divideScalar(3).applyMatrix4(d);b.copy(n).applyMatrix3(c).normalize().multiplyScalar(this.size).add(a);e.setXYZ(h,a.x,a.y,a.z);h+=1;e.setXYZ(h,b.x,b.y,b.z);h+=1}e.needsUpdate=!0}}();nc.prototype=Object.create(w.prototype);nc.prototype.constructor=nc;nc.prototype.dispose=function(){this.lightPlane.geometry.dispose();
this.lightPlane.material.dispose();this.targetLine.geometry.dispose();this.targetLine.material.dispose()};nc.prototype.update=function(){var a=new n,b=new n,c=new n;return function(){a.setFromMatrixPosition(this.light.matrixWorld);b.setFromMatrixPosition(this.light.target.matrixWorld);c.subVectors(b,a);this.lightPlane.lookAt(c);void 0!==this.color?(this.lightPlane.material.color.set(this.color),this.targetLine.material.color.set(this.color)):(this.lightPlane.material.color.copy(this.light.color),
this.targetLine.material.color.copy(this.light.color));this.targetLine.lookAt(c);this.targetLine.scale.z=c.length()}}();bd.prototype=Object.create(X.prototype);bd.prototype.constructor=bd;bd.prototype.update=function(){function a(a,g,h,k){d.set(g,h,k).unproject(e);a=c[a];if(void 0!==a)for(g=b.getAttribute("position"),h=0,k=a.length;h<k;h++)g.setXYZ(a[h],d.x,d.y,d.z)}var b,c,d=new n,e=new Ma;return function(){b=this.geometry;c=this.pointMap;e.projectionMatrix.copy(this.camera.projectionMatrix);a("c",
0,0,-1);a("t",0,0,1);a("n1",-1,-1,-1);a("n2",1,-1,-1);a("n3",-1,1,-1);a("n4",1,1,-1);a("f1",-1,-1,1);a("f2",1,-1,1);a("f3",-1,1,1);a("f4",1,1,1);a("u1",.7,1.1,-1);a("u2",-.7,1.1,-1);a("u3",0,2,-1);a("cf1",-1,0,1);a("cf2",1,0,1);a("cf3",0,-1,1);a("cf4",0,1,1);a("cn1",-1,0,-1);a("cn2",1,0,-1);a("cn3",0,-1,-1);a("cn4",0,1,-1);b.getAttribute("position").needsUpdate=!0}}();yb.prototype=Object.create(X.prototype);yb.prototype.constructor=yb;yb.prototype.update=function(){var a=new Pa;return function(b){void 0!==
b&&console.warn("THREE.BoxHelper: .update() has no longer arguments.");void 0!==this.object&&a.setFromObject(this.object);if(!a.isEmpty()){b=a.min;var c=a.max,d=this.geometry.attributes.position,e=d.array;e[0]=c.x;e[1]=c.y;e[2]=c.z;e[3]=b.x;e[4]=c.y;e[5]=c.z;e[6]=b.x;e[7]=b.y;e[8]=c.z;e[9]=c.x;e[10]=b.y;e[11]=c.z;e[12]=c.x;e[13]=c.y;e[14]=b.z;e[15]=b.x;e[16]=c.y;e[17]=b.z;e[18]=b.x;e[19]=b.y;e[20]=b.z;e[21]=c.x;e[22]=b.y;e[23]=b.z;d.needsUpdate=!0;this.geometry.computeBoundingSphere()}}}();yb.prototype.setFromObject=
function(a){this.object=a;this.update();return this};cd.prototype=Object.create(X.prototype);cd.prototype.constructor=cd;cd.prototype.onBeforeRender=function(){var a=this.box;a.isEmpty()||(a.getCenter(this.position),a.getSize(this.scale),this.scale.multiplyScalar(.5))};dd.prototype=Object.create(ra.prototype);dd.prototype.constructor=dd;dd.prototype.onBeforeRender=function(){var a=-this.plane.constant;1E-8>Math.abs(a)&&(a=1E-8);this.scale.set(.5*this.size,.5*this.size,a);this.lookAt(this.plane.normal);
this.updateMatrixWorld()};var Kd,re;zb.prototype=Object.create(w.prototype);zb.prototype.constructor=zb;zb.prototype.setDirection=function(){var a=new n,b;return function(c){.99999<c.y?this.quaternion.set(0,0,0,1):-.99999>c.y?this.quaternion.set(1,0,0,0):(a.set(c.z,0,-c.x).normalize(),b=Math.acos(c.y),this.quaternion.setFromAxisAngle(a,b))}}();zb.prototype.setLength=function(a,b,c){void 0===b&&(b=.2*a);void 0===c&&(c=.2*b);this.line.scale.set(1,Math.max(0,a-b),1);this.line.updateMatrix();this.cone.scale.set(c,
b,c);this.cone.position.y=a;this.cone.updateMatrix()};zb.prototype.setColor=function(a){this.line.material.color.copy(a);this.cone.material.color.copy(a)};Ld.prototype=Object.create(X.prototype);Ld.prototype.constructor=Ld;var Od=new n,ve=new se,we=new se,xe=new se;Ja.prototype=Object.create(pa.prototype);Ja.prototype.constructor=Ja;Ja.prototype.getPoint=function(a){var b=this.points,c=b.length;a*=c-(this.closed?0:1);var d=Math.floor(a);a-=d;this.closed?d+=0<d?0:(Math.floor(Math.abs(d)/b.length)+
1)*b.length:0===a&&d===c-1&&(d=c-2,a=1);if(this.closed||0<d)var e=b[(d-1)%c];else Od.subVectors(b[0],b[1]).add(b[0]),e=Od;var f=b[d%c];var g=b[(d+1)%c];this.closed||d+2<c?b=b[(d+2)%c]:(Od.subVectors(b[c-1],b[c-2]).add(b[c-1]),b=Od);if(void 0===this.type||"centripetal"===this.type||"chordal"===this.type){var h="chordal"===this.type?.5:.25,c=Math.pow(e.distanceToSquared(f),h),d=Math.pow(f.distanceToSquared(g),h),h=Math.pow(g.distanceToSquared(b),h);1E-4>d&&(d=1);1E-4>c&&(c=d);1E-4>h&&(h=d);ve.initNonuniformCatmullRom(e.x,
f.x,g.x,b.x,c,d,h);we.initNonuniformCatmullRom(e.y,f.y,g.y,b.y,c,d,h);xe.initNonuniformCatmullRom(e.z,f.z,g.z,b.z,c,d,h)}else"catmullrom"===this.type&&(c=void 0!==this.tension?this.tension:.5,ve.initCatmullRom(e.x,f.x,g.x,b.x,c),we.initCatmullRom(e.y,f.y,g.y,b.y,c),xe.initCatmullRom(e.z,f.z,g.z,b.z,c));return new n(ve.calc(a),we.calc(a),xe.calc(a))};ed.prototype=Object.create(pa.prototype);ed.prototype.constructor=ed;ed.prototype.getPoint=function(a){var b=this.v0,c=this.v1,d=this.v2,e=this.v3;return new n(vb(a,
b.x,c.x,d.x,e.x),vb(a,b.y,c.y,d.y,e.y),vb(a,b.z,c.z,d.z,e.z))};fd.prototype=Object.create(pa.prototype);fd.prototype.constructor=fd;fd.prototype.getPoint=function(a){var b=this.v0,c=this.v1,d=this.v2;return new n(ub(a,b.x,c.x,d.x),ub(a,b.y,c.y,d.y),ub(a,b.z,c.z,d.z))};gd.prototype=Object.create(pa.prototype);gd.prototype.constructor=gd;gd.prototype.getPoint=function(a){if(1===a)return this.v2.clone();var b=new n;b.subVectors(this.v2,this.v1);b.multiplyScalar(a);b.add(this.v1);return b};Md.prototype=
Object.create(Ua.prototype);Md.prototype.constructor=Md;pa.create=function(a,b){console.log("THREE.Curve.create() has been deprecated");a.prototype=Object.create(pa.prototype);a.prototype.constructor=a;a.prototype.getPoint=b;return a};ff.prototype=Object.create(Ja.prototype);gf.prototype=Object.create(Ja.prototype);te.prototype=Object.create(Ja.prototype);Object.assign(te.prototype,{initFromArray:function(a){console.error("THREE.Spline: .initFromArray() has been removed.")},getControlPointsArray:function(a){console.error("THREE.Spline: .getControlPointsArray() has been removed.")},
reparametrizeByArcLength:function(a){console.error("THREE.Spline: .reparametrizeByArcLength() has been removed.")}});$c.prototype.setColors=function(){console.error("THREE.GridHelper: setColors() has been deprecated, pass them in the constructor instead.")};jc.prototype.update=function(){console.error("THREE.SkeletonHelper: update() no longer needs to be called.")};Object.assign(id.prototype,{center:function(a){console.warn("THREE.Box2: .center() has been renamed to .getCenter().");return this.getCenter(a)},
empty:function(){console.warn("THREE.Box2: .empty() has been renamed to .isEmpty().");return this.isEmpty()},isIntersectionBox:function(a){console.warn("THREE.Box2: .isIntersectionBox() has been renamed to .intersectsBox().");return this.intersectsBox(a)},size:function(a){console.warn("THREE.Box2: .size() has been renamed to .getSize().");return this.getSize(a)}});Object.assign(Pa.prototype,{center:function(a){console.warn("THREE.Box3: .center() has been renamed to .getCenter().");return this.getCenter(a)},
empty:function(){console.warn("THREE.Box3: .empty() has been renamed to .isEmpty().");return this.isEmpty()},isIntersectionBox:function(a){console.warn("THREE.Box3: .isIntersectionBox() has been renamed to .intersectsBox().");return this.intersectsBox(a)},isIntersectionSphere:function(a){console.warn("THREE.Box3: .isIntersectionSphere() has been renamed to .intersectsSphere().");return this.intersectsSphere(a)},size:function(a){console.warn("THREE.Box3: .size() has been renamed to .getSize().");return this.getSize(a)}});
Fb.prototype.center=function(a){console.warn("THREE.Line3: .center() has been renamed to .getCenter().");return this.getCenter(a)};R.random16=function(){console.warn("THREE.Math.random16() has been deprecated. Use Math.random() instead.");return Math.random()};Object.assign(qa.prototype,{flattenToArrayOffset:function(a,b){console.warn("THREE.Matrix3: .flattenToArrayOffset() has been deprecated. Use .toArray() instead.");return this.toArray(a,b)},multiplyVector3:function(a){console.warn("THREE.Matrix3: .multiplyVector3() has been removed. Use vector.applyMatrix3( matrix ) instead.");
return a.applyMatrix3(this)},multiplyVector3Array:function(a){console.error("THREE.Matrix3: .multiplyVector3Array() has been removed.")},applyToBuffer:function(a,b,c){console.warn("THREE.Matrix3: .applyToBuffer() has been removed. Use matrix.applyToBufferAttribute( attribute ) instead.");return this.applyToBufferAttribute(a)},applyToVector3Array:function(a,b,c){console.error("THREE.Matrix3: .applyToVector3Array() has been removed.")}});Object.assign(O.prototype,{extractPosition:function(a){console.warn("THREE.Matrix4: .extractPosition() has been renamed to .copyPosition().");
return this.copyPosition(a)},flattenToArrayOffset:function(a,b){console.warn("THREE.Matrix4: .flattenToArrayOffset() has been deprecated. Use .toArray() instead.");return this.toArray(a,b)},getPosition:function(){var a;return function(){void 0===a&&(a=new n);console.warn("THREE.Matrix4: .getPosition() has been removed. Use Vector3.setFromMatrixPosition( matrix ) instead.");return a.setFromMatrixColumn(this,3)}}(),setRotationFromQuaternion:function(a){console.warn("THREE.Matrix4: .setRotationFromQuaternion() has been renamed to .makeRotationFromQuaternion().");
return this.makeRotationFromQuaternion(a)},multiplyToArray:function(){console.warn("THREE.Matrix4: .multiplyToArray() has been removed.")},multiplyVector3:function(a){console.warn("THREE.Matrix4: .multiplyVector3() has been removed. Use vector.applyMatrix4( matrix ) instead.");return a.applyMatrix4(this)},multiplyVector4:function(a){console.warn("THREE.Matrix4: .multiplyVector4() has been removed. Use vector.applyMatrix4( matrix ) instead.");return a.applyMatrix4(this)},multiplyVector3Array:function(a){console.error("THREE.Matrix4: .multiplyVector3Array() has been removed.")},
rotateAxis:function(a){console.warn("THREE.Matrix4: .rotateAxis() has been removed. Use Vector3.transformDirection( matrix ) instead.");a.transformDirection(this)},crossVector:function(a){console.warn("THREE.Matrix4: .crossVector() has been removed. Use vector.applyMatrix4( matrix ) instead.");return a.applyMatrix4(this)},translate:function(){console.error("THREE.Matrix4: .translate() has been removed.")},rotateX:function(){console.error("THREE.Matrix4: .rotateX() has been removed.")},rotateY:function(){console.error("THREE.Matrix4: .rotateY() has been removed.")},
rotateZ:function(){console.error("THREE.Matrix4: .rotateZ() has been removed.")},rotateByAxis:function(){console.error("THREE.Matrix4: .rotateByAxis() has been removed.")},applyToBuffer:function(a,b,c){console.warn("THREE.Matrix4: .applyToBuffer() has been removed. Use matrix.applyToBufferAttribute( attribute ) instead.");return this.applyToBufferAttribute(a)},applyToVector3Array:function(a,b,c){console.error("THREE.Matrix4: .applyToVector3Array() has been removed.")},makeFrustum:function(a,b,c,d,
e,f){console.warn("THREE.Matrix4: .makeFrustum() has been removed. Use .makePerspective( left, right, top, bottom, near, far ) instead.");return this.makePerspective(a,b,d,c,e,f)}});za.prototype.isIntersectionLine=function(a){console.warn("THREE.Plane: .isIntersectionLine() has been renamed to .intersectsLine().");return this.intersectsLine(a)};ia.prototype.multiplyVector3=function(a){console.warn("THREE.Quaternion: .multiplyVector3() has been removed. Use is now vector.applyQuaternion( quaternion ) instead.");
return a.applyQuaternion(this)};Object.assign(hb.prototype,{isIntersectionBox:function(a){console.warn("THREE.Ray: .isIntersectionBox() has been renamed to .intersectsBox().");return this.intersectsBox(a)},isIntersectionPlane:function(a){console.warn("THREE.Ray: .isIntersectionPlane() has been renamed to .intersectsPlane().");return this.intersectsPlane(a)},isIntersectionSphere:function(a){console.warn("THREE.Ray: .isIntersectionSphere() has been renamed to .intersectsSphere().");return this.intersectsSphere(a)}});
Object.assign(xb.prototype,{extrude:function(a){console.warn("THREE.Shape: .extrude() has been removed. Use ExtrudeGeometry() instead.");return new $a(this,a)},makeGeometry:function(a){console.warn("THREE.Shape: .makeGeometry() has been removed. Use ShapeGeometry() instead.");return new Wb(this,a)}});Object.assign(D.prototype,{fromAttribute:function(a,b,c){console.error("THREE.Vector2: .fromAttribute() has been renamed to .fromBufferAttribute().");return this.fromBufferAttribute(a,b,c)}});Object.assign(n.prototype,
{setEulerFromRotationMatrix:function(){console.error("THREE.Vector3: .setEulerFromRotationMatrix() has been removed. Use Euler.setFromRotationMatrix() instead.")},setEulerFromQuaternion:function(){console.error("THREE.Vector3: .setEulerFromQuaternion() has been removed. Use Euler.setFromQuaternion() instead.")},getPositionFromMatrix:function(a){console.warn("THREE.Vector3: .getPositionFromMatrix() has been renamed to .setFromMatrixPosition().");return this.setFromMatrixPosition(a)},getScaleFromMatrix:function(a){console.warn("THREE.Vector3: .getScaleFromMatrix() has been renamed to .setFromMatrixScale().");
return this.setFromMatrixScale(a)},getColumnFromMatrix:function(a,b){console.warn("THREE.Vector3: .getColumnFromMatrix() has been renamed to .setFromMatrixColumn().");return this.setFromMatrixColumn(b,a)},applyProjection:function(a){console.warn("THREE.Vector3: .applyProjection() has been removed. Use .applyMatrix4( m ) instead.");return this.applyMatrix4(a)},fromAttribute:function(a,b,c){console.error("THREE.Vector3: .fromAttribute() has been renamed to .fromBufferAttribute().");return this.fromBufferAttribute(a,
b,c)}});Object.assign(S.prototype,{fromAttribute:function(a,b,c){console.error("THREE.Vector4: .fromAttribute() has been renamed to .fromBufferAttribute().");return this.fromBufferAttribute(a,b,c)}});Q.prototype.computeTangents=function(){console.warn("THREE.Geometry: .computeTangents() has been removed.")};Object.assign(w.prototype,{getChildByName:function(a){console.warn("THREE.Object3D: .getChildByName() has been renamed to .getObjectByName().");return this.getObjectByName(a)},renderDepth:function(){console.warn("THREE.Object3D: .renderDepth has been removed. Use .renderOrder, instead.")},
translate:function(a,b){console.warn("THREE.Object3D: .translate() has been removed. Use .translateOnAxis( axis, distance ) instead.");return this.translateOnAxis(b,a)}});Object.defineProperties(w.prototype,{eulerOrder:{get:function(){console.warn("THREE.Object3D: .eulerOrder is now .rotation.order.");return this.rotation.order},set:function(a){console.warn("THREE.Object3D: .eulerOrder is now .rotation.order.");this.rotation.order=a}},useQuaternion:{get:function(){console.warn("THREE.Object3D: .useQuaternion has been removed. The library now uses quaternions by default.")},
set:function(){console.warn("THREE.Object3D: .useQuaternion has been removed. The library now uses quaternions by default.")}}});Object.defineProperties(yc.prototype,{objects:{get:function(){console.warn("THREE.LOD: .objects has been renamed to .levels.");return this.levels}}});Object.defineProperty(zc.prototype,"useVertexTexture",{get:function(){console.warn("THREE.Skeleton: useVertexTexture has been removed.")},set:function(){console.warn("THREE.Skeleton: useVertexTexture has been removed.")}});
Object.defineProperty(pa.prototype,"__arcLengthDivisions",{get:function(){console.warn("THREE.Curve: .__arcLengthDivisions is now .arcLengthDivisions.");return this.arcLengthDivisions},set:function(a){console.warn("THREE.Curve: .__arcLengthDivisions is now .arcLengthDivisions.");this.arcLengthDivisions=a}});ja.prototype.setLens=function(a,b){console.warn("THREE.PerspectiveCamera.setLens is deprecated. Use .setFocalLength and .filmGauge for a photographic setup.");void 0!==b&&(this.filmGauge=b);this.setFocalLength(a)};
Object.defineProperties(aa.prototype,{onlyShadow:{set:function(){console.warn("THREE.Light: .onlyShadow has been removed.")}},shadowCameraFov:{set:function(a){console.warn("THREE.Light: .shadowCameraFov is now .shadow.camera.fov.");this.shadow.camera.fov=a}},shadowCameraLeft:{set:function(a){console.warn("THREE.Light: .shadowCameraLeft is now .shadow.camera.left.");this.shadow.camera.left=a}},shadowCameraRight:{set:function(a){console.warn("THREE.Light: .shadowCameraRight is now .shadow.camera.right.");
this.shadow.camera.right=a}},shadowCameraTop:{set:function(a){console.warn("THREE.Light: .shadowCameraTop is now .shadow.camera.top.");this.shadow.camera.top=a}},shadowCameraBottom:{set:function(a){console.warn("THREE.Light: .shadowCameraBottom is now .shadow.camera.bottom.");this.shadow.camera.bottom=a}},shadowCameraNear:{set:function(a){console.warn("THREE.Light: .shadowCameraNear is now .shadow.camera.near.");this.shadow.camera.near=a}},shadowCameraFar:{set:function(a){console.warn("THREE.Light: .shadowCameraFar is now .shadow.camera.far.");
this.shadow.camera.far=a}},shadowCameraVisible:{set:function(){console.warn("THREE.Light: .shadowCameraVisible has been removed. Use new THREE.CameraHelper( light.shadow.camera ) instead.")}},shadowBias:{set:function(a){console.warn("THREE.Light: .shadowBias is now .shadow.bias.");this.shadow.bias=a}},shadowDarkness:{set:function(){console.warn("THREE.Light: .shadowDarkness has been removed.")}},shadowMapWidth:{set:function(a){console.warn("THREE.Light: .shadowMapWidth is now .shadow.mapSize.width.");
this.shadow.mapSize.width=a}},shadowMapHeight:{set:function(a){console.warn("THREE.Light: .shadowMapHeight is now .shadow.mapSize.height.");this.shadow.mapSize.height=a}}});Object.defineProperties(K.prototype,{length:{get:function(){console.warn("THREE.BufferAttribute: .length has been deprecated. Use .count instead.");return this.array.length}}});Object.assign(F.prototype,{addIndex:function(a){console.warn("THREE.BufferGeometry: .addIndex() has been renamed to .setIndex().");this.setIndex(a)},addDrawCall:function(a,
b,c){void 0!==c&&console.warn("THREE.BufferGeometry: .addDrawCall() no longer supports indexOffset.");console.warn("THREE.BufferGeometry: .addDrawCall() is now .addGroup().");this.addGroup(a,b)},clearDrawCalls:function(){console.warn("THREE.BufferGeometry: .clearDrawCalls() is now .clearGroups().");this.clearGroups()},computeTangents:function(){console.warn("THREE.BufferGeometry: .computeTangents() has been removed.")},computeOffsets:function(){console.warn("THREE.BufferGeometry: .computeOffsets() has been removed.")}});
Object.defineProperties(F.prototype,{drawcalls:{get:function(){console.error("THREE.BufferGeometry: .drawcalls has been renamed to .groups.");return this.groups}},offsets:{get:function(){console.warn("THREE.BufferGeometry: .offsets has been renamed to .groups.");return this.groups}}});Object.defineProperties(Id.prototype,{dynamic:{set:function(){console.warn("THREE.Uniform: .dynamic has been removed. Use object.onBeforeRender() instead.")}},onUpdate:{value:function(){console.warn("THREE.Uniform: .onUpdate() has been removed. Use object.onBeforeRender() instead.");
return this}}});Object.defineProperties(P.prototype,{wrapAround:{get:function(){console.warn("THREE.Material: .wrapAround has been removed.")},set:function(){console.warn("THREE.Material: .wrapAround has been removed.")}},wrapRGB:{get:function(){console.warn("THREE.Material: .wrapRGB has been removed.");return new C}},shading:{get:function(){console.error("THREE."+this.type+": .shading has been removed. Use the boolean .flatShading instead.")},set:function(a){console.warn("THREE."+this.type+": .shading has been removed. Use the boolean .flatShading instead.");
this.flatShading=1===a}}});Object.defineProperties(Aa.prototype,{metal:{get:function(){console.warn("THREE.MeshPhongMaterial: .metal has been removed. Use THREE.MeshStandardMaterial instead.");return!1},set:function(){console.warn("THREE.MeshPhongMaterial: .metal has been removed. Use THREE.MeshStandardMaterial instead")}}});Object.defineProperties(ya.prototype,{derivatives:{get:function(){console.warn("THREE.ShaderMaterial: .derivatives has been moved to .extensions.derivatives.");return this.extensions.derivatives},
set:function(a){console.warn("THREE. ShaderMaterial: .derivatives has been moved to .extensions.derivatives.");this.extensions.derivatives=a}}});Object.assign(Yd.prototype,{getCurrentRenderTarget:function(){console.warn("THREE.WebGLRenderer: .getCurrentRenderTarget() is now .getRenderTarget().");return this.getRenderTarget()},getMaxAnisotropy:function(){console.warn("THREE.WebGLRenderer: .getMaxAnisotropy() is now .capabilities.getMaxAnisotropy().");return this.capabilities.getMaxAnisotropy()},getPrecision:function(){console.warn("THREE.WebGLRenderer: .getPrecision() is now .capabilities.precision.");
return this.capabilities.precision},supportsFloatTextures:function(){console.warn("THREE.WebGLRenderer: .supportsFloatTextures() is now .extensions.get( 'OES_texture_float' ).");return this.extensions.get("OES_texture_float")},supportsHalfFloatTextures:function(){console.warn("THREE.WebGLRenderer: .supportsHalfFloatTextures() is now .extensions.get( 'OES_texture_half_float' ).");return this.extensions.get("OES_texture_half_float")},supportsStandardDerivatives:function(){console.warn("THREE.WebGLRenderer: .supportsStandardDerivatives() is now .extensions.get( 'OES_standard_derivatives' ).");
return this.extensions.get("OES_standard_derivatives")},supportsCompressedTextureS3TC:function(){console.warn("THREE.WebGLRenderer: .supportsCompressedTextureS3TC() is now .extensions.get( 'WEBGL_compressed_texture_s3tc' ).");return this.extensions.get("WEBGL_compressed_texture_s3tc")},supportsCompressedTexturePVRTC:function(){console.warn("THREE.WebGLRenderer: .supportsCompressedTexturePVRTC() is now .extensions.get( 'WEBGL_compressed_texture_pvrtc' ).");return this.extensions.get("WEBGL_compressed_texture_pvrtc")},
supportsBlendMinMax:function(){console.warn("THREE.WebGLRenderer: .supportsBlendMinMax() is now .extensions.get( 'EXT_blend_minmax' ).");return this.extensions.get("EXT_blend_minmax")},supportsVertexTextures:function(){console.warn("THREE.WebGLRenderer: .supportsVertexTextures() is now .capabilities.vertexTextures.");return this.capabilities.vertexTextures},supportsInstancedArrays:function(){console.warn("THREE.WebGLRenderer: .supportsInstancedArrays() is now .extensions.get( 'ANGLE_instanced_arrays' ).");
return this.extensions.get("ANGLE_instanced_arrays")},enableScissorTest:function(a){console.warn("THREE.WebGLRenderer: .enableScissorTest() is now .setScissorTest().");this.setScissorTest(a)},initMaterial:function(){console.warn("THREE.WebGLRenderer: .initMaterial() has been removed.")},addPrePlugin:function(){console.warn("THREE.WebGLRenderer: .addPrePlugin() has been removed.")},addPostPlugin:function(){console.warn("THREE.WebGLRenderer: .addPostPlugin() has been removed.")},updateShadowMap:function(){console.warn("THREE.WebGLRenderer: .updateShadowMap() has been removed.")}});
Object.defineProperties(Yd.prototype,{shadowMapEnabled:{get:function(){return this.shadowMap.enabled},set:function(a){console.warn("THREE.WebGLRenderer: .shadowMapEnabled is now .shadowMap.enabled.");this.shadowMap.enabled=a}},shadowMapType:{get:function(){return this.shadowMap.type},set:function(a){console.warn("THREE.WebGLRenderer: .shadowMapType is now .shadowMap.type.");this.shadowMap.type=a}},shadowMapCullFace:{get:function(){return this.shadowMap.cullFace},set:function(a){console.warn("THREE.WebGLRenderer: .shadowMapCullFace is now .shadowMap.cullFace.");
this.shadowMap.cullFace=a}}});Object.defineProperties(Ke.prototype,{cullFace:{get:function(){return this.renderReverseSided?2:1},set:function(a){a=1!==a;console.warn("WebGLRenderer: .shadowMap.cullFace is deprecated. Set .shadowMap.renderReverseSided to "+a+".");this.renderReverseSided=a}}});Object.defineProperties(Ab.prototype,{wrapS:{get:function(){console.warn("THREE.WebGLRenderTarget: .wrapS is now .texture.wrapS.");return this.texture.wrapS},set:function(a){console.warn("THREE.WebGLRenderTarget: .wrapS is now .texture.wrapS.");
this.texture.wrapS=a}},wrapT:{get:function(){console.warn("THREE.WebGLRenderTarget: .wrapT is now .texture.wrapT.");return this.texture.wrapT},set:function(a){console.warn("THREE.WebGLRenderTarget: .wrapT is now .texture.wrapT.");this.texture.wrapT=a}},magFilter:{get:function(){console.warn("THREE.WebGLRenderTarget: .magFilter is now .texture.magFilter.");return this.texture.magFilter},set:function(a){console.warn("THREE.WebGLRenderTarget: .magFilter is now .texture.magFilter.");this.texture.magFilter=
a}},minFilter:{get:function(){console.warn("THREE.WebGLRenderTarget: .minFilter is now .texture.minFilter.");return this.texture.minFilter},set:function(a){console.warn("THREE.WebGLRenderTarget: .minFilter is now .texture.minFilter.");this.texture.minFilter=a}},anisotropy:{get:function(){console.warn("THREE.WebGLRenderTarget: .anisotropy is now .texture.anisotropy.");return this.texture.anisotropy},set:function(a){console.warn("THREE.WebGLRenderTarget: .anisotropy is now .texture.anisotropy.");this.texture.anisotropy=
a}},offset:{get:function(){console.warn("THREE.WebGLRenderTarget: .offset is now .texture.offset.");return this.texture.offset},set:function(a){console.warn("THREE.WebGLRenderTarget: .offset is now .texture.offset.");this.texture.offset=a}},repeat:{get:function(){console.warn("THREE.WebGLRenderTarget: .repeat is now .texture.repeat.");return this.texture.repeat},set:function(a){console.warn("THREE.WebGLRenderTarget: .repeat is now .texture.repeat.");this.texture.repeat=a}},format:{get:function(){console.warn("THREE.WebGLRenderTarget: .format is now .texture.format.");
return this.texture.format},set:function(a){console.warn("THREE.WebGLRenderTarget: .format is now .texture.format.");this.texture.format=a}},type:{get:function(){console.warn("THREE.WebGLRenderTarget: .type is now .texture.type.");return this.texture.type},set:function(a){console.warn("THREE.WebGLRenderTarget: .type is now .texture.type.");this.texture.type=a}},generateMipmaps:{get:function(){console.warn("THREE.WebGLRenderTarget: .generateMipmaps is now .texture.generateMipmaps.");return this.texture.generateMipmaps},
set:function(a){console.warn("THREE.WebGLRenderTarget: .generateMipmaps is now .texture.generateMipmaps.");this.texture.generateMipmaps=a}}});gc.prototype.load=function(a){console.warn("THREE.Audio: .load has been deprecated. Use THREE.AudioLoader instead.");var b=this;(new ge).load(a,function(a){b.setBuffer(a)});return this};ke.prototype.getData=function(){console.warn("THREE.AudioAnalyser: .getData() is now .getFrequencyData().");return this.getFrequencyData()};Xc.prototype.updateCubeMap=function(a,
b){console.warn("THREE.CubeCamera: .updateCubeMap() is now .update().");return this.update(a,b)};m.WebGLRenderTargetCube=Bb;m.WebGLRenderTarget=Ab;m.WebGLRenderer=Yd;m.ShaderLib=ib;m.UniformsLib=L;m.UniformsUtils=Da;m.ShaderChunk=V;m.FogExp2=Hb;m.Fog=Ib;m.Scene=nd;m.LensFlare=Zd;m.Sprite=xc;m.LOD=yc;m.SkinnedMesh=pd;m.Skeleton=zc;m.Bone=od;m.Mesh=fa;m.LineSegments=X;m.LineLoop=qd;m.Line=ra;m.Points=Jb;m.Group=Ac;m.VideoTexture=rd;m.DataTexture=bb;m.CompressedTexture=Kb;m.CubeTexture=Va;m.CanvasTexture=
oc;m.DepthTexture=Bc;m.Texture=N;m.CompressedTextureLoader=Re;m.DataTextureLoader=ae;m.CubeTextureLoader=be;m.TextureLoader=sd;m.ObjectLoader=Se;m.MaterialLoader=Hd;m.BufferGeometryLoader=ce;m.DefaultLoadingManager=oa;m.LoadingManager=$d;m.JSONLoader=de;m.ImageLoader=Sc;m.FontLoader=Ue;m.FileLoader=Ia;m.Loader=dc;m.Cache=hd;m.AudioLoader=ge;m.SpotLightShadow=ud;m.SpotLight=vd;m.PointLight=wd;m.RectAreaLight=Ad;m.HemisphereLight=td;m.DirectionalLightShadow=xd;m.DirectionalLight=yd;m.AmbientLight=zd;
m.LightShadow=rb;m.Light=aa;m.StereoCamera=Ve;m.PerspectiveCamera=ja;m.OrthographicCamera=Db;m.CubeCamera=Xc;m.ArrayCamera=md;m.Camera=Ma;m.AudioListener=he;m.PositionalAudio=je;m.AudioContext=ie;m.AudioAnalyser=ke;m.Audio=gc;m.VectorKeyframeTrack=bc;m.StringKeyframeTrack=Ed;m.QuaternionKeyframeTrack=Uc;m.NumberKeyframeTrack=cc;m.ColorKeyframeTrack=Gd;m.BooleanKeyframeTrack=Fd;m.PropertyMixer=le;m.PropertyBinding=da;m.KeyframeTrack=tb;m.AnimationUtils=ea;m.AnimationObjectGroup=Xe;m.AnimationMixer=
Ze;m.AnimationClip=Ba;m.Uniform=Id;m.InstancedBufferGeometry=me;m.BufferGeometry=F;m.GeometryIdCount=function(){return Rd++};m.Geometry=Q;m.InterleavedBufferAttribute=ne;m.InstancedInterleavedBuffer=oe;m.InterleavedBuffer=hc;m.InstancedBufferAttribute=pe;m.Face3=Qa;m.Object3D=w;m.Raycaster=$e;m.Layers=Qd;m.EventDispatcher=na;m.Clock=bf;m.QuaternionLinearInterpolant=Dd;m.LinearInterpolant=Tc;m.DiscreteInterpolant=Cd;m.CubicInterpolant=Bd;m.Interpolant=wa;m.Triangle=Ra;m.Math=R;m.Spherical=cf;m.Cylindrical=
df;m.Plane=za;m.Frustum=kd;m.Sphere=Ca;m.Ray=hb;m.Matrix4=O;m.Matrix3=qa;m.Box3=Pa;m.Box2=id;m.Line3=Fb;m.Euler=Ya;m.Vector4=S;m.Vector3=n;m.Vector2=D;m.Quaternion=ia;m.Color=C;m.ImmediateRenderObject=Yc;m.VertexNormalsHelper=Zc;m.SpotLightHelper=ic;m.SkeletonHelper=jc;m.PointLightHelper=kc;m.RectAreaLightHelper=lc;m.HemisphereLightHelper=mc;m.GridHelper=$c;m.PolarGridHelper=Jd;m.FaceNormalsHelper=ad;m.DirectionalLightHelper=nc;m.CameraHelper=bd;m.BoxHelper=yb;m.Box3Helper=cd;m.PlaneHelper=dd;m.ArrowHelper=
zb;m.AxisHelper=Ld;m.CatmullRomCurve3=Ja;m.CubicBezierCurve3=ed;m.QuadraticBezierCurve3=fd;m.LineCurve3=gd;m.ArcCurve=Md;m.EllipseCurve=Ua;m.SplineCurve=wb;m.CubicBezierCurve=ec;m.QuadraticBezierCurve=fc;m.LineCurve=Oa;m.Shape=xb;m.Path=Wc;m.ShapePath=ee;m.Font=fe;m.CurvePath=Vc;m.Curve=pa;m.ShapeUtils=Fa;m.SceneUtils={createMultiMaterialObject:function(a,b){for(var c=new Ac,d=0,e=b.length;d<e;d++)c.add(new fa(a,b[d]));return c},detach:function(a,b,c){a.applyMatrix(b.matrixWorld);b.remove(a);c.add(a)},
attach:function(a,b,c){a.applyMatrix((new O).getInverse(c.matrixWorld));b.remove(a);c.add(a)}};m.WebGLUtils=Qe;m.WireframeGeometry=Lb;m.ParametricGeometry=Cc;m.ParametricBufferGeometry=Mb;m.TetrahedronGeometry=Ec;m.TetrahedronBufferGeometry=Nb;m.OctahedronGeometry=Fc;m.OctahedronBufferGeometry=jb;m.IcosahedronGeometry=Gc;m.IcosahedronBufferGeometry=Ob;m.DodecahedronGeometry=Hc;m.DodecahedronBufferGeometry=Pb;m.PolyhedronGeometry=Dc;m.PolyhedronBufferGeometry=ua;m.TubeGeometry=Ic;m.TubeBufferGeometry=
Qb;m.TorusKnotGeometry=Jc;m.TorusKnotBufferGeometry=Rb;m.TorusGeometry=Kc;m.TorusBufferGeometry=Sb;m.TextGeometry=Lc;m.TextBufferGeometry=Tb;m.SphereGeometry=Mc;m.SphereBufferGeometry=kb;m.RingGeometry=Nc;m.RingBufferGeometry=Ub;m.PlaneGeometry=vc;m.PlaneBufferGeometry=gb;m.LatheGeometry=Oc;m.LatheBufferGeometry=Vb;m.ShapeGeometry=Wb;m.ShapeBufferGeometry=Xb;m.ExtrudeGeometry=$a;m.ExtrudeBufferGeometry=Ea;m.EdgesGeometry=Yb;m.ConeGeometry=Pc;m.ConeBufferGeometry=Qc;m.CylinderGeometry=lb;m.CylinderBufferGeometry=
Ta;m.CircleGeometry=Rc;m.CircleBufferGeometry=Zb;m.BoxGeometry=Eb;m.BoxBufferGeometry=fb;m.ShadowMaterial=$b;m.SpriteMaterial=Za;m.RawShaderMaterial=ac;m.ShaderMaterial=ya;m.PointsMaterial=ma;m.MeshPhysicalMaterial=mb;m.MeshStandardMaterial=Na;m.MeshPhongMaterial=Aa;m.MeshToonMaterial=nb;m.MeshNormalMaterial=ob;m.MeshLambertMaterial=pb;m.MeshDepthMaterial=Wa;m.MeshDistanceMaterial=Xa;m.MeshBasicMaterial=sa;m.LineDashedMaterial=qb;m.LineBasicMaterial=W;m.Material=P;m.Float64BufferAttribute=uc;m.Float32BufferAttribute=
z;m.Uint32BufferAttribute=eb;m.Int32BufferAttribute=tc;m.Uint16BufferAttribute=db;m.Int16BufferAttribute=sc;m.Uint8ClampedBufferAttribute=rc;m.Uint8BufferAttribute=qc;m.Int8BufferAttribute=pc;m.BufferAttribute=K;m.REVISION="87";m.MOUSE={LEFT:0,MIDDLE:1,RIGHT:2};m.CullFaceNone=0;m.CullFaceBack=1;m.CullFaceFront=2;m.CullFaceFrontBack=3;m.FrontFaceDirectionCW=0;m.FrontFaceDirectionCCW=1;m.BasicShadowMap=0;m.PCFShadowMap=1;m.PCFSoftShadowMap=2;m.FrontSide=0;m.BackSide=1;m.DoubleSide=2;m.FlatShading=1;
m.SmoothShading=2;m.NoColors=0;m.FaceColors=1;m.VertexColors=2;m.NoBlending=0;m.NormalBlending=1;m.AdditiveBlending=2;m.SubtractiveBlending=3;m.MultiplyBlending=4;m.CustomBlending=5;m.AddEquation=100;m.SubtractEquation=101;m.ReverseSubtractEquation=102;m.MinEquation=103;m.MaxEquation=104;m.ZeroFactor=200;m.OneFactor=201;m.SrcColorFactor=202;m.OneMinusSrcColorFactor=203;m.SrcAlphaFactor=204;m.OneMinusSrcAlphaFactor=205;m.DstAlphaFactor=206;m.OneMinusDstAlphaFactor=207;m.DstColorFactor=208;m.OneMinusDstColorFactor=
209;m.SrcAlphaSaturateFactor=210;m.NeverDepth=0;m.AlwaysDepth=1;m.LessDepth=2;m.LessEqualDepth=3;m.EqualDepth=4;m.GreaterEqualDepth=5;m.GreaterDepth=6;m.NotEqualDepth=7;m.MultiplyOperation=0;m.MixOperation=1;m.AddOperation=2;m.NoToneMapping=0;m.LinearToneMapping=1;m.ReinhardToneMapping=2;m.Uncharted2ToneMapping=3;m.CineonToneMapping=4;m.UVMapping=300;m.CubeReflectionMapping=301;m.CubeRefractionMapping=302;m.EquirectangularReflectionMapping=303;m.EquirectangularRefractionMapping=304;m.SphericalReflectionMapping=
305;m.CubeUVReflectionMapping=306;m.CubeUVRefractionMapping=307;m.RepeatWrapping=1E3;m.ClampToEdgeWrapping=1001;m.MirroredRepeatWrapping=1002;m.NearestFilter=1003;m.NearestMipMapNearestFilter=1004;m.NearestMipMapLinearFilter=1005;m.LinearFilter=1006;m.LinearMipMapNearestFilter=1007;m.LinearMipMapLinearFilter=1008;m.UnsignedByteType=1009;m.ByteType=1010;m.ShortType=1011;m.UnsignedShortType=1012;m.IntType=1013;m.UnsignedIntType=1014;m.FloatType=1015;m.HalfFloatType=1016;m.UnsignedShort4444Type=1017;
m.UnsignedShort5551Type=1018;m.UnsignedShort565Type=1019;m.UnsignedInt248Type=1020;m.AlphaFormat=1021;m.RGBFormat=1022;m.RGBAFormat=1023;m.LuminanceFormat=1024;m.LuminanceAlphaFormat=1025;m.RGBEFormat=1023;m.DepthFormat=1026;m.DepthStencilFormat=1027;m.RGB_S3TC_DXT1_Format=2001;m.RGBA_S3TC_DXT1_Format=2002;m.RGBA_S3TC_DXT3_Format=2003;m.RGBA_S3TC_DXT5_Format=2004;m.RGB_PVRTC_4BPPV1_Format=2100;m.RGB_PVRTC_2BPPV1_Format=2101;m.RGBA_PVRTC_4BPPV1_Format=2102;m.RGBA_PVRTC_2BPPV1_Format=2103;m.RGB_ETC1_Format=
2151;m.LoopOnce=2200;m.LoopRepeat=2201;m.LoopPingPong=2202;m.InterpolateDiscrete=2300;m.InterpolateLinear=2301;m.InterpolateSmooth=2302;m.ZeroCurvatureEnding=2400;m.ZeroSlopeEnding=2401;m.WrapAroundEnding=2402;m.TrianglesDrawMode=0;m.TriangleStripDrawMode=1;m.TriangleFanDrawMode=2;m.LinearEncoding=3E3;m.sRGBEncoding=3001;m.GammaEncoding=3007;m.RGBEEncoding=3002;m.LogLuvEncoding=3003;m.RGBM7Encoding=3004;m.RGBM16Encoding=3005;m.RGBDEncoding=3006;m.BasicDepthPacking=3200;m.RGBADepthPacking=3201;m.CubeGeometry=
Eb;m.Face4=function(a,b,c,d,e,f,g){console.warn("THREE.Face4 has been removed. A THREE.Face3 will be created instead.");return new Qa(a,b,c,e,f,g)};m.LineStrip=0;m.LinePieces=1;m.MeshFaceMaterial=function(a){console.warn("THREE.MeshFaceMaterial has been removed. Use an Array instead.");return a};m.MultiMaterial=function(a){void 0===a&&(a=[]);console.warn("THREE.MultiMaterial has been removed. Use an Array instead.");a.isMultiMaterial=!0;a.materials=a;a.clone=function(){return a.slice()};return a};
m.PointCloud=function(a,b){console.warn("THREE.PointCloud has been renamed to THREE.Points.");return new Jb(a,b)};m.Particle=function(a){console.warn("THREE.Particle has been renamed to THREE.Sprite.");return new xc(a)};m.ParticleSystem=function(a,b){console.warn("THREE.ParticleSystem has been renamed to THREE.Points.");return new Jb(a,b)};m.PointCloudMaterial=function(a){console.warn("THREE.PointCloudMaterial has been renamed to THREE.PointsMaterial.");return new ma(a)};m.ParticleBasicMaterial=function(a){console.warn("THREE.ParticleBasicMaterial has been renamed to THREE.PointsMaterial.");
return new ma(a)};m.ParticleSystemMaterial=function(a){console.warn("THREE.ParticleSystemMaterial has been renamed to THREE.PointsMaterial.");return new ma(a)};m.Vertex=function(a,b,c){console.warn("THREE.Vertex has been removed. Use THREE.Vector3 instead.");return new n(a,b,c)};m.DynamicBufferAttribute=function(a,b){console.warn("THREE.DynamicBufferAttribute has been removed. Use new THREE.BufferAttribute().setDynamic( true ) instead.");return(new K(a,b)).setDynamic(!0)};m.Int8Attribute=function(a,
b){console.warn("THREE.Int8Attribute has been removed. Use new THREE.Int8BufferAttribute() instead.");return new pc(a,b)};m.Uint8Attribute=function(a,b){console.warn("THREE.Uint8Attribute has been removed. Use new THREE.Uint8BufferAttribute() instead.");return new qc(a,b)};m.Uint8ClampedAttribute=function(a,b){console.warn("THREE.Uint8ClampedAttribute has been removed. Use new THREE.Uint8ClampedBufferAttribute() instead.");return new rc(a,b)};m.Int16Attribute=function(a,b){console.warn("THREE.Int16Attribute has been removed. Use new THREE.Int16BufferAttribute() instead.");
return new sc(a,b)};m.Uint16Attribute=function(a,b){console.warn("THREE.Uint16Attribute has been removed. Use new THREE.Uint16BufferAttribute() instead.");return new db(a,b)};m.Int32Attribute=function(a,b){console.warn("THREE.Int32Attribute has been removed. Use new THREE.Int32BufferAttribute() instead.");return new tc(a,b)};m.Uint32Attribute=function(a,b){console.warn("THREE.Uint32Attribute has been removed. Use new THREE.Uint32BufferAttribute() instead.");return new eb(a,b)};m.Float32Attribute=
function(a,b){console.warn("THREE.Float32Attribute has been removed. Use new THREE.Float32BufferAttribute() instead.");return new z(a,b)};m.Float64Attribute=function(a,b){console.warn("THREE.Float64Attribute has been removed. Use new THREE.Float64BufferAttribute() instead.");return new uc(a,b)};m.ClosedSplineCurve3=ff;m.SplineCurve3=gf;m.Spline=te;m.BoundingBoxHelper=function(a,b){console.warn("THREE.BoundingBoxHelper has been deprecated. Creating a THREE.BoxHelper instead.");return new yb(a,b)};
m.EdgesHelper=function(a,b){console.warn("THREE.EdgesHelper has been removed. Use THREE.EdgesGeometry instead.");return new X(new Yb(a.geometry),new W({color:void 0!==b?b:16777215}))};m.WireframeHelper=function(a,b){console.warn("THREE.WireframeHelper has been removed. Use THREE.WireframeGeometry instead.");return new X(new Lb(a.geometry),new W({color:void 0!==b?b:16777215}))};m.XHRLoader=function(a){console.warn("THREE.XHRLoader has been renamed to THREE.FileLoader.");return new Ia(a)};m.BinaryTextureLoader=
function(a){console.warn("THREE.BinaryTextureLoader has been renamed to THREE.DataTextureLoader.");return new ae(a)};m.GeometryUtils={merge:function(a,b,c){console.warn("THREE.GeometryUtils: .merge() has been moved to Geometry. Use geometry.merge( geometry2, matrix, materialIndexOffset ) instead.");if(b.isMesh){b.matrixAutoUpdate&&b.updateMatrix();var d=b.matrix;b=b.geometry}a.merge(b,d,c)},center:function(a){console.warn("THREE.GeometryUtils: .center() has been moved to Geometry. Use geometry.center() instead.");
return a.center()}};m.ImageUtils={crossOrigin:void 0,loadTexture:function(a,b,c,d){console.warn("THREE.ImageUtils.loadTexture has been deprecated. Use THREE.TextureLoader() instead.");var e=new sd;e.setCrossOrigin(this.crossOrigin);a=e.load(a,c,void 0,d);b&&(a.mapping=b);return a},loadTextureCube:function(a,b,c,d){console.warn("THREE.ImageUtils.loadTextureCube has been deprecated. Use THREE.CubeTextureLoader() instead.");var e=new be;e.setCrossOrigin(this.crossOrigin);a=e.load(a,c,void 0,d);b&&(a.mapping=
b);return a},loadCompressedTexture:function(){console.error("THREE.ImageUtils.loadCompressedTexture has been removed. Use THREE.DDSLoader instead.")},loadCompressedTextureCube:function(){console.error("THREE.ImageUtils.loadCompressedTextureCube has been removed. Use THREE.DDSLoader instead.")}};m.Projector=function(){console.error("THREE.Projector has been moved to /examples/js/renderers/Projector.js.");this.projectVector=function(a,b){console.warn("THREE.Projector: .projectVector() is now vector.project().");
a.project(b)};this.unprojectVector=function(a,b){console.warn("THREE.Projector: .unprojectVector() is now vector.unproject().");a.unproject(b)};this.pickingRay=function(){console.error("THREE.Projector: .pickingRay() is now raycaster.setFromCamera().")}};m.CanvasRenderer=function(){console.error("THREE.CanvasRenderer has been moved to /examples/js/renderers/CanvasRenderer.js");this.domElement=document.createElementNS("http://www.w3.org/1999/xhtml","canvas");this.clear=function(){};this.render=function(){};
this.setClearColor=function(){};this.setSize=function(){}};Object.defineProperty(m,"__esModule",{value:!0})});

(function(global, $) {
    function GlPlotter() {
        this.pluginName = 'glplotter';
        this.pluginVersion = '0.2';

        /**
         * Initialize the flot-gl-plotter-plugin
         * Adds the processOptions hook
         */
        this.init = function(plot) {
            var defaultPlotOffset = {
                left: 0,
                right: 0,
                top: 0,
                bottom: 0
            };

            var container, canvas, width, height,
                renderer, pixelRatio, mustClear = false;

            if (isTHREEAvailable()) {
                plot.hooks.processOptions.push(processOptions);
            }

            /**
             * Checks if Threejs is available
             */
            function isTHREEAvailable() {
                return typeof THREE !== 'undefined';
            };

            /**
             * Initialize the webgl drawing layer, renderer, camera and scene
             * Adds the hooks needed for drawing
             */
            function processOptions(plot, options) {
                var mainScene, camera, cameraFocus;
                container = plot.getPlaceholder()[0];

                if (isGlRequested()) {
                    if (setupWebGl()) {
                        resize(plot, width, height);
                        plot.hooks.drawSeries.push(drawSeries);
                        plot.hooks.draw.push(render);
                        plot.hooks.resize.push(resize);
                        plot.hooks.drawBackground.push(clear);
                        plot.hooks.shutdown.push(shutdown);
                    }
                }
            };

            /**
             * Initialize the webgl drawing layer, renderer, camera and the scene
             */
            function setupWebGl() {
                if (!canvas) {
                    canvas = getGlSurface("flot-gl", container);
                }

                if(!renderer) {
                    try {
                        renderer = new THREE.WebGLRenderer({ canvas: canvas, antialias: false, alpha: true, preserveDrawingBuffer: false });
                        mainScene = new THREE.Scene();
                        camera = new THREE.OrthographicCamera(width / 2, -width / 2, -height / 2, height / 2, 0.1, 1000);
                        cameraFocus = new THREE.Vector3(width / 2, height / 2, 1000);
                    } catch (e) {
                        console.warn("Cannot create WebGlRenderer: " + e);
                        return false;
                    }
                    var devicePixelRatio = window.devicePixelRatio || 1;
                    var backingStoreRatio =
                            renderer.webkitBackingStorePixelRatio ||
                            renderer.mozBackingStorePixelRatio ||
                            renderer.msBackingStorePixelRatio ||
                            renderer.oBackingStorePixelRatio ||
                            renderer.backingStorePixelRatio || 1;

                    pixelRatio = devicePixelRatio / backingStoreRatio;
                } else {
                    mainScene = renderer.userData.mainScene;
                    camera = renderer.userData.camera;
                    cameraFocus = camera.userData.cameraFocus;
                }

                // Setup the THREE.OrthographicCamera
                camera.aspect = width / height;
                camera.position.set(width / 2, height / 2, 0);
                camera.lookAt(cameraFocus);
                camera.updateMatrixWorld();
                camera.updateProjectionMatrix();

                // Setup the THREE.WebGLRenderer
                renderer.setPixelRatio(pixelRatio);
                renderer.setSize(width, height, true);
                renderer.autoClear = true;
                renderer.userData = {};

                // Save settings for future reuse.
                camera.userData.cameraFocus = cameraFocus;
                renderer.userData.camera = camera;
                renderer.userData.mainScene = mainScene;
                renderer.userData.plotOffset = defaultPlotOffset;

                return true;
            }

            /**
             * Return the webgl drawing layer, create one if needed
             */
            function getGlSurface(cls, container) {
                var element = container.getElementsByClassName(cls)[0];
                var flotBaseElement = container.getElementsByClassName("flot-base")[0];

                if (!element) {
                    element = document.createElement('canvas');
                    element.className = cls;
                    element.style.direction = 'ltr';
                    element.style.position = 'absolute';
                    element.style.left = '0px';
                    element.style.top = '0px';

                    container.insertBefore(element, flotBaseElement.nextSibling);
                }

                var box = container.getBoundingClientRect();

                // Size the canvas to match the internal dimensions of its container
                width = box.width;
                height = box.height;

                return element;
            };

            /**
             * Render the visible plotObjects contained inside the scene
             * All invisible objects will be removed from scene before rendering
             */
            function render() {
                var camera = renderer.userData.camera,
                    mainScene = renderer.userData.mainScene,
                    cameraFocus = camera.userData.cameraFocus,
                    plotOffset = renderer.userData.plotOffset || defaultPlotOffset;

                // Remove invisible objects from the scene
                mainScene.children.forEach(function(plotObject) {
                    if (!plotObject.visible) {
                        mainScene.remove(plotObject);
                    }
                });

                cameraFocus.x = width / 2;
                cameraFocus.y = height / 2;
                cameraFocus.z = 1000;
                renderer.clear();
                renderer.setSize(width, height, false);
                renderer.setViewport(0, 0, width, height);

                camera.position.set(width / 2, height / 2, 0);
                camera.lookAt(cameraFocus);
                camera.updateProjectionMatrix();
                camera.updateMatrixWorld();

                renderer.setScissor(
                    plotOffset.left,
                    plotOffset.top,
                    width - plotOffset.right - plotOffset.left,
                    height - plotOffset.bottom - plotOffset.top
                );

                renderer.render(mainScene, camera);
                renderer.clearDepth();
            };

            function resize(plot, newWidth, newHeight) {
                var userData = renderer.userData,
                    minSize = 10,
                    shouldresize = false,
                    element = canvas;

                    newWidth = newWidth < minSize ? minSize : newWidth;
                    newHeight = newHeight < minSize ? minSize : newHeight;

                    if (width !== newWidth) {
                        element.width = newWidth * pixelRatio;
                        element.style.width = newWidth + 'px';
                        width = newWidth;
                        shouldresize = true;
                    }

                    if (height !== newHeight) {
                        element.height = newHeight * pixelRatio;
                        element.style.height = newHeight + 'px';
                        height = newHeight;
                        shouldresize = true;
                    }

                    if (renderer && shouldresize) {
                        var mainscene = renderer.userData.mainScene,
                            camera = renderer.userData.camera;

                        renderer.setClearColor(0xff0000, 0);
                        renderer.setSize(width, height, false);
                        renderer.setPixelRatio(pixelRatio);

                        if (camera) {
                            camera.aspect = width/height;
                            camera.userData.cameraFocus.x = width / 2;
                            camera.userData.cameraFocus.y = height / 2;
                            camera.userData.cameraFocus.z = 1000;

                            camera.position.set(width / 2, height / 2, 0);
                            camera.lookAt(camera.userData.cameraFocus);
                            camera.updateProjectionMatrix();
                        }

                        renderer.clear();
                    }
            };

            /**
             * Clears the renderer and sets the visibility of the objects to false
             */
            function clear() {
                if (renderer && mustClear) {
                    mustClear = false;
                    // Make objects invisible
                    var mainscene = renderer.userData.mainScene;
                    mainscene.children.forEach(function(plotObject) {
                        plotObject.visible = false;
                    });

                    // Clear the renderer
                    renderer.setClearColor(0x0f0f0f, 0);
                    renderer.setScissorTest(false);
                    renderer.clear();

                    renderer.setClearColor(0xff0000, 0);
                    renderer.setScissorTest(true);
                    renderer.clear();
                }
            };

            /**
             * Remove objects from scene and free memory
             */
            function shutdown() {
                var mainscene = renderer.userData.mainScene;
                while(mainscene.children.length > 0) {
                    mainscene.children[0].material.dispose(true);
                    mainscene.children[0].geometry.dispose(true);
                    mainscene.remove(mainscene.children[0]);
                }

                mainscene = null;
                renderer.userData = null;
                renderer.dispose(true);
                canvas.remove();
            };

            /**
             * Draw using the Three.js library for rendering
             * Each plot is trasformed to a plotObject (THREE.Object3D)
             * For every point, a vertex is added to the plotObject's geometry
             *
             * Currently, the only type of drawing is points which uses the THREE.Points for creating the plotObject.
             * Not Implemented: support for Lines, Area, Bars (Ex: drawSeriesLines -> THREE.Line() as a plotObject)
             */
            function drawSeries(plot, ctx, series, index, getColorOrGradient) {
                var plotOffset = plot.getPlotOffset(),
                    plotWidth, plotHeight;
                if (mustDrawSeriesWithGl(series)) {
                    mustClear = true;
                    series.points.show = false;
                    series.points.glshow = true;
                    renderer.userData.plotOffset = plotOffset;

                    var datapoints = {
                        points: series.datapoints.points,
                        pointsize: series.datapoints.pointsize
                    };

                    if (series.decimatePoints) {
                        //after adjusting the axis, plot width and height will be modified
                        plotWidth = width - plotOffset.left - plotOffset.right;
                        plotHeight = height - plotOffset.bottom - plotOffset.top;
                        datapoints.points = series.decimatePoints(
                            series,
                            series.xaxis.min,
                            series.xaxis.max,
                            plotWidth,
                            series.yaxis.min,
                            series.yaxis.max,
                            plotHeight
                        );
                    }

                    drawSeriesPoints(
                        renderer,
                        pointsToVertices(datapoints, index, series, plotOffset),
                        index,
                        series,
                        getColorOrGradient
                    );
                }
            };

            /**
             * Checks the settings and url flags
             */
            function mustDrawSeriesWithGl(series) {
                return series.points.glshow || (series.points.show && isGlRequested());
            };

            /**
             * Checks for the gl=true flag inside the url params
             */
            function isGlRequested() {
                var url = window.location.href,
                    params = url.split('?')[1];

                if (params && params.includes('gl=true')) {
                    return true;
                }
                return false;
            };

            /**
             * Transform the list of 2D points(x,y) to 3D points(x,y,z) TypedArray
             * The z coord is the same for all
             * @param {*} index - plot index, used to set the plotObject's position on z direction
             */
            function pointsToVertices(datapoints, index, series, offset) {
                var points = datapoints.points,
                    ps = datapoints.pointsize,
                    i, j = 0, z = 1000 - index / 10,
                    vertices = new Float32Array(points.length / ps * 3);
                for (i = 0; i < points.length; i += ps) {
                    if (points[i] == null) continue;

                    // set x,y,z coords of point
                    vertices[j] = series.xaxis.p2c(points[i]) + offset.left;
                    vertices[j + 1] = series.yaxis.p2c(points[i + 1]) + offset.top;
                    vertices[j + 2] = z;
                    j += 3;
                }

                return vertices;
            }

            /**
             * Uses the THREE.Points as a plotObject for drawing the plot using points
             * Adds an plotObject to the scene / Update an plotObject from the scene
             * Makes the plotObject visible before rendering
             */
            function drawSeriesPoints(renderer, vertices, index, series, getColorOrGradient) {
                var mainscene = renderer.userData.mainScene,
                    plotObject = mainscene.getObjectByName('Plot' + index),
                    vs = 3;

                if (plotObject) {
                    updateGeometry(plotObject, vertices, vs);
                    plotObject.visible = true;
                } else {
                    plotObject = new THREE.Points(
                            generateGeometry(vertices, vs),
                            generateMaterial(series, getColorOrGradient)
                        );
                    plotObject.name = 'Plot' + index;
                    mainscene.add(plotObject);
                }
            };

            /**
             * Creates a BufferGeometry from a TypedArray of vertices
             */
            function generateGeometry(vertices, vertexSize) {
                var geometry = new THREE.BufferGeometry();
                geometry.addAttribute('position', new THREE.Float32BufferAttribute(vertices, vertexSize));
                geometry.attributes.position.dynamic = true;
                geometry.attributes.position.needsUpdate = true;
                return geometry;
            };

            /**
             * Update plotObject's geometry
             * If the plotObject geometry is big enough, update position and draw range,
             * else dispose the plotObject's geometry and generate a new one to fit the data
             */
            function updateGeometry(plotObject, vertices, vertexSize) {
                var geometry = plotObject.geometry;
                if (geometry.attributes.position.count >= vertices.length / vertexSize) {
                    geometry.attributes.position.setArray(vertices);
                    geometry.setDrawRange(0, vertices.length / vertexSize);
                    geometry.attributes.position.needsUpdate = true;
                } else {
                    geometry.dispose(true);
                    plotObject.geometry = generateGeometry(vertices, vertexSize);
                }
            };

            /**
             * Generate a material for points
             */
            function generateMaterial(series, getColorOrGradient) {
                return new THREE.PointsMaterial({
                        size: series.points.radius * 4,
                        sizeAttenuation: false,
                        map: generateTexture(series, getColorOrGradient),
                        transparent: true,
                        fog: false,
                        alphaTest: 0.1
                    });
            };

            /**
             * Create a texture for points
             */
            function generateTexture(series, getColorOrGradient){
                var filloptions = getFillStyle(series.points, series.color, null, null, getColorOrGradient) || series.color;
                return createTexture(series.points.symbol, series.points.lineWidth, series.color, filloptions, plot.drawSymbol)
            };

            function getFillStyle(filloptions, seriesColor, bottom, top, getColorOrGradient) {
                var fill = filloptions.fill;
                if (!fill) {
                    return null;
                }

                if (filloptions.fillColor) {
                    return getColorOrGradient(filloptions.fillColor, bottom, top, seriesColor);
                }

                var c = $.color.parse(seriesColor);
                c.a = typeof fill === "number" ? fill : 0.4;
                c.normalize();
                return c.toString();
            };

            /**
             * Use flot drawSymbol function(2D canvas) to achieve the same visual style of points
             * by drawing a single point to a temporary 2D canvas and then transforming the canvas to a texture
             */
            function createTexture(symbol, lineWidth, color, filloptions, drawSymbol) {
                var textureCanvas, context, texture;
                var size = 128;
                var halfSize = size / 2;
                textureCanvas = document.createElement('canvas');
                textureCanvas.width = size;
                textureCanvas.height = size;
                context = textureCanvas.getContext('2d');
                context.clearRect(0, 0, size, size);
                context.globalAlpha = 1;
                context.strokeStyle = color;
                context.lineWidth = (lineWidth || 1) * size / 10;

                if (symbol === "circle") {
                    context.arc(halfSize, halfSize, size / 4, 0, 2 * Math.PI);
                } else if (typeof symbol === 'string' && drawSymbol && drawSymbol[symbol]) {
                    drawSymbol[symbol](context, halfSize, halfSize, size / 4, false);
                } else if (typeof drawSymbol === 'function') {
                    drawSymbol(context, halfSize, halfSize, size / 4, false);
                }

                context.fillStyle = filloptions;
                context.fill();
                context.stroke();

                texture = new THREE.CanvasTexture(textureCanvas);
                texture.minFilter = THREE.LinearFilter;
                texture.needsUpdate = true;

                return texture;
            };
        };
    };

    var glplotter = new GlPlotter();
    $.plot.plugins.push({
        init: glplotter.init,
        name: glplotter.pluginName,
        version: glplotter.pluginVersion
    });
    global.GlPlotter = GlPlotter;
})(this, jQuery);

(function(){/*

 Copyright (c) 2016 The Polymer Project Authors. All rights reserved.
 This code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt
 The complete set of authors may be found at http://polymer.github.io/AUTHORS.txt
 The complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt
 Code distributed by Google as part of the polymer project is also
 subject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt
*/
'use strict';var p,q="undefined"!=typeof window&&window===this?this:"undefined"!=typeof global&&null!=global?global:this,ba="function"==typeof Object.defineProperties?Object.defineProperty:function(a,b,c){a!=Array.prototype&&a!=Object.prototype&&(a[b]=c.value)};function ca(){ca=function(){};q.Symbol||(q.Symbol=da)}var da=function(){var a=0;return function(b){return"jscomp_symbol_"+(b||"")+a++}}();
function ea(){ca();var a=q.Symbol.iterator;a||(a=q.Symbol.iterator=q.Symbol("iterator"));"function"!=typeof Array.prototype[a]&&ba(Array.prototype,a,{configurable:!0,writable:!0,value:function(){return fa(this)}});ea=function(){}}function fa(a){var b=0;return ha(function(){return b<a.length?{done:!1,value:a[b++]}:{done:!0}})}function ha(a){ea();a={next:a};a[q.Symbol.iterator]=function(){return this};return a}function ia(a){ea();var b=a[Symbol.iterator];return b?b.call(a):fa(a)}
function ja(a){for(var b,c=[];!(b=a.next()).done;)c.push(b.value);return c}
(function(){if(!function(){var a=document.createEvent("Event");a.initEvent("foo",!0,!0);a.preventDefault();return a.defaultPrevented}()){var a=Event.prototype.preventDefault;Event.prototype.preventDefault=function(){this.cancelable&&(a.call(this),Object.defineProperty(this,"defaultPrevented",{get:function(){return!0},configurable:!0}))}}var b=/Trident/.test(navigator.userAgent);if(!window.CustomEvent||b&&"function"!==typeof window.CustomEvent)window.CustomEvent=function(a,b){b=b||{};var c=document.createEvent("CustomEvent");
c.initCustomEvent(a,!!b.bubbles,!!b.cancelable,b.detail);return c},window.CustomEvent.prototype=window.Event.prototype;if(!window.Event||b&&"function"!==typeof window.Event){var c=window.Event;window.Event=function(a,b){b=b||{};var c=document.createEvent("Event");c.initEvent(a,!!b.bubbles,!!b.cancelable);return c};if(c)for(var d in c)window.Event[d]=c[d];window.Event.prototype=c.prototype}if(!window.MouseEvent||b&&"function"!==typeof window.MouseEvent){b=window.MouseEvent;window.MouseEvent=function(a,
b){b=b||{};var c=document.createEvent("MouseEvent");c.initMouseEvent(a,!!b.bubbles,!!b.cancelable,b.view||window,b.detail,b.screenX,b.screenY,b.clientX,b.clientY,b.ctrlKey,b.altKey,b.shiftKey,b.metaKey,b.button,b.relatedTarget);return c};if(b)for(d in b)window.MouseEvent[d]=b[d];window.MouseEvent.prototype=b.prototype}Array.from||(Array.from=function(a){return[].slice.call(a)});Object.assign||(Object.assign=function(a,b){for(var c=[].slice.call(arguments,1),d=0,e;d<c.length;d++)if(e=c[d])for(var f=
a,m=e,n=Object.getOwnPropertyNames(m),t=0;t<n.length;t++)e=n[t],f[e]=m[e];return a})})(window.WebComponents);(function(){function a(){}function b(a,b){if(!a.childNodes.length)return[];switch(a.nodeType){case Node.DOCUMENT_NODE:return t.call(a,b);case Node.DOCUMENT_FRAGMENT_NODE:return C.call(a,b);default:return n.call(a,b)}}var c="undefined"===typeof HTMLTemplateElement,d=!(document.createDocumentFragment().cloneNode()instanceof DocumentFragment),e=!1;/Trident/.test(navigator.userAgent)&&function(){function a(a,b){if(a instanceof DocumentFragment)for(var d;d=a.firstChild;)c.call(this,d,b);else c.call(this,
a,b);return a}e=!0;var b=Node.prototype.cloneNode;Node.prototype.cloneNode=function(a){a=b.call(this,a);this instanceof DocumentFragment&&(a.__proto__=DocumentFragment.prototype);return a};DocumentFragment.prototype.querySelectorAll=HTMLElement.prototype.querySelectorAll;DocumentFragment.prototype.querySelector=HTMLElement.prototype.querySelector;Object.defineProperties(DocumentFragment.prototype,{nodeType:{get:function(){return Node.DOCUMENT_FRAGMENT_NODE},configurable:!0},localName:{get:function(){},
configurable:!0},nodeName:{get:function(){return"#document-fragment"},configurable:!0}});var c=Node.prototype.insertBefore;Node.prototype.insertBefore=a;var d=Node.prototype.appendChild;Node.prototype.appendChild=function(b){b instanceof DocumentFragment?a.call(this,b,null):d.call(this,b);return b};var f=Node.prototype.removeChild,h=Node.prototype.replaceChild;Node.prototype.replaceChild=function(b,c){b instanceof DocumentFragment?(a.call(this,b,c),f.call(this,c)):h.call(this,b,c);return c};Document.prototype.createDocumentFragment=
function(){var a=this.createElement("df");a.__proto__=DocumentFragment.prototype;return a};var g=Document.prototype.importNode;Document.prototype.importNode=function(a,b){b=g.call(this,a,b||!1);a instanceof DocumentFragment&&(b.__proto__=DocumentFragment.prototype);return b}}();var f=Node.prototype.cloneNode,h=Document.prototype.createElement,g=Document.prototype.importNode,k=Node.prototype.removeChild,l=Node.prototype.appendChild,m=Node.prototype.replaceChild,n=Element.prototype.querySelectorAll,
t=Document.prototype.querySelectorAll,C=DocumentFragment.prototype.querySelectorAll,eb=function(){if(!c){var a=document.createElement("template"),b=document.createElement("template");b.content.appendChild(document.createElement("div"));a.content.appendChild(b);a=a.cloneNode(!0);return 0===a.content.childNodes.length||0===a.content.firstChild.content.childNodes.length||d}}();if(c){var J=document.implementation.createHTMLDocument("template"),Ca=!0,Da=document.createElement("style");Da.textContent="template{display:none;}";
var Ea=document.head;Ea.insertBefore(Da,Ea.firstElementChild);a.prototype=Object.create(HTMLElement.prototype);var x=!document.createElement("div").hasOwnProperty("innerHTML");a.D=function(b){if(!b.content){b.content=J.createDocumentFragment();for(var c;c=b.firstChild;)l.call(b.content,c);if(x)b.__proto__=a.prototype;else if(b.cloneNode=function(b){return a.ca(this,b)},Ca)try{na(b),aa(b)}catch(Mg){Ca=!1}a.J(b.content)}};var na=function(b){Object.defineProperty(b,"innerHTML",{get:function(){for(var a=
"",b=this.content.firstChild;b;b=b.nextSibling)a+=b.outerHTML||b.data.replace(oa,U);return a},set:function(b){J.body.innerHTML=b;for(a.J(J);this.content.firstChild;)k.call(this.content,this.content.firstChild);for(;J.body.firstChild;)l.call(this.content,J.body.firstChild)},configurable:!0})},aa=function(a){Object.defineProperty(a,"outerHTML",{get:function(){return"<template>"+this.innerHTML+"</template>"},set:function(a){if(this.parentNode){J.body.innerHTML=a;for(a=this.ownerDocument.createDocumentFragment();J.body.firstChild;)l.call(a,
J.body.firstChild);m.call(this.parentNode,a,this)}else throw Error("Failed to set the 'outerHTML' property on 'Element': This element has no parent node.");},configurable:!0})};na(a.prototype);aa(a.prototype);a.J=function(c){c=b(c,"template");for(var d=0,e=c.length,f;d<e&&(f=c[d]);d++)a.D(f)};document.addEventListener("DOMContentLoaded",function(){a.J(document)});Document.prototype.createElement=function(){var b=h.apply(this,arguments);"template"===b.localName&&a.D(b);return b};var oa=/[&\u00A0<>]/g,
U=function(a){switch(a){case "&":return"&amp;";case "<":return"&lt;";case ">":return"&gt;";case "\u00a0":return"&nbsp;"}}}if(c||eb){a.ca=function(a,b){var c=f.call(a,!1);this.D&&this.D(c);b&&(l.call(c.content,f.call(a.content,!0)),fb(c.content,a.content));return c};var fb=function(c,d){if(d.querySelectorAll&&(d=b(d,"template"),0!==d.length)){c=b(c,"template");for(var e=0,f=c.length,h,g;e<f;e++)g=d[e],h=c[e],a&&a.D&&a.D(g),m.call(h.parentNode,pa.call(g,!0),h)}},pa=Node.prototype.cloneNode=function(b){if(!e&&
d&&this instanceof DocumentFragment)if(b)var c=qa.call(this.ownerDocument,this,!0);else return this.ownerDocument.createDocumentFragment();else c=this.nodeType===Node.ELEMENT_NODE&&"template"===this.localName?a.ca(this,b):f.call(this,b);b&&fb(c,this);return c},qa=Document.prototype.importNode=function(c,d){d=d||!1;if("template"===c.localName)return a.ca(c,d);var e=g.call(this,c,d);if(d){fb(e,c);c=b(e,'script:not([type]),script[type="application/javascript"],script[type="text/javascript"]');for(var f,
k=0;k<c.length;k++){f=c[k];d=h.call(document,"script");d.textContent=f.textContent;for(var l=f.attributes,qa=0,pa;qa<l.length;qa++)pa=l[qa],d.setAttribute(pa.name,pa.value);m.call(f.parentNode,d,f)}}return e}}c&&(window.HTMLTemplateElement=a)})();var ka=Array.isArray?Array.isArray:function(a){return"[object Array]"===Object.prototype.toString.call(a)};var la=0,ma,ra="undefined"!==typeof window?window:void 0,sa=ra||{},ta=sa.MutationObserver||sa.WebKitMutationObserver,ua="undefined"!==typeof Uint8ClampedArray&&"undefined"!==typeof importScripts&&"undefined"!==typeof MessageChannel;function va(){return"undefined"!==typeof ma?function(){ma(wa)}:xa()}function ya(){var a=0,b=new ta(wa),c=document.createTextNode("");b.observe(c,{characterData:!0});return function(){c.data=a=++a%2}}
function za(){var a=new MessageChannel;a.port1.onmessage=wa;return function(){return a.port2.postMessage(0)}}function xa(){var a=setTimeout;return function(){return a(wa,1)}}var Aa=Array(1E3);function wa(){for(var a=0;a<la;a+=2)(0,Aa[a])(Aa[a+1]),Aa[a]=void 0,Aa[a+1]=void 0;la=0}var Ba,Fa;
if("undefined"===typeof self&&"undefined"!==typeof process&&"[object process]"==={}.toString.call(process))Fa=function(){return process.ib(wa)};else{var Ga;if(ta)Ga=ya();else{var Ha;if(ua)Ha=za();else{var Ia;if(void 0===ra&&"function"===typeof require)try{var Ja=require("vertx");ma=Ja.kb||Ja.jb;Ia=va()}catch(a){Ia=xa()}else Ia=xa();Ha=Ia}Ga=Ha}Fa=Ga}Ba=Fa;function Ka(a,b){Aa[la]=a;Aa[la+1]=b;la+=2;2===la&&Ba()};function La(a,b){var c=this,d=new this.constructor(Ma);void 0===d[Na]&&Oa(d);var e=c.g;if(e){var f=arguments[e-1];Ka(function(){return Pa(e,d,f,c.f)})}else Qa(c,d,a,b);return d};function Ra(a){if(a&&"object"===typeof a&&a.constructor===this)return a;var b=new this(Ma);Sa(b,a);return b};var Na=Math.random().toString(36).substring(16);function Ma(){}var Ua=new Ta;function Va(a){try{return a.then}catch(b){return Ua.error=b,Ua}}function Wa(a,b,c,d){try{a.call(b,c,d)}catch(e){return e}}function Xa(a,b,c){Ka(function(a){var d=!1,f=Wa(c,b,function(c){d||(d=!0,b!==c?Sa(a,c):r(a,c))},function(b){d||(d=!0,u(a,b))});!d&&f&&(d=!0,u(a,f))},a)}function Ya(a,b){1===b.g?r(a,b.f):2===b.g?u(a,b.f):Qa(b,void 0,function(b){return Sa(a,b)},function(b){return u(a,b)})}
function Za(a,b,c){b.constructor===a.constructor&&c===La&&b.constructor.resolve===Ra?Ya(a,b):c===Ua?(u(a,Ua.error),Ua.error=null):void 0===c?r(a,b):"function"===typeof c?Xa(a,b,c):r(a,b)}function Sa(a,b){if(a===b)u(a,new TypeError("You cannot resolve a promise with itself"));else{var c=typeof b;null===b||"object"!==c&&"function"!==c?r(a,b):Za(a,b,Va(b))}}function $a(a){a.na&&a.na(a.f);ab(a)}function r(a,b){void 0===a.g&&(a.f=b,a.g=1,0!==a.I.length&&Ka(ab,a))}
function u(a,b){void 0===a.g&&(a.g=2,a.f=b,Ka($a,a))}function Qa(a,b,c,d){var e=a.I,f=e.length;a.na=null;e[f]=b;e[f+1]=c;e[f+2]=d;0===f&&a.g&&Ka(ab,a)}function ab(a){var b=a.I,c=a.g;if(0!==b.length){for(var d,e,f=a.f,h=0;h<b.length;h+=3)d=b[h],e=b[h+c],d?Pa(c,d,e,f):e(f);a.I.length=0}}function Ta(){this.error=null}var bb=new Ta;
function Pa(a,b,c,d){var e="function"===typeof c;if(e){try{var f=c(d)}catch(l){bb.error=l,f=bb}if(f===bb){var h=!0;var g=f.error;f.error=null}else var k=!0;if(b===f){u(b,new TypeError("A promises callback cannot return that same promise."));return}}else f=d,k=!0;void 0===b.g&&(e&&k?Sa(b,f):h?u(b,g):1===a?r(b,f):2===a&&u(b,f))}function cb(a,b){try{b(function(b){Sa(a,b)},function(b){u(a,b)})}catch(c){u(a,c)}}var db=0;function Oa(a){a[Na]=db++;a.g=void 0;a.f=void 0;a.I=[]};function gb(a,b){this.Ea=a;this.A=new a(Ma);this.A[Na]||Oa(this.A);if(ka(b))if(this.S=this.length=b.length,this.f=Array(this.length),0===this.length)r(this.A,this.f);else{this.length=this.length||0;for(a=0;void 0===this.g&&a<b.length;a++)hb(this,b[a],a);0===this.S&&r(this.A,this.f)}else u(this.A,Error("Array Methods must be provided an Array"))}
function hb(a,b,c){var d=a.Ea,e=d.resolve;e===Ra?(e=Va(b),e===La&&void 0!==b.g?ib(a,b.g,c,b.f):"function"!==typeof e?(a.S--,a.f[c]=b):d===v?(d=new d(Ma),Za(d,b,e),jb(a,d,c)):jb(a,new d(function(a){return a(b)}),c)):jb(a,e(b),c)}function ib(a,b,c,d){var e=a.A;void 0===e.g&&(a.S--,2===b?u(e,d):a.f[c]=d);0===a.S&&r(e,a.f)}function jb(a,b,c){Qa(b,void 0,function(b){return ib(a,1,c,b)},function(b){return ib(a,2,c,b)})};function kb(a){return(new gb(this,a)).A};function lb(a){var b=this;return ka(a)?new b(function(c,d){for(var e=a.length,f=0;f<e;f++)b.resolve(a[f]).then(c,d)}):new b(function(a,b){return b(new TypeError("You must pass an array to race."))})};function mb(a){var b=new this(Ma);u(b,a);return b};function v(a){this[Na]=db++;this.f=this.g=void 0;this.I=[];if(Ma!==a){if("function"!==typeof a)throw new TypeError("You must pass a resolver function as the first argument to the promise constructor");if(this instanceof v)cb(this,a);else throw new TypeError("Failed to construct 'Promise': Please use the 'new' operator, this object constructor cannot be called as a function.");}}v.prototype={constructor:v,then:La,a:function(a){return this.then(null,a)}};/*

Copyright (c) 2017 The Polymer Project Authors. All rights reserved.
This code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt
The complete set of authors may be found at http://polymer.github.io/AUTHORS.txt
The complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt
Code distributed by Google as part of the polymer project is also
subject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt
*/
window.Promise||(window.Promise=v,v.prototype["catch"]=v.prototype.a,v.prototype.then=v.prototype.then,v.all=kb,v.race=lb,v.resolve=Ra,v.reject=mb);(function(a){function b(a,b){if("function"===typeof window.CustomEvent)return new CustomEvent(a,b);var c=document.createEvent("CustomEvent");c.initCustomEvent(a,!!b.bubbles,!!b.cancelable,b.detail);return c}function c(a){if(C)return a.ownerDocument!==document?a.ownerDocument:null;var b=a.__importDoc;if(!b&&a.parentNode){b=a.parentNode;if("function"===typeof b.closest)b=b.closest("link[rel=import]");else for(;!g(b)&&(b=b.parentNode););a.__importDoc=b}return b}function d(a){var b=m(document,"link[rel=import]:not([import-dependency])"),
c=b.length;c?n(b,function(b){return h(b,function(){0===--c&&a()})}):a()}function e(a){function b(){"loading"!==document.readyState&&document.body&&(document.removeEventListener("readystatechange",b),a())}document.addEventListener("readystatechange",b);b()}function f(a){e(function(){return d(function(){return a&&a()})})}function h(a,b){if(a.__loaded)b&&b();else if("script"===a.localName&&!a.src||"style"===a.localName&&!a.firstChild)a.__loaded=!0,b&&b();else{var c=function(d){a.removeEventListener(d.type,
c);a.__loaded=!0;b&&b()};a.addEventListener("load",c);aa&&"style"===a.localName||a.addEventListener("error",c)}}function g(a){return a.nodeType===Node.ELEMENT_NODE&&"link"===a.localName&&"import"===a.rel}function k(){var a=this;this.a={};this.b=0;this.c=new MutationObserver(function(b){return a.Ra(b)});this.c.observe(document.head,{childList:!0,subtree:!0});this.loadImports(document)}function l(a){n(m(a,"template"),function(a){n(m(a.content,'script:not([type]),script[type="application/javascript"],script[type="text/javascript"]'),
function(a){var b=document.createElement("script");n(a.attributes,function(a){return b.setAttribute(a.name,a.value)});b.textContent=a.textContent;a.parentNode.replaceChild(b,a)});l(a.content)})}function m(a,b){return a.childNodes.length?a.querySelectorAll(b):eb}function n(a,b,c){var d=a?a.length:0,e=c?-1:1;for(c=c?d-1:0;c<d&&0<=c;c+=e)b(a[c],c)}var t=document.createElement("link"),C="import"in t,eb=t.querySelectorAll("*"),J=null;!1==="currentScript"in document&&Object.defineProperty(document,"currentScript",
{get:function(){return J||("complete"!==document.readyState?document.scripts[document.scripts.length-1]:null)},configurable:!0});var Ca=/(url\()([^)]*)(\))/g,Da=/(@import[\s]+(?!url\())([^;]*)(;)/g,Ea=/(<link[^>]*)(rel=['|"]?stylesheet['|"]?[^>]*>)/g,x={La:function(a,b){a.href&&a.setAttribute("href",x.Y(a.getAttribute("href"),b));a.src&&a.setAttribute("src",x.Y(a.getAttribute("src"),b));if("style"===a.localName){var c=x.ta(a.textContent,b,Ca);a.textContent=x.ta(c,b,Da)}},ta:function(a,b,c){return a.replace(c,
function(a,c,d,e){a=d.replace(/["']/g,"");b&&(a=x.Y(a,b));return c+"'"+a+"'"+e})},Y:function(a,b){if(void 0===x.ba){x.ba=!1;try{var c=new URL("b","http://a");c.pathname="c%20d";x.ba="http://a/c%20d"===c.href}catch(Lg){}}if(x.ba)return(new URL(a,b)).href;c=x.Ba;c||(c=document.implementation.createHTMLDocument("temp"),x.Ba=c,c.ma=c.createElement("base"),c.head.appendChild(c.ma),c.la=c.createElement("a"));c.ma.href=b;c.la.href=a;return c.la.href||a}},na={async:!0,load:function(a,b,c){if(a)if(a.match(/^data:/)){a=
a.split(",");var d=a[1];d=-1<a[0].indexOf(";base64")?atob(d):decodeURIComponent(d);b(d)}else{var e=new XMLHttpRequest;e.open("GET",a,na.async);e.onload=function(){var a=e.responseURL||e.getResponseHeader("Location");a&&0===a.indexOf("/")&&(a=(location.origin||location.protocol+"//"+location.host)+a);var d=e.response||e.responseText;304===e.status||0===e.status||200<=e.status&&300>e.status?b(d,a):c(d)};e.send()}else c("error: href must be specified")}},aa=/Trident/.test(navigator.userAgent)||/Edge\/\d./i.test(navigator.userAgent);
k.prototype.loadImports=function(a){var b=this;a=m(a,"link[rel=import]");n(a,function(a){return b.s(a)})};k.prototype.s=function(a){var b=this,c=a.href;if(void 0!==this.a[c]){var d=this.a[c];d&&d.__loaded&&(a.__import=d,this.h(a))}else this.b++,this.a[c]="pending",na.load(c,function(a,d){a=b.Sa(a,d||c);b.a[c]=a;b.b--;b.loadImports(a);b.L()},function(){b.a[c]=null;b.b--;b.L()})};k.prototype.Sa=function(a,b){if(!a)return document.createDocumentFragment();aa&&(a=a.replace(Ea,function(a,b,c){return-1===
a.indexOf("type=")?b+" type=import-disable "+c:a}));var c=document.createElement("template");c.innerHTML=a;if(c.content)a=c.content,l(a);else for(a=document.createDocumentFragment();c.firstChild;)a.appendChild(c.firstChild);if(c=a.querySelector("base"))b=x.Y(c.getAttribute("href"),b),c.removeAttribute("href");c=m(a,'link[rel=import],link[rel=stylesheet][href][type=import-disable],style:not([type]),link[rel=stylesheet][href]:not([type]),script:not([type]),script[type="application/javascript"],script[type="text/javascript"]');
var d=0;n(c,function(a){h(a);x.La(a,b);a.setAttribute("import-dependency","");"script"===a.localName&&!a.src&&a.textContent&&(a.setAttribute("src","data:text/javascript;charset=utf-8,"+encodeURIComponent(a.textContent+("\n//# sourceURL="+b+(d?"-"+d:"")+".js\n"))),a.textContent="",d++)});return a};k.prototype.L=function(){var a=this;if(!this.b){this.c.disconnect();this.flatten(document);var b=!1,c=!1,d=function(){c&&b&&(a.loadImports(document),a.b||(a.c.observe(document.head,{childList:!0,subtree:!0}),
a.Pa()))};this.Ua(function(){c=!0;d()});this.Ta(function(){b=!0;d()})}};k.prototype.flatten=function(a){var b=this;a=m(a,"link[rel=import]");n(a,function(a){var c=b.a[a.href];(a.__import=c)&&c.nodeType===Node.DOCUMENT_FRAGMENT_NODE&&(b.a[a.href]=a,a.readyState="loading",a.__import=a,b.flatten(c),a.appendChild(c))})};k.prototype.Ta=function(a){function b(e){if(e<d){var f=c[e],g=document.createElement("script");f.removeAttribute("import-dependency");n(f.attributes,function(a){return g.setAttribute(a.name,
a.value)});J=g;f.parentNode.replaceChild(g,f);h(g,function(){J=null;b(e+1)})}else a()}var c=m(document,"script[import-dependency]"),d=c.length;b(0)};k.prototype.Ua=function(a){var b=m(document,"style[import-dependency],link[rel=stylesheet][import-dependency]"),d=b.length;if(d){var e=aa&&!!document.querySelector("link[rel=stylesheet][href][type=import-disable]");n(b,function(b){h(b,function(){b.removeAttribute("import-dependency");0===--d&&a()});if(e&&b.parentNode!==document.head){var f=document.createElement(b.localName);
f.__appliedElement=b;f.setAttribute("type","import-placeholder");b.parentNode.insertBefore(f,b.nextSibling);for(f=c(b);f&&c(f);)f=c(f);f.parentNode!==document.head&&(f=null);document.head.insertBefore(b,f);b.removeAttribute("type")}})}else a()};k.prototype.Pa=function(){var a=this,b=m(document,"link[rel=import]");n(b,function(b){return a.h(b)},!0)};k.prototype.h=function(a){a.__loaded||(a.__loaded=!0,a.import&&(a.import.readyState="complete"),a.dispatchEvent(b(a.import?"load":"error",{bubbles:!1,
cancelable:!1,detail:void 0})))};k.prototype.Ra=function(a){var b=this;n(a,function(a){return n(a.addedNodes,function(a){a&&a.nodeType===Node.ELEMENT_NODE&&(g(a)?b.s(a):b.loadImports(a))})})};var oa=null;if(C)t=m(document,"link[rel=import]"),n(t,function(a){a.import&&"loading"===a.import.readyState||(a.__loaded=!0)}),t=function(a){a=a.target;g(a)&&(a.__loaded=!0)},document.addEventListener("load",t,!0),document.addEventListener("error",t,!0);else{var U=Object.getOwnPropertyDescriptor(Node.prototype,
"baseURI");Object.defineProperty((!U||U.configurable?Node:Element).prototype,"baseURI",{get:function(){var a=g(this)?this:c(this);return a?a.href:U&&U.get?U.get.call(this):(document.querySelector("base")||window.location).href},configurable:!0,enumerable:!0});Object.defineProperty(HTMLLinkElement.prototype,"import",{get:function(){return this.__import||null},configurable:!0,enumerable:!0});e(function(){oa=new k})}f(function(){return document.dispatchEvent(b("HTMLImportsLoaded",{cancelable:!0,bubbles:!0,
detail:void 0}))});a.useNative=C;a.whenReady=f;a.importForElement=c;a.loadImports=function(a){oa&&oa.loadImports(a)}})(window.HTMLImports=window.HTMLImports||{});/*

 Copyright (c) 2014 The Polymer Project Authors. All rights reserved.
 This code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt
 The complete set of authors may be found at http://polymer.github.io/AUTHORS.txt
 The complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt
 Code distributed by Google as part of the polymer project is also
 subject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt
*/
window.WebComponents=window.WebComponents||{flags:{}};var nb=document.querySelector('script[src*="webcomponents-lite.js"]'),ob=/wc-(.+)/,w={};if(!w.noOpts){location.search.slice(1).split("&").forEach(function(a){a=a.split("=");var b;a[0]&&(b=a[0].match(ob))&&(w[b[1]]=a[1]||!0)});if(nb)for(var pb=0,qb;qb=nb.attributes[pb];pb++)"src"!==qb.name&&(w[qb.name]=qb.value||!0);if(w.log&&w.log.split){var rb=w.log.split(",");w.log={};rb.forEach(function(a){w.log[a]=!0})}else w.log={}}
window.WebComponents.flags=w;var sb=w.shadydom;sb&&(window.ShadyDOM=window.ShadyDOM||{},window.ShadyDOM.force=sb);var tb=w.register||w.ce;tb&&window.customElements&&(window.customElements.forcePolyfill=tb);/*

Copyright (c) 2016 The Polymer Project Authors. All rights reserved.
This code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt
The complete set of authors may be found at http://polymer.github.io/AUTHORS.txt
The complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt
Code distributed by Google as part of the polymer project is also
subject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt
*/
var y=window.ShadyDOM||{};y.Na=!(!Element.prototype.attachShadow||!Node.prototype.getRootNode);var ub=Object.getOwnPropertyDescriptor(Node.prototype,"firstChild");y.M=!!(ub&&ub.configurable&&ub.get);y.sa=y.force||!y.Na;function vb(a){return a.__shady&&void 0!==a.__shady.firstChild}function z(a){return"ShadyRoot"===a.ya}function wb(a){a=a.getRootNode();if(z(a))return a}var xb=Element.prototype,yb=xb.matches||xb.matchesSelector||xb.mozMatchesSelector||xb.msMatchesSelector||xb.oMatchesSelector||xb.webkitMatchesSelector;
function zb(a,b){if(a&&b)for(var c=Object.getOwnPropertyNames(b),d=0,e;d<c.length&&(e=c[d]);d++){var f=Object.getOwnPropertyDescriptor(b,e);f&&Object.defineProperty(a,e,f)}}function Ab(a,b){for(var c=[],d=1;d<arguments.length;++d)c[d-1]=arguments[d];for(d=0;d<c.length;d++)zb(a,c[d]);return a}function Bb(a,b){for(var c in b)a[c]=b[c]}var Cb=document.createTextNode(""),Db=0,Eb=[];(new MutationObserver(function(){for(;Eb.length;)try{Eb.shift()()}catch(a){throw Cb.textContent=Db++,a;}})).observe(Cb,{characterData:!0});
function Fb(a){Eb.push(a);Cb.textContent=Db++}var Gb=!!document.contains;function Hb(a,b){for(;b;){if(b==a)return!0;b=b.parentNode}return!1};var Ib=[],Jb;function Kb(a){Jb||(Jb=!0,Fb(Lb));Ib.push(a)}function Lb(){Jb=!1;for(var a=!!Ib.length;Ib.length;)Ib.shift()();return a}Lb.list=Ib;function Mb(){this.a=!1;this.addedNodes=[];this.removedNodes=[];this.V=new Set}function Nb(a){a.a||(a.a=!0,Fb(function(){Ob(a)}))}function Ob(a){if(a.a){a.a=!1;var b=a.takeRecords();b.length&&a.V.forEach(function(a){a(b)})}}Mb.prototype.takeRecords=function(){if(this.addedNodes.length||this.removedNodes.length){var a=[{addedNodes:this.addedNodes,removedNodes:this.removedNodes}];this.addedNodes=[];this.removedNodes=[];return a}return[]};
function Pb(a,b){a.__shady=a.__shady||{};a.__shady.N||(a.__shady.N=new Mb);a.__shady.N.V.add(b);var c=a.__shady.N;return{Ca:b,C:c,Ga:a,takeRecords:function(){return c.takeRecords()}}}function Qb(a){var b=a&&a.C;b&&(b.V.delete(a.Ca),b.V.size||(a.Ga.__shady.N=null))}
function Rb(a,b){var c=b.getRootNode();return a.map(function(a){var b=c===a.target.getRootNode();if(b&&a.addedNodes){if(b=Array.from(a.addedNodes).filter(function(a){return c===a.getRootNode()}),b.length)return a=Object.create(a),Object.defineProperty(a,"addedNodes",{value:b,configurable:!0}),a}else if(b)return a}).filter(function(a){return a})};var A={},Sb=Element.prototype.insertBefore,Tb=Element.prototype.removeChild,Ub=Element.prototype.setAttribute,Vb=Element.prototype.removeAttribute,Wb=Element.prototype.cloneNode,Xb=Document.prototype.importNode,Yb=Element.prototype.addEventListener,Zb=Element.prototype.removeEventListener,$b=Window.prototype.addEventListener,ac=Window.prototype.removeEventListener,bc=Element.prototype.dispatchEvent,cc=Element.prototype.querySelector,dc=Element.prototype.querySelectorAll,ec=Node.prototype.contains||
HTMLElement.prototype.contains;A.appendChild=Element.prototype.appendChild;A.insertBefore=Sb;A.removeChild=Tb;A.setAttribute=Ub;A.removeAttribute=Vb;A.cloneNode=Wb;A.importNode=Xb;A.addEventListener=Yb;A.removeEventListener=Zb;A.ab=$b;A.bb=ac;A.dispatchEvent=bc;A.querySelector=cc;A.querySelectorAll=dc;A.contains=ec;var fc=/[&\u00A0"]/g,gc=/[&\u00A0<>]/g;function hc(a){switch(a){case "&":return"&amp;";case "<":return"&lt;";case ">":return"&gt;";case '"':return"&quot;";case "\u00a0":return"&nbsp;"}}function ic(a){for(var b={},c=0;c<a.length;c++)b[a[c]]=!0;return b}var jc=ic("area base br col command embed hr img input keygen link meta param source track wbr".split(" ")),kc=ic("style script xmp iframe noembed noframes plaintext noscript".split(" "));
function lc(a,b){"template"===a.localName&&(a=a.content);for(var c="",d=b?b(a):a.childNodes,e=0,f=d.length,h;e<f&&(h=d[e]);e++){a:{var g=h;var k=a;var l=b;switch(g.nodeType){case Node.ELEMENT_NODE:for(var m=g.localName,n="<"+m,t=g.attributes,C=0;k=t[C];C++)n+=" "+k.name+'="'+k.value.replace(fc,hc)+'"';n+=">";g=jc[m]?n:n+lc(g,l)+"</"+m+">";break a;case Node.TEXT_NODE:g=g.data;g=k&&kc[k.localName]?g:g.replace(gc,hc);break a;case Node.COMMENT_NODE:g="\x3c!--"+g.data+"--\x3e";break a;default:throw window.console.error(g),
Error("not implemented");}}c+=g}return c};var B={},D=document.createTreeWalker(document,NodeFilter.SHOW_ALL,null,!1),E=document.createTreeWalker(document,NodeFilter.SHOW_ELEMENT,null,!1);function mc(a){var b=[];D.currentNode=a;for(a=D.firstChild();a;)b.push(a),a=D.nextSibling();return b}B.parentNode=function(a){D.currentNode=a;return D.parentNode()};B.firstChild=function(a){D.currentNode=a;return D.firstChild()};B.lastChild=function(a){D.currentNode=a;return D.lastChild()};B.previousSibling=function(a){D.currentNode=a;return D.previousSibling()};
B.nextSibling=function(a){D.currentNode=a;return D.nextSibling()};B.childNodes=mc;B.parentElement=function(a){E.currentNode=a;return E.parentNode()};B.firstElementChild=function(a){E.currentNode=a;return E.firstChild()};B.lastElementChild=function(a){E.currentNode=a;return E.lastChild()};B.previousElementSibling=function(a){E.currentNode=a;return E.previousSibling()};B.nextElementSibling=function(a){E.currentNode=a;return E.nextSibling()};
B.children=function(a){var b=[];E.currentNode=a;for(a=E.firstChild();a;)b.push(a),a=E.nextSibling();return b};B.innerHTML=function(a){return lc(a,function(a){return mc(a)})};B.textContent=function(a){switch(a.nodeType){case Node.ELEMENT_NODE:case Node.DOCUMENT_FRAGMENT_NODE:a=document.createTreeWalker(a,NodeFilter.SHOW_TEXT,null,!1);for(var b="",c;c=a.nextNode();)b+=c.nodeValue;return b;default:return a.nodeValue}};var nc=Object.getOwnPropertyDescriptor(Element.prototype,"innerHTML")||Object.getOwnPropertyDescriptor(HTMLElement.prototype,"innerHTML"),oc=document.implementation.createHTMLDocument("inert"),pc=Object.getOwnPropertyDescriptor(Document.prototype,"activeElement"),qc={parentElement:{get:function(){var a=this.__shady&&this.__shady.parentNode;a&&a.nodeType!==Node.ELEMENT_NODE&&(a=null);return void 0!==a?a:B.parentElement(this)},configurable:!0},parentNode:{get:function(){var a=this.__shady&&this.__shady.parentNode;
return void 0!==a?a:B.parentNode(this)},configurable:!0},nextSibling:{get:function(){var a=this.__shady&&this.__shady.nextSibling;return void 0!==a?a:B.nextSibling(this)},configurable:!0},previousSibling:{get:function(){var a=this.__shady&&this.__shady.previousSibling;return void 0!==a?a:B.previousSibling(this)},configurable:!0},className:{get:function(){return this.getAttribute("class")||""},set:function(a){this.setAttribute("class",a)},configurable:!0},nextElementSibling:{get:function(){if(this.__shady&&
void 0!==this.__shady.nextSibling){for(var a=this.nextSibling;a&&a.nodeType!==Node.ELEMENT_NODE;)a=a.nextSibling;return a}return B.nextElementSibling(this)},configurable:!0},previousElementSibling:{get:function(){if(this.__shady&&void 0!==this.__shady.previousSibling){for(var a=this.previousSibling;a&&a.nodeType!==Node.ELEMENT_NODE;)a=a.previousSibling;return a}return B.previousElementSibling(this)},configurable:!0}},rc={childNodes:{get:function(){if(vb(this)){if(!this.__shady.childNodes){this.__shady.childNodes=
[];for(var a=this.firstChild;a;a=a.nextSibling)this.__shady.childNodes.push(a)}var b=this.__shady.childNodes}else b=B.childNodes(this);b.item=function(a){return b[a]};return b},configurable:!0},childElementCount:{get:function(){return this.children.length},configurable:!0},firstChild:{get:function(){var a=this.__shady&&this.__shady.firstChild;return void 0!==a?a:B.firstChild(this)},configurable:!0},lastChild:{get:function(){var a=this.__shady&&this.__shady.lastChild;return void 0!==a?a:B.lastChild(this)},
configurable:!0},textContent:{get:function(){if(vb(this)){for(var a=[],b=0,c=this.childNodes,d;d=c[b];b++)d.nodeType!==Node.COMMENT_NODE&&a.push(d.textContent);return a.join("")}return B.textContent(this)},set:function(a){if("undefined"===typeof a||null===a)a="";switch(this.nodeType){case Node.ELEMENT_NODE:case Node.DOCUMENT_FRAGMENT_NODE:for(;this.firstChild;)this.removeChild(this.firstChild);(0<a.length||this.nodeType===Node.ELEMENT_NODE)&&this.appendChild(document.createTextNode(a));break;default:this.nodeValue=
a}},configurable:!0},firstElementChild:{get:function(){if(this.__shady&&void 0!==this.__shady.firstChild){for(var a=this.firstChild;a&&a.nodeType!==Node.ELEMENT_NODE;)a=a.nextSibling;return a}return B.firstElementChild(this)},configurable:!0},lastElementChild:{get:function(){if(this.__shady&&void 0!==this.__shady.lastChild){for(var a=this.lastChild;a&&a.nodeType!==Node.ELEMENT_NODE;)a=a.previousSibling;return a}return B.lastElementChild(this)},configurable:!0},children:{get:function(){var a=vb(this)?
Array.prototype.filter.call(this.childNodes,function(a){return a.nodeType===Node.ELEMENT_NODE}):B.children(this);a.item=function(b){return a[b]};return a},configurable:!0},innerHTML:{get:function(){var a="template"===this.localName?this.content:this;return vb(this)?lc(a):B.innerHTML(a)},set:function(a){for(var b="template"===this.localName?this.content:this;b.firstChild;)b.removeChild(b.firstChild);var c=this.localName;c&&"template"!==c||(c="div");c=oc.createElement(c);for(nc&&nc.set?nc.set.call(c,
a):c.innerHTML=a;c.firstChild;)b.appendChild(c.firstChild)},configurable:!0}},sc={shadowRoot:{get:function(){return this.__shady&&this.__shady.Va||null},configurable:!0}},tc={activeElement:{get:function(){var a=pc&&pc.get?pc.get.call(document):y.M?void 0:document.activeElement;if(a&&a.nodeType){var b=!!z(this);if(this===document||b&&this.host!==a&&A.contains.call(this.host,a)){for(b=wb(a);b&&b!==this;)a=b.host,b=wb(a);a=this===document?b?null:a:b===this?a:null}else a=null}else a=null;return a},set:function(){},
configurable:!0}};function F(a,b,c){for(var d in b){var e=Object.getOwnPropertyDescriptor(a,d);e&&e.configurable||!e&&c?Object.defineProperty(a,d,b[d]):c&&console.warn("Could not define",d,"on",a)}}function G(a){F(a,qc);F(a,rc);F(a,tc)}var uc=y.M?function(){}:function(a){a.__shady&&a.__shady.za||(a.__shady=a.__shady||{},a.__shady.za=!0,F(a,qc,!0))},vc=y.M?function(){}:function(a){a.__shady&&a.__shady.xa||(a.__shady=a.__shady||{},a.__shady.xa=!0,F(a,rc,!0),F(a,sc,!0))};function wc(a,b,c){uc(a);c=c||null;a.__shady=a.__shady||{};b.__shady=b.__shady||{};c&&(c.__shady=c.__shady||{});a.__shady.previousSibling=c?c.__shady.previousSibling:b.lastChild;var d=a.__shady.previousSibling;d&&d.__shady&&(d.__shady.nextSibling=a);(d=a.__shady.nextSibling=c)&&d.__shady&&(d.__shady.previousSibling=a);a.__shady.parentNode=b;c?c===b.__shady.firstChild&&(b.__shady.firstChild=a):(b.__shady.lastChild=a,b.__shady.firstChild||(b.__shady.firstChild=a));b.__shady.childNodes=null}
function xc(a){if(!a.__shady||void 0===a.__shady.firstChild){a.__shady=a.__shady||{};a.__shady.firstChild=B.firstChild(a);a.__shady.lastChild=B.lastChild(a);vc(a);for(var b=a.__shady.childNodes=B.childNodes(a),c=0,d;c<b.length&&(d=b[c]);c++)d.__shady=d.__shady||{},d.__shady.parentNode=a,d.__shady.nextSibling=b[c+1]||null,d.__shady.previousSibling=b[c-1]||null,uc(d)}};function yc(a,b,c){if(b===a)throw Error("Failed to execute 'appendChild' on 'Node': The new child element contains the parent.");if(c){var d=c.__shady&&c.__shady.parentNode;if(void 0!==d&&d!==a||void 0===d&&B.parentNode(c)!==a)throw Error("Failed to execute 'insertBefore' on 'Node': The node before which the new node is to be inserted is not a child of this node.");}if(c===b)return b;b.parentNode&&zc(b.parentNode,b);d=wb(a);var e;if(e=d)a:{if(!b.__noInsertionPoint){var f;"slot"===b.localName?f=[b]:
b.querySelectorAll&&(f=b.querySelectorAll("slot"));if(f&&f.length){e=f;break a}}e=void 0}(f=e)&&d.H.push.apply(d.H,[].concat(f instanceof Array?f:ja(ia(f))));d&&("slot"===a.localName||f)&&Ac(d);if(vb(a)){d=c;vc(a);a.__shady=a.__shady||{};void 0!==a.__shady.firstChild&&(a.__shady.childNodes=null);if(b.nodeType===Node.DOCUMENT_FRAGMENT_NODE){f=b.childNodes;for(e=0;e<f.length;e++)wc(f[e],a,d);b.__shady=b.__shady||{};d=void 0!==b.__shady.firstChild?null:void 0;b.__shady.firstChild=b.__shady.lastChild=
d;b.__shady.childNodes=d}else wc(b,a,d);if(Bc(a)){Ac(a.__shady.root);var h=!0}else a.__shady.root&&(h=!0)}h||(h=z(a)?a.host:a,c?(c=Cc(c),A.insertBefore.call(h,b,c)):A.appendChild.call(h,b));Dc(a,b);return b}
function zc(a,b){if(b.parentNode!==a)throw Error("The node to be removed is not a child of this node: "+b);var c=wb(b);if(vb(a)){b.__shady=b.__shady||{};a.__shady=a.__shady||{};b===a.__shady.firstChild&&(a.__shady.firstChild=b.__shady.nextSibling);b===a.__shady.lastChild&&(a.__shady.lastChild=b.__shady.previousSibling);var d=b.__shady.previousSibling,e=b.__shady.nextSibling;d&&(d.__shady=d.__shady||{},d.__shady.nextSibling=e);e&&(e.__shady=e.__shady||{},e.__shady.previousSibling=d);b.__shady.parentNode=
b.__shady.previousSibling=b.__shady.nextSibling=void 0;void 0!==a.__shady.childNodes&&(a.__shady.childNodes=null);if(Bc(a)){Ac(a.__shady.root);var f=!0}}Ec(b);if(c){(d=a&&"slot"===a.localName)&&(f=!0);Fc(c);e=c.l;for(var h in e)for(var g=e[h],k=0;k<g.length;k++){var l=g[k];if(Hb(b,l)){g.splice(k,1);var m=c.o.indexOf(l);0<=m&&c.o.splice(m,1);k--;if(m=l.__shady.K)for(l=0;l<m.length;l++){var n=m[l],t=B.parentNode(n);t&&A.removeChild.call(t,n)}m=!0}}(m||d)&&Ac(c)}f||(f=z(a)?a.host:a,(!a.__shady.root&&
"slot"!==b.localName||f===B.parentNode(b))&&A.removeChild.call(f,b));Dc(a,null,b);return b}function Ec(a){if(a.__shady&&void 0!==a.__shady.ka)for(var b=a.childNodes,c=0,d=b.length,e;c<d&&(e=b[c]);c++)Ec(e);a.__shady&&(a.__shady.ka=void 0)}function Cc(a){var b=a;a&&"slot"===a.localName&&(b=(b=a.__shady&&a.__shady.K)&&b.length?b[0]:Cc(a.nextSibling));return b}function Bc(a){return(a=a&&a.__shady&&a.__shady.root)&&Gc(a)}
function Hc(a,b){if("slot"===b)a=a.parentNode,Bc(a)&&Ac(a.__shady.root);else if("slot"===a.localName&&"name"===b&&(b=wb(a))){var c=a.Aa,d=Ic(a);if(d!==c){c=b.l[c];var e=c.indexOf(a);0<=e&&c.splice(e,1);c=b.l[d]||(b.l[d]=[]);c.push(a);1<c.length&&(b.l[d]=Jc(c))}Ac(b)}}function Dc(a,b,c){if(a=a.__shady&&a.__shady.N)b&&a.addedNodes.push(b),c&&a.removedNodes.push(c),Nb(a)}
function Kc(a){if(a&&a.nodeType){a.__shady=a.__shady||{};var b=a.__shady.ka;void 0===b&&(b=z(a)?a:(b=a.parentNode)?Kc(b):a,A.contains.call(document.documentElement,a)&&(a.__shady.ka=b));return b}}function Lc(a,b,c){var d=[];Mc(a.childNodes,b,c,d);return d}function Mc(a,b,c,d){for(var e=0,f=a.length,h;e<f&&(h=a[e]);e++){var g;if(g=h.nodeType===Node.ELEMENT_NODE){g=h;var k=b,l=c,m=d,n=k(g);n&&m.push(g);l&&l(n)?g=n:(Mc(g.childNodes,k,l,m),g=void 0)}if(g)break}}var Nc=null;
function Oc(a,b,c){Nc||(Nc=window.ShadyCSS&&window.ShadyCSS.ScopingShim);Nc&&"class"===b?Nc.setElementClass(a,c):(A.setAttribute.call(a,b,c),Hc(a,b))}function Pc(a,b){if(a.ownerDocument!==document)return A.importNode.call(document,a,b);var c=A.importNode.call(document,a,!1);if(b){a=a.childNodes;b=0;for(var d;b<a.length;b++)d=Pc(a[b],!0),c.appendChild(d)}return c};var Qc="__eventWrappers"+Date.now(),Rc={blur:!0,focus:!0,focusin:!0,focusout:!0,click:!0,dblclick:!0,mousedown:!0,mouseenter:!0,mouseleave:!0,mousemove:!0,mouseout:!0,mouseover:!0,mouseup:!0,wheel:!0,beforeinput:!0,input:!0,keydown:!0,keyup:!0,compositionstart:!0,compositionupdate:!0,compositionend:!0,touchstart:!0,touchend:!0,touchmove:!0,touchcancel:!0,pointerover:!0,pointerenter:!0,pointerdown:!0,pointermove:!0,pointerup:!0,pointercancel:!0,pointerout:!0,pointerleave:!0,gotpointercapture:!0,lostpointercapture:!0,
dragstart:!0,drag:!0,dragenter:!0,dragleave:!0,dragover:!0,drop:!0,dragend:!0,DOMActivate:!0,DOMFocusIn:!0,DOMFocusOut:!0,keypress:!0};function Sc(a,b){var c=[],d=a;for(a=a===window?window:a.getRootNode();d;)c.push(d),d=d.assignedSlot?d.assignedSlot:d.nodeType===Node.DOCUMENT_FRAGMENT_NODE&&d.host&&(b||d!==a)?d.host:d.parentNode;c[c.length-1]===document&&c.push(window);return c}
function Tc(a,b){if(!z)return a;a=Sc(a,!0);for(var c=0,d,e,f,h;c<b.length;c++)if(d=b[c],f=d===window?window:d.getRootNode(),f!==e&&(h=a.indexOf(f),e=f),!z(f)||-1<h)return d}
var Uc={get composed(){!1!==this.isTrusted&&void 0===this.Z&&(this.Z=Rc[this.type]);return this.Z||!1},composedPath:function(){this.b||(this.b=Sc(this.__target,this.composed));return this.b},get target(){return Tc(this.currentTarget,this.composedPath())},get relatedTarget(){if(!this.$)return null;this.c||(this.c=Sc(this.$,!0));return Tc(this.currentTarget,this.c)},stopPropagation:function(){Event.prototype.stopPropagation.call(this);this.a=!0},stopImmediatePropagation:function(){Event.prototype.stopImmediatePropagation.call(this);
this.a=this.h=!0}};function Vc(a){function b(b,d){b=new a(b,d);b.Z=d&&!!d.composed;return b}Bb(b,a);b.prototype=a.prototype;return b}var Wc={focus:!0,blur:!0};function Xc(a){return a.__target!==a.target||a.$!==a.relatedTarget}function Yc(a,b,c){if(c=b.__handlers&&b.__handlers[a.type]&&b.__handlers[a.type][c])for(var d=0,e;(e=c[d])&&(!Xc(a)||a.target!==a.relatedTarget)&&(e.call(b,a),!a.h);d++);}
function Zc(a){var b=a.composedPath();Object.defineProperty(a,"currentTarget",{get:function(){return d},configurable:!0});for(var c=b.length-1;0<=c;c--){var d=b[c];Yc(a,d,"capture");if(a.a)return}Object.defineProperty(a,"eventPhase",{get:function(){return Event.AT_TARGET}});var e;for(c=0;c<b.length;c++){d=b[c];var f=d.__shady&&d.__shady.root;if(0===c||f&&f===e)if(Yc(a,d,"bubble"),d!==window&&(e=d.getRootNode()),a.a)break}}
function $c(a,b,c,d,e,f){for(var h=0;h<a.length;h++){var g=a[h],k=g.type,l=g.capture,m=g.once,n=g.passive;if(b===g.node&&c===k&&d===l&&e===m&&f===n)return h}return-1}
function ad(a,b,c){if(b){var d=typeof b;if("function"===d||"object"===d)if("object"!==d||b.handleEvent&&"function"===typeof b.handleEvent){if(c&&"object"===typeof c){var e=!!c.capture;var f=!!c.once;var h=!!c.passive}else e=!!c,h=f=!1;var g=c&&c.aa||this,k=b[Qc];if(k){if(-1<$c(k,g,a,e,f,h))return}else b[Qc]=[];k=function(e){f&&this.removeEventListener(a,b,c);e.__target||bd(e);if(g!==this){var h=Object.getOwnPropertyDescriptor(e,"currentTarget");Object.defineProperty(e,"currentTarget",{get:function(){return g},
configurable:!0})}if(e.composed||-1<e.composedPath().indexOf(g))if(Xc(e)&&e.target===e.relatedTarget)e.eventPhase===Event.BUBBLING_PHASE&&e.stopImmediatePropagation();else if(e.eventPhase===Event.CAPTURING_PHASE||e.bubbles||e.target===g||g instanceof Window){var k="function"===d?b.call(g,e):b.handleEvent&&b.handleEvent(e);g!==this&&(h?(Object.defineProperty(e,"currentTarget",h),h=null):delete e.currentTarget);return k}};b[Qc].push({node:this,type:a,capture:e,once:f,passive:h,cb:k});Wc[a]?(this.__handlers=
this.__handlers||{},this.__handlers[a]=this.__handlers[a]||{capture:[],bubble:[]},this.__handlers[a][e?"capture":"bubble"].push(k)):(this instanceof Window?A.ab:A.addEventListener).call(this,a,k,c)}}}
function cd(a,b,c){if(b){if(c&&"object"===typeof c){var d=!!c.capture;var e=!!c.once;var f=!!c.passive}else d=!!c,f=e=!1;var h=c&&c.aa||this,g=void 0;var k=null;try{k=b[Qc]}catch(l){}k&&(e=$c(k,h,a,d,e,f),-1<e&&(g=k.splice(e,1)[0].cb,k.length||(b[Qc]=void 0)));(this instanceof Window?A.bb:A.removeEventListener).call(this,a,g||b,c);g&&Wc[a]&&this.__handlers&&this.__handlers[a]&&(a=this.__handlers[a][d?"capture":"bubble"],g=a.indexOf(g),-1<g&&a.splice(g,1))}}
function dd(){for(var a in Wc)window.addEventListener(a,function(a){a.__target||(bd(a),Zc(a))},!0)}function bd(a){a.__target=a.target;a.$=a.relatedTarget;if(y.M){var b=Object.getPrototypeOf(a);if(!b.hasOwnProperty("__patchProto")){var c=Object.create(b);c.fb=b;zb(c,Uc);b.__patchProto=c}a.__proto__=b.__patchProto}else zb(a,Uc)}var ed=Vc(window.Event),fd=Vc(window.CustomEvent),gd=Vc(window.MouseEvent);function hd(a,b){return{index:a,O:[],U:b}}
function id(a,b,c,d){var e=0,f=0,h=0,g=0,k=Math.min(b-e,d-f);if(0==e&&0==f)a:{for(h=0;h<k;h++)if(a[h]!==c[h])break a;h=k}if(b==a.length&&d==c.length){g=a.length;for(var l=c.length,m=0;m<k-h&&jd(a[--g],c[--l]);)m++;g=m}e+=h;f+=h;b-=g;d-=g;if(0==b-e&&0==d-f)return[];if(e==b){for(b=hd(e,0);f<d;)b.O.push(c[f++]);return[b]}if(f==d)return[hd(e,b-e)];k=e;h=f;d=d-h+1;g=b-k+1;b=Array(d);for(l=0;l<d;l++)b[l]=Array(g),b[l][0]=l;for(l=0;l<g;l++)b[0][l]=l;for(l=1;l<d;l++)for(m=1;m<g;m++)if(a[k+m-1]===c[h+l-1])b[l][m]=
b[l-1][m-1];else{var n=b[l-1][m]+1,t=b[l][m-1]+1;b[l][m]=n<t?n:t}k=b.length-1;h=b[0].length-1;d=b[k][h];for(a=[];0<k||0<h;)0==k?(a.push(2),h--):0==h?(a.push(3),k--):(g=b[k-1][h-1],l=b[k-1][h],m=b[k][h-1],n=l<m?l<g?l:g:m<g?m:g,n==g?(g==d?a.push(0):(a.push(1),d=g),k--,h--):n==l?(a.push(3),k--,d=l):(a.push(2),h--,d=m));a.reverse();b=void 0;k=[];for(h=0;h<a.length;h++)switch(a[h]){case 0:b&&(k.push(b),b=void 0);e++;f++;break;case 1:b||(b=hd(e,0));b.U++;e++;b.O.push(c[f]);f++;break;case 2:b||(b=hd(e,0));
b.U++;e++;break;case 3:b||(b=hd(e,0)),b.O.push(c[f]),f++}b&&k.push(b);return k}function jd(a,b){return a===b};var kd={};function H(a,b,c){if(a!==kd)throw new TypeError("Illegal constructor");a=document.createDocumentFragment();a.__proto__=H.prototype;a.ya="ShadyRoot";xc(b);xc(a);a.host=b;a.Fa=c&&c.mode;b.__shady=b.__shady||{};b.__shady.root=a;b.__shady.Va="closed"!==a.Fa?a:null;a.T=!1;a.o=[];a.l={};a.H=[];c=B.childNodes(b);for(var d=0,e=c.length;d<e;d++)A.removeChild.call(b,c[d]);return a}H.prototype=Object.create(DocumentFragment.prototype);function Ac(a){a.T||(a.T=!0,Kb(function(){return ld(a)}))}
function ld(a){for(var b;a;){a.T&&(b=a);a:{var c=a;a=c.host.getRootNode();if(z(a))for(var d=c.host.childNodes,e=0;e<d.length;e++)if(c=d[e],"slot"==c.localName)break a;a=void 0}}b&&b._renderRoot()}
H.prototype._renderRoot=function(){this.T=!1;Fc(this);for(var a=0,b;a<this.o.length;a++){b=this.o[a];var c=b.__shady.assignedNodes;b.__shady.assignedNodes=[];b.__shady.K=[];if(b.__shady.oa=c)for(var d=0;d<c.length;d++){var e=c[d];e.__shady.ga=e.__shady.assignedSlot;e.__shady.assignedSlot===b&&(e.__shady.assignedSlot=null)}}for(b=this.host.firstChild;b;b=b.nextSibling)md(this,b);for(a=0;a<this.o.length;a++){b=this.o[a];if(!b.__shady.assignedNodes.length)for(c=b.firstChild;c;c=c.nextSibling)md(this,
c,b);c=b.parentNode;(c=c.__shady&&c.__shady.root)&&Gc(c)&&c._renderRoot();nd(this,b.__shady.K,b.__shady.assignedNodes);if(c=b.__shady.oa){for(d=0;d<c.length;d++)c[d].__shady.ga=null;b.__shady.oa=null;c.length>b.__shady.assignedNodes.length&&(b.__shady.ia=!0)}b.__shady.ia&&(b.__shady.ia=!1,od(this,b))}a=this.o;b=[];for(c=0;c<a.length;c++)d=a[c].parentNode,d.__shady&&d.__shady.root||!(0>b.indexOf(d))||b.push(d);for(a=0;a<b.length;a++){c=b[a];d=c===this?this.host:c;e=[];c=c.childNodes;for(var f=0;f<
c.length;f++){var h=c[f];if("slot"==h.localName){h=h.__shady.K;for(var g=0;g<h.length;g++)e.push(h[g])}else e.push(h)}c=void 0;f=B.childNodes(d);h=id(e,e.length,f,f.length);for(var k=g=0;g<h.length&&(c=h[g]);g++){for(var l=0,m;l<c.O.length&&(m=c.O[l]);l++)B.parentNode(m)===d&&A.removeChild.call(d,m),f.splice(c.index+k,1);k-=c.U}for(k=0;k<h.length&&(c=h[k]);k++)for(g=f[c.index],l=c.index;l<c.index+c.U;l++)m=e[l],A.insertBefore.call(d,m,g),f.splice(l,0,m)}};
function md(a,b,c){b.__shady=b.__shady||{};var d=b.__shady.ga;b.__shady.ga=null;c||(c=(a=a.l[b.slot||"__catchall"])&&a[0]);c?(c.__shady.assignedNodes.push(b),b.__shady.assignedSlot=c):b.__shady.assignedSlot=void 0;d!==b.__shady.assignedSlot&&b.__shady.assignedSlot&&(b.__shady.assignedSlot.__shady.ia=!0)}function nd(a,b,c){for(var d=0,e;d<c.length&&(e=c[d]);d++)if("slot"==e.localName){var f=e.__shady.assignedNodes;f&&f.length&&nd(a,b,f)}else b.push(c[d])}
function od(a,b){A.dispatchEvent.call(b,new Event("slotchange"));b.__shady.assignedSlot&&od(a,b.__shady.assignedSlot)}function Fc(a){if(a.H.length){for(var b=a.H,c,d=0;d<b.length;d++){var e=b[d];e.__shady=e.__shady||{};xc(e);xc(e.parentNode);var f=Ic(e);a.l[f]?(c=c||{},c[f]=!0,a.l[f].push(e)):a.l[f]=[e];a.o.push(e)}if(c)for(var h in c)a.l[h]=Jc(a.l[h]);a.H=[]}}function Ic(a){var b=a.name||a.getAttribute("name")||"__catchall";return a.Aa=b}
function Jc(a){return a.sort(function(a,c){a=pd(a);for(var b=pd(c),e=0;e<a.length;e++){c=a[e];var f=b[e];if(c!==f)return a=Array.from(c.parentNode.childNodes),a.indexOf(c)-a.indexOf(f)}})}function pd(a){var b=[];do b.unshift(a);while(a=a.parentNode);return b}function Gc(a){Fc(a);return!!a.o.length}H.prototype.addEventListener=function(a,b,c){"object"!==typeof c&&(c={capture:!!c});c.aa=this;this.host.addEventListener(a,b,c)};
H.prototype.removeEventListener=function(a,b,c){"object"!==typeof c&&(c={capture:!!c});c.aa=this;this.host.removeEventListener(a,b,c)};H.prototype.getElementById=function(a){return Lc(this,function(b){return b.id==a},function(a){return!!a})[0]||null};var qd=H.prototype;F(qd,rc,!0);F(qd,tc,!0);function rd(a){var b=a.getRootNode();z(b)&&ld(b);return a.__shady&&a.__shady.assignedSlot||null}
var sd={addEventListener:ad.bind(window),removeEventListener:cd.bind(window)},td={addEventListener:ad,removeEventListener:cd,appendChild:function(a){return yc(this,a)},insertBefore:function(a,b){return yc(this,a,b)},removeChild:function(a){return zc(this,a)},replaceChild:function(a,b){yc(this,a,b);zc(this,b);return a},cloneNode:function(a){if("template"==this.localName)var b=A.cloneNode.call(this,a);else if(b=A.cloneNode.call(this,!1),a){a=this.childNodes;for(var c=0,d;c<a.length;c++)d=a[c].cloneNode(!0),
b.appendChild(d)}return b},getRootNode:function(){return Kc(this)},contains:function(a){return Hb(this,a)},get isConnected(){var a=this.ownerDocument;if(Gb&&A.contains.call(a,this)||a.documentElement&&A.contains.call(a.documentElement,this))return!0;for(a=this;a&&!(a instanceof Document);)a=a.parentNode||(a instanceof H?a.host:void 0);return!!(a&&a instanceof Document)},dispatchEvent:function(a){Lb();return A.dispatchEvent.call(this,a)}},ud={get assignedSlot(){return rd(this)}},vd={querySelector:function(a){return Lc(this,
function(b){return yb.call(b,a)},function(a){return!!a})[0]||null},querySelectorAll:function(a){return Lc(this,function(b){return yb.call(b,a)})}},wd={assignedNodes:function(a){if("slot"===this.localName){var b=this.getRootNode();z(b)&&ld(b);return this.__shady?(a&&a.flatten?this.__shady.K:this.__shady.assignedNodes)||[]:[]}}},xd=Ab({setAttribute:function(a,b){Oc(this,a,b)},removeAttribute:function(a){A.removeAttribute.call(this,a);Hc(this,a)},attachShadow:function(a){if(!this)throw"Must provide a host.";
if(!a)throw"Not enough arguments.";return new H(kd,this,a)},get slot(){return this.getAttribute("slot")},set slot(a){Oc(this,"slot",a)},get assignedSlot(){return rd(this)}},vd,wd);Object.defineProperties(xd,sc);var yd=Ab({importNode:function(a,b){return Pc(a,b)},getElementById:function(a){return Lc(this,function(b){return b.id==a},function(a){return!!a})[0]||null}},vd);Object.defineProperties(yd,{_activeElement:tc.activeElement});
var zd=HTMLElement.prototype.blur,Ad=Ab({blur:function(){var a=this.__shady&&this.__shady.root;(a=a&&a.activeElement)?a.blur():zd.call(this)}});function I(a,b){for(var c=Object.getOwnPropertyNames(b),d=0;d<c.length;d++){var e=c[d],f=Object.getOwnPropertyDescriptor(b,e);f.value?a[e]=f.value:Object.defineProperty(a,e,f)}};if(y.sa){var ShadyDOM={inUse:y.sa,patch:function(a){return a},isShadyRoot:z,enqueue:Kb,flush:Lb,settings:y,filterMutations:Rb,observeChildren:Pb,unobserveChildren:Qb,nativeMethods:A,nativeTree:B};window.ShadyDOM=ShadyDOM;window.Event=ed;window.CustomEvent=fd;window.MouseEvent=gd;dd();var Bd=window.customElements&&window.customElements.nativeHTMLElement||HTMLElement;I(window.Node.prototype,td);I(window.Window.prototype,sd);I(window.Text.prototype,ud);I(window.DocumentFragment.prototype,vd);I(window.Element.prototype,
xd);I(window.Document.prototype,yd);window.HTMLSlotElement&&I(window.HTMLSlotElement.prototype,wd);I(Bd.prototype,Ad);y.M&&(G(window.Node.prototype),G(window.Text.prototype),G(window.DocumentFragment.prototype),G(window.Element.prototype),G(Bd.prototype),G(window.Document.prototype),window.HTMLSlotElement&&G(window.HTMLSlotElement.prototype));window.ShadowRoot=H};var Cd=new Set("annotation-xml color-profile font-face font-face-src font-face-uri font-face-format font-face-name missing-glyph".split(" "));function Dd(a){var b=Cd.has(a);a=/^[a-z][.0-9_a-z]*-[\-.0-9_a-z]*$/.test(a);return!b&&a}function K(a){var b=a.isConnected;if(void 0!==b)return b;for(;a&&!(a.__CE_isImportDocument||a instanceof Document);)a=a.parentNode||(window.ShadowRoot&&a instanceof ShadowRoot?a.host:void 0);return!(!a||!(a.__CE_isImportDocument||a instanceof Document))}
function Ed(a,b){for(;b&&b!==a&&!b.nextSibling;)b=b.parentNode;return b&&b!==a?b.nextSibling:null}
function L(a,b,c){c=void 0===c?new Set:c;for(var d=a;d;){if(d.nodeType===Node.ELEMENT_NODE){var e=d;b(e);var f=e.localName;if("link"===f&&"import"===e.getAttribute("rel")){d=e.import;if(d instanceof Node&&!c.has(d))for(c.add(d),d=d.firstChild;d;d=d.nextSibling)L(d,b,c);d=Ed(a,e);continue}else if("template"===f){d=Ed(a,e);continue}if(e=e.__CE_shadowRoot)for(e=e.firstChild;e;e=e.nextSibling)L(e,b,c)}d=d.firstChild?d.firstChild:Ed(a,d)}}function M(a,b,c){a[b]=c};function Fd(){this.a=new Map;this.s=new Map;this.h=[];this.c=!1}function Gd(a,b,c){a.a.set(b,c);a.s.set(c.constructor,c)}function Hd(a,b){a.c=!0;a.h.push(b)}function Id(a,b){a.c&&L(b,function(b){return a.b(b)})}Fd.prototype.b=function(a){if(this.c&&!a.__CE_patched){a.__CE_patched=!0;for(var b=0;b<this.h.length;b++)this.h[b](a)}};function N(a,b){var c=[];L(b,function(a){return c.push(a)});for(b=0;b<c.length;b++){var d=c[b];1===d.__CE_state?a.connectedCallback(d):Jd(a,d)}}
function O(a,b){var c=[];L(b,function(a){return c.push(a)});for(b=0;b<c.length;b++){var d=c[b];1===d.__CE_state&&a.disconnectedCallback(d)}}
function P(a,b,c){c=void 0===c?{}:c;var d=c.$a||new Set,e=c.va||function(b){return Jd(a,b)},f=[];L(b,function(b){if("link"===b.localName&&"import"===b.getAttribute("rel")){var c=b.import;c instanceof Node&&(c.__CE_isImportDocument=!0,c.__CE_hasRegistry=!0);c&&"complete"===c.readyState?c.__CE_documentLoadHandled=!0:b.addEventListener("load",function(){var c=b.import;if(!c.__CE_documentLoadHandled){c.__CE_documentLoadHandled=!0;var f=new Set(d);f.delete(c);P(a,c,{$a:f,va:e})}})}else f.push(b)},d);if(a.c)for(b=
0;b<f.length;b++)a.b(f[b]);for(b=0;b<f.length;b++)e(f[b])}
function Jd(a,b){if(void 0===b.__CE_state){var c=b.ownerDocument;if(c.defaultView||c.__CE_isImportDocument&&c.__CE_hasRegistry)if(c=a.a.get(b.localName)){c.constructionStack.push(b);var d=c.constructor;try{try{if(new d!==b)throw Error("The custom element constructor did not produce the element being upgraded.");}finally{c.constructionStack.pop()}}catch(h){throw b.__CE_state=2,h;}b.__CE_state=1;b.__CE_definition=c;if(c.attributeChangedCallback)for(c=c.observedAttributes,d=0;d<c.length;d++){var e=c[d],
f=b.getAttribute(e);null!==f&&a.attributeChangedCallback(b,e,null,f,null)}K(b)&&a.connectedCallback(b)}}}Fd.prototype.connectedCallback=function(a){var b=a.__CE_definition;b.connectedCallback&&b.connectedCallback.call(a)};Fd.prototype.disconnectedCallback=function(a){var b=a.__CE_definition;b.disconnectedCallback&&b.disconnectedCallback.call(a)};
Fd.prototype.attributeChangedCallback=function(a,b,c,d,e){var f=a.__CE_definition;f.attributeChangedCallback&&-1<f.observedAttributes.indexOf(b)&&f.attributeChangedCallback.call(a,b,c,d,e)};function Kd(a){var b=document;this.j=a;this.a=b;this.C=void 0;P(this.j,this.a);"loading"===this.a.readyState&&(this.C=new MutationObserver(this.b.bind(this)),this.C.observe(this.a,{childList:!0,subtree:!0}))}Kd.prototype.disconnect=function(){this.C&&this.C.disconnect()};Kd.prototype.b=function(a){var b=this.a.readyState;"interactive"!==b&&"complete"!==b||this.disconnect();for(b=0;b<a.length;b++)for(var c=a[b].addedNodes,d=0;d<c.length;d++)P(this.j,c[d])};function Ld(){var a=this;this.b=this.a=void 0;this.c=new Promise(function(b){a.b=b;a.a&&b(a.a)})}Ld.prototype.resolve=function(a){if(this.a)throw Error("Already resolved.");this.a=a;this.b&&this.b(a)};function Q(a){this.da=!1;this.j=a;this.ha=new Map;this.ea=function(a){return a()};this.R=!1;this.fa=[];this.Da=new Kd(a)}
Q.prototype.define=function(a,b){var c=this;if(!(b instanceof Function))throw new TypeError("Custom element constructors must be functions.");if(!Dd(a))throw new SyntaxError("The element name '"+a+"' is not valid.");if(this.j.a.get(a))throw Error("A custom element with name '"+a+"' has already been defined.");if(this.da)throw Error("A custom element is already being defined.");this.da=!0;try{var d=function(a){var b=e[a];if(void 0!==b&&!(b instanceof Function))throw Error("The '"+a+"' callback must be a function.");
return b},e=b.prototype;if(!(e instanceof Object))throw new TypeError("The custom element constructor's prototype is not an object.");var f=d("connectedCallback");var h=d("disconnectedCallback");var g=d("adoptedCallback");var k=d("attributeChangedCallback");var l=b.observedAttributes||[]}catch(m){return}finally{this.da=!1}b={localName:a,constructor:b,connectedCallback:f,disconnectedCallback:h,adoptedCallback:g,attributeChangedCallback:k,observedAttributes:l,constructionStack:[]};Gd(this.j,a,b);this.fa.push(b);
this.R||(this.R=!0,this.ea(function(){return Md(c)}))};function Md(a){if(!1!==a.R){a.R=!1;for(var b=a.fa,c=[],d=new Map,e=0;e<b.length;e++)d.set(b[e].localName,[]);P(a.j,document,{va:function(b){if(void 0===b.__CE_state){var e=b.localName,f=d.get(e);f?f.push(b):a.j.a.get(e)&&c.push(b)}}});for(e=0;e<c.length;e++)Jd(a.j,c[e]);for(;0<b.length;){var f=b.shift();e=f.localName;f=d.get(f.localName);for(var h=0;h<f.length;h++)Jd(a.j,f[h]);(e=a.ha.get(e))&&e.resolve(void 0)}}}
Q.prototype.get=function(a){if(a=this.j.a.get(a))return a.constructor};Q.prototype.a=function(a){if(!Dd(a))return Promise.reject(new SyntaxError("'"+a+"' is not a valid custom element name."));var b=this.ha.get(a);if(b)return b.c;b=new Ld;this.ha.set(a,b);this.j.a.get(a)&&!this.fa.some(function(b){return b.localName===a})&&b.resolve(void 0);return b.c};Q.prototype.b=function(a){this.Da.disconnect();var b=this.ea;this.ea=function(c){return a(function(){return b(c)})}};
window.CustomElementRegistry=Q;Q.prototype.define=Q.prototype.define;Q.prototype.get=Q.prototype.get;Q.prototype.whenDefined=Q.prototype.a;Q.prototype.polyfillWrapFlushCallback=Q.prototype.b;var Nd=window.Document.prototype.createElement,Od=window.Document.prototype.createElementNS,Pd=window.Document.prototype.importNode,Qd=window.Document.prototype.prepend,Rd=window.Document.prototype.append,Sd=window.DocumentFragment.prototype.prepend,Td=window.DocumentFragment.prototype.append,Ud=window.Node.prototype.cloneNode,Vd=window.Node.prototype.appendChild,Wd=window.Node.prototype.insertBefore,Xd=window.Node.prototype.removeChild,Yd=window.Node.prototype.replaceChild,Zd=Object.getOwnPropertyDescriptor(window.Node.prototype,
"textContent"),$d=window.Element.prototype.attachShadow,ae=Object.getOwnPropertyDescriptor(window.Element.prototype,"innerHTML"),be=window.Element.prototype.getAttribute,ce=window.Element.prototype.setAttribute,de=window.Element.prototype.removeAttribute,ee=window.Element.prototype.getAttributeNS,fe=window.Element.prototype.setAttributeNS,ge=window.Element.prototype.removeAttributeNS,he=window.Element.prototype.insertAdjacentElement,ie=window.Element.prototype.prepend,je=window.Element.prototype.append,
ke=window.Element.prototype.before,le=window.Element.prototype.after,me=window.Element.prototype.replaceWith,ne=window.Element.prototype.remove,oe=window.HTMLElement,pe=Object.getOwnPropertyDescriptor(window.HTMLElement.prototype,"innerHTML"),qe=window.HTMLElement.prototype.insertAdjacentElement;var re=new function(){};function se(){var a=te;window.HTMLElement=function(){function b(){var b=this.constructor,d=a.s.get(b);if(!d)throw Error("The custom element being constructed was not registered with `customElements`.");var e=d.constructionStack;if(0===e.length)return e=Nd.call(document,d.localName),Object.setPrototypeOf(e,b.prototype),e.__CE_state=1,e.__CE_definition=d,a.b(e),e;d=e.length-1;var f=e[d];if(f===re)throw Error("The HTMLElement constructor was either called reentrantly for this constructor or called multiple times.");
e[d]=re;Object.setPrototypeOf(f,b.prototype);a.b(f);return f}b.prototype=oe.prototype;return b}()};function ue(a,b,c){function d(b){return function(c){for(var d=[],e=0;e<arguments.length;++e)d[e-0]=arguments[e];e=[];for(var f=[],l=0;l<d.length;l++){var m=d[l];m instanceof Element&&K(m)&&f.push(m);if(m instanceof DocumentFragment)for(m=m.firstChild;m;m=m.nextSibling)e.push(m);else e.push(m)}b.apply(this,d);for(d=0;d<f.length;d++)O(a,f[d]);if(K(this))for(d=0;d<e.length;d++)f=e[d],f instanceof Element&&N(a,f)}}void 0!==c.X&&(b.prepend=d(c.X));void 0!==c.append&&(b.append=d(c.append))};function ve(){var a=te;M(Document.prototype,"createElement",function(b){if(this.__CE_hasRegistry){var c=a.a.get(b);if(c)return new c.constructor}b=Nd.call(this,b);a.b(b);return b});M(Document.prototype,"importNode",function(b,c){b=Pd.call(this,b,c);this.__CE_hasRegistry?P(a,b):Id(a,b);return b});M(Document.prototype,"createElementNS",function(b,c){if(this.__CE_hasRegistry&&(null===b||"http://www.w3.org/1999/xhtml"===b)){var d=a.a.get(c);if(d)return new d.constructor}b=Od.call(this,b,c);a.b(b);return b});
ue(a,Document.prototype,{X:Qd,append:Rd})};function we(){var a=te;function b(b,d){Object.defineProperty(b,"textContent",{enumerable:d.enumerable,configurable:!0,get:d.get,set:function(b){if(this.nodeType===Node.TEXT_NODE)d.set.call(this,b);else{var c=void 0;if(this.firstChild){var e=this.childNodes,g=e.length;if(0<g&&K(this)){c=Array(g);for(var k=0;k<g;k++)c[k]=e[k]}}d.set.call(this,b);if(c)for(b=0;b<c.length;b++)O(a,c[b])}}})}M(Node.prototype,"insertBefore",function(b,d){if(b instanceof DocumentFragment){var c=Array.prototype.slice.apply(b.childNodes);
b=Wd.call(this,b,d);if(K(this))for(d=0;d<c.length;d++)N(a,c[d]);return b}c=K(b);d=Wd.call(this,b,d);c&&O(a,b);K(this)&&N(a,b);return d});M(Node.prototype,"appendChild",function(b){if(b instanceof DocumentFragment){var c=Array.prototype.slice.apply(b.childNodes);b=Vd.call(this,b);if(K(this))for(var e=0;e<c.length;e++)N(a,c[e]);return b}c=K(b);e=Vd.call(this,b);c&&O(a,b);K(this)&&N(a,b);return e});M(Node.prototype,"cloneNode",function(b){b=Ud.call(this,b);this.ownerDocument.__CE_hasRegistry?P(a,b):
Id(a,b);return b});M(Node.prototype,"removeChild",function(b){var c=K(b),e=Xd.call(this,b);c&&O(a,b);return e});M(Node.prototype,"replaceChild",function(b,d){if(b instanceof DocumentFragment){var c=Array.prototype.slice.apply(b.childNodes);b=Yd.call(this,b,d);if(K(this))for(O(a,d),d=0;d<c.length;d++)N(a,c[d]);return b}c=K(b);var f=Yd.call(this,b,d),h=K(this);h&&O(a,d);c&&O(a,b);h&&N(a,b);return f});Zd&&Zd.get?b(Node.prototype,Zd):Hd(a,function(a){b(a,{enumerable:!0,configurable:!0,get:function(){for(var a=
[],b=0;b<this.childNodes.length;b++)a.push(this.childNodes[b].textContent);return a.join("")},set:function(a){for(;this.firstChild;)Xd.call(this,this.firstChild);Vd.call(this,document.createTextNode(a))}})})};function xe(a){var b=Element.prototype;function c(b){return function(c){for(var d=[],e=0;e<arguments.length;++e)d[e-0]=arguments[e];e=[];for(var g=[],k=0;k<d.length;k++){var l=d[k];l instanceof Element&&K(l)&&g.push(l);if(l instanceof DocumentFragment)for(l=l.firstChild;l;l=l.nextSibling)e.push(l);else e.push(l)}b.apply(this,d);for(d=0;d<g.length;d++)O(a,g[d]);if(K(this))for(d=0;d<e.length;d++)g=e[d],g instanceof Element&&N(a,g)}}void 0!==ke&&(b.before=c(ke));void 0!==ke&&(b.after=c(le));void 0!==
me&&M(b,"replaceWith",function(b){for(var c=[],d=0;d<arguments.length;++d)c[d-0]=arguments[d];d=[];for(var h=[],g=0;g<c.length;g++){var k=c[g];k instanceof Element&&K(k)&&h.push(k);if(k instanceof DocumentFragment)for(k=k.firstChild;k;k=k.nextSibling)d.push(k);else d.push(k)}g=K(this);me.apply(this,c);for(c=0;c<h.length;c++)O(a,h[c]);if(g)for(O(a,this),c=0;c<d.length;c++)h=d[c],h instanceof Element&&N(a,h)});void 0!==ne&&M(b,"remove",function(){var b=K(this);ne.call(this);b&&O(a,this)})};function ye(){var a=te;function b(b,c){Object.defineProperty(b,"innerHTML",{enumerable:c.enumerable,configurable:!0,get:c.get,set:function(b){var d=this,e=void 0;K(this)&&(e=[],L(this,function(a){a!==d&&e.push(a)}));c.set.call(this,b);if(e)for(var f=0;f<e.length;f++){var l=e[f];1===l.__CE_state&&a.disconnectedCallback(l)}this.ownerDocument.__CE_hasRegistry?P(a,this):Id(a,this);return b}})}function c(b,c){M(b,"insertAdjacentElement",function(b,d){var e=K(d);b=c.call(this,b,d);e&&O(a,d);K(b)&&N(a,d);
return b})}$d&&M(Element.prototype,"attachShadow",function(a){return this.__CE_shadowRoot=a=$d.call(this,a)});ae&&ae.get?b(Element.prototype,ae):pe&&pe.get?b(HTMLElement.prototype,pe):Hd(a,function(a){b(a,{enumerable:!0,configurable:!0,get:function(){return Ud.call(this,!0).innerHTML},set:function(a){var b="template"===this.localName,c=b?this.content:this,d=Nd.call(document,this.localName);for(d.innerHTML=a;0<c.childNodes.length;)Xd.call(c,c.childNodes[0]);for(a=b?d.content:d;0<a.childNodes.length;)Vd.call(c,
a.childNodes[0])}})});M(Element.prototype,"setAttribute",function(b,c){if(1!==this.__CE_state)return ce.call(this,b,c);var d=be.call(this,b);ce.call(this,b,c);c=be.call(this,b);a.attributeChangedCallback(this,b,d,c,null)});M(Element.prototype,"setAttributeNS",function(b,c,f){if(1!==this.__CE_state)return fe.call(this,b,c,f);var d=ee.call(this,b,c);fe.call(this,b,c,f);f=ee.call(this,b,c);a.attributeChangedCallback(this,c,d,f,b)});M(Element.prototype,"removeAttribute",function(b){if(1!==this.__CE_state)return de.call(this,
b);var c=be.call(this,b);de.call(this,b);null!==c&&a.attributeChangedCallback(this,b,c,null,null)});M(Element.prototype,"removeAttributeNS",function(b,c){if(1!==this.__CE_state)return ge.call(this,b,c);var d=ee.call(this,b,c);ge.call(this,b,c);var e=ee.call(this,b,c);d!==e&&a.attributeChangedCallback(this,c,d,e,b)});qe?c(HTMLElement.prototype,qe):he?c(Element.prototype,he):console.warn("Custom Elements: `Element#insertAdjacentElement` was not patched.");ue(a,Element.prototype,{X:ie,append:je});xe(a)}
;var ze=window.customElements;if(!ze||ze.forcePolyfill||"function"!=typeof ze.define||"function"!=typeof ze.get){var te=new Fd;se();ve();ue(te,DocumentFragment.prototype,{X:Sd,append:Td});we();ye();document.__CE_hasRegistry=!0;var customElements=new Q(te);Object.defineProperty(window,"customElements",{configurable:!0,enumerable:!0,value:customElements})};function Ae(){this.end=this.start=0;this.rules=this.parent=this.previous=null;this.cssText=this.parsedCssText="";this.atRule=!1;this.type=0;this.parsedSelector=this.selector=this.keyframesName=""}
function Be(a){a=a.replace(Ce,"").replace(De,"");var b=Ee,c=a,d=new Ae;d.start=0;d.end=c.length;for(var e=d,f=0,h=c.length;f<h;f++)if("{"===c[f]){e.rules||(e.rules=[]);var g=e,k=g.rules[g.rules.length-1]||null;e=new Ae;e.start=f+1;e.parent=g;e.previous=k;g.rules.push(e)}else"}"===c[f]&&(e.end=f+1,e=e.parent||d);return b(d,a)}
function Ee(a,b){var c=b.substring(a.start,a.end-1);a.parsedCssText=a.cssText=c.trim();a.parent&&(c=b.substring(a.previous?a.previous.end:a.parent.start,a.start-1),c=Fe(c),c=c.replace(Ge," "),c=c.substring(c.lastIndexOf(";")+1),c=a.parsedSelector=a.selector=c.trim(),a.atRule=0===c.indexOf("@"),a.atRule?0===c.indexOf("@media")?a.type=He:c.match(Ie)&&(a.type=Je,a.keyframesName=a.selector.split(Ge).pop()):a.type=0===c.indexOf("--")?Ke:Le);if(c=a.rules)for(var d=0,e=c.length,f;d<e&&(f=c[d]);d++)Ee(f,
b);return a}function Fe(a){return a.replace(/\\([0-9a-f]{1,6})\s/gi,function(a,c){a=c;for(c=6-a.length;c--;)a="0"+a;return"\\"+a})}
function Me(a,b,c){c=void 0===c?"":c;var d="";if(a.cssText||a.rules){var e=a.rules,f;if(f=e)f=e[0],f=!(f&&f.selector&&0===f.selector.indexOf("--"));if(f){f=0;for(var h=e.length,g;f<h&&(g=e[f]);f++)d=Me(g,b,d)}else b?b=a.cssText:(b=a.cssText,b=b.replace(Ne,"").replace(Oe,""),b=b.replace(Pe,"").replace(Qe,"")),(d=b.trim())&&(d="  "+d+"\n")}d&&(a.selector&&(c+=a.selector+" {\n"),c+=d,a.selector&&(c+="}\n\n"));return c}
var Le=1,Je=7,He=4,Ke=1E3,Ce=/\/\*[^*]*\*+([^/*][^*]*\*+)*\//gim,De=/@import[^;]*;/gim,Ne=/(?:^[^;\-\s}]+)?--[^;{}]*?:[^{};]*?(?:[;\n]|$)/gim,Oe=/(?:^[^;\-\s}]+)?--[^;{}]*?:[^{};]*?{[^}]*?}(?:[;\n]|$)?/gim,Pe=/@apply\s*\(?[^);]*\)?\s*(?:[;\n]|$)?/gim,Qe=/[^;:]*?:[^;]*?var\([^;]*\)(?:[;\n]|$)?/gim,Ie=/^@[^\s]*keyframes/,Ge=/\s+/g;var R=!(window.ShadyDOM&&window.ShadyDOM.inUse),Re;function Se(a){Re=a&&a.shimcssproperties?!1:R||!(navigator.userAgent.match(/AppleWebKit\/601|Edge\/15/)||!window.CSS||!CSS.supports||!CSS.supports("box-shadow","0 0 0 var(--foo)"))}window.ShadyCSS&&void 0!==window.ShadyCSS.nativeCss?Re=window.ShadyCSS.nativeCss:window.ShadyCSS?(Se(window.ShadyCSS),window.ShadyCSS=void 0):Se(window.WebComponents&&window.WebComponents.flags);var S=Re;var Te=/(?:^|[;\s{]\s*)(--[\w-]*?)\s*:\s*(?:((?:'(?:\\'|.)*?'|"(?:\\"|.)*?"|\([^)]*?\)|[^};{])+)|\{([^}]*)\}(?:(?=[;\s}])|$))/gi,Ue=/(?:^|\W+)@apply\s*\(?([^);\n]*)\)?/gi,Ve=/(--[\w-]+)\s*([:,;)]|$)/gi,We=/(animation\s*:)|(animation-name\s*:)/,Xe=/@media\s(.*)/,Ye=/\{[^}]*\}/g;var Ze=new Set;function $e(a,b){if(!a)return"";"string"===typeof a&&(a=Be(a));b&&af(a,b);return Me(a,S)}function bf(a){!a.__cssRules&&a.textContent&&(a.__cssRules=Be(a.textContent));return a.__cssRules||null}function cf(a){return!!a.parent&&a.parent.type===Je}function af(a,b,c,d){if(a){var e=!1,f=a.type;if(d&&f===He){var h=a.selector.match(Xe);h&&(window.matchMedia(h[1]).matches||(e=!0))}f===Le?b(a):c&&f===Je?c(a):f===Ke&&(e=!0);if((a=a.rules)&&!e){e=0;f=a.length;for(var g;e<f&&(g=a[e]);e++)af(g,b,c,d)}}}
function df(a,b,c,d){var e=document.createElement("style");b&&e.setAttribute("scope",b);e.textContent=a;ef(e,c,d);return e}var T=null;function ef(a,b,c){b=b||document.head;b.insertBefore(a,c&&c.nextSibling||b.firstChild);T?a.compareDocumentPosition(T)===Node.DOCUMENT_POSITION_PRECEDING&&(T=a):T=a}
function ff(a,b){var c=a.indexOf("var(");if(-1===c)return b(a,"","","");a:{var d=0;var e=c+3;for(var f=a.length;e<f;e++)if("("===a[e])d++;else if(")"===a[e]&&0===--d)break a;e=-1}d=a.substring(c+4,e);c=a.substring(0,c);a=ff(a.substring(e+1),b);e=d.indexOf(",");return-1===e?b(c,d.trim(),"",a):b(c,d.substring(0,e).trim(),d.substring(e+1).trim(),a)}function gf(a,b){R?a.setAttribute("class",b):window.ShadyDOM.nativeMethods.setAttribute.call(a,"class",b)}
function V(a){var b=a.localName,c="";b?-1<b.indexOf("-")||(c=b,b=a.getAttribute&&a.getAttribute("is")||""):(b=a.is,c=a.extends);return{is:b,P:c}};function hf(){}function jf(a,b,c){var d=W;a.__styleScoped?a.__styleScoped=null:kf(d,a,b||"",c)}function kf(a,b,c,d){b.nodeType===Node.ELEMENT_NODE&&lf(b,c,d);if(b="template"===b.localName?(b.content||b.gb).childNodes:b.children||b.childNodes)for(var e=0;e<b.length;e++)kf(a,b[e],c,d)}
function lf(a,b,c){if(b)if(a.classList)c?(a.classList.remove("style-scope"),a.classList.remove(b)):(a.classList.add("style-scope"),a.classList.add(b));else if(a.getAttribute){var d=a.getAttribute(mf);c?d&&(b=d.replace("style-scope","").replace(b,""),gf(a,b)):gf(a,(d?d+" ":"")+"style-scope "+b)}}function nf(a,b,c){var d=W,e=a.__cssBuild;R||"shady"===e?b=$e(b,c):(a=V(a),b=of(d,b,a.is,a.P,c)+"\n\n");return b.trim()}
function of(a,b,c,d,e){var f=pf(c,d);c=c?qf+c:"";return $e(b,function(b){b.c||(b.selector=b.m=rf(a,b,a.b,c,f),b.c=!0);e&&e(b,c,f)})}function pf(a,b){return b?"[is="+a+"]":a}function rf(a,b,c,d,e){var f=b.selector.split(sf);if(!cf(b)){b=0;for(var h=f.length,g;b<h&&(g=f[b]);b++)f[b]=c.call(a,g,d,e)}return f.join(sf)}function tf(a){return a.replace(uf,function(a,c,d){-1<d.indexOf("+")?d=d.replace(/\+/g,"___"):-1<d.indexOf("___")&&(d=d.replace(/___/g,"+"));return":"+c+"("+d+")"})}
hf.prototype.b=function(a,b,c){var d=!1;a=a.trim();var e=uf.test(a);e&&(a=a.replace(uf,function(a,b,c){return":"+b+"("+c.replace(/\s/g,"")+")"}),a=tf(a));a=a.replace(vf,wf+" $1");a=a.replace(xf,function(a,e,g){d||(a=yf(g,e,b,c),d=d||a.stop,e=a.Ka,g=a.value);return e+g});e&&(a=tf(a));return a};
function yf(a,b,c,d){var e=a.indexOf(zf);0<=a.indexOf(wf)?a=Af(a,d):0!==e&&(a=c?Bf(a,c):a);c=!1;0<=e&&(b="",c=!0);if(c){var f=!0;c&&(a=a.replace(Cf,function(a,b){return" > "+b}))}a=a.replace(Df,function(a,b,c){return'[dir="'+c+'"] '+b+", "+b+'[dir="'+c+'"]'});return{value:a,Ka:b,stop:f}}function Bf(a,b){a=a.split(Ef);a[0]+=b;return a.join(Ef)}
function Af(a,b){var c=a.match(Ff);return(c=c&&c[2].trim()||"")?c[0].match(Gf)?a.replace(Ff,function(a,c,f){return b+f}):c.split(Gf)[0]===b?c:Hf:a.replace(wf,b)}function If(a){a.selector===Jf&&(a.selector="html")}hf.prototype.c=function(a){return a.match(zf)?this.b(a,Kf):Bf(a.trim(),Kf)};q.Object.defineProperties(hf.prototype,{a:{configurable:!0,enumerable:!0,get:function(){return"style-scope"}}});
var uf=/:(nth[-\w]+)\(([^)]+)\)/,Kf=":not(.style-scope)",sf=",",xf=/(^|[\s>+~]+)((?:\[.+?\]|[^\s>+~=[])+)/g,Gf=/[[.:#*]/,wf=":host",Jf=":root",zf="::slotted",vf=new RegExp("^("+zf+")"),Ff=/(:host)(?:\(((?:\([^)(]*\)|[^)(]*)+?)\))/,Cf=/(?:::slotted)(?:\(((?:\([^)(]*\)|[^)(]*)+?)\))/,Df=/(.*):dir\((?:(ltr|rtl))\)/,qf=".",Ef=":",mf="class",Hf="should_not_match",W=new hf;function Lf(a,b,c,d){this.w=a||null;this.b=b||null;this.ja=c||[];this.G=null;this.P=d||"";this.a=this.u=this.B=null}function X(a){return a?a.__styleInfo:null}function Mf(a,b){return a.__styleInfo=b}Lf.prototype.c=function(){return this.w};Lf.prototype._getStyleRules=Lf.prototype.c;var Nf,Of=window.Element.prototype;Nf=Of.matches||Of.matchesSelector||Of.mozMatchesSelector||Of.msMatchesSelector||Of.oMatchesSelector||Of.webkitMatchesSelector;var Pf=navigator.userAgent.match("Trident");function Qf(){}function Rf(a){var b={},c=[],d=0;af(a,function(a){Sf(a);a.index=d++;a=a.i.cssText;for(var c;c=Ve.exec(a);){var e=c[1];":"!==c[2]&&(b[e]=!0)}},function(a){c.push(a)});a.b=c;a=[];for(var e in b)a.push(e);return a}
function Sf(a){if(!a.i){var b={},c={};Tf(a,c)&&(b.v=c,a.rules=null);b.cssText=a.parsedCssText.replace(Ye,"").replace(Te,"");a.i=b}}function Tf(a,b){var c=a.i;if(c){if(c.v)return Object.assign(b,c.v),!0}else{c=a.parsedCssText;for(var d;a=Te.exec(c);){d=(a[2]||a[3]).trim();if("inherit"!==d||"unset"!==d)b[a[1].trim()]=d;d=!0}return d}}
function Uf(a,b,c){b&&(b=0<=b.indexOf(";")?Vf(a,b,c):ff(b,function(b,e,f,h){if(!e)return b+h;(e=Uf(a,c[e],c))&&"initial"!==e?"apply-shim-inherit"===e&&(e="inherit"):e=Uf(a,c[f]||f,c)||f;return b+(e||"")+h}));return b&&b.trim()||""}
function Vf(a,b,c){b=b.split(";");for(var d=0,e,f;d<b.length;d++)if(e=b[d]){Ue.lastIndex=0;if(f=Ue.exec(e))e=Uf(a,c[f[1]],c);else if(f=e.indexOf(":"),-1!==f){var h=e.substring(f);h=h.trim();h=Uf(a,h,c)||h;e=e.substring(0,f)+h}b[d]=e&&e.lastIndexOf(";")===e.length-1?e.slice(0,-1):e||""}return b.join(";")}
function Wf(a,b){var c={},d=[];af(a,function(a){a.i||Sf(a);var e=a.m||a.parsedSelector;b&&a.i.v&&e&&Nf.call(b,e)&&(Tf(a,c),a=a.index,e=parseInt(a/32,10),d[e]=(d[e]||0)|1<<a%32)},null,!0);return{v:c,key:d}}
function Xf(a,b,c,d){b.i||Sf(b);if(b.i.v){var e=V(a);a=e.is;e=e.P;e=a?pf(a,e):"html";var f=b.parsedSelector,h=":host > *"===f||"html"===f,g=0===f.indexOf(":host")&&!h;"shady"===c&&(h=f===e+" > *."+e||-1!==f.indexOf("html"),g=!h&&0===f.indexOf(e));"shadow"===c&&(h=":host > *"===f||"html"===f,g=g&&!h);if(h||g)c=e,g&&(R&&!b.m&&(b.m=rf(W,b,W.b,a?qf+a:"",e)),c=b.m||e),d({Xa:c,Qa:g,hb:h})}}
function Yf(a,b){var c={},d={},e=b&&b.__cssBuild;af(b,function(b){Xf(a,b,e,function(e){Nf.call(a.b||a,e.Xa)&&(e.Qa?Tf(b,c):Tf(b,d))})},null,!0);return{Wa:d,Oa:c}}
function Zf(a,b,c,d){var e=V(b),f=pf(e.is,e.P),h=new RegExp("(?:^|[^.#[:])"+(b.extends?"\\"+f.slice(0,-1)+"\\]":f)+"($|[.:[\\s>+~])");e=X(b).w;var g=$f(e,d);return nf(b,e,function(b){var e="";b.i||Sf(b);b.i.cssText&&(e=Vf(a,b.i.cssText,c));b.cssText=e;if(!R&&!cf(b)&&b.cssText){var k=e=b.cssText;null==b.ra&&(b.ra=We.test(e));if(b.ra)if(null==b.W){b.W=[];for(var n in g)k=g[n],k=k(e),e!==k&&(e=k,b.W.push(n))}else{for(n=0;n<b.W.length;++n)k=g[b.W[n]],e=k(e);k=e}b.cssText=k;b.m=b.m||b.selector;e="."+d;
n=b.m.split(",");k=0;for(var t=n.length,C;k<t&&(C=n[k]);k++)n[k]=C.match(h)?C.replace(f,e):e+" "+C;b.selector=n.join(",")}})}function $f(a,b){a=a.b;var c={};if(!R&&a)for(var d=0,e=a[d];d<a.length;e=a[++d]){var f=e,h=b;f.h=new RegExp("\\b"+f.keyframesName+"(?!\\B|-)","g");f.a=f.keyframesName+"-"+h;f.m=f.m||f.selector;f.selector=f.m.replace(f.keyframesName,f.a);c[e.keyframesName]=ag(e)}return c}function ag(a){return function(b){return b.replace(a.h,a.a)}}
function bg(a,b){var c=cg,d=bf(a);a.textContent=$e(d,function(a){var d=a.cssText=a.parsedCssText;a.i&&a.i.cssText&&(d=d.replace(Ne,"").replace(Oe,""),a.cssText=Vf(c,d,b))})}q.Object.defineProperties(Qf.prototype,{a:{configurable:!0,enumerable:!0,get:function(){return"x-scope"}}});var cg=new Qf;var dg={},eg=window.customElements;if(eg&&!R){var fg=eg.define;eg.define=function(a,b,c){var d=document.createComment(" Shady DOM styles for "+a+" "),e=document.head;e.insertBefore(d,(T?T.nextSibling:null)||e.firstChild);T=d;dg[a]=d;return fg.call(eg,a,b,c)}};function gg(){this.cache={}}gg.prototype.store=function(a,b,c,d){var e=this.cache[a]||[];e.push({v:b,styleElement:c,u:d});100<e.length&&e.shift();this.cache[a]=e};gg.prototype.fetch=function(a,b,c){if(a=this.cache[a])for(var d=a.length-1;0<=d;d--){var e=a[d],f;a:{for(f=0;f<c.length;f++){var h=c[f];if(e.v[h]!==b[h]){f=!1;break a}}f=!0}if(f)return e}};function hg(){}
function ig(a){for(var b=0;b<a.length;b++){var c=a[b];if(c.target!==document.documentElement&&c.target!==document.head)for(var d=0;d<c.addedNodes.length;d++){var e=c.addedNodes[d];if(e.nodeType===Node.ELEMENT_NODE){var f=e.getRootNode();var h=e;var g=[];h.classList?g=Array.from(h.classList):h instanceof window.SVGElement&&h.hasAttribute("class")&&(g=h.getAttribute("class").split(/\s+/));h=g;g=h.indexOf(W.a);if((h=-1<g?h[g+1]:"")&&f===e.ownerDocument)jf(e,h,!0);else if(f.nodeType===Node.DOCUMENT_FRAGMENT_NODE&&
(f=f.host))if(f=V(f).is,h===f)for(e=window.ShadyDOM.nativeMethods.querySelectorAll.call(e,":not(."+W.a+")"),f=0;f<e.length;f++)lf(e[f],h);else h&&jf(e,h,!0),jf(e,f)}}}}
if(!R){var jg=new MutationObserver(ig),kg=function(a){jg.observe(a,{childList:!0,subtree:!0})};if(window.customElements&&!window.customElements.polyfillWrapFlushCallback)kg(document);else{var lg=function(){kg(document.body)};window.HTMLImports?window.HTMLImports.whenReady(lg):requestAnimationFrame(function(){if("loading"===document.readyState){var a=function(){lg();document.removeEventListener("readystatechange",a)};document.addEventListener("readystatechange",a)}else lg()})}hg=function(){ig(jg.takeRecords())}}
var mg=hg;var ng={};var og=Promise.resolve();function pg(a){if(a=ng[a])a._applyShimCurrentVersion=a._applyShimCurrentVersion||0,a._applyShimValidatingVersion=a._applyShimValidatingVersion||0,a._applyShimNextVersion=(a._applyShimNextVersion||0)+1}function qg(a){return a._applyShimCurrentVersion===a._applyShimNextVersion}function rg(a){a._applyShimValidatingVersion=a._applyShimNextVersion;a.qa||(a.qa=!0,og.then(function(){a._applyShimCurrentVersion=a._applyShimNextVersion;a.qa=!1}))};var sg=null,tg=window.HTMLImports&&window.HTMLImports.whenReady||null,ug;function vg(a){requestAnimationFrame(function(){tg?tg(a):(sg||(sg=new Promise(function(a){ug=a}),"complete"===document.readyState?ug():document.addEventListener("readystatechange",function(){"complete"===document.readyState&&ug()})),sg.then(function(){a&&a()}))})};var wg=new gg;function Y(){var a=this;this.L={};this.c=document.documentElement;var b=new Ae;b.rules=[];this.h=Mf(this.c,new Lf(b));this.s=!1;this.b=this.a=null;vg(function(){xg(a)})}p=Y.prototype;p.wa=function(){mg()};p.Ma=function(a){return bf(a)};p.Za=function(a){return $e(a)};
p.prepareTemplate=function(a,b,c){if(!a.Ia){a.Ia=!0;a.name=b;a.extends=c;ng[b]=a;var d=(d=a.content.querySelector("style"))?d.getAttribute("css-build")||"":"";var e=[];for(var f=a.content.querySelectorAll("style"),h=0;h<f.length;h++){var g=f[h];if(g.hasAttribute("shady-unscoped")){if(!R){var k=g.textContent;Ze.has(k)||(Ze.add(k),k=g.cloneNode(!0),document.head.appendChild(k));g.parentNode.removeChild(g)}}else e.push(g.textContent),g.parentNode.removeChild(g)}e=e.join("").trim();c={is:b,extends:c,
eb:d};R||jf(a.content,b);xg(this);f=Ue.test(e)||Te.test(e);Ue.lastIndex=0;Te.lastIndex=0;e=Be(e);f&&S&&this.a&&this.a.transformRules(e,b);a._styleAst=e;a.a=d;d=[];S||(d=Rf(a._styleAst));if(!d.length||S)e=R?a.content:null,b=dg[b],f=nf(c,a._styleAst),b=f.length?df(f,c.is,e,b):void 0,a.pa=b;a.Ha=d}};
function yg(a){!a.b&&window.ShadyCSS&&window.ShadyCSS.CustomStyleInterface&&(a.b=window.ShadyCSS.CustomStyleInterface,a.b.transformCallback=function(b){a.ua(b)},a.b.validateCallback=function(){requestAnimationFrame(function(){(a.b.enqueued||a.s)&&a.F()})})}function xg(a){!a.a&&window.ShadyCSS&&window.ShadyCSS.ApplyShim&&(a.a=window.ShadyCSS.ApplyShim,a.a.invalidCallback=pg);yg(a)}
p.F=function(){xg(this);if(this.b){var a=this.b.processStyles();if(this.b.enqueued){if(S)for(var b=0;b<a.length;b++){var c=this.b.getStyleForCustomStyle(a[b]);if(c&&S&&this.a){var d=bf(c);xg(this);this.a.transformRules(d);c.textContent=$e(d)}}else for(zg(this,this.c,this.h),b=0;b<a.length;b++)(c=this.b.getStyleForCustomStyle(a[b]))&&bg(c,this.h.B);this.b.enqueued=!1;this.s&&!S&&this.styleDocument()}}};
p.styleElement=function(a,b){var c=V(a).is,d=X(a);if(!d){var e=V(a);d=e.is;e=e.P;var f=dg[d];d=ng[d];if(d){var h=d._styleAst;var g=d.Ha}d=Mf(a,new Lf(h,f,g,e))}a!==this.c&&(this.s=!0);b&&(d.G=d.G||{},Object.assign(d.G,b));if(S){if(d.G){b=d.G;for(var k in b)null===k?a.style.removeProperty(k):a.style.setProperty(k,b[k])}if(((k=ng[c])||a===this.c)&&k&&k.pa&&!qg(k)){if(qg(k)||k._applyShimValidatingVersion!==k._applyShimNextVersion)xg(this),this.a&&this.a.transformRules(k._styleAst,c),k.pa.textContent=
nf(a,d.w),rg(k);R&&(c=a.shadowRoot)&&(c.querySelector("style").textContent=nf(a,d.w));d.w=k._styleAst}}else if(zg(this,a,d),d.ja&&d.ja.length){c=d;k=V(a).is;d=(b=wg.fetch(k,c.B,c.ja))?b.styleElement:null;h=c.u;(g=b&&b.u)||(g=this.L[k]=(this.L[k]||0)+1,g=k+"-"+g);c.u=g;g=c.u;e=cg;e=d?d.textContent||"":Zf(e,a,c.B,g);f=X(a);var l=f.a;l&&!R&&l!==d&&(l._useCount--,0>=l._useCount&&l.parentNode&&l.parentNode.removeChild(l));R?f.a?(f.a.textContent=e,d=f.a):e&&(d=df(e,g,a.shadowRoot,f.b)):d?d.parentNode||
(Pf&&-1<e.indexOf("@media")&&(d.textContent=e),ef(d,null,f.b)):e&&(d=df(e,g,null,f.b));d&&(d._useCount=d._useCount||0,f.a!=d&&d._useCount++,f.a=d);g=d;R||(d=c.u,f=e=a.getAttribute("class")||"",h&&(f=e.replace(new RegExp("\\s*x-scope\\s*"+h+"\\s*","g")," ")),f+=(f?" ":"")+"x-scope "+d,e!==f&&gf(a,f));b||wg.store(k,c.B,g,c.u)}};function Ag(a,b){return(b=b.getRootNode().host)?X(b)?b:Ag(a,b):a.c}
function zg(a,b,c){a=Ag(a,b);var d=X(a);a=Object.create(d.B||null);var e=Yf(b,c.w);b=Wf(d.w,b).v;Object.assign(a,e.Oa,b,e.Wa);b=c.G;for(var f in b)if((e=b[f])||0===e)a[f]=e;f=cg;b=Object.getOwnPropertyNames(a);for(e=0;e<b.length;e++)d=b[e],a[d]=Uf(f,a[d],a);c.B=a}p.styleDocument=function(a){this.styleSubtree(this.c,a)};
p.styleSubtree=function(a,b){var c=a.shadowRoot;(c||a===this.c)&&this.styleElement(a,b);if(b=c&&(c.children||c.childNodes))for(a=0;a<b.length;a++)this.styleSubtree(b[a]);else if(a=a.children||a.childNodes)for(b=0;b<a.length;b++)this.styleSubtree(a[b])};p.ua=function(a){var b=this,c=bf(a);af(c,function(a){if(R)If(a);else{var c=W;a.selector=a.parsedSelector;If(a);a.selector=a.m=rf(c,a,c.c,void 0,void 0)}S&&(xg(b),b.a&&b.a.transformRule(a))});S?a.textContent=$e(c):this.h.w.rules.push(c)};
p.getComputedStyleValue=function(a,b){var c;S||(c=(X(a)||X(Ag(this,a))).B[b]);return(c=c||window.getComputedStyle(a).getPropertyValue(b))?c.trim():""};p.Ya=function(a,b){var c=a.getRootNode();b=b?b.split(/\s/):[];c=c.host&&c.host.localName;if(!c){var d=a.getAttribute("class");if(d){d=d.split(/\s/);for(var e=0;e<d.length;e++)if(d[e]===W.a){c=d[e+1];break}}}c&&b.push(W.a,c);S||(c=X(a))&&c.u&&b.push(cg.a,c.u);gf(a,b.join(" "))};p.Ja=function(a){return X(a)};Y.prototype.flush=Y.prototype.wa;
Y.prototype.prepareTemplate=Y.prototype.prepareTemplate;Y.prototype.styleElement=Y.prototype.styleElement;Y.prototype.styleDocument=Y.prototype.styleDocument;Y.prototype.styleSubtree=Y.prototype.styleSubtree;Y.prototype.getComputedStyleValue=Y.prototype.getComputedStyleValue;Y.prototype.setElementClass=Y.prototype.Ya;Y.prototype._styleInfoForNode=Y.prototype.Ja;Y.prototype.transformCustomStyleForDocument=Y.prototype.ua;Y.prototype.getStyleAst=Y.prototype.Ma;Y.prototype.styleAstToString=Y.prototype.Za;
Y.prototype.flushCustomStyles=Y.prototype.F;Object.defineProperties(Y.prototype,{nativeShadow:{get:function(){return R}},nativeCss:{get:function(){return S}}});var Z=new Y,Bg,Cg;window.ShadyCSS&&(Bg=window.ShadyCSS.ApplyShim,Cg=window.ShadyCSS.CustomStyleInterface);window.ShadyCSS={ScopingShim:Z,prepareTemplate:function(a,b,c){Z.F();Z.prepareTemplate(a,b,c)},styleSubtree:function(a,b){Z.F();Z.styleSubtree(a,b)},styleElement:function(a){Z.F();Z.styleElement(a)},styleDocument:function(a){Z.F();Z.styleDocument(a)},getComputedStyleValue:function(a,b){return Z.getComputedStyleValue(a,b)},nativeCss:S,nativeShadow:R};Bg&&(window.ShadyCSS.ApplyShim=Bg);
Cg&&(window.ShadyCSS.CustomStyleInterface=Cg);var Dg=window.customElements,Eg=window.HTMLImports,Fg=window.HTMLTemplateElement;window.WebComponents=window.WebComponents||{};if(Dg&&Dg.polyfillWrapFlushCallback){var Gg,Hg=function(){if(Gg){Fg.J&&Fg.J(window.document);var a=Gg;Gg=null;a();return!0}},Ig=Eg.whenReady;Dg.polyfillWrapFlushCallback(function(a){Gg=a;Ig(Hg)});Eg.whenReady=function(a){Ig(function(){Hg()?Eg.whenReady(a):a()})}}
Eg.whenReady(function(){requestAnimationFrame(function(){window.WebComponents.ready=!0;document.dispatchEvent(new CustomEvent("WebComponentsReady",{bubbles:!0}))})});var Jg=document.createElement("style");Jg.textContent="body {transition: opacity ease-in 0.2s; } \nbody[unresolved] {opacity: 0; display: block; overflow: hidden; position: relative; } \n";var Kg=document.querySelector("head");Kg.insertBefore(Jg,Kg.firstChild);}).call(this);

//# sourceMappingURL=webcomponents-lite.js.map

(function () {
'use strict';

(()=>{'use strict';if(!window.customElements)return;const a=window.HTMLElement,b=window.customElements.define,c=window.customElements.get,d=new Map,e=new Map;let f=!1,g=!1;window.HTMLElement=function(){if(!f){const a=d.get(this.constructor),b=c.call(window.customElements,a);g=!0;const e=new b;return e}f=!1;},window.HTMLElement.prototype=a.prototype;Object.defineProperty(window,'customElements',{value:window.customElements,configurable:!0,writable:!0}),Object.defineProperty(window.customElements,'define',{value:(c,h)=>{const i=h.prototype,j=class extends a{constructor(){super(),Object.setPrototypeOf(this,i),g||(f=!0,h.call(this)),g=!1;}},k=j.prototype;j.observedAttributes=h.observedAttributes,k.connectedCallback=i.connectedCallback,k.disconnectedCallback=i.disconnectedCallback,k.attributeChangedCallback=i.attributeChangedCallback,k.adoptedCallback=i.adoptedCallback,d.set(h,c),e.set(c,h),b.call(window.customElements,c,j);},configurable:!0,writable:!0}),Object.defineProperty(window.customElements,'get',{value:(a)=>e.get(a),configurable:!0,writable:!0});})();

/**
@license
Copyright (c) 2017 The Polymer Project Authors. All rights reserved.
This code may only be used under the BSD style license found at http://polymer.github.io/LICENSE.txt
The complete set of authors may be found at http://polymer.github.io/AUTHORS.txt
The complete set of contributors may be found at http://polymer.github.io/CONTRIBUTORS.txt
Code distributed by Google as part of the polymer project is also
subject to an additional IP rights grant found at http://polymer.github.io/PATENTS.txt
*/

}());

(function () {
    'use strict';
    if (typeof HTMLElement !== 'function') {
        var _HTMLElement = function () { };
        _HTMLElement.prototype = HTMLElement.prototype;
        HTMLElement = _HTMLElement;
    }

    if (!Array.prototype.findIndex) {
        Object.defineProperty(Array.prototype, 'findIndex', {
            value: function (predicate) {
                if (this == null) {
                    throw new TypeError('Array.prototype.findIndex called on null or undefined');
                }
                if (typeof predicate !== 'function') {
                    throw new TypeError('predicate must be a function');
                }
                var list = Object(this);
                var length = list.length >>> 0;
                var thisArg = arguments[1];
                var value;

                for (var i = 0; i < length; i++) {
                    value = list[i];
                    if (predicate.call(thisArg, value, i, list)) {
                        return i;
                    }
                }
                return -1;
            },
            enumerable: false,
            configurable: false,
            writable: false
        });
    }

    if (!Array.prototype.find) {
        Object.defineProperty(Array.prototype, 'find', {
            value: function (predicate) {
                if (this == null) {
                    throw new TypeError('Array.prototype.find called on null or undefined');
                }
                if (typeof predicate !== 'function') {
                    throw new TypeError('predicate must be a function');
                }
                var list = Object(this);
                var length = list.length >>> 0;
                var thisArg = arguments[1];
                var value;

                for (var i = 0; i < length; i++) {
                    value = list[i];
                    if (predicate.call(thisArg, value, i, list)) {
                        return value;
                    }
                }
                return undefined;
            }
        });
    }

    if (typeof Object.assign != 'function') {
        (function () {
            Object.assign = function (target) {
                // We must check against these specific cases.
                if (target === undefined || target === null) {
                    throw new TypeError('Cannot convert undefined or null to object');
                }

                var output = Object(target);
                for (var index = 1; index < arguments.length; index++) {
                    var source = arguments[index];
                    if (source !== undefined && source !== null) {
                        for (var nextKey in source) {
                            if (source.hasOwnProperty(nextKey)) {
                                output[nextKey] = source[nextKey];
                            }
                        }
                    }
                }
                return output;
            };
        })();
    }

    if (!String.prototype.startsWith) {
        String.prototype.startsWith = function (searchString, position) {
            position = position || 0;
            return this.substr(position, searchString.length) === searchString;
        };
    }

    if (!Math.log10) {
        Math.log10 = function (value) {
            var v = +value, s;
            if (v > 0 && /^(?:10*|0\.0*1)$/.test(s = '' + v)) {
                return v < 1 ?
                    2 - s.length :
                    s.length - 1;
            }
            return Math.log(v) / Math.LN10
        }
    }

    if (!Math.sign) {
        Math.sign = function (x) {
            // If x is NaN, the result is NaN.
            // If x is -0, the result is -0.
            // If x is +0, the result is +0.
            // If x is negative and not -0, the result is -1.
            // If x is positive and not +0, the result is +1.
            return ((x > 0) - (x < 0)) || +x;
            // A more aesthetical persuado-representation is shown below
            //
            // ( (x > 0) ? 0 : 1 )  // if x is negative then negative one
            //          +           // else (because you cant be both - and +)
            // ( (x < 0) ? 0 : -1 ) // if x is positive then positive one
            //         ||           // if x is 0, -0, or NaN, or not a number,
            //         +x           // Then the result will be x, (or) if x is
            //                      // not a number, then x converts to number
        };
    }

    //Used in jqx-list-box
    if (!String.prototype.endsWith) {
        String.prototype.endsWith = function (searchString, position) {
            var subjectString = this.toString();
            if (typeof position !== 'number' || !isFinite(position) || Math.floor(position) !== position || position > subjectString.length) {
                position = subjectString.length;
            }
            position -= searchString.length;
            var lastIndex = subjectString.lastIndexOf(searchString, position);
            return lastIndex !== -1 && lastIndex === position;
        };
    }

    //isInteger polyfill
    Number.isInteger = Number.isInteger || function (value) {
        return typeof value === 'number' &&
            isFinite(value) &&
            Math.floor(value) === value;
    };

    //KeyboardEvent.key polyfill
    if (('KeyboardEvent' in window) || !('key' in KeyboardEvent.prototype)) {
        var keyboardeventKeyPolyfill = {
            keys: {
                3: 'Cancel',
                6: 'Help',
                8: 'Backspace',
                9: 'Tab',
                12: 'Clear',
                13: 'Enter',
                16: 'Shift',
                17: 'Control',
                18: 'Alt',
                19: 'Pause',
                20: 'CapsLock',
                27: 'Escape',
                28: 'Convert',
                29: 'NonConvert',
                30: 'Accept',
                31: 'ModeChange',
                32: ' ',
                33: 'PageUp',
                34: 'PageDown',
                35: 'End',
                36: 'Home',
                37: 'ArrowLeft',
                38: 'ArrowUp',
                39: 'ArrowRight',
                40: 'ArrowDown',
                41: 'Select',
                42: 'Print',
                43: 'Execute',
                44: 'PrintScreen',
                45: 'Insert',
                46: 'Delete',
                48: ['0', ')'],
                49: ['1', '!'],
                50: ['2', '@'],
                51: ['3', '#'],
                52: ['4', '$'],
                53: ['5', '%'],
                54: ['6', '^'],
                55: ['7', '&'],
                56: ['8', '*'],
                57: ['9', '('],
                59: [';', ':'],
                91: 'OS',
                93: 'ContextMenu',
                96: ['0'],
                97: ['1'],
                98: ['2'],
                99: ['3'],
                100: ['4'],
                101: ['5'],
                102: ['6'],
                103: ['7'],
                104: ['8'],
                105: ['9'],
                106: ['*'],
                107: ['+'],
                109: ['-'],
                110: ['.'],
                111: ['/'],
                144: 'NumLock',
                145: 'ScrollLock',
                173: ['-', '_'],
                181: 'VolumeMute',
                182: 'VolumeDown',
                183: 'VolumeUp',
                186: [';', ':'],
                187: ['=', '+'],
                188: [',', '<'],
                189: ['-', '_'],
                190: ['.', '>'],
                191: ['/', '?'],
                192: ['`', '~'],
                219: ['[', '{'],
                220: ['\\', '|'],
                221: [']', '}'],
                222: ["'", '"'],
                224: 'Meta',
                225: 'AltGraph',
                246: 'Attn',
                247: 'CrSel',
                248: 'ExSel',
                249: 'EraseEof',
                250: 'Play',
                251: 'ZoomOut'
            }
        };

        // Function keys (F1-24).
        var i;
        for (i = 1; i < 25; i++) {
            keyboardeventKeyPolyfill.keys[111 + i] = 'F' + i;
        }

        // Printable ASCII characters.
        var letter = '';
        for (i = 65; i < 91; i++) {
            letter = String.fromCharCode(i);
            keyboardeventKeyPolyfill.keys[i] = [letter.toLowerCase(), letter.toUpperCase()];
        }

        // Polyfill `key` on `KeyboardEvent`.
        var proto = {
            get: function (x) {
                var key = keyboardeventKeyPolyfill.keys[this.which || this.keyCode];

                if (Array.isArray(key)) {
                    key = key[+this.shiftKey];
                }

                return key;
            }
        };

        Object.defineProperty(KeyboardEvent.prototype, 'key', proto);
    }

    // Production steps of ECMA-262, Edition 6, 22.1.2.1
    if (!Array.from) {
        Array.from = (function () {
            var toStr = Object.prototype.toString;
            var isCallable = function (fn) {
                return typeof fn === 'function' || toStr.call(fn) === '[object Function]';
            };
            var toInteger = function (value) {
                var number = Number(value);
                if (isNaN(number)) { return 0; }
                if (number === 0 || !isFinite(number)) { return number; }
                return (number > 0 ? 1 : -1) * Math.floor(Math.abs(number));
            };
            var maxSafeInteger = Math.pow(2, 53) - 1;
            var toLength = function (value) {
                var len = toInteger(value);
                return Math.min(Math.max(len, 0), maxSafeInteger);
            };

            // The length property of the from method is 1.
            return function from(arrayLike/*, mapFn, thisArg */) {
                // 1. Let C be the this value.
                var C = this;

                // 2. Let items be ToObject(arrayLike).
                var items = Object(arrayLike);

                // 3. ReturnIfAbrupt(items).
                if (arrayLike == null) {
                    throw new TypeError('Array.from requires an array-like object - not null or undefined');
                }

                // 4. If mapfn is undefined, then let mapping be false.
                var mapFn = arguments.length > 1 ? arguments[1] : void undefined;
                var T;
                if (typeof mapFn !== 'undefined') {
                    // 5. else
                    // 5. a If IsCallable(mapfn) is false, throw a TypeError exception.
                    if (!isCallable(mapFn)) {
                        throw new TypeError('Array.from: when provided, the second argument must be a function');
                    }

                    // 5. b. If thisArg was supplied, let T be thisArg; else let T be undefined.
                    if (arguments.length > 2) {
                        T = arguments[2];
                    }
                }

                // 10. Let lenValue be Get(items, "length").
                // 11. Let len be ToLength(lenValue).
                var len = toLength(items.length);

                // 13. If IsConstructor(C) is true, then
                // 13. a. Let A be the result of calling the [[Construct]] internal method 
                // of C with an argument list containing the single item len.
                // 14. a. Else, Let A be ArrayCreate(len).
                var A = isCallable(C) ? Object(new C(len)) : new Array(len);

                // 16. Let k be 0.
                var k = 0;
                // 17. Repeat, while k < len… (also steps a - h)
                var kValue;
                while (k < len) {
                    kValue = items[k];
                    if (mapFn) {
                        A[k] = typeof T === 'undefined' ? mapFn(kValue, k) : mapFn.call(T, kValue, k);
                    } else {
                        A[k] = kValue;
                    }
                    k += 1;
                }
                // 18. Let putStatus be Put(A, "length", len, true).
                A.length = len;
                // 20. Return A.
                return A;
            };
        }());
    }

    if (!Element.prototype.matches) {
        Element.prototype.matches = Element.prototype.msMatchesSelector ||
            Element.prototype.webkitMatchesSelector;
    }

    if (!Element.prototype.closest) {
        Element.prototype.closest = function (s) {
            var el = this;
            if (!document.documentElement.contains(el)) return null;
            do {
                if (el.matches(s)) return el;
                el = el.parentElement || el.parentNode;
            } while (el !== null && el.nodeType === 1);
            return null;
        };
    }

    if (!String.prototype.repeat) {
        String.prototype.repeat = function (count) {
            'use strict';
            if (this == null) {
                throw new TypeError('can\'t convert ' + this + ' to object');
            }
            var str = '' + this;
            count = +count;
            if (count != count) {
                count = 0;
            }
            if (count < 0) {
                throw new RangeError('repeat count must be non-negative');
            }
            if (count == Infinity) {
                throw new RangeError('repeat count must be less than infinity');
            }
            count = Math.floor(count);
            if (str.length == 0 || count == 0) {
                return '';
            }
            // Ensuring count is a 31-bit integer allows us to heavily optimize the
            // main part. But anyway, most current (August 2014) browsers can't handle
            // strings 1 << 28 chars or longer, so:
            if (str.length * count >= 1 << 28) {
                throw new RangeError('repeat count must not overflow maximum string size');
            }
            var rpt = '';
            for (var i = 0; i < count; i++) {
                rpt += str;
            }
            return rpt;
        }
    }

    if (!Array.prototype.fill) {
        Object.defineProperty(Array.prototype, 'fill', {
            value: function (value) {

                if (this == null) {
                    throw new TypeError('this is null or not defined');
                }

                var O = Object(this);

                var len = O.length >>> 0;

                var start = arguments[1];
                var relativeStart = start >> 0;

                var k = relativeStart < 0 ?
                    Math.max(len + relativeStart, 0) :
                    Math.min(relativeStart, len);

                var end = arguments[2];
                var relativeEnd = end === undefined ?
                    len : end >> 0;

                var final = relativeEnd < 0 ?
                    Math.max(len + relativeEnd, 0) :
                    Math.min(relativeEnd, len);

                while (k < final) {
                    O[k] = value;
                    k++;
                }

                return O;
            }
        });
    }

    //IE11 DocumentFragment.children polyfill
    (function (constructor) {
        if (constructor &&
            constructor.prototype &&
            constructor.prototype.children == null) {
            Object.defineProperty(constructor.prototype, 'children', {
                get: function () {
                    var i = 0, node, nodes = this.childNodes, children = [];
                    while (node = nodes[i++]) {
                        if (node.nodeType === 1) {
                            children.push(node);
                        }
                    }
                    return children;
                }
            });
        }
    })(window.Node || window.Element);

    if ("document" in self) {

        // Full polyfill for browsers with no classList support
        // Including IE < Edge missing SVGElement.classList
        if (
               !("classList" in document.createElement("_"))
            || document.createElementNS
            && !("classList" in document.createElementNS("http://www.w3.org/2000/svg", "g"))
        ) {

            (function (view) {

                "use strict";

                if (!('Element' in view)) return;

                var
                      classListProp = "classList"
                    , protoProp = "prototype"
                    , elemCtrProto = view.Element[protoProp]
                    , objCtr = Object
                    , strTrim = String[protoProp].trim || function () {
                        return this.replace(/^\s+|\s+$/g, "");
                    }
                    , arrIndexOf = Array[protoProp].indexOf || function (item) {
                        var
                              i = 0
                            , len = this.length
                        ;
                        for (; i < len; i++) {
                            if (i in this && this[i] === item) {
                                return i;
                            }
                        }
                        return -1;
                    }
                    // Vendors: please allow content code to instantiate DOMExceptions
                    , DOMEx = function (type, message) {
                        this.name = type;
                        this.code = DOMException[type];
                        this.message = message;
                    }
                    , checkTokenAndGetIndex = function (classList, token) {
                        if (token === "") {
                            throw new DOMEx(
                                  "SYNTAX_ERR"
                                , "The token must not be empty."
                            );
                        }
                        if (/\s/.test(token)) {
                            throw new DOMEx(
                                  "INVALID_CHARACTER_ERR"
                                , "The token must not contain space characters."
                            );
                        }
                        return arrIndexOf.call(classList, token);
                    }
                    , ClassList = function (elem) {
                        var
                              trimmedClasses = strTrim.call(elem.getAttribute("class") || "")
                            , classes = trimmedClasses ? trimmedClasses.split(/\s+/) : []
                            , i = 0
                            , len = classes.length
                        ;
                        for (; i < len; i++) {
                            this.push(classes[i]);
                        }
                        this._updateClassName = function () {
                            elem.setAttribute("class", this.toString());
                        };
                    }
                    , classListProto = ClassList[protoProp] = []
                    , classListGetter = function () {
                        return new ClassList(this);
                    }
                ;
                // Most DOMException implementations don't allow calling DOMException's toString()
                // on non-DOMExceptions. Error's toString() is sufficient here.
                DOMEx[protoProp] = Error[protoProp];
                classListProto.item = function (i) {
                    return this[i] || null;
                };
                classListProto.contains = function (token) {
                    return ~checkTokenAndGetIndex(this, token + "");
                };
                classListProto.add = function () {
                    var
                          tokens = arguments
                        , i = 0
                        , l = tokens.length
                        , token
                        , updated = false
                    ;
                    do {
                        token = tokens[i] + "";
                        if (!~checkTokenAndGetIndex(this, token)) {
                            this.push(token);
                            updated = true;
                        }
                    }
                    while (++i < l);

                    if (updated) {
                        this._updateClassName();
                    }
                };
                classListProto.remove = function () {
                    var
                          tokens = arguments
                        , i = 0
                        , l = tokens.length
                        , token
                        , updated = false
                        , index
                    ;
                    do {
                        token = tokens[i] + "";
                        index = checkTokenAndGetIndex(this, token);
                        while (~index) {
                            this.splice(index, 1);
                            updated = true;
                            index = checkTokenAndGetIndex(this, token);
                        }
                    }
                    while (++i < l);

                    if (updated) {
                        this._updateClassName();
                    }
                };
                classListProto.toggle = function (token, force) {
                    var
                          result = this.contains(token)
                        , method = result ?
                            force !== true && "remove"
                        :
                            force !== false && "add"
                    ;

                    if (method) {
                        this[method](token);
                    }

                    if (force === true || force === false) {
                        return force;
                    } else {
                        return !result;
                    }
                };
                classListProto.replace = function (token, replacement_token) {
                    var index = checkTokenAndGetIndex(token + "");
                    if (~index) {
                        this.splice(index, 1, replacement_token);
                        this._updateClassName();
                    }
                }
                classListProto.toString = function () {
                    return this.join(" ");
                };

                if (objCtr.defineProperty) {
                    var classListPropDesc = {
                        get: classListGetter
                        , enumerable: true
                        , configurable: true
                    };
                    try {
                        objCtr.defineProperty(elemCtrProto, classListProp, classListPropDesc);
                    } catch (ex) { // IE 8 doesn't support enumerable:true
                        // adding undefined to fight this issue https://github.com/eligrey/classList.js/issues/36
                        // modernie IE8-MSW7 machine has IE8 8.0.6001.18702 and is affected
                        if (ex.number === undefined || ex.number === -0x7FF5EC54) {
                            classListPropDesc.enumerable = false;
                            objCtr.defineProperty(elemCtrProto, classListProp, classListPropDesc);
                        }
                    }
                } else if (objCtr[protoProp].__defineGetter__) {
                    elemCtrProto.__defineGetter__(classListProp, classListGetter);
                }

            }(self));

        }

        // There is full or partial native classList support, so just check if we need
        // to normalize the add/remove and toggle APIs.

        (function () {
            "use strict";

            var testElement = document.createElement("_");

            testElement.classList.add("c1", "c2");

            // Polyfill for IE 10/11 and Firefox <26, where classList.add and
            // classList.remove exist but support only one argument at a time.
            if (!testElement.classList.contains("c2")) {
                var createMethod = function (method) {
                    var original = DOMTokenList.prototype[method];

                    DOMTokenList.prototype[method] = function (token) {
                        var i, len = arguments.length;

                        for (i = 0; i < len; i++) {
                            token = arguments[i];
                            original.call(this, token);
                        }
                    };
                };
                createMethod('add');
                createMethod('remove');
            }

            testElement.classList.toggle("c3", false);

            // Polyfill for IE 10 and Firefox <24, where classList.toggle does not
            // support the second argument.
            if (testElement.classList.contains("c3")) {
                var _toggle = DOMTokenList.prototype.toggle;

                DOMTokenList.prototype.toggle = function (token, force) {
                    if (1 in arguments && !this.contains(token) === !force) {
                        return force;
                    } else {
                        return _toggle.call(this, token);
                    }
                };

            }

            // replace() polyfill
            if (!("replace" in document.createElement("_").classList)) {
                DOMTokenList.prototype.replace = function (token, replacement_token) {
                    var
                          tokens = this.toString().split(" ")
                        , index = tokens.indexOf(token + "")
                    ;
                    if (~index) {
                        tokens = tokens.slice(index);
                        this.remove.apply(this, tokens);
                        this.add(replacement_token);
                        this.add.apply(this, tokens.slice(1));
                    }
                }
            }

            testElement = null;
        }());

    }

    if (!document.elementsFromPoint) {
        document.elementsFromPoint = elementsFromPoint;
    }

    function elementsFromPoint(x, y) {
        var parents = [];
        var parent = void 0;
        do {
            if (parent !== document.elementFromPoint(x, y)) {
                parent = document.elementFromPoint(x, y);
                parents.push(parent);
                parent.style.pointerEvents = 'none';
            } else {
                parent = false;
            }
        } while (parent);
        parents.forEach(function (parent) {
            return parent.style.pointerEvents = 'all';
        });
        return parents;
    }
})();

(function (global) {
    var babelHelpers = global.babelHelpers = {};
    babelHelpers.typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) {
        return typeof obj;
    } : function (obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
    };

    babelHelpers.jsx = function () {
        var REACT_ELEMENT_TYPE = typeof Symbol === "function" && Symbol.for && Symbol.for("react.element") || 0xeac7;
        return function createRawReactElement(type, props, key, children) {
            var defaultProps = type && type.defaultProps;
            var childrenLength = arguments.length - 3;

            if (!props && childrenLength !== 0) {
                props = {};
            }

            if (props && defaultProps) {
                for (var propName in defaultProps) {
                    if (props[propName] === void 0) {
                        props[propName] = defaultProps[propName];
                    }
                }
            } else if (!props) {
                props = defaultProps || {};
            }

            if (childrenLength === 1) {
                props.children = children;
            } else if (childrenLength > 1) {
                var childArray = Array(childrenLength);

                for (var i = 0; i < childrenLength; i++) {
                    childArray[i] = arguments[i + 3];
                }

                props.children = childArray;
            }

            return {
                $$typeof: REACT_ELEMENT_TYPE,
                type: type,
                key: key === undefined ? null : '' + key,
                ref: null,
                props: props,
                _owner: null
            };
        };
    }();

    babelHelpers.asyncIterator = function (iterable) {
        if (typeof Symbol === "function") {
            if (Symbol.asyncIterator) {
                var method = iterable[Symbol.asyncIterator];
                if (method != null) return method.call(iterable);
            }

            if (Symbol.iterator) {
                return iterable[Symbol.iterator]();
            }
        }

        throw new TypeError("Object is not async iterable");
    };

    babelHelpers.asyncGenerator = function () {
        function AwaitValue(value) {
            this.value = value;
        }

        function AsyncGenerator(gen) {
            var front, back;

            function send(key, arg) {
                return new Promise(function (resolve, reject) {
                    var request = {
                        key: key,
                        arg: arg,
                        resolve: resolve,
                        reject: reject,
                        next: null
                    };

                    if (back) {
                        back = back.next = request;
                    } else {
                        front = back = request;
                        resume(key, arg);
                    }
                });
            }

            function resume(key, arg) {
                try {
                    var result = gen[key](arg);
                    var value = result.value;

                    if (value instanceof AwaitValue) {
                        Promise.resolve(value.value).then(function (arg) {
                            resume("next", arg);
                        }, function (arg) {
                            resume("throw", arg);
                        });
                    } else {
                        settle(result.done ? "return" : "normal", result.value);
                    }
                } catch (err) {
                    settle("throw", err);
                }
            }

            function settle(type, value) {
                switch (type) {
                    case "return":
                        front.resolve({
                            value: value,
                            done: true
                        });
                        break;

                    case "throw":
                        front.reject(value);
                        break;

                    default:
                        front.resolve({
                            value: value,
                            done: false
                        });
                        break;
                }

                front = front.next;

                if (front) {
                    resume(front.key, front.arg);
                } else {
                    back = null;
                }
            }

            this._invoke = send;

            if (typeof gen.return !== "function") {
                this.return = undefined;
            }
        }

        if (typeof Symbol === "function" && Symbol.asyncIterator) {
            AsyncGenerator.prototype[Symbol.asyncIterator] = function () {
                return this;
            };
        }

        AsyncGenerator.prototype.next = function (arg) {
            return this._invoke("next", arg);
        };

        AsyncGenerator.prototype.throw = function (arg) {
            return this._invoke("throw", arg);
        };

        AsyncGenerator.prototype.return = function (arg) {
            return this._invoke("return", arg);
        };

        return {
            wrap: function (fn) {
                return function () {
                    return new AsyncGenerator(fn.apply(this, arguments));
                };
            },
            await: function (value) {
                return new AwaitValue(value);
            }
        };
    }();

    babelHelpers.asyncGeneratorDelegate = function (inner, awaitWrap) {
        var iter = {},
            waiting = false;

        function pump(key, value) {
            waiting = true;
            value = new Promise(function (resolve) {
                resolve(inner[key](value));
            });
            return {
                done: false,
                value: awaitWrap(value)
            };
        }

        ;

        if (typeof Symbol === "function" && Symbol.iterator) {
            iter[Symbol.iterator] = function () {
                return this;
            };
        }

        iter.next = function (value) {
            if (waiting) {
                waiting = false;
                return value;
            }

            return pump("next", value);
        };

        if (typeof inner.throw === "function") {
            iter.throw = function (value) {
                if (waiting) {
                    waiting = false;
                    throw value;
                }

                return pump("throw", value);
            };
        }

        if (typeof inner.return === "function") {
            iter.return = function (value) {
                return pump("return", value);
            };
        }

        return iter;
    };

    babelHelpers.asyncToGenerator = function (fn) {
        return function () {
            var gen = fn.apply(this, arguments);
            return new Promise(function (resolve, reject) {
                function step(key, arg) {
                    try {
                        var info = gen[key](arg);
                        var value = info.value;
                    } catch (error) {
                        reject(error);
                        return;
                    }

                    if (info.done) {
                        resolve(value);
                    } else {
                        return Promise.resolve(value).then(function (value) {
                            step("next", value);
                        }, function (err) {
                            step("throw", err);
                        });
                    }
                }

                return step("next");
            });
        };
    };

    babelHelpers.classCallCheck = function (instance, Constructor) {
        if (!(instance instanceof Constructor)) {
            throw new TypeError("Cannot call a class as a function");
        }
    };

    babelHelpers.createClass = function () {
        function defineProperties(target, props) {
            for (var i = 0; i < props.length; i++) {
                var descriptor = props[i];
                descriptor.enumerable = descriptor.enumerable || false;
                descriptor.configurable = true;
                if ("value" in descriptor) descriptor.writable = true;
                Object.defineProperty(target, descriptor.key, descriptor);
            }
        }

        return function (Constructor, protoProps, staticProps) {
            if (protoProps) defineProperties(Constructor.prototype, protoProps);
            if (staticProps) defineProperties(Constructor, staticProps);
            return Constructor;
        };
    }();

    babelHelpers.defineEnumerableProperties = function (obj, descs) {
        for (var key in descs) {
            var desc = descs[key];
            desc.configurable = desc.enumerable = true;
            if ("value" in desc) desc.writable = true;
            Object.defineProperty(obj, key, desc);
        }

        return obj;
    };

    babelHelpers.defaults = function (obj, defaults) {
        var keys = Object.getOwnPropertyNames(defaults);

        for (var i = 0; i < keys.length; i++) {
            var key = keys[i];
            var value = Object.getOwnPropertyDescriptor(defaults, key);

            if (value && value.configurable && obj[key] === undefined) {
                Object.defineProperty(obj, key, value);
            }
        }

        return obj;
    };

    babelHelpers.defineProperty = function (obj, key, value) {
        if (key in obj) {
            Object.defineProperty(obj, key, {
                value: value,
                enumerable: true,
                configurable: true,
                writable: true
            });
        } else {
            obj[key] = value;
        }

        return obj;
    };

    babelHelpers.extends = Object.assign || function (target) {
        for (var i = 1; i < arguments.length; i++) {
            var source = arguments[i];

            for (var key in source) {
                if (Object.prototype.hasOwnProperty.call(source, key)) {
                    target[key] = source[key];
                }
            }
        }

        return target;
    };

    babelHelpers.get = function get(object, property, receiver) {
        if (object === null) object = Function.prototype;
        var desc = Object.getOwnPropertyDescriptor(object, property);

        if (desc === undefined) {
            var parent = Object.getPrototypeOf(object);

            if (parent === null) {
                return undefined;
            } else {
                return get(parent, property, receiver);
            }
        } else if ("value" in desc) {
            return desc.value;
        } else {
            var getter = desc.get;

            if (getter === undefined) {
                return undefined;
            }

            return getter.call(receiver);
        }
    };

    babelHelpers.inherits = function (subClass, superClass) {
        if (typeof superClass !== "function" && superClass !== null) {
            throw new TypeError("Super expression must either be null or a function, not " + typeof superClass);
        }

        subClass.prototype = Object.create(superClass && superClass.prototype, {
            constructor: {
                value: subClass,
                enumerable: false,
                writable: true,
                configurable: true
            }
        });
        if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass;
    };

    babelHelpers.instanceof = function (left, right) {
        if (right != null && typeof Symbol !== "undefined" && right[Symbol.hasInstance]) {
            return right[Symbol.hasInstance](left);
        } else {
            return left instanceof right;
        }
    };

    babelHelpers.interopRequireDefault = function (obj) {
        return obj && obj.__esModule ? obj : {
            default: obj
        };
    };

    babelHelpers.interopRequireWildcard = function (obj) {
        if (obj && obj.__esModule) {
            return obj;
        } else {
            var newObj = {};

            if (obj != null) {
                for (var key in obj) {
                    if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key];
                }
            }

            newObj.default = obj;
            return newObj;
        }
    };

    babelHelpers.newArrowCheck = function (innerThis, boundThis) {
        if (innerThis !== boundThis) {
            throw new TypeError("Cannot instantiate an arrow function");
        }
    };

    babelHelpers.objectDestructuringEmpty = function (obj) {
        if (obj == null) throw new TypeError("Cannot destructure undefined");
    };

    babelHelpers.objectWithoutProperties = function (obj, keys) {
        var target = {};

        for (var i in obj) {
            if (keys.indexOf(i) >= 0) continue;
            if (!Object.prototype.hasOwnProperty.call(obj, i)) continue;
            target[i] = obj[i];
        }

        return target;
    };

    babelHelpers.possibleConstructorReturn = function (self, call) {
        if (!self) {
            throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
        }

        return call && (typeof call === "object" || typeof call === "function") ? call : self;
    };

    babelHelpers.selfGlobal = typeof global === "undefined" ? self : global;

    babelHelpers.set = function set(object, property, value, receiver) {
        var desc = Object.getOwnPropertyDescriptor(object, property);

        if (desc === undefined) {
            var parent = Object.getPrototypeOf(object);

            if (parent !== null) {
                set(parent, property, value, receiver);
            }
        } else if ("value" in desc && desc.writable) {
            desc.value = value;
        } else {
            var setter = desc.set;

            if (setter !== undefined) {
                setter.call(receiver, value);
            }
        }

        return value;
    };

    babelHelpers.slicedToArray = function () {
        function sliceIterator(arr, i) {
            var _arr = [];
            var _n = true;
            var _d = false;
            var _e = undefined;

            try {
                for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done) ; _n = true) {
                    _arr.push(_s.value);

                    if (i && _arr.length === i) break;
                }
            } catch (err) {
                _d = true;
                _e = err;
            } finally {
                try {
                    if (!_n && _i["return"]) _i["return"]();
                } finally {
                    if (_d) throw _e;
                }
            }

            return _arr;
        }

        return function (arr, i) {
            if (Array.isArray(arr)) {
                return arr;
            } else if (Symbol.iterator in Object(arr)) {
                return sliceIterator(arr, i);
            } else {
                throw new TypeError("Invalid attempt to destructure non-iterable instance");
            }
        };
    }();

    babelHelpers.slicedToArrayLoose = function (arr, i) {
        if (Array.isArray(arr)) {
            return arr;
        } else if (Symbol.iterator in Object(arr)) {
            var _arr = [];

            for (var _iterator = arr[Symbol.iterator](), _step; !(_step = _iterator.next()).done;) {
                _arr.push(_step.value);

                if (i && _arr.length === i) break;
            }

            return _arr;
        } else {
            throw new TypeError("Invalid attempt to destructure non-iterable instance");
        }
    };

    babelHelpers.taggedTemplateLiteral = function (strings, raw) {
        return Object.freeze(Object.defineProperties(strings, {
            raw: {
                value: Object.freeze(raw)
            }
        }));
    };

    babelHelpers.taggedTemplateLiteralLoose = function (strings, raw) {
        strings.raw = raw;
        return strings;
    };

    babelHelpers.temporalRef = function (val, name, undef) {
        if (val === undef) {
            throw new ReferenceError(name + " is not defined - temporal dead zone");
        } else {
            return val;
        }
    };

    babelHelpers.temporalUndefined = {};

    babelHelpers.toArray = function (arr) {
        return Array.isArray(arr) ? arr : Array.from(arr);
    };

    babelHelpers.toConsumableArray = function (arr) {
        if (Array.isArray(arr)) {
            for (var i = 0, arr2 = Array(arr.length) ; i < arr.length; i++) arr2[i] = arr[i];

            return arr2;
        } else {
            return Array.from(arr);
        }
    };
})(typeof global === "undefined" ? self : global);
(function () {
    var needsTemplate = typeof HTMLTemplateElement === "undefined";
    if (/Trident/.test(navigator.userAgent)) {
        (function () {
            var importNode = document.importNode;
            document.importNode = function () {
                var n = importNode.apply(document, arguments);
                if (n.nodeType === Node.DOCUMENT_FRAGMENT_NODE) {
                    var f = document.createDocumentFragment();
                    f.appendChild(n);
                    return f;
                } else {
                    return n;
                }
            };
        })();
    }
    var needsCloning = function () {
        if (!needsTemplate) {
            var t = document.createElement("template");
            var t2 = document.createElement("template");
            t2.content.appendChild(document.createElement("div"));
            t.content.appendChild(t2);
            var clone = t.cloneNode(true);
            return clone.content.childNodes.length === 0 || clone.content.firstChild.content.childNodes.length === 0;
        }
    }();
    var TEMPLATE_TAG = "template";
    var TemplateImpl = function () { };
    if (needsTemplate) {
        var contentDoc = document.implementation.createHTMLDocument("template");
        var canDecorate = true;
        var templateStyle = document.createElement("style");
        templateStyle.textContent = TEMPLATE_TAG + "{display:none;}";
        var head = document.head;
        head.insertBefore(templateStyle, head.firstElementChild);
        TemplateImpl.prototype = Object.create(HTMLElement.prototype);
        TemplateImpl.decorate = function (template) {
            if (template.content) {
                return;
            }
            template.content = contentDoc.createDocumentFragment();
            var child;
            while (child = template.firstChild) {
                template.content.appendChild(child);
            }
            template.cloneNode = function (deep) {
                return TemplateImpl.cloneNode(this, deep);
            };
            if (canDecorate) {
                try {
                    Object.defineProperty(template, "innerHTML", {
                        get: function () {
                            var o = "";
                            for (var e = this.content.firstChild; e; e = e.nextSibling) {
                                o += e.outerHTML || escapeData(e.data);
                            }
                            return o;
                        },
                        set: function (text) {
                            contentDoc.body.innerHTML = text;
                            TemplateImpl.bootstrap(contentDoc);
                            while (this.content.firstChild) {
                                this.content.removeChild(this.content.firstChild);
                            }
                            while (contentDoc.body.firstChild) {
                                this.content.appendChild(contentDoc.body.firstChild);
                            }
                        },
                        configurable: true
                    });
                } catch (err) {
                    canDecorate = false;
                }
            }
            TemplateImpl.bootstrap(template.content);
        };
        TemplateImpl.bootstrap = function (doc) {
            var templates = doc.querySelectorAll(TEMPLATE_TAG);
            for (var i = 0, l = templates.length, t; i < l && (t = templates[i]) ; i++) {
                TemplateImpl.decorate(t);
            }
        };
        document.addEventListener("DOMContentLoaded", function () {
            TemplateImpl.bootstrap(document);
        });
        var createElement = document.createElement;
        document.createElement = function () {
            "use strict";
            var el = createElement.apply(document, arguments);
            if (el.localName === "template") {
                TemplateImpl.decorate(el);
            }
            return el;
        };
        var createElementNS = document.createElementNS;
        document.createElementNS = function () {
            "use strict";
            var el = createElementNS.apply(document, arguments);
            if (el.namespaceURI === "http://www.w3.org/1999/xhtml" && el.localName === "template") {
                TemplateImpl.decorate(el);
            }
            return el;
        };
        var escapeDataRegExp = /[&\u00A0<>]/g;
        function escapeReplace(c) {
            switch (c) {
                case "&":
                    return "&amp;";

                case "<":
                    return "&lt;";

                case ">":
                    return "&gt;";

                case " ":
                    return "&nbsp;";
            }
        }
        function escapeData(s) {
            return s.replace(escapeDataRegExp, escapeReplace);
        }
    }
    if (needsTemplate || needsCloning) {
        var nativeCloneNode = Node.prototype.cloneNode;
        TemplateImpl.cloneNode = function (template, deep) {
            var clone = nativeCloneNode.call(template, false);
            if (this.decorate) {
                this.decorate(clone);
            }
            if (deep) {
                clone.content.appendChild(nativeCloneNode.call(template.content, true));
                this.fixClonedDom(clone.content, template.content);
            }
            return clone;
        };
        TemplateImpl.fixClonedDom = function (clone, source) {
            if (!source.querySelectorAll) return;
            var s$ = source.querySelectorAll(TEMPLATE_TAG);
            var t$ = clone.querySelectorAll(TEMPLATE_TAG);
            for (var i = 0, l = t$.length, t, s; i < l; i++) {
                s = s$[i];
                t = t$[i];
                if (this.decorate) {
                    this.decorate(s);
                }
                t.parentNode.replaceChild(s.cloneNode(true), t);
            }
        };
        var originalImportNode = document.importNode;
        Node.prototype.cloneNode = function (deep) {
            var dom = nativeCloneNode.call(this, deep);
            if (deep) {
                TemplateImpl.fixClonedDom(dom, this);
            }
            return dom;
        };
        document.importNode = function (element, deep) {
            if (element.localName === TEMPLATE_TAG) {
                return TemplateImpl.cloneNode(element, deep);
            } else {
                var dom = originalImportNode.call(document, element, deep);
                if (deep) {
                    TemplateImpl.fixClonedDom(dom, element);
                }
                return dom;
            }
        };
        if (needsCloning) {
            HTMLTemplateElement.prototype.cloneNode = function (deep) {
                return TemplateImpl.cloneNode(this, deep);
            };
        }
    }
    if (needsTemplate) {
        window.HTMLTemplateElement = TemplateImpl;
    }
})();

"use strict";!function(){function e(e,t){var n=0,r=function(e,t){return new Promise(function(n){var r=document.createElement("script");r.src=e,r.onload=n;for(var i=0;i<document.head.children.length;i++){var a=document.head.children[i];if(a.src&&a.src.toString().indexOf(t)>=0)return void n()}document.head.appendChild(r)})};return new Promise(function(i){var a=x.Core.getScriptLocation();if(t)for(var o=0;o<e.length;o++){var l=a+"/"+e[o];r(l,e[o]).then(function(){++n===e.length&&i()})}else!function t(o){if(e[o]){var l=a+"/"+e[o];r(l,e[o]).then(function(){n++,n===e.length&&i(),t(o+1)})}}(0)})}function t(e,t){var n=t.properties;t._properties=[];!function n(r,i){for(var a=Object.keys(r),o=0;o<a.length;o++){(function(o){var l=a[o],s=r[l];t._properties[i+l]=s,Array.isArray(s)?t._properties[i+l]=new H(s,function(t){var n=l+"."+t.path,r=t.newValue,i=document.querySelector(e);if(i){for(var a=n.split("."),o=i,s=0;s<a.length;s++){o=o[a[s]]}o=r}}):(Object.defineProperty(r,l,{configurable:!1,enumerable:!0,get:function(){return t._properties[i+l]},set:function(e){t._properties[i+l]=e}}),"DataAdapter"===s.constructor.name||"object"===(void 0===s?"undefined":babelHelpers.typeof(s))&&s&&Object.keys(s).length>0&&n(s,i+l+"."))})(o)}}(n,""),Object.defineProperty(t,"properties",{configurable:!1,enumerable:!0,get:function(){return n}});var r=document.querySelector(e);if(r&&r.isReady)for(var i in n)r[i]=n[i]}var n=[],r="JQX";if(window[r]&&window[r].Version){if("3.4.0"===window[r].Version)return;if("3.4.0"!==window[r].Version)r+="3.4.0";else for(var i=2;window[r];)r+=i.toString(),i++}var a=function(){function e(){babelHelpers.classCallCheck(this,e)}return babelHelpers.createClass(e,[{key:"addMessages",value:function(e,t){var n=this;Object.assign(n.messages[e],t)}},{key:"localize",value:function(e,t){var n=this;if(n.messages&&n.messages[n.locale]){var r=n.messages[n.locale][e];if(""===r)return"";if(r){var i=r;for(var a in t){var o=t[a];r=r.replace(new RegExp("{{"+a+"}}","g"),o)}return n.localizeFormatFunction&&n.localizeFormatFunction(i,r,t),r}}}}],[{key:"moduleName",get:function(){return"LocalizationModule"}},{key:"properties",get:function(){return{messages:{value:{en:{}},type:"object",inherit:!0,reflectToAttribute:!1},locale:{value:"en",type:"string",reflectToAttribute:!1},localizeFormatFunction:{value:void 0,type:"function",reflectToAttribute:!1}}}}]),e}(),o=function(){function e(){babelHelpers.classCallCheck(this,e)}return babelHelpers.createClass(e,[{key:"log",value:function(e){this._logger("log",e)}},{key:"warn",value:function(e){this._logger("warn",e)}},{key:"error",value:function(e){this._logger("error",e)}},{key:"_logger",value:function(e,t){var n=this;if(n.debugMode){var r=t instanceof Error?t.message:t.toString();console[e](r)}if(n.rethrowError&&"error"===e)throw t}}],[{key:"moduleName",get:function(){return"ErrorModule"}},{key:"properties",get:function(){return{rethrowError:{value:!0,type:"boolean",reflectToAttribute:!1},debugMode:{value:!0,type:"boolean",reflectToAttribute:!1}}}}]),e}(),l=function(){function e(){babelHelpers.classCallCheck(this,e)}return babelHelpers.createClass(e,[{key:"getBindings",value:function(e,t){var n=this,r=0,i={},a=function(e){if(e instanceof HTMLElement)return n.parseAttributes(e);var t=n.parseProperty(e.data?e.data.trim():null,"textContent",e);return t?(n.ownerElement&&e.parentNode===n.ownerElement.$.content&&(t.value=""!==n.ownerElement.$.html?n.ownerElement.$.html:void 0,n.ownerElement.innerHTML=""),{textContent:t}):void 0}(e);a&&(i.data=a),t||(i.mapping=[],t=i),e.getAttribute&&(i.nodeId=e.getAttribute("jqx-id"),t&&a&&(t.mapping[i.nodeId]=a)),i.node=e,e.firstChild&&(i.children={});for(var o=e.firstChild;o;o=o.nextSibling)i.children[r++]=n.getBindings(o,t);return i}},{key:"_addRemovePropertyBinding",value:function(e,t,n,r){if(e&&t&&n){var i=this,a=i.ownerElement.bindings,o=n.getAttribute("jqx-id"),l=e.indexOf("{{")>=0;e=e.replace("{{","").replace("}}","").replace("[[","").replace("]]","");var s=!1;e.indexOf("!")>=0&&(e=e.replace("!",""),s=!0);var u=i.ownerElement._properties[e],d={name:e,reflectToAttribute:u.reflectToAttribute,twoWay:l,type:u.type,not:s};!function e(a){for(var l in a){var s=a[l];if(s.nodeId===o){s.data||(s.data={}),r?(s.data[t]=null,delete s.data[t]):s.data[t]=d;break}if(s.children)e(s.children);else if(s.node&&s.node.children&&s.node===n.parentElement){var u=s.node;if(!u.firstChild)continue;s.children={};for(var c=0,p=u.firstChild;p;p=p.nextSibling)s.children[c++]=i.getBindings(p);e(s.children)}}}(a.children),r?delete i.ownerElement.boundProperties[e]:i.ownerElement.boundProperties[e]=!0,i.updateBoundNodes(e)}}},{key:"addPropertyBinding",value:function(e,t,n){this._addRemovePropertyBinding(e,t,n)}},{key:"removePropertyBinding",value:function(e,t,n){this._addRemovePropertyBinding(e,t,n,!0)}},{key:"parseAttributes",value:function(t){for(var n=this,r=void 0,i=0;i<t.attributes.length;i++){var a=t.attributes[i],o=a.name,l=a.value;e.cache["toCamelCase"+o]||(e.cache["toCamelCase"+o]=x.Core.toCamelCase(o));var s=e.cache["toCamelCase"+o];if(o.indexOf("(")>=0){var u=o.substring(1,o.length-1);if(n.ownerElement&&!n.ownerElement.dataContext){n.ownerElement.templateListeners[t.getAttribute("jqx-id")+"."+u]=l,t.removeAttribute(o);continue}r||(r={});var d=l.substring(0,l.indexOf("("));r[s]={isEvent:!0,name:u,value:d}}else{var c=n.parseProperty(l,o,t);c&&(r||(r={}),r[s]=c)}}return r}},{key:"parseProperty",value:function(e,t){if(e&&e.length){for(var n=this,r=void 0,i=e.length,a=0,o=0,l=0,s=!0;o<i;){a=e.indexOf("{{",o);var u=e.indexOf("[[",o),d="}}";if(u>=0&&(a<0||u<a)&&(a=u,s=!1,d="]]"),(l=a<0?-1:e.indexOf(d,a+2))<0)return;r=r||{};var c=e.slice(a+2,l).trim(),p=c;r.name=p,o=l+2}var v=r.name,f=n.ownerElement?n.ownerElement._properties[v]:null;if(r.twoWay=s,r.ready=!1,n.ownerElement&&(v.indexOf("::")>=0?n.ownerElement.boundProperties[v.substring(0,v.indexOf("::"))]=!0:n.ownerElement.boundProperties[v]=!0),f)r.type=f.type,r.reflectToAttribute=f.reflectToAttribute;else{["checked","selected","async","autofocus","autoplay","controls","defer","disabled","hidden","ismap","loop","multiple","open","readonly","required","scoped"].indexOf(t)>=0?r.type="boolean":r.type="string",r.reflectToAttribute=!0}return r}}},{key:"updateTextNodes",value:function(){var e=this;e.updateTextNode(e.ownerElement.shadowRoot||e.ownerElement,e.ownerElement.bindings,e.ownerElement)}},{key:"updateTextNode",value:function(e,t,n){var r=this;if(t){for(var i=0,a=e.firstChild;a&&t.children;a=a.nextSibling)r.updateTextNode(a,t.children[i++],n);if(t&&t.data)for(var o in t.data){var l=t.data[o],s=l.name;"textContent"===o&&l.twoWay&&!l.updating&&void 0!==l.value&&(n[s]=l.value)}}}},{key:"updateBoundProperty",value:function(e,t){if(!t.updating){var n=this,r=n.ownerElement;t.updating=!0,r[e]=t.value,t.updating=!1}}},{key:"updateBoundNodes",value:function(e){var t=this;if(t.updateBoundNode(t.ownerElement.shadowRoot||t.ownerElement,t.ownerElement.bindings,t.ownerElement,e),t.ownerElement.detachedChildren.length>0)for(var n=0;n<t.ownerElement.detachedChildren.length;n++)!function(n){var r=t.ownerElement.detachedChildren[n],i=r.getAttribute("jqx-id"),a=function e(t){if(t.nodeId===i)return t;for(var n in t.children){var r=t.children[n];if((r.getAttribute?r.getAttribute("jqx-id"):"")===i)return t;if(r.children){var a=e(r);if(a)return a}}return null}(t.ownerElement.bindings);if(a)t.updateBoundNode(r,a,t.ownerElement,e,!0);else if(r.getAttribute&&t.ownerElement.bindings.mapping){var o=t.ownerElement,l=t.ownerElement.bindings;if(l)for(var s in l.mapping){var u=o.querySelector('[jqx-id="'+s+'"]');if(u){var d=l.mapping[s];t.updateBoundData(u,d,o,e)}}}}(n)}},{key:"updateBoundMappedNodes",value:function(){var e=this,t=e.ownerElement.bindings,n=e.ownerElement;if(t.mapping)for(var r in t.mapping){var i=n.querySelector('[jqx-id="'+r+'"]');if(i){var a=t.mapping[r];e.updateBoundData(i,a,n)}else if(n.getAttribute("aria-controls")){var o=document.getElementById(n.getAttribute("aria-controls"));if(i=o.querySelector('[jqx-id="'+r+'"]')){var l=t.mapping[r];e.updateBoundData(i,l,n)}}}}},{key:"updateBoundNode",value:function(e,t,n,r,i){var a=this;if(t){var o=0;if(i){if(i&&!t.data)for(var l=e.firstChild;l&&t.children;l=l.nextSibling)l.getAttribute?function(){var e=l.getAttribute("jqx-id"),i=function(){for(var n in t.children)if(t.children[n].nodeId===e)return t.children[n]}();a.updateBoundNode(l,i,n,r),o++}():a.updateBoundNode(l,t.children[o++],n,r,i)}else for(var s=e.firstChild;s&&t.children;s=s.nextSibling)s.getAttribute?function(){var e=s.getAttribute("jqx-id"),i=function(){for(var n in t.children)if(t.children[n].nodeId===e)return t.children[n]}();a.updateBoundNode(s,i,n,r),o++}():a.updateBoundNode(s,t.children[o++],n,r);if(t&&t.data){var u=t.data;a.updateBoundData(e,u,n,r)}}}},{key:"updateBoundData",value:function(t,n,r,i){var a=this;for(var o in n){(function(o){var l=n[o],s=l.name;if(l.updating)return"continue";if(s.indexOf("::")>=0&&(s=s.substring(0,s.indexOf("::"))),void 0!==i&&i!==s)return"continue";if(s.indexOf("(")>=0){var u=s.substring(s.indexOf("(")),d=s.substring(0,s.indexOf("("));if(u=u.substring(1,u.length-1),u=u.replace(/ /gi,""),u=u.split(","),u.length>0&&""!==u[0]){for(var c=[],p=0;p<u.length;p++)c.push(r[u[p]]);l.value=r[d].apply(r,c)}else l.value=r[d]();l.type=babelHelpers.typeof(l.value)}else l.value=r[s];if("innerHTML"===s?t[o].toString().trim()!==r[s].toString().trim()&&(l.ready?t[o]=l.value.toString().trim():r._properties[s].defaultValue!==l.value&&(t[o]=l.value.toString().trim())):l.not?t[o]=!l.value:t[o]=l.value,t.$&&t.$.isNativeElement){e.cache["toDash"+o]||(e.cache["toDash"+o]=x.Core.toDash(o));var v=e.cache["toDash"+o],f=t.$.getAttributeValue(v,l.type);!l.reflectToAttribute||f===l.value&&l.ready||t.$.setAttributeValue(v,l.value,l.type),l.reflectToAttribute||t.$.setAttributeValue(v,null,l.type)}if(!l.ready){if(t.$&&t.$.isCustomElement){e.cache["toDash"+o]||(e.cache["toDash"+o]=x.Core.toDash(o));var h=e.cache["toDash"+o];t._properties||(t._beforeCreatedProperties=t._properties=t.propertyByAttributeName=[]),t._properties[o]||(t._properties[o]={attributeName:h},t._beforeCreatedProperties[o]=t._properties[o],t.propertyByAttributeName[h]=t._properties[o]);var m=t._properties[o];m.isUpdating=!0,l.reflectToAttribute&&(l.not?t.$.setAttributeValue(m.attributeName,!l.value,l.type):t.$.setAttributeValue(m.attributeName,l.value,l.type)),l.reflectToAttribute||t.$.setAttributeValue(m.attributeName,null,l.type),m.isUpdating=!1}if(l.twoWay){var y=function(n){if(l.value=n,t.$&&t.$.isNativeElement){e.cache["toDash"+o]||(e.cache["toDash"+o]=x.Core.toDash(o));var r=e.cache["toDash"+o],i=t.$.getAttributeValue(r,l.type);l.reflectToAttribute&&i!==l.value&&t.$.setAttributeValue(r,l.value,l.type),l.reflectToAttribute||t.$.setAttributeValue(r,null,l.type)}};if(l.name.indexOf("::")>=0){var g=l.name.indexOf("::"),b=l.name.substring(g+2);a.ownerElement["$"+t.getAttribute("jqx-id")].listen(b,function(){y(t[o]);var e=l.name.substring(0,l.name.indexOf("::"));a.updateBoundProperty(e,l)})}if(t.$&&t.$.isCustomElement){t._properties[o]&&(t._properties[o].notify=!0),e.cache["toDash"+o]||(e.cache["toDash"+o]=x.Core.toDash(o));var w=e.cache["toDash"+o];a.ownerElement["$"+t.getAttribute("jqx-id")].listen(w+"-changed",function(e){var t=e.detail;y(t.value);var n=a.ownerElement.context;e.context!==document&&(a.ownerElement.context=a.ownerElement),a.updateBoundProperty(l.name,l),a.ownerElement.context=n})}}}l.ready=!0})(o)}}}],[{key:"clearCache",value:function(){this.cache={}}},{key:"moduleName",get:function(){return"BindingModule"}}]),e}(),s=function(){function e(){babelHelpers.classCallCheck(this,e)}return babelHelpers.createClass(e,null,[{key:"isBoolean",value:function(e){return"boolean"==typeof e}},{key:"isFunction",value:function(e){return!!(e&&e.constructor&&e.call&&e.apply)}},{key:"isArray",value:function(e){return Array.isArray(e)}},{key:"isObject",value:function(e){var t=this;return e&&("object"===(void 0===e?"undefined":babelHelpers.typeof(e))||t.isFunction(e))||!1}},{key:"isDate",value:function(e){return e instanceof Date}},{key:"isString",value:function(e){return"string"==typeof e}},{key:"isNumber",value:function(e){return"number"==typeof e}},{key:"getType",value:function(e){var t=this,n=["Boolean","Number","String","Function","Array","Date","Object"],r=n.find(function(n){if(t["is"+n](e))return n});return r?r.toLowerCase():void 0}}]),e}(),u=function(){function e(){babelHelpers.classCallCheck(this,e)}return babelHelpers.createClass(e,null,[{key:"animate",value:function(e,t,n,i){var a=e;if(a&&a instanceof HTMLElement!=!1){if(0===a.getElementsByClassName("jqx-ripple").length){var o=document.createElement("span");o.classList.add("jqx-ripple");var l=!0,s=null;if(window[r].EnableShadowDOM&&a.enableShadowDOM){for(var u=0;u<a.shadowRoot.host.shadowRoot.children.length;u++)"link"!==a.shadowRoot.host.shadowRoot.children[u].tagName.toLowerCase()&&(s=a.shadowRoot.host.shadowRoot.children[u]);a.shadowRoot.host.shadowRoot.querySelector(".jqx-ripple")&&(l=!1)}else s=a.firstElementChild;l&&(s&&!s.noRipple&&s.offsetHeight>0?s.appendChild(o):a.appendChild(o))}var d=null;if(d=window[r].EnableShadowDOM&&a.enableShadowDOM?a.shadowRoot.host.shadowRoot.querySelector(".jqx-ripple"):a.getElementsByClassName("jqx-ripple")[0]){d.innerHTML="",d.classList.remove("jqx-animate"),d.style.height=d.style.width=Math.max(a.offsetHeight,a.offsetWidth)+"px";var c=window.getComputedStyle(d.parentElement),p=parseInt(c.borderLeftWidth)||0,v=parseInt(c.borderTopWidth)||0,f=a.getBoundingClientRect(),h=t-(f.left+window.pageXOffset)-d.offsetWidth/2-p,m=n-(f.top+window.pageYOffset)-d.offsetHeight/2-v;d.style.left=h+"px",d.style.top=m+"px",d.classList.add("jqx-animate"),d.addEventListener("animationend",function e(){d.parentElement&&d.parentElement.removeChild(d),i&&i(),d.removeEventListener("animationend",e),d.removeEventListener("animationcancel",e)}),d.addEventListener("animationcancel",function e(){d.parentElement&&d.parentElement.removeChild(d),i&&i(),d.removeEventListener("animationcancel",e),d.removeEventListener("animationend",e)})}}}}]),e}(),d=function(){function e(){babelHelpers.classCallCheck(this,e)}return babelHelpers.createClass(e,null,[{key:"easeInQuad",value:function(e,t,n,r){return n*(e/=r)*e+t}},{key:"easeOutQuad",value:function(e,t,n,r){return-n*(e/=r)*(e-2)+t}},{key:"easeInOutQuad",value:function(e,t,n,r){return(e/=r/2)<1?n/2*e*e+t:-n/2*(--e*(e-2)-1)+t}},{key:"easeInCubic",value:function(e,t,n,r){return n*(e/=r)*e*e+t}},{key:"easeOutCubic",value:function(e,t,n,r){return n*((e=e/r-1)*e*e+1)+t}},{key:"easeInOutCubic",value:function(e,t,n,r){return(e/=r/2)<1?n/2*e*e*e+t:n/2*((e-=2)*e*e+2)+t}},{key:"easeInQuart",value:function(e,t,n,r){return n*(e/=r)*e*e*e+t}},{key:"easeOutQuart",value:function(e,t,n,r){return-n*((e=e/r-1)*e*e*e-1)+t}},{key:"easeInOutQuart",value:function(e,t,n,r){return(e/=r/2)<1?n/2*e*e*e*e+t:-n/2*((e-=2)*e*e*e-2)+t}},{key:"easeInQuint",value:function(e,t,n,r){return n*(e/=r)*e*e*e*e+t}},{key:"easeOutQuint",value:function(e,t,n,r){return n*((e=e/r-1)*e*e*e*e+1)+t}},{key:"easeInOutQuint",value:function(e,t,n,r){return(e/=r/2)<1?n/2*e*e*e*e*e+t:n/2*((e-=2)*e*e*e*e+2)+t}},{key:"easeInSine",value:function(e,t,n,r){return-n*Math.cos(e/r*(Math.PI/2))+n+t}},{key:"easeOutSine",value:function(e,t,n,r){return n*Math.sin(e/r*(Math.PI/2))+t}},{key:"easeInOutSine",value:function(e,t,n,r){return-n/2*(Math.cos(Math.PI*e/r)-1)+t}},{key:"easeInExpo",value:function(e,t,n,r){return 0===e?t:n*Math.pow(2,10*(e/r-1))+t}},{key:"easeOutExpo",value:function(e,t,n,r){return e===r?t+n:n*(1-Math.pow(2,-10*e/r))+t}},{key:"easeInOutExpo",value:function(e,t,n,r){return 0===e?t:e===r?t+n:(e/=r/2)<1?n/2*Math.pow(2,10*(e-1))+t:n/2*(2-Math.pow(2,-10*--e))+t}},{key:"easeInCirc",value:function(e,t,n,r){return-n*(Math.sqrt(1-(e/=r)*e)-1)+t}},{key:"easeOutCirc",value:function(e,t,n,r){return n*Math.sqrt(1-(e=e/r-1)*e)+t}},{key:"easeInOutCirc",value:function(e,t,n,r){return(e/=r/2)<1?-n/2*(Math.sqrt(1-e*e)-1)+t:n/2*(Math.sqrt(1-(e-=2)*e)+1)+t}},{key:"easeInElastic",value:function(e,t,n,r){var i=1.70158,a=0,o=n;return 0===e?t:1==(e/=r)?t+n:(a||(a=.3*r),o<Math.abs(n)?(o=n,i=a/4):i=a/(2*Math.PI)*Math.asin(n/o),-o*Math.pow(2,10*(e-=1))*Math.sin((e*r-i)*(2*Math.PI)/a)+t)}},{key:"easeOutElastic",value:function(e,t,n,r){var i=1.70158,a=0,o=n;return 0===e?t:1==(e/=r)?t+n:(a||(a=.3*r),o<Math.abs(n)?(o=n,i=a/4):i=a/(2*Math.PI)*Math.asin(n/o),o*Math.pow(2,-10*e)*Math.sin((e*r-i)*(2*Math.PI)/a)+n+t)}},{key:"easeInOutElastic",value:function(e,t,n,r){var i=1.70158,a=0,o=n;return 0===e?t:2==(e/=r/2)?t+n:(a||(a=r*(.3*1.5)),o<Math.abs(n)?(o=n,i=a/4):i=a/(2*Math.PI)*Math.asin(n/o),e<1?o*Math.pow(2,10*(e-=1))*Math.sin((e*r-i)*(2*Math.PI)/a)*-.5+t:o*Math.pow(2,-10*(e-=1))*Math.sin((e*r-i)*(2*Math.PI)/a)*.5+n+t)}},{key:"easeInBack",value:function(e,t,n,r,i){return void 0===i&&(i=1.70158),n*(e/=r)*e*((i+1)*e-i)+t}},{key:"easeOutBack",value:function(e,t,n,r,i){return void 0===i&&(i=1.70158),n*((e=e/r-1)*e*((i+1)*e+i)+1)+t}},{key:"easeInOutBack",value:function(e,t,n,r,i){return void 0===i&&(i=1.70158),(e/=r/2)<1?n/2*(e*e*((1+(i*=1.525))*e-i))+t:n/2*((e-=2)*e*((1+(i*=1.525))*e+i)+2)+t}},{key:"easeInBounce",value:function(e,t,n,r){return n-this.easeOutBounce(r-e,0,n,r)+t}},{key:"easeOutBounce",value:function(e,t,n,r){return(e/=r)<1/2.75?n*(7.5625*e*e)+t:e<2/2.75?n*(7.5625*(e-=1.5/2.75)*e+.75)+t:e<2.5/2.75?n*(7.5625*(e-=2.25/2.75)*e+.9375)+t:n*(7.5625*(e-=2.625/2.75)*e+.984375)+t}},{key:"easeInOutBounce",value:function(e,t,n,r){return e<r/2?.5*this.easeInBounce(2*e,0,n,r)+t:.5*this.easeOutBounce(2*e-r,0,n,r)+.5*n+t}}]),e}(),c=function(){function e(){babelHelpers.classCallCheck(this,e)}return babelHelpers.createClass(e,null,[{key:"toCamelCase",value:function(e){return e.replace(/-([a-z])/g,function(e){return e[1].toUpperCase()})}},{key:"toDash",value:function(e){return e.split(/(?=[A-Z])/).join("-").toLowerCase()}},{key:"unescapeHTML",value:function(e){return(new DOMParser).parseFromString(e,"text/html").documentElement.textContent}},{key:"escapeHTML",value:function(e){var t={"&":"&amp;","<":"&lt;",">":"&gt;",'"':"&quot;","'":"&#39;","/":"&#x2F;","`":"&#x60;","=":"&#x3D;"};return String(e).replace(/[&<>"'`=\/]/g,function(e){return t[e]})}},{key:"createGUID",value:function(){function e(){return Math.floor(65536*(1+Math.random())).toString(16).substring(1)}return e()+e()+"-"+e()+"-"+e()+"-"+e()+"-"+e()+e()+e()}},{key:"getScriptLocation",value:function(){return"./"!==window[r].BaseUrl?window[r].BaseUrl:function(){if(document.currentScript){var e=document.currentScript.src,t=e.lastIndexOf("/");return e=e.substring(0,t)}var n=new Error,r="(",i=")";if(JQX.Utilities.Core.Browser.Safari&&(r="@",i="\n"),n.fileName)return n.fileName.replace("/jqxelement.js","");var a=n.stack.split(r);return a=a[1],a=a.split(i)[0],a=a.split(":"),a.splice(-2,2),a=a.join(":"),a.replace("/jqxelement.js","")}()}},{key:"CSSVariablesSupport",value:function(){return window.CSS&&window.CSS.supports&&window.CSS.supports("(--fake-var: 0)")}},{key:"assign",value:function(e,t){var n=this,r=function(e){return e&&"object"===(void 0===e?"undefined":babelHelpers.typeof(e))&&!Array.isArray(e)&&null!==e},i=Object.assign({},e);return r(e)&&r(t)&&Object.keys(t).forEach(function(a){r(t[a])&&a in e?i[a]=n.assign(e[a],t[a]):Object.assign(i,babelHelpers.defineProperty({},a,t[a]))}),i}},{key:"html",value:function(e,t){var n=this,r="",i=e.childNodes;if(t){var a=/<(?!area|br|col|embed|hr|img|input|link|meta|param)(([\w:]+)[^>]*)\/>/gi;return void(e.innerHTML=t.replace(a,"<$1></$2>"))}for(var o,l=0,s=i.length;l<s&&(o=i[l]);l++){var u=["strong"];if(o instanceof HTMLElement||o.tagName&&u.indexOf(o.tagName.toLowerCase())>=0){for(var d,c=o.tagName.toLowerCase(),p=o.attributes,v="<"+c,f=0;d=p[f];f++)v+=" "+d.name+'="'+d.value.replace(/[&\u00A0"]/g,x.Core.escapeHTML)+'"';v+=">";["area","base","br","col","command","embed","hr","img","input","keygen","link","meta","param","source","track","wbr"][c]&&(r+=v),r=r+v+n.html(o)+"</"+c+">"}else r+=o.textContent.replace(/[&\u00A0<>]/g,x.Core.escapeHTML)}return r}},{key:"isMobile",get:function(){return/(iphone|ipod|ipad|android|iemobile|blackberry|bada)/.test(window.navigator.userAgent.toLowerCase())}},{key:"Browser",get:function(){var e=void 0,t=function(t){var n=t.indexOf(e);if(-1!==n){var r=t.indexOf("rv:");return"Trident"===e&&-1!==r?parseFloat(t.substring(r+3)):parseFloat(t.substring(n+e.length+1))}},n={};return n[function(){for(var t=[{string:navigator.userAgent,subString:"Edge",identity:"Edge"},{string:navigator.userAgent,subString:"MSIE",identity:"IE"},{string:navigator.userAgent,subString:"Trident",identity:"IE"},{string:navigator.userAgent,subString:"Firefox",identity:"Firefox"},{string:navigator.userAgent,subString:"Opera",identity:"Opera"},{string:navigator.userAgent,subString:"OPR",identity:"Opera"},{string:navigator.userAgent,subString:"Chrome",identity:"Chrome"},{string:navigator.userAgent,subString:"Safari",identity:"Safari"}],n=0;n<t.length;n++){var r=t[n].string;if(e=t[n].subString,-1!==r.indexOf(t[n].subString))return t[n].identity}return"Other"}()]=!0,n.version=t(navigator.userAgent)||t(navigator.appVersion)||"Unknown",n}}]),e}(),p=[],v=function(){function e(){babelHelpers.classCallCheck(this,e)}return babelHelpers.createClass(e,null,[{key:"watch",value:function(t){p.push(t),e.interval&&clearInterval(e.interval),e.interval=setInterval(function(){e.observe()},100)}},{key:"observeElement",value:function(e){var t=e,n=e._computedStyle||"resize"!==t.hasStyleObserver?document.defaultView.getComputedStyle(t,null):{},r=!0,i="resize"!==t.hasStyleObserver?["paddingLeft","paddingRight","paddingTop","paddingBottom","borderLeftWidth","borderRightWidth","borderTopWidth","borderBottomWidth","display","visibility","font-size","font-family","font-style","font-weight","max-height","min-height","max-width","min-width","overflow","overflow-x","overflow-y"]:[];if(e.styleProperties&&(i=i.concat(e.styleProperties)),e.observableStyleProperties&&(i=e.observableStyleProperties),t._styleInfo){if(e.isHidden||"none"!==n.display&&(0!==e.offsetWidth&&0!==e.offsetHeight||(e.isHidden=!0)),e.isHidden){if(e.visibilityChangedHandler(),e.isHidden)return;r=!1}for(var a=[],o=0;o<i.length;o++){var l=i[o];t._styleInfo[l]!==n[l]&&(a[l]={oldValue:t._styleInfo[l],value:n[l]},a.length++),t._styleInfo[l]=n[l]}a.length>0&&(t.$.fireEvent("styleChanged",{styleProperties:a},{bubbles:!1,cancelable:!0}),a.display&&r&&t.$.fireEvent("resize",t,{bubbles:!1,cancelable:!0}))}else{t._styleInfo=[];for(var s=0;s<i.length;s++){var u=i[s];t._styleInfo[u]=n[u]}}}},{key:"observe",value:function(){for(var e=0;e<p.length;e++){var t=p[e];this.observeElement(t)}}},{key:"unwatch",value:function(t){e.interval&&clearInterval(e.interval);var n=p.indexOf(t);-1!==n&&p.splice(n,1),p.length>0&&(e.interval=setInterval(function(){e.observe()},100))}}]),e}(),f=[],h=[],m=["resize","down","up","move","tap","taphold","swipeleft","swiperight","swipetop","swipebottom"],y=function(){function e(t){babelHelpers.classCallCheck(this,e);var n=this;n.target=t,n.$target=new b(t),n.$document=new b(document),n.id=(Date.now().toString(36)+Math.random().toString(36).substr(2,5)).toUpperCase();var r={handlers:{},boundEventTypes:[],listen:n.listen.bind(n),unlisten:n.unlisten.bind(n)};return n.tapHoldDelay=750,n.swipeMin=10,n.swipeMax=5e3,n.swipeDelay=1e3,n.tapHoldDelay=750,n.inputEventProperties=["clientX","clientY","pageX","pageY","screenX","screenY"],m.forEach(function(e){r[e]=function(t){r.handlers[e]=t},n[e]=function(e){if(!r.handlers[e.type]){if(("mousemove"===e.type||"pointermove"===e.type||"touchmove"===e.type)&&r.handlers.move){var t=n.createEvent(e,"move");r.handlers.move(t)}return!0}return r.handlers[e.type](e)}}),n.listen(),n.handlers=r.handlers,r}return babelHelpers.createClass(e,[{key:"listen",value:function(e){var t=this;if("resize"===e&&!t.target.resizeTrigger&&t.target!==document&&t.target!==window&&!1!==t.target.hasResizeObserver){var n=document.createElement("div");n.className="jqx-resize-trigger-container",n.innerHTML='<div class="jqx-resize-trigger-container"><div class="jqx-resize-trigger"></div></div><div class="jqx-resize-trigger-container"><div class="jqx-resize-trigger-shrink"></div></div>',window[r].EnableShadowDOM&&t.target.enableShadowDOM?t.target.shadowRoot.appendChild(n):t.target.appendChild(n),t.target.resizeTrigger=n;var i=n.childNodes[0],a=i.childNodes[0],o=n.childNodes[1],l=function(){a.style.width="100000px",a.style.height="100000px",i.scrollLeft=1e5,i.scrollTop=1e5,o.scrollLeft=1e5,o.scrollTop=1e5},s=void 0,u=void 0,d=void 0,c=void 0,p=t.target.offsetWidth,v=t.target.offsetHeight;if(0===p||0===v){var f=function e(){l(),t.target.removeEventListener("resize",e)};t.target.addEventListener("resize",f),l()}else l();t.target.resizeHandler=function(){u||(u=requestAnimationFrame(function(){if(u=0,d=t.target.offsetWidth,c=t.target.offsetHeight,s=d!==p||c!==v,t.target.requiresLayout&&(s=!0),s){p=d,v=c;var e=new CustomEvent("resize",{bubbles:!1,cancelable:!0});t.resize(e),t.target.requiresLayout=!1}})),l()},i.addEventListener("scroll",t.target.resizeHandler),o.addEventListener("scroll",t.target.resizeHandler)}if(!t.isListening){if(t.isListening=!0,t.isPressed=!1,t.isReleased=!1,t.isInBounds=!1,window.PointerEvent)t.$target.listen("pointerdown.inputEvents"+t.id,t.pointerDown.bind(t)),t.$target.listen("pointerup.inputEvents"+t.id,t.pointerUp.bind(t)),t.$target.listen("pointermove.inputEvents"+t.id,t.pointerMove.bind(t)),t.$target.listen("pointercancel.inputEvents"+t.id,t.pointerCancel.bind(t));else{"ontouchstart"in window&&(t.$target.listen("touchmove.inputEvents"+t.id,t.touchMove.bind(t)),t.$target.listen("touchstart.inputEvents"+t.id,t.touchStart.bind(t)),t.$target.listen("touchend.inputEvents"+t.id,t.touchEnd.bind(t)),t.$target.listen("touchcancel.inputEvents"+t.id,t.touchCancel.bind(t))),t.$target.listen("mousedown.inputEvents"+t.id,t.mouseDown.bind(t)),t.$target.listen("mouseup.inputEvents"+t.id,t.mouseUp.bind(t)),t.$target.listen("mousemove.inputEvents"+t.id,t.mouseMove.bind(t)),t.$target.listen("mouseleave.inputEvents"+t.id,t.mouseLeave.bind(t))}t.$document.listen("mouseup.inputEvents"+t.id,t.handleDocumentUp.bind(t))}}},{key:"unlisten",value:function(e){var t=this;if(t.isListening=!1,window.PointerEvent)t.$target.unlisten("pointerdown.inputEvents"+t.id),t.$target.unlisten("pointerup.inputEvents"+t.id),t.$target.unlisten("pointermove.inputEvents"+t.id),t.$target.unlisten("pointercancel.inputEvents"+t.id);else{"ontouchstart"in window&&(t.$target.unlisten("touchstart.inputEvents"+t.id),t.$target.unlisten("touchmove.inputEvents"+t.id),t.$target.unlisten("touchend.inputEvents"+t.id),t.$target.unlisten("touchcancel.inputEvents"+t.id)),t.$target.unlisten("mousedown.inputEvents"+t.id),t.$target.unlisten("mouseup.inputEvents"+t.id),t.$target.unlisten("mousemove.inputEvents"+t.id),t.$target.unlisten("mouseleave.inputEvents"+t.id)}if(t.$document.unlisten("mouseup.inputEvents"+t.id,t.handleDocumentUp),"resize"===e&&t.target.resizeTrigger){var n=t.target.resizeTrigger,i=n.childNodes[0],a=n.childNodes[1];i.removeEventListener("scroll",t.target.resizeHandler),a.removeEventListener("scroll",t.target.resizeHandler),t.target.resizeHandler=null,(window[r].EnableShadowDOM&&t.target.enableShadowDOM?t.target.shadowRoot:t.target).removeChild(n),delete t.target.resizeTrigger}}},{key:"handleDocumentUp",value:function(e){var t=this;t.isPressed=!1,t.isReleased=!1,t.resetSwipe(e)}},{key:"createEvent",value:function(e,t){var n=this,r=e.touches,i=e.changedTouches,a=r&&r.length?r[0]:i&&i.length?i[0]:void 0,o=new CustomEvent(t,{bubbles:!0,cancelable:!0});if(o.originalEvent=e,a){for(var l=0;l<n.inputEventProperties.length;l++){var s=n.inputEventProperties[l];o[s]=a[s]}return o}for(var u in e)u in o||(o[u]=e[u]);return o}},{key:"fireTap",value:function(e){var t=this;if(clearTimeout(this.tapHoldTimeout),!this.tapHoldFired&&this.isInBounds){var n=t.createEvent(e,"tap");t.tap(n)}}},{key:"initTap",value:function(e){var t=this;t.isInBounds=!0,t.tapHoldFired=!1,t.tapHoldTimeout=setTimeout(function(){if(t.isInBounds){t.tapHoldFired=!0;var n=t.createEvent(e,"taphold");t.taphold(n)}},t.tapHoldDelay)}},{key:"pointerDown",value:function(e){return this.handleDown(e)}},{key:"mouseDown",value:function(e){var t=this;if(!(t.isPressed||t.touchStartTime&&new Date-t.touchStartTime<500))return t.handleDown(e)}},{key:"touchStart",value:function(e){var t=this;return t.touchStartTime=new Date,t.isTouchMoved=!0,t.handleDown(e)}},{key:"mouseUp",value:function(e){var t=this;if(!(t.isReleased||t.touchEndTime&&new Date-t.touchEndTime<500))return t.handleUp(e)}},{key:"handleDown",value:function(e){var t=this;t.isReleased=!1,t.isPressed=!0;var n=t.createEvent(e,"down");return(t.handlers.tap||t.handlers.taphold)&&t.initTap(n),(t.handlers.swipeleft||t.handlers.swiperight||t.handlers.swipetop||t.handlers.swipebottom)&&t.initSwipe(n),t.down(n)}},{key:"handleUp",value:function(e){var t=this;t.isReleased=!0,t.isPressed=!1;var n=t.createEvent(e,"up"),r=t.up(n);return(t.handlers.tap||t.handlers.taphold)&&t.fireTap(n),t.resetSwipe(n),r}},{key:"handleMove",value:function(e){var t=this,n=t.move(e);return t.isPressed&&(t._maxSwipeVerticalDistance=Math.max(t._maxSwipeVerticalDistance,Math.abs(t._startY-e.pageY)),t._maxSwipeHorizontalDistance=Math.max(t._maxSwipeHorizontalDistance,Math.abs(t._startX-e.pageX)),n=t.handleSwipeEvents(e)),n}},{key:"touchEnd",value:function(e){var t=this;return t.touchEndTime=new Date,t.handleUp(e)}},{key:"pointerUp",value:function(e){return this.handleUp(e)}},{key:"pointerCancel",value:function(e){this.pointerUp(e)}},{key:"touchCancel",value:function(e){this.touchEnd(e)}},{key:"mouseLeave",value:function(){this.isInBounds=!1}},{key:"mouseMove",value:function(e){var t=this;if(!t.isTouchMoved)return t.handleMove(e)}},{key:"pointerMove",value:function(e){return this.handleMove(e)}},{key:"touchMove",value:function(e){for(var t=this,n=e.touches,r=e.changedTouches,i=n&&n.length?n[0]:r&&r.length?r[0]:void 0,a=0;a<t.inputEventProperties.length;a++){var o=t.inputEventProperties[a];void 0===e[o]&&(e[o]=i[o])}return t.isTouchMoved=!0,t.handleMove(e)}},{key:"handleSwipeEvents",value:function(e){var t=this,n=!0;return(t.handlers.swipetop||t.handlers.swipebottom)&&(n=this.handleVerticalSwipeEvents(e)),!1===n?n:((t.handlers.swipeleft||t.handlers.swiperight)&&(n=this.handleHorizontalSwipeEvents(e)),n)}},{key:"handleVerticalSwipeEvents",value:function(e){var t=void 0,n=void 0;return t=e.pageY,n=t-this._startY,this.swiped(e,n,"vertical")}},{key:"handleHorizontalSwipeEvents",value:function(e){var t=void 0,n=void 0;return t=e.pageX,n=t-this._startX,this.swiped(e,n,"horizontal")}},{key:"swiped",value:function(e,t,n){var r=this;if(n=n||0,Math.abs(t)>=r.swipeMin&&!r._swipeEvent&&!r._swipeLocked){var i=t<0?"swipeleft":"swiperight";if("horizontal"===n?r._swipeEvent=r.createEvent(e,i):(i=t<0?"swipetop":"swipebottom",r._swipeEvent=r.createEvent(e,t<0?"swipetop":"swipebottom")),r[i]&&(r[i](this._swipeEvent),Math.abs(t)<=this.swipeMax))return e.stopImmediatePropagation(),!1}return!0}},{key:"resetSwipe",value:function(){this._swipeEvent=null,clearTimeout(this._swipeTimeout)}},{key:"initSwipe",value:function(e){var t=this;t._maxSwipeVerticalDistance=0,t._maxSwipeHorizontalDistance=0,t._startX=e.pageX,t._startY=e.pageY,t._swipeLocked=!1,t._swipeEvent=null,t._swipeTimeout=setTimeout(function(){t._swipeLocked=!0},t.swipeDelay)}}]),e}(),g=function(){function e(t,n,r){babelHelpers.classCallCheck(this,e);var i=this;i.container=t,i.horizontalScrollBar=n,i.verticalScrollBar=r,i.disableSwipeScroll=!1,i.listen()}return babelHelpers.createClass(e,[{key:"scrollWidth",get:function(){var e=this;return e.horizontalScrollBar?e.horizontalScrollBar.max:-1},set:function(e){var t=this;e<0&&(e=0),t.horizontalScrollBar&&(t.horizontalScrollBar.max=e)}},{key:"scrollHeight",get:function(){var e=this;return e.verticalScrollBar?e.verticalScrollBar.max:-1},set:function(e){var t=this
;e<0&&(e=0),t.verticalScrollBar&&(t.verticalScrollBar.max=e)}},{key:"scrollLeft",get:function(){var e=this;return e.horizontalScrollBar?e.horizontalScrollBar.value:-1},set:function(e){var t=this;e<0&&(e=0),t.horizontalScrollBar&&(t.horizontalScrollBar.value=e)}},{key:"scrollTop",get:function(){var e=this;return e.verticalScrollBar?e.verticalScrollBar.value:-1},set:function(e){var t=this;e<0&&(e=0),t.verticalScrollBar&&(t.verticalScrollBar.value=e)}},{key:"vScrollBar",get:function(){return this.verticalScrollBar}},{key:"hScrollBar",get:function(){return this.horizontalScrollBar}}]),babelHelpers.createClass(e,[{key:"listen",value:function(){function e(){var n=void 0,r=void 0;f.amplitude&&(t.container.$.fireEvent("kineticScroll"),n=Date.now()-s,r=-f.amplitude*Math.exp(-n/v),r>5||r<-5?(w(f.targetValue+r),cancelAnimationFrame(o),o=0,o=requestAnimationFrame(e)):w(f.targetValue))}var t=this,n=c.isMobile,r=t.horizontalScrollBar,i=t.verticalScrollBar;t.inputEvents=new y(t.container);var a=void 0,o=void 0,l=void 0,s=void 0,u=void 0,d=void 0,p=void 0,v=500,f=void 0,h=function(e){return{amplitude:0,delta:0,initialValue:0,min:0,max:e.max,previousValue:0,pointerPosition:0,targetValue:0,scrollBar:e,value:0,velocity:0}},m=h(r),g=h(i),b=function(){d=Date.now(),p=d-s,s=d;var e=function(e){e.delta=e.value-e.previousValue,e.previousValue=e.value;var t=1e3*e.delta/(1+p);e.velocity=.8*t+.2*e.velocity};e(g),e(m)},w=function(e){return f.value=e>f.max?f.max:e<f.min?f.min:e,f.scrollBar.value=f.value,e>f.max?"max":e<f.min?"min":"value"};t.inputEvents.down(function(e){if(n){var r=e.originalEvent.target,i=r&&r.closest?r.closest("jqx-scroll-bar"):void 0;if(i!==t.horizontalScrollBar&&i!==t.verticalScrollBar){l=!0,a=!1;var o=function(e,t){e.amplitude=0,e.pointerPosition=t,e.previousValue=e.value,e.value=e.scrollBar.value,e.initialValue=e.value,e.max=e.scrollBar.max};o(g,e.clientY),o(m,e.clientX),s=Date.now(),clearInterval(u),u=setInterval(b,v)}}}),t.inputEvents.up(function(){if(!l)return!0;if(clearInterval(u),t.disableSwipeScroll)return void(l=!1);var n=function(t){f=t,t.amplitude=.8*t.velocity,t.targetValue=Math.round(t.value+t.amplitude),s=Date.now(),cancelAnimationFrame(o),o=requestAnimationFrame(e),t.velocity=0};g.velocity>10||g.velocity<-10?n(g):(m.velocity>10||m.velocity<-10)&&n(m),l=!1}),t.inputEvents.move(function(e){if(!l)return!0;if(!t.disableSwipeScroll&&(a&&(e.originalEvent.preventDefault(),e.originalEvent.stopPropagation()),m.visible=r.offsetHeight>0,g.visible=i.offsetWidth>0,l&&(m.visible||g.visible))){g.ratio=-g.max/g.scrollBar.offsetHeight,g.delta=(e.clientY-g.pointerPosition)*g.ratio,m.ratio=-m.max/m.scrollBar.offsetWidth,m.delta=(e.clientX-m.pointerPosition)*m.ratio;var n="value",o=function(e,r,i){return e.delta>5||e.delta<-5?(f=e,"min"===(n=e.initialValue+e.delta>f.max?"max":e.initialValue+e.delta<f.min?"min":"value")&&0===e.initialValue||("max"===n&&e.initialValue===e.max||(!e.visible||(t.container.$.fireEvent("kineticScroll"),w(e.initialValue+e.delta),b(),i.originalEvent.preventDefault(),i.originalEvent.stopPropagation(),a=!0,!1)))):null},s=o(g,e.clientY,e);if(null!==s)return s;var u=o(m,e.clientX,e);return null!==u?u:void 0}});var _=void 0;t.scrollTo=function(e,n){var r=!1===n?m:g,i=!1;s||(s=Date.now()),_||(_=Date.now()),Math.abs(Date.now()-_)>375?s=Date.now():i=!0,_=Date.now(),r.value=r.scrollBar.value,r.delta=e-r.value,r.max=r.scrollBar.max,e<=r.min&&(e=r.min),e>=r.max&&(e=r.max),r.targetValue=e;var a=e,l=r.value;r.velocity=100*r.delta/(1+r.max),r.from=l;var u=function(e){return r.value=e>r.max?r.max:e<r.min?r.min:e,r.scrollBar.value=r.value,e>r.max?"max":e<r.min?"min":"value"},d=function n(){var d=void 0,c=Date.now()-_,p=Math.min(1e3,Date.now()-s),v=r.velocity*Math.exp(p/175);if(i)v<0&&r.value<=e?v=0:v>0&&r.value>=e&&(v=0),(r.value+v<=r.min||r.value+v>=r.max)&&(v=0),v>.5||v<-.5?(u(r.value+v),cancelAnimationFrame(o),o=0,o=requestAnimationFrame(n)):u(r.targetValue);else{if(c>=175)return cancelAnimationFrame(o),t.container.$.fireEvent("kineticScroll"),void(o=0);d=x.Animation.Easings.easeInSine(c,l,a-l,175),u(d),cancelAnimationFrame(o),o=0,o=requestAnimationFrame(n)}};cancelAnimationFrame(o),o=requestAnimationFrame(d)},t.inputEvents.listen()}},{key:"unlisten",value:function(){var e=this;e.inputEvents&&e.inputEvents.unlisten(),delete e.inputEvents}}]),e}(),b=function(){function e(t){babelHelpers.classCallCheck(this,e),this.events={},this.handlers={},this.element=t}return babelHelpers.createClass(e,[{key:"hasClass",value:function(e){for(var t=this,n=e.split(" "),r=0;r<n.length;r++){if(!t.element.classList.contains(n[r]))return!1}return!0}},{key:"addClass",value:function(e){var t=this;if(!t.hasClass(e)){for(var n=e.split(" "),r=0;r<n.length;r++)t.element.classList.add(n[r]);t.isNativeElement||v.observeElement(t.element)}}},{key:"removeClass",value:function(e){var t=this;if(0===arguments.length)return void t.element.removeAttribute("class");for(var n=e.split(" "),r=0;r<n.length;r++)t.element.classList.remove(n[r]);""===t.element.className&&t.element.removeAttribute("class"),t.isNativeElement||v.observeElement(t.element)}},{key:"dispatch",value:function(e){var t=this,n=t.events[e.type],r=!1;if(n.length>1)for(var i=0;i<n.length;i++){var a=n[i];if(a.namespace&&a.namespace.indexOf("_")>=0){r=!0;break}}r&&n.sort(function(e,t){var n=e.namespace,r=t.namespace;return n=-1===n.indexOf("_")?0:parseInt(n.substring(n.indexOf("_")+1)),r=-1===r.indexOf("_")?0:parseInt(r.substring(r.indexOf("_")+1)),n<r?-1:n>r?1:0});for(var o=0;o<n.length;o++){var l=n[o];if(e.namespace=l.namespace,e.context=l.context,e.defaultPrevented)break;var s=l.handler.apply(t.element,[e]);if(void 0!==s&&(e.result=s,!1===s)){e.preventDefault(),e.stopPropagation();break}}return e.result}},{key:"fireEvent",value:function(e,t,n){var r=this;n||(n={bubbles:!0,cancelable:!0}),n.detail=t||{};var i=new CustomEvent(e,n);return i.originalStopPropagation=i.stopPropagation,i.stopPropagation=function(){return i.isPropagationStopped=!0,i.originalStopPropagation()},r.dispatchEvent(i),i}},{key:"dispatchEvent",value:function(e){var t=this,n=e.type,r=t.element.context;t.element.context=document,t.element["on"+n]?t.element["on"+n](e):t.element.dispatchEvent(e),t.element.context=r}},{key:"listen",value:function(e,t){var n=this,r=e.split("."),i=r.slice(1).join("."),a=r[0];n.events[a]||(n.events[a]=[]);var o={type:a,handler:t,context:n.element,namespace:i};m.indexOf(a)>=0&&(n.inputEvents||(n.inputEvents=new y(n.element)),n.inputEvents[a](function(e){n.dispatchEvent(e)}),n.inputEvents.boundEventTypes.push(a),n.inputEvents.listen(a)),0===n.events[a].length&&(n.handlers[a]=n.dispatch.bind(n),"wheel"===a?n.element.addEventListener("wheel",n.handlers[a],!!n.isPassiveSupported&&{passive:!1}):n.element.addEventListener(a,n.handlers[a],!1)),n.events[a].push(o)}},{key:"unlisten",value:function(e){var t=this,n=e.split("."),r=n.slice(1).join("."),i=n[0],a=t.events[i];if(t.inputEvents&&t.inputEvents.boundEventTypes.indexOf(i)>=0&&(t.inputEvents.boundEventTypes.splice(t.inputEvents.boundEventTypes.indexOf(i),1),0===t.inputEvents.boundEventTypes.length&&t.inputEvents.unlisten(i)),a){for(var o=0;o<a.length;o++){if(""!==r){var l=a.findIndex(function(e){return e.namespace===r});a.splice(l,1);break}a=[]}0===a.length&&(t.element.removeEventListener(i,t.handlers[i]),t.events[i]=[],delete t.handlers[i])}}},{key:"getAttributeValue",value:function(e,t){var n=this,r=n.element.getAttribute(e);if(n.isNativeElement)return n.deserialize(r,t);var i=n.element.propertyByAttributeName[e];return void 0===i.deserialize?n.deserialize(r,t,i.nullable):n.element[i.deserialize](r)}},{key:"setAttributeValue",value:function(e,t,n){var r=this,i=void 0,a=!1;if(r.isNativeElement){if(i=r.serialize(t,n),"boolean"===n){var o=["checked","selected","async","autofocus","autoplay","controls","defer","disabled","hidden","ismap","loop","multiple","open","readonly","required","scoped"];if(o.indexOf(e)>=0)return void(t?r.element.setAttribute(e,""):r.element.removeAttribute(e))}}else{var l=r.element.propertyByAttributeName[e];a=!l||l.nullable,i=l&&l.serialize?r.element[l.serialize](t):r.serialize(t,n,a)}if(!("array"!==n&&"object"!==n||"[]"!==i&&"{}"!==i))return void r.element.removeAttribute(e);void 0===i?r.element.removeAttribute(e):r.element.setAttribute(e,i)}},{key:"serialize",value:function(e,t,n){if(void 0===t&&(t=x.Types.getType(e)),void 0!==e&&(n||null!==e)){if(n&&null===e)return"null";if("string"===t)return e;if("boolean"===t||"bool"===t){if(!0===e||"true"===e||1===e||"1"===e)return"";if(!1===e||"false"===e||0===e||"0"===e)return}if("array"===t)return JSON.stringify(e);return["string","number","int","integer","float","date","any","function"].indexOf(t)>=0?e.toString():"object"===t?JSON.stringify(e):void 0}}},{key:"deserialize",value:function(e,t,n){var r="null"===e;if(void 0!==e&&(!r||n)){if(r&&n)return null;if("boolean"===t||"bool"===t)return null!==e;if("number"===t||"float"===t)return"NaN"===e?NaN:"Infinity"===e?1/0:"-Infinity"===e?-1/0:parseFloat(e);if("int"===t||"integer"===t)return"NaN"===e?NaN:"Infinity"===e?1/0:"-Infinity"===e?-1/0:parseInt(e);if("string"===t)return e;if("any"===t)return e;if("date"===t)return new Date(e);if("function"===t){if("function"==typeof window[e])return window[e]}else if("array"===t||"object"===t)try{var i=JSON.parse(e);if(i)return i}catch(n){if(window[e]&&"object"===babelHelpers.typeof(window[e]))return window[e];if("array"===t&&e.indexOf("[")>=0){if(e.indexOf("{")>=0){var a=e.replace(/{/gi,"").replace("[","").replace("]","").replace(/'/gi,"").replace(/"/gi,"").trim();a=a.split("},");for(var o=0;o<a.length;o++){for(var l={},s=a[o].trim().split(","),u=0;u<s.length;u++){var d=s[u].split(":")[0].trim(),c=s[u].split(":")[1].trim();l[d]=c}a[o]=l}return a}var p=e.replace("[","").replace("]","").replace(/'/gi,"").replace(/"/gi,"").trim().split(",");return p}}}}},{key:"isCustomElement",get:function(){var e=this;return e.element instanceof window[r].BaseElement==!0||"DIV"!==e.element.tagName&&"SPAN"!==e.element.tagName&&"BUTTON"!==e.element.tagName&&"INPUT"!==e.element.tagName&&"UL"!==e.element.tagName&&"LI"!==e.element.tagName&&document.createElement(e.element.nodeName)instanceof window[r].BaseElement==!0}},{key:"isNativeElement",get:function(){return!this.isCustomElement}},{key:"isPassiveSupported",get:function(){var e=this;if(void 0!==e.supportsPassive)return e.supportsPassive;e.supportsPassive=!1;try{var t=Object.defineProperty({},"passive",{get:function(){e.supportsPassive=!0}});window.addEventListener("testPassive",null,t),window.removeEventListener("testPassive",null,t)}catch(e){}return e.supportsPassive}}]),e}(),w=function(){function e(){babelHelpers.classCallCheck(this,e)}return babelHelpers.createClass(e,null,[{key:"Ripple",get:function(){return u}},{key:"Easings",get:function(){return d}}]),e}(),x=function(){function e(){babelHelpers.classCallCheck(this,e)}return babelHelpers.createClass(e,null,[{key:"Extend",value:function(e){return new b(e)}},{key:"Assign",value:function(t,n){if(t.indexOf(".")>=0){var r=t.split(".");return e[r[0]]||(e[r[0]]={}),void(e[r[0]][r[1]]=n)}e[t]=n}},{key:"Types",get:function(){return s}},{key:"Core",get:function(){return c}},{key:"Animation",get:function(){return w}},{key:"Scroll",get:function(){return g}},{key:"InputEvents",get:function(){return y}}]),e}(),_=x.Extend(document);l.cache={};var C=function(e){function t(){return babelHelpers.classCallCheck(this,t),babelHelpers.possibleConstructorReturn(this,(t.__proto__||Object.getPrototypeOf(t)).apply(this,arguments))}return babelHelpers.inherits(t,e),babelHelpers.createClass(t,[{key:"template",value:function(){return"<div></div>"}},{key:"registered",value:function(){var e=this;e.onRegistered&&e.onRegistered()}},{key:"created",value:function(){var e=this;e.isReady=!1,e._initElement(e),e._setModuleState("created"),e.onCreated&&e.onCreated()}},{key:"completed",value:function(){var e=this;e.isCompleted=!0,e._onCompleted&&e._onCompleted(),e.onCompleted&&e.onCompleted()}},{key:"whenReady",value:function(e){var t=this;if(t.isCompleted)return void e();t.whenReadyCallbacks||(t.whenReadyCallbacks=[]),t.whenReadyCallbacks.push(e)}},{key:"addThemeClass",value:function(){var e=this;""!==e.theme&&e.classList.add("jqx-"+e.theme)}},{key:"addDefaultClass",value:function(){var e=this;e.classList.add(e.nodeName.toLowerCase()+"-element")}},{key:"ready",value:function(){var e=this,t=this;t.addThemeClass(),t.addDefaultClass(),"collapsed"===t.visibility?t.classList.add("jqx-hidden"):"hidden"===t.visibility&&t.classList.add("jqx-visibility-hidden");if(function(){var n=[],i=t.getStaticMember("requires");for(var a in i){var o=a.split(".");o.length>2?window[r].Utilities[o[2]]||n.push(i[a]):window[r][o[1]]||n.push(i[a])}if(n.length>0){var l=e;l.error(l.localize("missingReference",{elementType:l.nodeName.toLowerCase(),files:n.join(", ")}))}}(),t.dataContext&&t.applyDataContext(),t.onReady&&t.onReady(),t.shadowRoot&&JQX(t._selector)){if(JQX(t._selector).styleUrls)for(var n=JQX(t._selector).styleUrls,i=0;i<n.length;i++)t.importStyle(n[i]);if(JQX(t._selector).styles){var a=document.createElement("style");a.innerHTML=JQX(t._selector).styles,t.shadowRoot.insertBefore(a,t.shadowRoot.firstChild)}}JQX(t._selector)&&JQX(t._selector).ready&&JQX(t._selector).ready()}},{key:"applyDataContext",value:function(e){var t=this,n="string"==typeof t.dataContext?window[t.dataContext]||document[t.dataContext]:t.dataContext;if(e&&(n=e,t.dataContext=e),!n){t.dataContextProperties=null;var r=function e(){("string"==typeof t.dataContext?window[t.dataContext]||document[t.dataContext]:t.dataContext)&&(t.applyDataContext(),window.removeEventListener("load",e))};return void window.addEventListener("load",r)}if(!n._uid){n._uid=(Date.now().toString(36)+Math.random().toString(36).substr(2,5)).toUpperCase(),n._properties=[];for(var i in n){(function(e){var r=n[e];if("function"==typeof r||"_properties"===e||"_uid"===e)return"continue";n._properties[e]=r,Object.defineProperty(n,e,{configurable:!1,enumerable:!0,get:function(){return n._properties[e]},set:function(r){var i=n._properties[e];n._properties[e]=r;var a=[];a[e]={oldValue:i,value:r},a.length++,t.updatingDataContext=!0,_.fireEvent("dataContextPropertyChanged",{dataContext:n,properties:a},{bubbles:!1,cancelable:!0}),t.updatingDataContext=!1}})})(i)}}if(t.dataContextProperties=t.parseAttributes(t),t.dataContextPropertiesMap={},t.dataContextListeners={},!t.dataContextProperties)return void(t.dataContextProperties=null);t.updatingDataContext=!0;for(var a in t.dataContextProperties){var o=t.dataContextProperties[a],s=o.name;if(o.propertyName=a,t.dataContextPropertiesMap[s]=a,l.cache["toDash"+a]||(l.cache["toDash"+a]=x.Core.toDash(s)),o.isEvent&&function(){var e=o.value;t.dataContextListeners[s]&&t.removeEventListener(s,t.dataContextListeners[s]),t.dataContextListeners[s]=function(t){n[e](t)},t.addEventListener(s,t.dataContextListeners[s])}(),s.indexOf(".")>=0){for(var u=s.split("."),d=n[u[0]],c=1;c<u.length;c++)d=d[u[c]];void 0!==d&&(t[a]=d)}else t[a]=n[s]}t.dataContextPropertyChangedHandler=function(e){var n=e.detail.properties;if(e.detail.dataContext===("string"==typeof t.dataContext?window[t.dataContext]||document[t.dataContext]:t.dataContext))for(var r in n){var i=t.dataContextPropertiesMap[r],a=t.context;i&&(t.context=document,t[i]=n[r].value,t.context=a)}},_.listen("dataContextPropertyChanged",t.dataContextPropertyChangedHandler),t.updatingDataContext=!1}},{key:"updateDataContextProperty",value:function(e){var t=this,n="string"==typeof t.dataContext?window[t.dataContext]||document[t.dataContext]:t.dataContext,r=t.dataContextProperties[e];if(!t.updatingDataContext&&r.twoWay){var i=r.name;if(i.indexOf(".")>=0){for(var a=i.split("."),o=n[a[0]],l=1;l<a.length;l++)o=o[a[l]];void 0!==o&&(o=t[e],f[n._uid]&&(f[n._uid][e]=o))}else n[i]=t[e],f[n._uid]&&(f[n._uid][e]=n[i])}}},{key:"initProperties",value:function(){var e=this;if(JQX(e._selector)&&JQX(e._selector).properties&&(e._initProperties=JQX(e._selector).properties),e._initProperties)for(var t=Object.keys(e._initProperties),n=0;n<t.length;n++){var r=t[n],i=e._initProperties[r];i.constructor!==JQX.ObservableArray?i.constructor===JQX.DataAdapter||i.constructor===JQX.Observable||"object"!==(void 0===i?"undefined":babelHelpers.typeof(i))||x.Types.isArray(i)?e[r]=i:"object"===(void 0===i?"undefined":babelHelpers.typeof(i))&&function(){!function t(n,r){for(var i=Object.keys(n),a=0;a<i.length;a++){var o=i[a],l=n[o];"object"!==(void 0===l?"undefined":babelHelpers.typeof(l))||x.Types.isArray(l)||l.constructor===Date?e[r+"_"+o]=l:t(l,r+"_"+o)}}(i,r)}():e[r]=i.toArray()}}},{key:"setup",value:function(){var e=this;if(e.context=this,!e.isReady||e.isCompleted){if(e.isReady)return e._setModuleState("attached"),e.isAttached=!0,e.attached(),e._handleListeners("listen"),void(e.context=document);e.ownerElement&&e.ownerElement.detachedChildren.indexOf(e)>=0&&e.ownerElement.detachedChildren.splice(e.ownerElement.detachedChildren.indexOf(e),1),e.isReady=!0,e.methods=e.getStaticMember("methods"),e.initProperties();c.isMobile&&e.classList.add("jqx-mobile");for(var t=0;t<e.attributes.length;t+=1){var n=e.propertyByAttributeName[e.attributes[t].name];if(n){var i=e.$.getAttributeValue(n.attributeName,n.type),a=i?i.toString():"";if(!(a.indexOf("{{")>=0||a.indexOf("[[")>=0||"object"!==n.type&&"array"!==n.type&&(e.attributes[t].value.indexOf("{{")>=0||e.attributes[t].value.indexOf("[[")>=0)||void 0===i||n.value===i)){var o=x.Types.getType(i),l=e.attributes[t].value;if(("any"===n.type||"object"===n.type)&&""+e[n.name]===i)continue;if("array"===n.type&&e[n.name]&&JSON.stringify(e[n.name])===i)continue;if("number"===o&&isNaN(i)&&"NaN"!==l&&"Infinity"!==l&&"-Infinity"!==l){var s=e.localize("propertyInvalidValueType",{name:n.name,actualType:"string",type:n.type});e.log(s)}n.isUpdatingFromAttribute=!0,e[n.name]=i,n.isUpdatingFromAttribute=!1}}}for(var u in e._properties){var d=e._properties[u];if("innerHTML"===u&&d.value===d.defaultValue&&(d.value=d.defaultValue=x.Core.html(e)),"boolean"!==d.type&&"bool"!==d.type||"false"===e.getAttribute(d.attributeName)&&(d.isUpdating=!0,e.setAttribute(d.attributeName,""),d.isUpdating=!1),d.defaultReflectToAttribute&&d.reflectToAttribute){if(d.defaultReflectToAttribute&&d.defaultReflectToAttributeConditions){for(var p=!0,v=0;v<d.defaultReflectToAttributeConditions.length;v++){var f=d.defaultReflectToAttributeConditions[v],h=void 0,m=void 0;for(var y in f)h=y,m=f[y];e._properties[h]&&e._properties[h].value!==m&&(p=!1)}if(!p)continue}d.isUpdating=!0,e.$.setAttributeValue(d.attributeName,d.value,d.type),d.isUpdating=!1}}var g=[];if(e.children.length>0)for(var b=0;b<e.children.length;b++){var w=e.children[b];x.Extend(w).isCustomElement&&g.push(w)}e.applyTemplate(),e.complete=function(){if(!e.templateBindingsReady){var t=function(e){e.templateBindingsReady||(e.templateBindingsReady=!0,e.updateTextNodes(),e.updateBoundNodes())};if(e.ownerElement){for(var n=e.ownerElement,i=[];n;)i.push(n),n=n.ownerElement;for(var a=i.length-1;a>=0;a--)t(i[a]);t(e)}else t(e)}var o=function(){if(e._setModuleState("ready"),e.ready(),e.isAttached=!0,e._setModuleState("attached"),e.attached(),e._handleListeners("listen"),e.isHidden||0!==e.offsetWidth&&0!==e.offsetHeight||(e.isHidden=!0),e.completed(),e.context=document,e.whenReadyCallbacks){for(var t=0;t<e.whenReadyCallbacks.length;t++)e.whenReadyCallbacks[t]();e.whenReadyCallbacks=[]}};window[r].EnableShadowDOM?o():e.wait?e.classList.add("jqx-visibility-hidden"):e.classList.contains("jqx-async")?requestAnimationFrame(function(){o()}):e.ownerElement&&"HTML"!==e.parents[e.parents.length-1].nodeName?e.checkIsInDomInterval=setInterval(function(){if("HTML"===e.parents[e.parents.length-1].nodeName){clearInterval(e.checkIsInDomInterval);for(var t=e.ownerElement,n=[];t;)n.push(t),t=t.ownerElement;for(var r=n.length-1;r>=0;r--)n[r].updateBoundMappedNodes();o()}},100):o()};var _=[].slice.call(e.querySelectorAll("[jqx-id]")).concat(g);if(window[r].EnableShadowDOM&&e.enableShadowDOM&&(_=[].slice.call(e.shadowRoot.querySelectorAll("[jqx-id]")).concat(g)),0===_.length)e.complete();else{e._completeListeners=0;for(var C=0;C<_.length;C++)!function(t){var n=_[t];if(x.Extend(n).isCustomElement){var r=function(){0===--e._completeListeners&&(e.complete(),delete e._completeListeners)}.bind(e);n.isCompleted||n.isUtilityElement||!1!==n.wait||(e._completeListeners++,n._onCompleted||(n.completeHandlers=[],n._onCompleted=function(){for(var e=0;e<n.completeHandlers.length;e++)n.completeHandlers[e]()}),n.completeHandlers.push(r))}}(C);0===e._completeListeners&&e.complete()}}}},{key:"visibilityChangedHandler",value:function(){var e=this;e.isReady&&requestAnimationFrame(function(){!e.isHidden&&0===e.offsetWidth||0===e.offsetHeight?e.isHidden=!0:e.isHidden&&(e.isHidden=!1,e.$.fireEvent("resize",e,{bubbles:!1,cancelable:!0}))})}},{key:"attributeChangedCallback",value:function(e,t,n){var r=this,i=r.propertyByAttributeName[e];if("class"!==e&&"style"!==e||r.visibilityChangedHandler(),i||r.attributeChanged(e,t,n),!(!i||i&&i.isUpdating)){var a=r.$.getAttributeValue(i.attributeName,i.type);void 0!==n&&r[i.name]!==a&&(i.isUpdatingFromAttribute=!0,r[i.name]=void 0!==a?a:r._properties[i.name].defaultValue,i.isUpdatingFromAttribute=!1)}}},{key:"attributeChanged",value:function(e,t,n){}},{key:"attached",value:function(){var e=this;e.hasStyleObserver&&v.watch(e),e.onAttached&&e.onAttached(),JQX(e._selector)&&JQX(e._selector).attached&&JQX(e._selector).attached()}},{key:"detached",value:function(){var e=this;e.hasStyleObserver&&v.unwatch(e),e._setModuleState("detached"),e.isAttached=!1,e.ownerElement&&-1===e.ownerElement.detachedChildren.indexOf(e)&&e.ownerElement.detachedChildren.push(e),e._handleListeners("unlisten"),e.onDetached&&e.onDetached(),JQX(e._selector)&&JQX(e._selector).detached&&JQX(e._selector).detached()}},{key:"propertyChangedHandler",value:function(e,t,n){var r=this;t!==n&&("theme"===e&&(""!==t&&r.classList.remove("jqx-"+t),""!==n&&r.classList.add("jqx-"+n)),"visibility"===e&&("collapsed"===t?r.classList.remove("jqx-hidden"):"hidden"===t&&r.classList.remove("jqx-visibility-hidden"),"collapsed"===n?r.classList.add("jqx-hidden"):"hidden"===n&&r.classList.add("jqx-visibility-hidden")),r.propertyChanged&&r.propertyChanged(e,t,n))}},{key:"_handleListeners",value:function(e){var t=this,n=t.tagName.toLowerCase(),r=t.getStaticMember("listeners"),i=function(r){for(var i in r){(function(i){var a=i.split("."),o=a[0],l=t.$;if(a[1])if(o=a[1],l=t["$"+a[0]],"document"===a[0]){var s=t.jqxId;""===s&&(s=x.Core.toCamelCase(n)),o=o+"."+s}else t.jqxId&&(o=o+"."+t.jqxId+"_"+t.parents.length);else t.jqxId&&(o=o+"."+t.jqxId);var u=r[i],d=function(e){var n=t.context;t.context=t,t[u]&&t[u].apply(t,[e]),t.context=n};if(!l)return"continue";l[e](o,d)})(i)}};i(r),i(t.templateListeners),JQX(t._selector)&&JQX(t._selector).properties&&i(JQX(t._selector).listeners)}},{key:"parseTemplate",value:function(){var e=this,t=e.template(),r=document.createDocumentFragment();if(n[e.nodeName])return n[e.nodeName].cloneNode(!0);if(""===t)return null;var i=document.createElement("div");r.appendChild(i),i.innerHTML=t;var a=i.childNodes;i.parentNode.removeChild(i);for(var o=0;o<a.length;o++)r.appendChild(a[o]);return n[e.nodeName]=r,r.cloneNode(!0)}},{key:"applyTemplate",value:function(){var e=this,t=e.parseTemplate();if(t&&t.hasChildNodes){var n=t.childNodes[0],r=function(t,n){e["$"+t]=n.$=x.Extend(n),e.$[t]=n,n.ownerElement=e},i=n;if(n.getElementsByTagName("content").length>0){var a=n.getElementsByTagName("content")[0];i=a.parentNode,i.removeChild(a)}else{var o=t.querySelectorAll("[inner-h-t-m-l]");o&&o.length>0&&(i=o[0])}e.$.template="template"===n.nodeName.toLowerCase()?n:n.querySelector("template");var l=t.querySelectorAll("[id]");0===l.length&&(l=t.querySelectorAll("*")),r("root",n),r("content",i),e.$.html=e.innerHTML.toString().trim();for(var s=0;s<l.length;s+=1){var u=l[s];""===u.id&&(u.id="child"+s),r(u.id,u),u.setAttribute("jqx-id",u.id),e.shadowRoot||u.removeAttribute("id")}for(!1!==e.hasTemplateBindings?e.bindings=e.getBindings(t):e.bindings=[],e.$root.addClass("jqx-container");e.childNodes.length;)i.appendChild(e.firstChild);if(e.appendTemplate(t),e.$.template){var d=document.createElement("div");d.classList.add("jqx-template-container"),e.$.templateContainer=d,e.$.template.parentNode.insertBefore(d,e.$.template),e.refreshTemplate()}}}},{key:"refreshTemplate",value:function(){var e=this;if(e.$.templateContainer){e.templateDetached(e.$.templateContainer);var t=e.$.template.content.cloneNode(!0);e.templateBindings=e.getBindings(t),e.templateProperties=[];var n=document.createDocumentFragment();!function t(n,r,i){for(var a in n){var o=n[a],l=o.node.cloneNode();r.appendChild(l);var s=[],u=!1;if(o.data)for(var d in o.data){var c=o.data[d],p=c.name;if(e.templateProperties[p]=!0,l.removeAttribute(x.Core.toDash(d)),"*items"===d)s=e[p],u=!0;else if(p.indexOf("item.")>=0&&i)c.value=i[p.substring("item.".length)],l[d]=c.value;else if(p.indexOf("item")>=0&&i)c.value=i,l[d]=c.value;else if("*if"===d)if(p.indexOf("(")>=0){var v=p.substring(p.indexOf("(")),f=void 0,h=p.substring(0,p.indexOf("("));if(v=v.substring(1,v.length-1),v=v.replace(/ /gi,""),v=v.split(","),v.length>0&&""!==v[0]){for(var m=[],y=0;y<v.length;y++)m.push(e[v[y]]);f=e[h].apply(e,m)}else f=e[h]();!1===f&&r.removeChild(l)}else e[p]||r.removeChild(l);else e.updateBoundNode(l,o,e,p)}if(s.length>0||u)for(var g=0;g<s.length;g++)o.children&&t(o.children,l,s[g]);else o.children&&t(o.children,l,i)}}(e.templateBindings.children,n),e.$.templateContainer.innerHTML="",e.$.templateContainer.appendChild(n),e.templateAttached(e.$.templateContainer)}}},{key:"templateAttached",value:function(){}},{key:"templateDetached",value:function(){}},{key:"appendTemplate",value:function(e){this.appendChild(e)}},{key:"defineElementModules",value:function(){var e=this,t=e.constructor.prototype;if("BaseElement"===t.elementName){t.modules=e.constructor.modules;for(var n=t.modules,r=0;r<n.length;r+=1)e.addModule(n[r])}else for(var i=t.modules,a=0;a<i.length;a+=1){var o=i[a],l=o.prototype;e.defineElementMethods(l.methodNames,l),e.defineElementProperties(o.properties)}}},{key:"watch",value:function(e,t){var n=this;if(null===e||null===t)return void(n._watch=null);n._watch={properties:e,propertyChangedCallback:t}}},{key:"unwatch",value:function(){this._watch=null}},{key:"set",value:function(e,t,n){var r=this,i=r.context;r.context=!0===n?document:r,r[e]=t,r.context=i}},{key:"get",value:function(e){return this[e]}},{key:"_setModuleState",value:function(e,t){for(var n=this,r="is"+e.substring(0,1).toUpperCase()+e.substring(1),i="on"+e.substring(0,1).toUpperCase()+e.substring(1),a=0;a<n.modulesList.length;a++){var o=n.modulesList[a];o[r]=!0,o[e]&&o[e](t),o[i]&&o[i](t)}}},{key:"addModule",value:function(e,t){var n=this;if(e){var r=n.modules.slice(0),i=e.prototype,a=Object.getPrototypeOf(e);a.name&&a.name!==e.name&&n.addModule(a),!e.moduleName&&e.name&&(e.moduleName=e.name),-1===r.findIndex(function(t){return e.moduleName===t.moduleName})&&r.push(e),n.defineModule(e),n.defineElementMethods(i.methodNames,i),n.defineElementProperties(e.properties);if(n.constructor.prototype.modules=r,t)for(var o in JQX.Elements.tagNames){for(var l=JQX.Elements.tagNames[o],s=Object.getPrototypeOf(l),u=[];s!==HTMLElement;)u.push(s.prototype),s=Object.getPrototypeOf(s);u.indexOf(n)>=0&&l!==n&&l.prototype.addModule(e)}}}},{key:"defineModule",value:function(e){if(!e.isDefined){e.prototype._initModule=function(e){this.ownerElement=e};var t=e.properties||{},n=Object.keys(t),r=Object.getOwnPropertyNames(e.prototype);e.prototype.methodNames=r;for(var i=0;i<n.length;i+=1)!function(r){var i=n[r],a=t[i];Object.defineProperty(e.prototype,i,{configurable:!1,enumerable:!0,get:function(){var e=this;return e.ownerElement?e.ownerElement[i]:a.value},set:function(e){this.ownerElement[i]=e}})}(i);e.isDefined=!0}}},{key:"getStaticMember",value:function(e,t){var n=this,i=window[r][n.elementName],a=i[e];t||(t="");for(var o="array"===t?[]:"string"===t?"":{},l=Object.getPrototypeOf(i),s=[];l[e];)s.push(l[e]),l=Object.getPrototypeOf(l);for(var u=s.length-1;u>=0;u--)if("array"===t)for(var d=0;d<s[u].length;d++)-1===o.indexOf(s[u][d])&&o.push(s[u][d]);else"string"===t?-1===o.indexOf(s[u])&&(o+=s[u]):o=x.Core.assign(o,s[u]);if("array"===t){for(var c=0;c<a.length;c++)-1===o.indexOf(a[c])&&o.push(a[c]);return o}return"string"===t?(-1===o.indexOf(a)&&(o+=a),o):x.Core.assign(o,a)}},{key:"defineElementHierarchicalProperties",value:function(e,t){var n=this,r=[];!function(e){for(var n=Object.keys(e),i=0;i<n.length;i++){var a=n[i];if("messages"!==a){var o=e[a],l=Object.keys(o),s=l.indexOf("value")>=0&&l.indexOf("type")>=0&&"object"===babelHelpers.typeof(o.value);("propertyObject"===o.type||s)&&function(){!function e(n,i){if(n.value){var a=Object.keys(n.value);e:for(var o=0;o<a.length;o++){var l=function(o){var l=a[o],s=n.value[l],u=i+"_"+l;if("object"!==(void 0===s?"undefined":babelHelpers.typeof(s))||null===s)return"break";var d=Object.keys(s);if(!(d.indexOf("value")>=0&&d.indexOf("type")>=0))return"break";if(s.parentPropertyName=i,t){var c=t._properties[u];if(n.value.hasOwnProperty(l)){if(c.isDefined)return"continue";delete n.value[l]}c.isDefined=!0,Object.defineProperty(n.value,l,{configurable:!1,enumerable:!0,get:function(){return t._properties[u].value},set:function(e){t.updateProperty(t,t._properties[u],e)}})}r[u]||(r[u]=s,r.length++),("propertyObject"===s.type||"object"===babelHelpers.typeof(s.value)&&"array"!==s.type)&&(t?e(t._properties[u],u):e(s,u))}(o);switch(l){case"break":break e;case"continue":continue}}}}(o,a)}()}}}(e),r.length>0&&!t&&n.defineElementProperties(r)}},{key:"defineElement",value:function(){var e=this,t=e.constructor.prototype,n=e.getStaticMember("properties"),r=Object.getOwnPropertyNames(t);t.extendedProperties={},t.boundProperties={},t.templateListeners={},e.defineElementModules(),e.defineElementMethods(r,t),e.defineElementProperties(n),e.defineElementHierarchicalProperties(e.extendedProperties),t._initElement=function(){var e=this,n=t.extendedProperties,r=Object.keys(n),i=e.modules;e.$=x.Extend(e),e.$document=_,e.jqxId=(Date.now().toString(36)+Math.random().toString(36).substr(2,5)).toUpperCase(),e.isCreated||(e.modulesList=[],e._properties=[],e._beforeCreatedProperties&&(e._properties=e._beforeCreatedProperties,delete e._beforeCreatedProperties),e.detachedChildren=[],e.propertyByAttributeName=[]);for(var a=0;a<i.length;a+=1){var o=i[a],l=new o;l._initModule(e),e.modulesList.push(l)}for(var s=0;s<r.length;s+=1){(function(t){var i=r[t],a=n[i],o=a.value;if(e._properties[i]){if(void 0!==e._properties[i].notify)return"continue";delete e._properties[i]}if(S&&"innerHTML"===i&&delete e[i],-1===window.navigator.userAgent.indexOf("PhantomJS")&&e.hasOwnProperty(i)&&(o=e[i],delete e[i]),"array"===a.type&&void 0!==o&&null!==o&&(o=o.slice(0)),"object"===a.type&&void 0!==o&&null!==o&&(o=Array.isArray(o)?o.slice(0):Object.assign({},o)),e._properties[i]={name:i,notify:a.notify,allowedValues:a.allowedValues,type:a.type,nullable:a.nullable,reflectToAttribute:a.reflectToAttribute,defaultReflectToAttribute:a.defaultReflectToAttribute,defaultReflectToAttributeConditions:a.defaultReflectToAttributeConditions,value:o,readOnly:a.readOnly,defaultValue:o,attributeName:a.attributeName,observer:a.observer,inherit:a.inherit,extend:a.extend,validator:a.validator},e.propertyByAttributeName[a.attributeName]=e._properties[i],!a.hasOwnProperty("type")){var l=e.localize("propertyUnknownType",{name:i});e.log(l)}if("any"===a.type||"propertyObject"===a.type)return"continue";var s=x.Types.getType(o);if(void 0!==o&&null!==o&&a.type!==s&&!a.validator){if("object"===a.type&&"array"===s)return"continue";if("number"===s){if(["integer","int","float"].findIndex(function(e){return e===a.type})>=0)return"continue"}var u=e.localize("propertyInvalidValueType",{name:i,actualType:s,type:a.type});e.log(u)}})(s)}
e.defineElementHierarchicalProperties(e._properties,e),e.isCreated=!0},t.registered()}},{key:"defineElementMethods",value:function(e,t){var n=this,r=n.constructor.prototype,i=function(e,t){var n=Array.prototype.slice.call(arguments,2);return function(){if(!this.isReady&&"localize"!==t&&"importStyle"!==t&&"log"!==t&&"parseAttributes"!==t){var r=this.localize("elementNotInDOM");this.log(r)}for(var i=this,a=0;a<this.modulesList.length;a++){var o=this.modulesList[a];if(t in o){i=o;break}}var l=this.context,s=n.concat(Array.prototype.slice.call(arguments)),u=null,d=function(e,t){return e===t||("number"===e&&("int"===t||"integer"===t||"float"===t)||("bool"===e&&"boolean"===t||"boolean"===e&&"bool"===t||("object"===e&&"any"===t||void 0)))};if(this.methods){var c=this.methods[t];if(c){var p=c.split(":");u=p[p.length-1].trim();for(var v=c.substring(1+c.indexOf("("),c.lastIndexOf(")")),f=[],h=v.split(","),m="",y=0;y<h.length;y++){var g=h[y];m+=g,g.indexOf(":")>=0?(f.push(m),m=""):m+=","}for(var b=f.length,w=0;w<f.length;w++){var _=f[w].trim(),C=_.split(":"),k=C[0].split("=")[0].trim(),E=k.indexOf("?")>=0,j=C[1].indexOf("?")>=0,S=C[1].replace(/\?/gi,"").trim(),q=S.split("|"),A=C[0].split("=")[1],B=x.Types.getType(s[w]);if(void 0===s[w]&&A){switch(A=A.trim(),S[0]){case"date":var O=A.substring(A.indexOf("(")+1,A.lastIndexOf(")"));O=O.length>0?O.split(",").map(function(e){return parseInt(e)}):[],A=0===O.length?new Date:new Date(O[0],O[1],O[2]);break;case"bool":case"boolean":A="true"===A||"1"===A;break;case"int":case"integer":A=parseInt(A);break;case"float":case"number":A=parseFloat(A);break;case"any":case"object":A=A.indexOf("{")>=0?JSON.parse(A):A}s.push(A)}else E&&b--;if(S!==B&&B){for(var D=!0,P=0;P<q.length;P++)if(d(B,q[P])){D=!1;break}if(D&&(null!==s[w]||!j)){var H=this.localize("methodInvalidValueType",{name:t,actualType:B,type:S,argumentIndex:w});this.log(H)}}if(s.length<b){var T=this.localize("methodInvalidArgumentsCount",{name:t,actualArgumentsCount:s.length,argumentsCount:b});this.log(T)}}}}this.context=this;var N=e.apply(i,s);if(u){var V=void 0===x.Types.getType(N)?"void":x.Types.getType(N);if(!d(V,u)){var L=this.localize("methodInvalidReturnType",{name:t,actualType:V,type:u});this.log(L)}}return this.context=l,N}},a=["constructor","ready","created","attached","detached","appendChild","insertBefore","removeChild","connect","disconnectedCallback","connectedCallback","attributeChangedCallback","propertyChangedHandler"];for(var o in e){(function(n){var o=e[n];o.startsWith("_")||void 0!==a.find(function(e){return e===o})||(r.extendedProperties[o]||x.Types.isFunction(t[o])&&(r[o]=i(t[o],o)))})(o)}}},{key:"defineElementProperties",value:function(e){if(e){var t=this,n=t.constructor.prototype,r=Object.keys(e),i=t.getStaticMember("properties");Object.assign(n.extendedProperties,e),t.updateProperty=function(e,t,n){var r=e;if(t&&!t.readOnly){if(t.allowedValues){for(var i=!1,a=0;a<t.allowedValues.length;a++)if(t.allowedValues[a]===n){i=!0;break}if(!i){var o=JSON.stringify(t.allowedValues).replace(/\[|\]/gi,"").replace(",",", ").replace(/"/gi,"'"),l="'"+n+"'",s=r.localize("propertyInvalidValue",{name:t.name,actualValue:l,value:o});return void r.log(s)}}var u=t.name,d=r._properties[u].value;if(t.validator&&r[t.validator]){var c=r.context;r.context=r;var p=r[t.validator](d,n);void 0!==p&&(n=p),r.context=c}if(d!==n){if(r.propertyChanging){var v=r.propertyChanging(u,d,n);if(!1===v||null===v)return}if(!t.hasOwnProperty("type")){var f=r.localize("propertyUnknownType",{name:u});r.log(f)}if("array"!==t.type||JSON.stringify(d)!==JSON.stringify(n)){if(void 0!==n&&null!==n&&"any"!==t.type&&"propertyObject"!==t.type&&t.type!==x.Types.getType(n)&&!t.validator||null===n&&!t.nullable){var h=!0;if("object"===t.type&&"array"===x.Types.getType(n)&&(h=!1),"number"===x.Types.getType(n)){["integer","int","float"].findIndex(function(e){return e===t.type})>=0&&(h=!1)}if(h){var m=r.localize("propertyInvalidValueType",{name:u,actualType:x.Types.getType(n),type:t.type});return void r.error(m)}}t.isUpdating=!0,r._properties[u].value=n,!t.isUpdatingFromAttribute&&t.reflectToAttribute&&r.$.setAttributeValue(t.attributeName,n,t.type);if(r.isReady&&(!r.ownerElement||r.ownerElement&&r.ownerElement.isReady)){if("wait"===u&&(n||!d||r.isCompleted||(r.classList.remove("jqx-visibility-hidden"),r.ownerElement&&r.ownerElement.updateBoundMappedNodes(),r.updateBoundMappedNodes(),r.complete())),r.context!==r&&!r.wait){var y=r.context;r.context=r,r.propertyChangedHandler(u,d,n),r.context=y,t.observer&&r[t.observer]&&(r.context=r,r[t.observer](d,n),r.context=document),r._watch&&r._watch.properties.indexOf(u)>=0&&r._watch.propertyChangedCallback(u,d,n)}var g=t.notify||r.boundProperties[u];g&&(r.$.fireEvent(t.attributeName+"-changed",{context:r.context,oldValue:d,value:r[u]}),r.boundProperties[u]&&r.updateBoundNodes(u)),g&&r.templateProperties&&r.templateProperties[u]&&r.refreshTemplate(),r.dataContextProperties&&("dataContext"===u?r.applyDataContext():r.dataContextProperties[u]&&r.updateDataContextProperty(u))}t.isUpdating=!1}}}};for(var a=0;a<r.length;a+=1){(function(t){var a=r[t],o=e[a],l=x.Core.toDash(a),s=o.type||"any",u=s.indexOf("?")>=0||"any"===s;if(u&&"any"!==s&&(o.type=s.substring(0,s.length-1)),o.nullable=u,o.attributeName=l.toLowerCase(),o.name=a,o.reflectToAttribute=void 0===o.reflectToAttribute||o.reflectToAttribute,o.inherit&&i[a]&&(o.value=i[a].value),o.extend&&i[a]&&x.Core.assign(o.value,i[a].value),n.hasOwnProperty(a))return"continue";Object.defineProperty(n,a,{configurable:!1,enumerable:!0,get:function(){var e=this;if(e._properties[a])return e._properties[a].value},set:function(e){var t=this;t.updateProperty(t,t._properties[a],e)}})})(a)}}}},{key:"classNamesMap",get:function(){return{animation:"jqx-animate",rippleAnimation:"jqx-ripple"}}},{key:"hasAnimation",get:function(){return"none"!==this.animation}},{key:"hasRippleAnimation",get:function(){var e=this;return"none"!==e.animation&&"advanced"===e.animation}},{key:"properties",get:function(){var e=this;return e._properties||(e._properties=[]),e._properties}},{key:"parents",get:function(){for(var e=this,t=[],n=e.parentNode;n&&9!==n.nodeType;)n instanceof HTMLElement==!0&&t.push(n),n=n.parentNode;return t}},{key:"focused",get:function(){return this.contains(document.activeElement)}},{key:"_selector",get:function(){var e=this;return e.id?"#"+e.id:e.classList.length>0?"."+e.classList[0]:void 0}},{key:"hasStyleObserver",set:function(e){var t=this;void 0===t._hasStyleObserver&&(t._hasStyleObserver=e),e?v.watch(t):v.unwatch(t)},get:function(){var e=this;return void 0===e._hasStyleObserver||e._hasStyleObserver}}],[{key:"properties",get:function(){return{animation:{value:"advanced",type:"string",allowedValues:["none","simple","advanced"]},unfocusable:{value:!1,type:"boolean"},disabled:{value:!1,type:"boolean"},dataContext:{value:null,reflectToAttribute:!1,type:"any"},messages:{value:{en:{propertyUnknownType:"'{{name}}' property is with undefined 'type' member!",propertyInvalidValue:"Invalid '{{name}}' property value! Actual value: '{{actualValue}}', Expected value: '{{value}}'!",propertyInvalidValueType:"Invalid '{{name}}' property value type! Actual type: '{{actualType}}', Expected type: '{{type}}'!",methodInvalidValueType:"Invalid '{{name}}' method argument value type! Actual type: '{{actualType}}', Expected type: '{{type}}' for argument with index: '{{argumentIndex}}'!",methodInvalidArgumentsCount:"Invalid '{{name}}' method arguments count! Actual arguments count: '{{actualArgumentsCount}}', Expected at least: '{{argumentsCount}}' argument(s)!",methodInvalidReturnType:"Invalid '{{name}}' method return type! Actual type: '{{actualType}}', Expected type: '{{type}}'!",elementNotInDOM:"Element does not exist in DOM! Please, add the element to the DOM, before invoking a method.",moduleUndefined:"Module is undefined.",missingReference:"{{elementType}}: Missing reference to '{{files}}'.",htmlTemplateNotSuported:"{{elementType}}: Web Browser doesn't support HTMLTemplate elements.",invalidTemplate:"{{elementType}}: '{{property}}' property accepts a string that must match the id of an HTMLTemplate element from the DOM."}},reflectToAttribute:!1,type:"object"},readonly:{value:!1,type:"boolean"},rightToLeft:{value:!1,type:"boolean"},theme:{value:window[r].Theme,type:"string"},visibility:{value:"visible",allowedValues:["visible","collapsed","hidden"],type:"string"},wait:{value:!1,type:"boolean"}}}},{key:"requires",get:function(){return{}}},{key:"listeners",get:function(){return{"theme-changed":function(e){this.theme=e.detail.newValue}}}},{key:"methods",get:function(){return{}}},{key:"modules",get:function(){return window[r].Modules}},{key:"version",get:function(){return window[r].Version}}]),t}(HTMLElement),k=[],E=[],j=[],S=!1,q=navigator.userAgent.match(/Chrom(e|ium)\/([0-9]+)\./);if(q){parseInt(q[2],10)<=50&&(S=!0)}var A=function e(){if("complete"===document.readyState){j.sort(function(e,t){var n=e.element.parents.length,r=t.element.parents.length;return n<r?-1:n>r?1:0});for(var t=0;t<j.length;t++)j[t].element.isLoading=!1,j[t].callback();j=[],document.removeEventListener("readystatechange",e)}};document.addEventListener("readystatechange",A);var B=function(e){function t(e,n){babelHelpers.classCallCheck(this,t);var i=babelHelpers.possibleConstructorReturn(this,(t.__proto__||Object.getPrototypeOf(t)).call(this)),a=i;if(e){var o;n&&(a._initProperties=n);var l=function(e){if("string"==typeof e?document.querySelector(e):e){var t="string"==typeof e?document.querySelector(e):e;if(t instanceof HTMLDivElement){var r=document.createElement(a.tagName),i=!0,o=!1,l=void 0;try{for(var s,u=t.attributes[Symbol.iterator]();!(i=(s=u.next()).done);i=!0){var d=s.value;r.setAttribute(d.name,t.getAttribute(d.name))}}catch(e){o=!0,l=e}finally{try{!i&&u.return&&u.return()}finally{if(o)throw l}}for(;t.childNodes.length;)r.appendChild(t.firstChild);return"string"==typeof e&&(r.id=e.substring(1)),r._initProperties=n,t.parentNode&&t.parentNode.replaceChild(r,t),r}if(n){var c=t.context;if(t._initProperties=n,t.isReady){t.context=t;var p={},v={};for(var f in n)p[f]=t[f],v[f]=n[f];Object.getOwnPropertyNames(n).length>0&&(t.initProperties(),t.propertyChangedHandler(n,p,v)),t.context=c}}return t}};if("string"==typeof e){var s=document.querySelectorAll(e),u=[];if(s.length>1){for(var d,c=0;c<s.length;c++){var p=l(s[c]);u.push(p)}return d=u,babelHelpers.possibleConstructorReturn(i,d)}}else if(e&&e.length>0){var v=e;if(v.length>1){for(var f,h=0;h<v.length;h++){var m=l(v[h]);k.push(m)}return f=k,babelHelpers.possibleConstructorReturn(i,f)}}return o=l(e),babelHelpers.possibleConstructorReturn(i,o)}return a._styleUrl="",window[r].EnableShadowDOM&&a.enableShadowDOM&&a.attachShadow({mode:"open"}),a.isUtilityElement?babelHelpers.possibleConstructorReturn(i):(a.created(),i)}return babelHelpers.inherits(t,e),babelHelpers.createClass(t,[{key:"importStyle",value:function(e,t){var n=this;if(n.shadowRoot&&e){for(var r=n.shadowRoot.children,i=0;i<r.length;i++){var a=r[i];if(a instanceof HTMLLinkElement&&a.href===e)return}var o=document.createElement("link");o.rel="stylesheet",o.type="text/css",o.href=e,o.onload=t,n.shadowRoot.insertBefore(o,n.shadowRoot.firstChild)}}},{key:"attributeChanged",value:function(e,t,n){"style-url"===e&&(this.styleUrl=n)}},{key:"attributeChangedCallback",value:function(e,n,r){this.isReady&&babelHelpers.get(t.prototype.__proto__||Object.getPrototypeOf(t.prototype),"attributeChangedCallback",this).call(this,e,n,r)}},{key:"styleUrl",get:function(){return this._styleUrl},set:function(e){this._styleUrl=e}},{key:"enableShadowDOM",get:function(){return window[r].EnableShadowDOM}}],[{key:"observedAttributes",get:function(){var e=this,t=["external-style"];for(var n in e.prototype.extendedProperties){var r=e.prototype.extendedProperties[n];t.push(r.attributeName)}return t}},{key:"styleUrls",get:function(){return["jqx.variables.css","jqx.misc.css","jqx.common.css"]}},{key:"styles",get:function(){return""}}]),babelHelpers.createClass(t,[{key:"connect",value:function(){var e=this,t=e.isReady,n=void 0;t||e.children.length>0&&e.children[0]instanceof HTMLStyleElement&&(n=e.children[0],e.removeChild(n)),(!e.shadowRoot||t&&e.shadowRoot)&&e.setup(),!t&&e.shadowRoot&&function(){e.wait=!1,e.removeAttribute("wait"),n&&e.shadowRoot.insertBefore(n,e.shadowRoot.firstChild),e.importStyle(e._styleUrl);var t=e.getStaticMember("styleUrls","array"),i=e.getStaticMember("styles","string"),a=0;e.classList.add("jqx-element-init");for(var o=0;o<t.length;o++)e.importStyle(x.Core.getScriptLocation()+window[r].StyleBaseUrl+t[o],function(){++a===t.length&&(e.whenReady(function(){e.classList.remove("jqx-element-init")}),e.setup())});if(i){var l=document.createElement("style");l.innerHTML=i,e.shadowRoot.insertBefore(l,e.shadowRoot.firstChild)}}()}},{key:"connectedCallback",value:function(){var e=this;if(!e.isLoading&&!e.isUtilityElement){e.classList.add("jqx-element-init");var t=function(){e.classList.remove("jqx-element-init")};"complete"===document.readyState?(t(),e.connect()):(e.isLoading=!0,j.push({element:this,callback:function(){this.isReady||(t(),this.connect())}.bind(e)}))}}},{key:"disconnectedCallback",value:function(){var e=this;e.isAttached&&e.detached()}},{key:"adoptedCallback",value:function(){this.setup()}},{key:"appendTemplate",value:function(e){var t=this;t.shadowRoot?t.shadowRoot.appendChild(e):t.appendChild(e)}}]),t}(C),O={"jqx-accordion":["jqx-accordion-item"],"jqx-breadcrumb":[],"jqx-button":[],"jqx-toggle-button":["jqx-button"],"jqx-repeat-button":["jqx-button"],"jqx-calendar":["jqx-repeat-button","jqx-drop-down-list","jqx-tooltip"],"jqx-card":[],"jqx-carousel":["jqx-button"],"jqx-chart":[],"jqx-check-box":["jqx-toggle-button"],"jqx-chip":[],"jqx-color-panel":["jqx-button"],"jqx-color-picker":["jqx-drop-down-button"],"jqx-combo-box":["jqx-drop-down-list"],"jqx-date-time-picker":["jqx-calendar","jqx-time-picker"],"jqx-docking-layout":["jqx-splitter","jqx-window","jqx-tabs"],"jqx-drop-down-button":["jqx-button"],"jqx-drop-down-list":["jqx-list-box"],"jqx-file-upload":["jqx-button"],"jqx-filter-panel":["jqx-list-box","jqx-numeric-text-box","jqx-menu","jqx-tree","jqx-drop-down-list","jqx-date-time-picker","jqx-calendar","jqx-tooltip"],"jqx-gauge":["jqx-button","jqx-tank"],"jqx-grid":["jqx-grid-cell","jqx-grid-column","jqx-grid-row","jqx-input","jqx-menu","jqx-filter-panel","jqx-pager","jqx-date-time-picker"],"jqx-grid-cell":["jqx-grid"],"jqx-grid-column":["jqx-grid"],"jqx-grid-row":["jqx-grid"],"jqx-input":["jqx-scroll-bar"],"jqx-led":["jqx-button"],"jqx-list-box":["jqx-scroll-viewer","jqx-list-item","jqx-list-items-group"],"jqx-list-item":["jqx-list-box"],"jqx-list-items-group":["jqx-list-box"],"jqx-list-menu":["jqx-menu","jqx-list-menu-item","jqx-list-menu-items-group"],"jqx-list-menu-item":["jqx-list-menu"],"jqx-list-menu-items-group":["jqx-list-menu"],"jqx-masked-text-box":["jqx-text-box"],"jqx-menu":["jqx-scroll-viewer","jqx-menu-item"],"jqx-multiline-text-box":["jqx-text-box"],"jqx-multiline-split-button":["jqx-drop-down-button"],"jqx-numeric-text-box":["jqx-button"],"jqx-pager":["jqx-drop-down-list"],"jqx-password-text-box":["jqx-text-box"],"jqx-power-button":["jqx-button"],"jqx-progress-bar":["jqx-button"],"jqx-radio-button":["jqx-button","jqx-toggle-button"],"jqx-scroll-bar":[],"jqx-slider":["jqx-button","jqx-repeat-button","jqx-tank"],"jqx-sortable":["jqx-button"],"jqx-splitter":[],"jqx-sort-panel":["jqx-input","jqx-sortable"],"jqx-switch-button":["jqx-toggle-button"],"jqx-scroll-viewer":["jqx-button","jqx-scroll-bar"],"jqx-table":[],"jqx-tabs":["jqx-repeat-button","jqx-tab-item","jqx-tab-items-group"],"jqx-tab-item":["jqx-tabs"],"jqx-tab-items-group":["jqx-tabs"],"jqx-tank":["jqx-button"],"jqx-text-box":["jqx-drop-down-list"],"jqx-time-picker":[],"jqx-toast":[],"jqx-tooltip":[],"jqx-tree":["jqx-menu","jqx-tree-item","jqx-tree-items-group"],"jqx-tree-item":["jqx-tree"],"jqx-tree-items-group":["jqx-tree"],"jqx-window":["jqx-button"]},D=function(){function e(){babelHelpers.classCallCheck(this,e)}return babelHelpers.createClass(e,null,[{key:"register",value:function(e,t){var n=t.prototype,i=c.toCamelCase(e).replace(/[a-z]+/,""),a=t.version||window[r].Version;if(!window.customElements.get(e)||window.customElements.get(e).version!==a){if(window[r].Define&&-1===window[r].Define.indexOf(e)&&"jqx-base-element"!==e&&"jqx-content-element"!==e&&"jqx-scroll-viewer"!==e){if(window[r].Defined)return;for(var o=window[r].Define,l=o.slice(0),s=0;s<o.length;s++)for(var u=function e(t,n){var r=O[t];if(n||(n=[]),r)for(var i=0;i<r.length;i++){var a=r[i];-1===n.indexOf(a)&&(n.push(a),n=e(a,n))}return n}(o[s]),d=0;d<u.length;d++)-1===l.indexOf(u[d])&&l.push(u[d]);if(window[r].Define=l,window[r].Defined=!0,-1===window[r].Define.indexOf(e))return}var p=e;for(a=a.split(".");window.customElements.get(e);)e=p+"-"+a.join("."),a[2]=parseInt(a[2])+1;k[e]||(k[e]=window[r][i]=window[r.toLowerCase()+i]=t,n.elementName=i,n.defineElement(),E[e]&&E[e](n),window.customElements.define(e,t))}}},{key:"registerElements",value:function(){var e=this;if(e.toRegister){e.isRegistering=!0;for(var t=0;t<e.toRegister.length;t++){var n=e.toRegister[t];e.register(n.tagName,n.element)}e.isRegistering=!1}}},{key:"get",value:function(e){if(k[e])return k[e]}},{key:"whenRegistered",value:function(e,t){if(!e)throw new Error("Syntax Error: Invalid tag name");var n=this,r=E[e],i=n.get(e),a=i?i.modules.length:3;try{r||i?!r&&i?(t(i.prototype),E[e]=void 0):r&&!i?E[e]=function(e){r(e),t(e)}:r&&i&&(i.proto&&(r(i.proto),t(i.proto)),E[e]=void 0):E[e]=function(e){try{t(e)}catch(e){var n=e instanceof Error?e.message:e.toString();console.log(n)}}}catch(e){var o=e instanceof Error?e.message:e.toString();console.log(o)}if(i&&a!==i.prototype.modules.length)for(var l=document.querySelectorAll(e),s=0;s<l.length;s++){var u=l[s];u.isCreated&&u._initElement()}}}]),e}();D.lazyRegister=!1,D.tagNames=[];var P=function(){function e(t,n){babelHelpers.classCallCheck(this,e);var r=this;this.name="observable",t&&Object.assign(r,t);return function(e){Object.getOwnPropertyNames(Object.getPrototypeOf(e)).forEach(function(t){return"constructor"===t||(!!t.startsWith("_")||void(r[t]=e[t]))})}(t),new Proxy(r,{deleteProperty:function(e,t){return delete e[t],!0},get:function(e,t){return e[t]},set:function(e,t,i){var a=e[t];return a===i||(e[t]=i,!("notifyFn"!==t&&!t.startsWith("_")&&"canNotify"!==t)||(!(!n||-1!==n.indexOf(t))||(!r.canNotify||(r._notify({target:e,propertyName:t,oldValue:a,newValue:i}),!0))))}})}return babelHelpers.createClass(e,[{key:"_notify",value:function(e){var t=this;if(t.canNotify&&t.notifyFn)for(var n=0;n<t.notifyFn.length;n++)t.notifyFn[n](e)}},{key:"notify",value:function(e){var t=this;e&&(t.notifyFn||(t.notifyFn=[]),t.notifyFn.push(e))}},{key:"canNotify",get:function(){var e=this;return void 0===e._canNotify&&(e._canNotify=!0),e._canNotify},set:function(e){this._canNotify=e}}]),e}(),H=function(){function e(){babelHelpers.classCallCheck(this,e);var t=this;t.name="observableArray",t.observables=arguments.length<3?null:arguments[2];var n=new Proxy(t,{deleteProperty:function(e,t){return delete e[t],!0},apply:function(e,t,n){return e.apply(t,n)},get:function(e,n){return e[n]||isNaN(parseInt(n))?e[n]:t.getItem(parseInt(n))},set:function(e,n,r){return e[n]||isNaN(parseInt(n))?(e[n]=r,!0):(t.setItem(parseInt(n),r),!0)}});if(t._addArgs={eventName:"change",object:n,action:"add",index:null,removed:new Array,addedCount:1},t._removeArgs={eventName:"change",object:n,action:"remove",index:null,removed:null,addedCount:0},arguments.length>=1&&Array.isArray(arguments[0])){t._array=[];for(var r=arguments[0],i=0,a=r.length;i<a;i++){var o=t._getItem(t._array.length,r[i]);t._array.push(o)}}else t._array=Array.apply(null,arguments);return 2===arguments.length&&(t.notifyFn=arguments[1]),n}return babelHelpers.createClass(e,[{key:"_notify",value:function(e){var t=this;t.canNotify&&t.notifyFn&&t.notifyFn(e)}},{key:"notify",value:function(e){var t=this;e&&(t.notifyFn=e)}},{key:"toArray",value:function(){return this._array}},{key:"_getItem",value:function(e,t){var n=this;return"string"==typeof t?t:"number"==typeof t?t:void 0===t?t:new Proxy(t,{deleteProperty:function(e,t){delete e[t]},set:function(t,r,i){var a=t[r];return t[r]=i,!n._canNotify||!1===t.canNotify||(!(!n.observables||n.observables[r])||(n._notify({eventName:"change",object:n,target:t,action:"update",index:e,path:e+"."+r,oldValue:a,newValue:i,propertyName:r}),!0))}})}},{key:"getItem",value:function(e){return this._array[e]}},{key:"setItem",value:function(e,t){var n=this,r=n._array[e];n._array[e]=n._getItem(e,t),n._notify({eventName:"change",object:this,action:"update",index:e,removed:[r],addedCount:1})}},{key:"toString",value:function(){return this._array.toString()}},{key:"toLocaleString",value:function(){return this._array.toLocaleString()}},{key:"concat",value:function(){var e=this;e._addArgs.index=e._array.length;var t=e._array.concat.apply(e._array,arguments);return new JQX.ObservableArray(t)}},{key:"join",value:function(e){return this._array.join(e)}},{key:"pop",value:function(){var e=this;e._removeArgs.index=e._array.length-1,delete e[e._array.length-1];var t=e._array.pop();return e._removeArgs.removed=[t],e._notify(e._removeArgs),e._notifyLengthChange(),t}},{key:"push",value:function(){var e=this;if(e._addArgs.index=e._array.length,1===arguments.length&&Array.isArray(arguments[0]))for(var t=arguments[0],n=0,r=t.length;n<r;n++){var i=e._getItem(e._array.length,t[n]);e._array.push(i)}else{var a=e._getItem(e._addArgs.index,arguments[0]);e._array.push.apply(e._array,[a])}return e._addArgs.addedCount=e._array.length-e._addArgs.index,e._notify(e._addArgs),e._notifyLengthChange(),e._array.length}},{key:"_notifyLengthChange",value:function(){var e=this;if(e.canNotify){var t=e._createPropertyChangeData("length",e._array.length);e._notify(t)}}},{key:"_createPropertyChangeData",value:function(e,t,n){return{eventName:"change",object:this,propertyName:e,value:t,oldValue:n}}},{key:"reverse",value:function(){return this._array.reverse()}},{key:"shift",value:function(){var e=this,t=e._array.shift();return e._removeArgs.index=0,e._removeArgs.removed=[t],e._notify(e._removeArgs),e._notifyLengthChange(),t}},{key:"slice",value:function(e,t){return this._array.slice(e,t)}},{key:"sort",value:function(e){return this._array.sort(e)}},{key:"splice",value:function(e,t,n){var r=this,i=r._array.length,a=r._array.splice.apply(r._array,arguments);return n?r._notify({eventName:"change",object:this,action:"add",index:e,added:a,addedCount:r._array.length>i?r._array.length-i:0}):r._notify({eventName:"change",object:this,action:"remove",index:e,removed:a,addedCount:r._array.length>i?r._array.length-i:0}),r._array.length!==i&&r._notifyLengthChange(),a}},{key:"unshift",value:function(){var e=this,t=e._array.length,n=e._array.unshift.apply(e._array,arguments);return e._addArgs.index=0,e._addArgs.addedCount=n-t,e._notify(this._addArgs),e._notifyLengthChange(),n}},{key:"indexOf",value:function(e,t){for(var n=this,r=t||0,i=r,a=n._array.length;i<a;i++)if(n._array[i]===e)return i;return-1}},{key:"lastIndexOf",value:function(e,t){for(var n=this,r=t||n._array.length-1,i=r;i>=0;i--)if(n._array[i]===e)return i;return-1}},{key:"find",value:function(e,t){return this._array.find(e,t)}},{key:"findIndex",value:function(e,t){return this._array.findIndex(e,t)}},{key:"every",value:function(e,t){return this._array.every(e,t)}},{key:"some",value:function(e,t){return this._array.some(e,t)}},{key:"forEach",value:function(e,t){this._array.forEach(e,t)}},{key:"map",value:function(e,t){return this._array.map(e,t)}},{key:"filter",value:function(e,t){return this._array.filter(e,t)}},{key:"reduce",value:function(e,t){var n=this;return void 0!==t?n._array.reduce(e,t):n._array.reduce(e)}},{key:"reduceRight",value:function(e,t){var n=this;return void 0!==t?n._array.reduceRight(e,t):n._array.reduceRight(e)}},{key:"canNotify",get:function(){var e=this;return void 0===e._canNotify&&(e._canNotify=!0),e._canNotify},set:function(e){this._canNotify=e}},{key:"length",get:function(){return this._array.length},set:function(e){var t=this;s.isNumber(e)&&t._array&&t._array.length!==e&&t.splice(e,t._array.length-e)}}]),e}(),T={};window[r]&&(T=window[r]),window[r]=function(e,n){var i=e;if(e)if(e.indexOf("#")>=0||e.indexOf(".")>=0){if(h[e])return h[e];if(n)return h[e]=new n,t(e,h[e]),h[e]}else if(n){if(D.tagNames[e]=n,D.lazyRegister){D.toRegister||(D.toRegister=[]);var a=c.toCamelCase(i).replace(/[a-z]+/,"");return window[r][a]=n,void D.toRegister.push({tagName:i,element:n})}D.register(i,n)}},window.addEventListener("load",function(){var e=window[r].Elements.tagNames,t=[];for(var n in e){for(var i=e[n],a=document.querySelectorAll("["+n+"]"),o=0;o<a.length;o++){var l=a[o];l instanceof HTMLDivElement&&(l.__proto__=i.prototype,l.created(),l.connectedCallback()),l.classList.add("jqx-element-ready")}var s=i.name;"Item"===s&&(s="ListItem"),a=document.querySelectorAll('[is="'+r.toLocaleLowerCase()+s+'"]');for(var u=0;u<a.length;u++)t.push(a[u])}if(t.length>0){var d=function(e){for(var t=[],n=e.parentNode;n&&9!==n.nodeType;)n instanceof HTMLElement==!0&&t.push(n),n=n.parentNode;return t};t.sort(function(e,t){var n=d(e).length,r=d(t).length;return n<r?1:n>r?-1:0});for(var c=0;c<t.length;c++){var p=t[c],v=p.getAttribute("is"),f=void 0;f="jqxItem"===v?new window.jqxListItem(p):new window[v](p),f.removeAttribute("is")}}});var N=function(){function e(t,n){babelHelpers.classCallCheck(this,e);var r=this,i=this.constructor.name,a=null;return t?a=new window[i](t,n):(a=new window[i],a._initProperties=n),r._element=a,a}return babelHelpers.createClass(e,[{key:"element",get:function(){return this._element}}]),e}(),V=function(){function e(t){babelHelpers.classCallCheck(this,e);var n=this;n._id=t.id,t.id?n._appRoot=document.getElementById(n._id):n._id=window[r].Utilities.Core.createGUID(),t.selector&&(n._id=window[r].Utilities.Core.createGUID(),n._appRoot=document.querySelector(t.selector)),n._appRoot||(n._appRoot=document.body),n._appRoot.classList.add("jqx-visibility-hidden");var i={};if(t.render){var a=t.render(),o=t.components;!function(){var e=document.createDocumentFragment(),n=document.implementation.createDocument("http://www.w3.org/1999/xhtml","html",null),l=document.createElementNS("http://www.w3.org/1999/xhtml","body"),s=document.createElement("div");n.documentElement.appendChild(l),l.appendChild(s),s.innerHTML=a;for(var u=0;u<o.length;u++){var d=o[u],c=d.name,p=x.Core.toDash(c),v=n.querySelectorAll(c);d.tagName=p;for(var f=0;f<v.length;f++){var h=v[f],m=h.getAttribute("id")||window[r].Utilities.Core.createGUID(),y=document.createElement("div");y.id=m,s.insertBefore(y,h),i["#"+m]={name:c,properties:[],rendered:!1},h.parentNode.removeChild(h)}}e.appendChild(s);var g=document.querySelector(t.selector);g&&g.appendChild(e)}()}n._template=t.template||{},n._data=t.data||{},n._components=i;var l=function(){n._addAttributeBindings(),n._renderForBindings(),n._addModelBindings(),n._observeData(),n.render(),n._appRoot.classList.remove("jqx-visibility-hidden")};"complete"===document.readyState?l():window.addEventListener("load",l)}return babelHelpers.createClass(e,[{key:"_addAttributeBindings",value:function(e,t){var n=this,r=new l,i=e?r.getBindings(e):r.getBindings(n._appRoot);t||(t="");var a=function(){return Math.floor(65536*(1+Math.random())).toString(16).substring(1)};!function e(r){var i=function(e){if(e.data){var r=e.node.id;r||(e.node.id=r="id"+a());for(var i in e.data){var o=e.data[i];if("textContent"===i&&(e.node.parentNode.id?r=e.node.parentNode.id:(e.node.id="",e.node.parentNode.id=r)),o.isEvent){var l={};l[o.name]=o.value,n._addListenerBinding(r,l)}else{var s={};s[i]=t+o.name,n._addTemplateBinding(r,s)}}}};i(r);for(var o in r.children){var l=r.children[o];l.node&&l.node.getAttribute&&l.node.getAttribute("jqx-for")&&null===l.node.getAttribute("jqx-for-rendered")||(i(l),l.children&&e(l))}}(i)}},{key:"_addTemplateBinding",value:function(e,t){var n=this;n.template["#"+e]?n.template["#"+e].bind?Object.assign(n.template["#"+e].bind,t):n.template["#"+e].bind=t:n.template["#"+e]={bind:t}}},{key:"_addListenerBinding",value:function(e,t){var n=this;n.template["#"+e]?n.template["#"+e].listeners?Object.assign(n.template["#"+e].listeners,t):n.template["#"+e].listeners=t:n.template["#"+e]={listeners:t}}},{key:"_updateDataFromBooleanElement",value:function(e,t){var n=this,r=t.checked,i=n.data[r];if(e.value&&"on"!==e.value)if(Array.isArray(i)||"observableArray"===i.name)if(e.checked)i.push(e.value);else{var a=i.indexOf(e.value);a>=0&&i.splice(a,1)}else"radio"!==e.type?e.checked?n.data[r]=e.value:n.data[r]="":e.checked&&(n.data[r]=e.value);else n.data[r]=e.checked}},{key:"_updateDataFromNativeElement",value:function(e,t){var n=this;if("SELECT"===e.tagName&&e.addEventListener("change",function(){var r=t.value,i=n.data[r];if(e.__updating=!0,Array.isArray(i)||"observableArray"===i.name){if(i=new H,e.selectedOptions)for(var a=0;a<e.selectedOptions.length;a++){var o=e.selectedOptions[a];i.push(o.value)}n.data[r]=i}else n.data[r]=e.value;e.__updating=!1}),"INPUT"===e.tagName||"TEXTAREA"===e.tagName){e.addEventListener("change",function(){e.__updating=!0,r?n._updateDataFromBooleanElement(e,t):n.data.value=e.value,e.__updating=!1});var r="checkbox"===e.type||"radio"===e.type;r||e.addEventListener("keyup",function(){var r=t.value;n.data[r]=e.value})}}},{key:"_addModelBindings",value:function(e){for(var t=this,n=e?e.querySelectorAll("[jqx-model]"):t._appRoot.querySelectorAll("[jqx-model]"),r=0;r<n.length;r++){var i=n[r],a={value:i.getAttribute("jqx-model")};"list"===i.type&&(a={selectedValues:i.getAttribute("jqx-model")}),"checkbox"!==i.type&&"radio"!==i.type||(a={checked:i.getAttribute("jqx-model")}),i.id||(i.id="id"+JQX.Utilities.Core.createGUID().replace(/-/gi,"")),t._updateDataFromNativeElement(i,a),t._addTemplateBinding(i.id,a)}}},{key:"_renderForBindings",value:function(e){for(var t=this,n=t._appRoot.querySelectorAll("[jqx-for]"),r=0;r<n.length;r++){var i=n[r],a=i.getAttribute("jqx-for"),o=t.data[a];i.id||(i.id="id"+JQX.Utilities.Core.createGUID().replace(/-/gi,"")),i.setAttribute("jqx-for-rendered","");for(var l=null!==i.getAttribute("jqx-for-self"),s=l?i.parentNode.querySelectorAll(".jqx-for-item-"+i.id):i.querySelectorAll(".jqx-for-item-"+i.id),u=0;u<s.length;u++)t.template[s[u].id]&&delete t.template[s[u].id],s[u].remove();for(var d=l?i:i.firstElementChild,c=document.createDocumentFragment(),p=0;p<o.length;p++){var v=d.cloneNode(!0);v.style.display="",v.id=i.id+"_"+p,v.classList.add("jqx-for-item"),v.classList.add("jqx-for-item-"+i.id),v.removeAttribute("jqx-for"),c.appendChild(v)}d.style.display="none",l?i.parentNode.insertBefore(c,i.nextSibling):i.appendChild(c);for(var f=t._appRoot.querySelectorAll(".jqx-for-item-"+i.id),h=0;h<f.length;h++){var m=f[h];t._addAttributeBindings(m,a+"."+h+".")}}e&&n.length>0&&t.render()}},{key:"notify",value:function(e){this.notifyFn=e}},{key:"_notify",value:function(e){var t=this;if("length"!==e.propertyName){t.notifyFn&&t.notifyFn(e);var n=e.propertyName;e.object&&(n=e.object.propertyName);for(var r in t.template){var i=t.template[r],a=null;for(var o in i.bind)if("function"!=typeof i.bind[o]&&i.bind[o].indexOf(n)>=0){a=o;break}a&&t._setPropertyFromData(i,a)}t._renderForBindings(!0)}}},{key:"_observeData",value:function(){var e=this;e._data=new window[r].Observable(e._data),e._data.canNotify=!1,e._data.notify(e._notify.bind(e));for(var t in e.data)if("function"!=typeof e.data[t]&&!t.startsWith("_")&&"notifyFn"!==t&&"canNotify"!==t&&"name"!==t){var n=e.data[t];Array.isArray(n)?(e.data[t]=new JQX.ObservableArray(e.data[t]),e.data[t].canNotify=!1,e.data[t].notify(e._notify.bind(e)),e.data[t].canNotify=!0,
e.data[t].propertyName=t):"object"===(void 0===n?"undefined":babelHelpers.typeof(n))&&n.constructor===JQX.DataAdapter?e.data[t].propertyName=t:"object"===(void 0===n?"undefined":babelHelpers.typeof(n))&&(e.data[t]=new JQX.Observable(e.data[t]),e.data[t].canNotify=!1,e.data[t].notify(e._notify.bind(e)),e.data[t].canNotify=!0,e.data[t].propertyName=t)}e._data.canNotify=!0}},{key:"_setPropertyFromData",value:function(e,t){var n=this;if(!e.element.__updating&&e.bind){var r=e.bind[t];if("function"!=typeof r){for(var i=r?r.split("."):[],a=n.data,o=0;o<i.length;o++){var l=i[o];if("string"==typeof a)break;if(void 0===a[l])break;a=a[l]}if(e.bind.computed){var s={item:e,name:r,value:a};e.bind.computed(s),s.value!==a&&(a=s.value)}e.element.__updatingProperties=!0,r&&void 0!==a?("observableArray"===a.name?"checkbox"===e.element.type?e.element[t]=a.indexOf(e.element.value)>=0:e.element[t]=a.toArray().slice(0):"radio"===e.element.type?e.element.value===a?e.element[t]=!0:e.element[t]=!1:e.element[t]=a,n._components[e.selector]&&!n._components[e.selector].rendered&&(n._components[e.selector].properties[t]=a)):e.properties&&(e.element[t]=e.properties[t],n._components[e.selector]&&!n._components[e.selector].rendered&&(n._components[e.selector].properties[t]=e.properties[t])),e.element.__updatingProperties=!1}}}},{key:"render",value:function(){var e=this;for(var t in e.template){(function(t){var n=e.template[t],r=n.element?n.element:document.querySelector(t),i=n.properties,a=n.listeners,o=n.bind;if(!r)return"continue";n.selector=t,n.element=r,r._properties||(r._properties=[]);for(var l in i){var s=r._properties?r._properties[l]:null;s&&(s.notify=!0),e._setPropertyFromData(n,l)}for(var u in o){var d=r._properties?r._properties[u]:null;d&&(d.notify=!0),e._setPropertyFromData(n,u)}if(e._components&&e._components[t]&&!1===e._components[t].rendered){var c=e._components[t];n.element=c.instance=new window[c.name](t,c.properties),c.rendered=!0}var p=function(t){var r=n.element;for(var i in a)!function(n){r.$||(r.$=JQX.Utilities.Extend(r)),r.$[t](n,function(t){var r=a[n];e.data[r]&&e.data[r](t)})}(i);for(var l in o)!function(n){var i=r._properties?r._properties[n]:null;if(i){var a=function(t){if(!r.__updatingProperties){r.__updating=!0;var i=function(e){if("radio"===r.type)for(var t=r.parentNode.querySelectorAll('[type="radio"]'),n=0;n<t.length;n++)t[n].__updating=e};i(!0);var a=o[n];if("radio"===r.type||"toggle"===r.type||"checkbox"===r.type)e._updateDataFromBooleanElement(r,o);else{!function(e,t,n){var r;for(r=0;r<t.length-1;r++)e=e[t[r]];e[t[r]]=n}(e.data,a.split("."),t.detail.value)}r.__updating=!1,i(!1)}};"textarea"===r.type&&r.$[t]("input.keyup",function(e){var t=new CustomEvent("keyup",{detail:{originalEvent:e,value:r.$.input.value}});a(t)}),r.$[t](i.attributeName+"-changed",function(e){a(e)})}}(l)};p("unlisten"),p("listen"),r.onAttached=function(){p("listen")},r.onDetached=function(){p("unlisten")}})(t)}}},{key:"template",get:function(){return this._template},set:function(e){this._template=e,this.render()}},{key:"id",get:function(){return this._id},set:function(e){this._id=e}},{key:"data",get:function(){return this._data},set:function(e){var t=this;t._data=e,t._observeData(),t.render()}}]),e}();Object.assign(window[r],{Elements:D,Modules:[o,a,l],BaseElement:B,Utilities:x,Import:e,ObservableArray:H,Observable:P,App:V,Component:N,Define:T.Define||null,Theme:T.Theme||"",EnableShadowDOM:!1,BaseUrl:"./",StyleBaseUrl:"/styles/default/scoped/",Version:"3.4.0"});var L=window[r].Theme;Object.defineProperty(window[r],"Theme",{configurable:!1,enumerable:!0,get:function(){return L},set:function(e){var t=L;L=e,_.fireEvent("theme-changed",{oldValue:t,newValue:e},{bubbles:!0,cancelable:!0})}}),window[r]("jqx-base-element",window[r].BaseElement),window[r]("jqx-content-element",function(e){function t(){return babelHelpers.classCallCheck(this,t),babelHelpers.possibleConstructorReturn(this,(t.__proto__||Object.getPrototypeOf(t)).apply(this,arguments))}return babelHelpers.inherits(t,e),babelHelpers.createClass(t,[{key:"template",value:function(){return"<div inner-h-t-m-l='[[innerHTML]]'></div>"}},{key:"ready",value:function(){babelHelpers.get(t.prototype.__proto__||Object.getPrototypeOf(t.prototype),"ready",this).call(this),this.applyContent()}},{key:"clearContent",value:function(){for(var e=this;e.$.content.firstChild;)e.$.content.removeChild(e.$.content.firstChild)}},{key:"applyContent",value:function(){var e=this;if(void 0===e.content)return void(e.content=e.$.content);if(""===e.content||null===e.content)return void e.clearContent();if(e.content instanceof HTMLElement)return e.clearContent(),void e.$.content.appendChild(e.content);var t=document.createDocumentFragment(),n=document.createElement("div");t.appendChild(n),e.content instanceof HTMLElement?n.appendChild(e.content):n.innerHTML=e.content;var r=Array.from(n.childNodes);n.parentNode.removeChild(n);for(var i=0;i<r.length;i++)t.appendChild(r[i]);e.clearContent(),e.$.content.appendChild(t)}},{key:"propertyChangedHandler",value:function(e,n,r){babelHelpers.get(t.prototype.__proto__||Object.getPrototypeOf(t.prototype),"propertyChangedHandler",this).call(this,e,n,r);var i=this;n!==r&&("innerHTML"===e&&(i.content=r,i.applyContent(),i.innerHTML=i.content=x.Core.html(i.$.content)),"content"===e&&i.applyContent())}}],[{key:"properties",get:function(){return{content:{type:"any",reflectToAttribute:!1},innerHTML:{type:"string",reflectToAttribute:!1}}}}]),t}(window[r].BaseElement)),window[r]("jqx-scroll-viewer",function(e){function t(){return babelHelpers.classCallCheck(this,t),babelHelpers.possibleConstructorReturn(this,(t.__proto__||Object.getPrototypeOf(t)).apply(this,arguments))}return babelHelpers.inherits(t,e),babelHelpers.createClass(t,[{key:"template",value:function(){return'<div id="container" class="jqx-container">\n                    <div id="scrollViewerContainer" class ="jqx-scroll-viewer-container">\n                      <div id="scrollViewerContentContainer" inner-h-t-m-l=\'[[innerHTML]]\' class ="jqx-scroll-viewer-content-container">\n                          <content></content>\n                      </div>\n                    </div>\n                    <jqx-scroll-bar id="verticalScrollBar" animation="[[animation]]" disabled="[[disabled]]" orientation="vertical"></jqx-scroll-bar>\n                    <jqx-scroll-bar id="horizontalScrollBar" animation="[[animation]]" disabled="[[disabled]]"></jqx-scroll-bar>\n                </div>'}},{key:"appendChild",value:function(e){var t=this;if(e){if(!t.isCompleted||e.classList&&e.classList.contains("jqx-resize-trigger-container")){var n=Array.prototype.slice.call(arguments,2);return HTMLElement.prototype.appendChild.apply(t,n.concat(Array.prototype.slice.call(arguments)))}t.$.scrollViewerContentContainer.appendChild(e)}}},{key:"removeChild",value:function(e){var t=this;if(e){if(!t.isCompleted||e.classList&&e.classList.contains("jqx-resize-trigger-container")){var n=Array.prototype.slice.call(arguments,2);return HTMLElement.prototype.removeChild.apply(t,n.concat(Array.prototype.slice.call(arguments)))}t.$.scrollViewerContentContainer.removeChild(e)}}},{key:"removeAll",value:function(){var e=this;e.isCompleted&&(e.$.scrollViewerContentContainer.innerHTML="")}},{key:"_horizontalScrollbarHandler",value:function(e){var t=this;t.$.scrollViewerContentContainer.style.left=-t.scrollLeft+"px",e.stopPropagation(),t.onHorizontalChange&&t.onHorizontalChange(e)}},{key:"_verticalScrollbarHandler",value:function(e){var t=this;t.$.scrollViewerContentContainer.style.top=-t.scrollTop+"px",e.stopPropagation(),t.onVerticalChange&&t.onVerticalChange(e)}},{key:"_mouseWheelHandler",value:function(e){var t=this;t.disabled||!t.computedHorizontalScrollBarVisibility&&!t.computedVerticalScrollBarVisibility||(t.computedVerticalScrollBarVisibility?(e.stopPropagation(),e.preventDefault(),t.scrollHeight>0&&t.scrollTo(t.scrollTop+t._getScrollCoefficient(e,t.offsetHeight))):t.computedHorizontalScrollBarVisibility&&(e.stopPropagation(),e.preventDefault(),t.scrollWidth>0&&t.scrollTo(void 0,t.scrollLeft+t._getScrollCoefficient(e,t.offsetWidth))))}},{key:"_getScrollCoefficient",value:function(e,t){var n=e.deltaMode,r=Math.abs(e.deltaY),i=void 0;return 0===n?i=r<100/3?r:t:1===n?i=r<1?r*(100/3):t:2===n&&(i=t),e.deltaY<0?-i:i}},{key:"applyContent",value:function(){var e=this;babelHelpers.get(t.prototype.__proto__||Object.getPrototypeOf(t.prototype),"applyContent",this).call(this),e.refresh()}},{key:"scrollTo",value:function(e,t){var n=this;n._scrollView&&(void 0!==e&&n._scrollView.scrollTo(e),void 0!==t&&n._scrollView.scrollTo(t,!1))}},{key:"refreshScrollBarsVisibility",value:function(){var e=this;e._scrollView&&(e._scrollView.hScrollBar.disabled=e.disabled,e._scrollView.vScrollBar.disabled=e.disabled,"disabled"===e.horizontalScrollBarVisibility&&(e._scrollView.hScrollBar.disabled=!0),"disabled"===e.verticalScrollBarVisibility&&(e._scrollView.vScrollBar.disabled=!0),e.scrollWidth>0?e._scrollView.hScrollBar.$.removeClass("jqx-hidden"):"visible"!==e.horizontalScrollBarVisibility&&e._scrollView.hScrollBar.$.addClass("jqx-hidden"),e.scrollHeight>0?e._scrollView.vScrollBar.$.removeClass("jqx-hidden"):"visible"!==e.verticalScrollBarVisibility&&e._scrollView.vScrollBar.$.addClass("jqx-hidden"),"hidden"===e.horizontalScrollBarVisibility&&e._scrollView.hScrollBar.$.addClass("jqx-hidden"),"hidden"===e.verticalScrollBarVisibility&&e._scrollView.vScrollBar.$.addClass("jqx-hidden"),"visible"===e.horizontalScrollBarVisibility&&e._scrollView.hScrollBar.$.removeClass("jqx-hidden"),"visible"===e.verticalScrollBarVisibility&&(e._scrollView.vScrollBar.$.removeClass("jqx-hidden"),e.disabled||(e._scrollView.vScrollBar.disabled=e.scrollHeight<=0)),e.computedHorizontalScrollBarVisibility&&e.computedVerticalScrollBarVisibility?(e._scrollView.hScrollBar.$.addClass("bottom-corner"),e._scrollView.vScrollBar.$.addClass("bottom-corner")):(e._scrollView.hScrollBar.$.removeClass("bottom-corner"),e._scrollView.vScrollBar.$.removeClass("bottom-corner")))}},{key:"ready",value:function(){babelHelpers.get(t.prototype.__proto__||Object.getPrototypeOf(t.prototype),"ready",this).call(this);var e=this;e._scrollView=new JQX.Utilities.Scroll(e,e.$.horizontalScrollBar,e.$.verticalScrollBar),e.refresh()}},{key:"refresh",value:function(){function e(){var e=n.$.scrollViewerContentContainer.offsetWidth-n.$.scrollViewerContainer.offsetWidth;return e>0&&"hidden"!==n.horizontalScrollBarVisibility||"visible"===n.horizontalScrollBarVisibility?n.$.scrollViewerContainer.classList.add("hscroll"):n.$.scrollViewerContainer.classList.remove("hscroll"),e}function t(){var e=void 0;if(JQX.Utilities.Core.Browser.Safari){var t=n.$.scrollViewerContentContainer.getBoundingClientRect().height,r=n.$.scrollViewerContainer.getBoundingClientRect().height;t&&r&&(e=parseInt(t)-parseInt(r))}else e=n.$.scrollViewerContentContainer.offsetHeight-n.$.scrollViewerContainer.offsetHeight;return e>0&&"hidden"!==n.verticalScrollBarVisibility||"visible"===n.verticalScrollBarVisibility?n.$.scrollViewerContainer.classList.add("vscroll"):n.$.scrollViewerContainer.classList.remove("vscroll"),e}var n=this;if(n.$.scrollViewerContentContainer){var r=n.scrollWidth,i=n.scrollHeight;n.scrollWidth=e(),n.scrollHeight=t(),n.scrollHeight&&i===n.scrollHeight||(n.scrollWidth=e()),n.scrollWidth&&r===n.scrollWidth||(n.scrollHeight=t()),n.computedVerticalScrollBarVisibility&&(n.scrollHeight+=n._scrollView.hScrollBar.offsetHeight),n.computedHorizontalScrollBarVisibility&&(n.scrollWidth+=n._scrollView.vScrollBar.offsetWidth)}}},{key:"attached",value:function(){var e=this;babelHelpers.get(t.prototype.__proto__||Object.getPrototypeOf(t.prototype),"attached",this).call(this),e._scrollView||(e._scrollView=new JQX.Utilities.Scroll(e,e.$.horizontalScrollBar,e.$.verticalScrollBar))}},{key:"detached",value:function(){var e=this;babelHelpers.get(t.prototype.__proto__||Object.getPrototypeOf(t.prototype),"detached",this).call(this),e._scrollView&&(e._scrollView.unlisten(),delete e._scrollView)}},{key:"propertyChangedHandler",value:function(e,n,r){var i=this;babelHelpers.get(t.prototype.__proto__||Object.getPrototypeOf(t.prototype),"propertyChangedHandler",this).call(this,e,n,r),i.refresh()}},{key:"enableShadowDOM",get:function(){return!1}},{key:"computedHorizontalScrollBarVisibility",get:function(){var e=this;return e._scrollView&&e._scrollView.hScrollBar?!e._scrollView.hScrollBar.$.hasClass("jqx-hidden"):null}},{key:"computedVerticalScrollBarVisibility",get:function(){var e=this;return e._scrollView&&e._scrollView.vScrollBar?!e._scrollView.vScrollBar.$.hasClass("jqx-hidden"):null}},{key:"scrollWidth",get:function(){var e=this;return e._scrollView&&e._scrollView.hScrollBar?1===e._scrollView.hScrollBar.max&&"visible"===e.horizontalScrollBarVisibility?0:e._scrollView.hScrollBar.max:-1},set:function(e){var t=this;e<0&&(e=0),t._scrollView&&t._scrollView.hScrollBar&&(0===e&&"visible"===t.horizontalScrollBarVisibility?t._scrollView.hScrollBar.max=0:t._scrollView.hScrollBar.max=e,t.refreshScrollBarsVisibility())}},{key:"scrollHeight",get:function(){var e=this;return e._scrollView&&e._scrollView.vScrollBar?1===e._scrollView.vScrollBar.max&&"visible"===e.verticalScrollBarVisibility?0:e._scrollView.vScrollBar.max:0},set:function(e){var t=this;e<0&&(e=0),t._scrollView&&t._scrollView.vScrollBar&&(0===e&&"visible"===t.verticalScrollBarVisibility?t._scrollView.vScrollBar.max=1:t._scrollView.vScrollBar.max=e,t.refreshScrollBarsVisibility())}},{key:"scrollLeft",get:function(){var e=this;return e._scrollView&&e._scrollView.hScrollBar?e._scrollView.hScrollBar.value:0},set:function(e){var t=this;e<0&&(e=0),t._scrollView&&t._scrollView.hScrollBar&&(t._scrollView.hScrollBar.value=e)}},{key:"scrollTop",get:function(){var e=this;return e._scrollView&&e._scrollView.vScrollBar?e._scrollView.vScrollBar.value:0},set:function(e){var t=this;e<0&&(e=0),t._scrollView&&t._scrollView.vScrollBar&&(t._scrollView.vScrollBar.value=e)}}],[{key:"properties",get:function(){return{horizontalScrollBarVisibility:{type:"string",value:"auto",allowedValues:["auto","disabled","hidden","visible"]},verticalScrollBarVisibility:{type:"string",value:"auto",allowedValues:["auto","disabled","hidden","visible"]}}}},{key:"listeners",get:function(){return{"horizontalScrollBar.change":"_horizontalScrollbarHandler","verticalScrollBar.change":"_verticalScrollbarHandler",wheel:"_mouseWheelHandler"}}}]),t}(window[r].ContentElement)),window[r].Utilities.Assign("PositionDetection",function(){function e(t,n,r,i){babelHelpers.classCallCheck(this,e);var a=this;if(n){var o="dropDown"+Math.floor(65536*(1+Math.random())).toString(16).substring(1);n.id=o,t.setAttribute("aria-controls",o)}a.context=t,a.dropDown=n,a.defaultParent=r,a.closeMethod=i}return babelHelpers.createClass(e,[{key:"handleAutoPositioning",value:function(){function e(){a=r(e),("auto"!==n.dropDownPosition||n.disabled||null===n.parentElement)&&cancelAnimationFrame(a),Date.now()-i>=200&&(t.scrollHandler(),i=Date.now())}var t=this,n=t.context;if("auto"===n.dropDownPosition&&!n.disabled){var r=function(){return window.requestAnimationFrame}(),i=Date.now(),a=void 0;return a=r(e)}}},{key:"checkBrowserBounds",value:function(e){var t=this.context;if("auto"===t.dropDownPosition&&!t.disabled)switch(e){case"vertically":this.checkBrowserBoundsVertically();break;case"horizontally":this.checkBrowserBoundsHorizontally();break;default:this.checkBrowserBoundsVertically(),this.checkBrowserBoundsHorizontally()}}},{key:"checkBrowserBoundsHorizontally",value:function(){var e=this.context,t=this.dropDown,n=void 0,r=0;c.isMobile||window.innerWidth===document.documentElement.clientWidth||(r=window.innerWidth-document.documentElement.clientWidth),null!==e._dropDownParent?n=!0:t.style.left="";var i=window.innerWidth-r,a=e.getBoundingClientRect().left;if(a<0&&(t.style.left=(n?0:Math.abs(a))+"px",a=parseFloat(t.style.left)),a+t.offsetWidth>i){var o=a-Math.abs(i-a-t.offsetWidth),l=Math.max(0,document.documentElement.scrollWidth-(window.innerWidth+document.documentElement.scrollLeft-r));t.style.left=(n?o:Math.max(0,o-a)-l)+"px",window.innerWidth===document.documentElement.clientWidth&&(t.style.left=parseFloat(t.style.left)+r+"px"),n&&window.innerHeight===document.documentElement.clientHeight&&this.positionDropDown(!0)}}},{key:"checkBrowserBoundsVertically",value:function(e){var t=this.context,n=this.dropDown,r=t._dropDownListPosition;e||(e=t.getBoundingClientRect()),0!==e.height&&(document.documentElement.clientHeight-Math.abs(e.top+e.height+n.offsetHeight)>=0?t._dropDownListPosition="bottom":e.top-n.offsetHeight>=0?t._dropDownListPosition="top":t._dropDownListPosition="overlay-center",this.updatePositionAttribute(r,t._dropDownListPosition))}},{key:"scrollHandler",value:function(){var e=this.context;if(e.parentElement){var t=e.getBoundingClientRect();if(t.top!==e._positionTop){var n=e._dropDownListPosition;this.checkBrowserBoundsVertically(t),e._dropDownListPosition!==n&&this.positionDropDown(),e._positionTop=t.top}}}},{key:"getDropDownParent",value:function(e){var t=this.context,n=this.dropDown,r=t.dropDownAppendTo;t._positionedParent=null,null===r?t._dropDownParent=null:"body"===r||r===document.body?t._dropDownParent=document.body:r instanceof HTMLElement?t._dropDownParent=r:"string"==typeof r?(r=document.getElementById(r),r instanceof HTMLElement?t._dropDownParent=r:(t.dropDownAppendTo=null,t._dropDownParent=null)):(t.dropDownAppendTo=null,t._dropDownParent=null);var i=t._dropDownParent;if(null!==i){for(;"static"===window.getComputedStyle(i).position&&i!==document.body;)i=i.parentElement;i===document.body?t._positionedParent=null:t._positionedParent=i,n&&(n.setAttribute("animation",t.animation),""!==t.theme&&n.$.addClass(t.theme),e&&(t._dropDownParent.appendChild(n),n.$.addClass("jqx-drop-down-repositioned")),-1===t.detachedChildren.indexOf(n)&&t.detachedChildren.push(n))}}},{key:"dropDownAppendToChangedHandler",value:function(){var e=this.context,t=this.dropDown,n=e._dropDownParent;this.getDropDownParent(),e._dropDownParent!==n&&(e[this.closeMethod](),["left","top","font-size","font-family","font-style","font-weight"].forEach(function(e){return t.style[e]=null}),null===e._dropDownParent?(this.defaultParent.appendChild(t),t.$.removeClass("jqx-drop-down-repositioned")):(e._dropDownParent.appendChild(t),t.$.addClass("jqx-drop-down-repositioned")))}},{key:"dropDownPositionChangedHandler",value:function(){var e=this;e.dropDown.style.transition="none",e.context[e.closeMethod](),e.setDropDownPosition(),e.handleAutoPositioning()}},{key:"dropDownAttached",value:function(e){var t=this.context;null!==t._dropDownParent&&(t._dropDownParent.appendChild(this.dropDown),this.handleAutoPositioning(),e&&t[e]())}},{key:"dropDownDetached",value:function(){var e=this.context;null!==e._dropDownParent&&document.body.contains(this.dropDown)&&document.body.contains(e._dropDownParent)&&e._dropDownParent.removeChild(this.dropDown)}},{key:"setDropDownPosition",value:function(){var e=this.context,t=e.dropDownPosition,n=e._dropDownListPosition;"auto"===t?this.checkBrowserBounds():e._dropDownListPosition=t,this.updatePositionAttribute(n,e._dropDownListPosition)}},{key:"updatePositionAttribute",value:function(e,t){var n=this.context,r=this.dropDown;n.$.dropDownButton&&!n.$.dropDownButton.hasAttribute(t)&&(n.$.dropDownButton.removeAttribute(e),n.$.dropDownButton.setAttribute(t,"")),r.hasAttribute(t)||(r.style.transition="none",r.removeAttribute(e),r.setAttribute(t,""),requestAnimationFrame(function(){r.style.transition=null}))}},{key:"positionDropDown",value:function(e){var t=this.context,n=this.dropDown;if(t.opened&&null!==t._dropDownParent){var r=t.getBoundingClientRect(),i=void 0,a=void 0;if(this.customPositionDropDown){var o=this.customPositionDropDown(r);i=o.left,a=o.top}else switch(i=r.left,a=r.top,t._dropDownListPosition){case"bottom":a+=t.$.container.offsetHeight-1;break;case"center-bottom":a+=t.$.container.offsetHeight-1,i+=t.offsetWidth-n.offsetWidth/2;break;case"center-top":a-=n.offsetHeight-1,i+=t.offsetWidth-n.offsetWidth/2;break;case"top":a-=n.offsetHeight-1;break;case"overlay-bottom":break;case"overlay-center":a-=n.offsetHeight/2-t.offsetHeight/2;break;case"overlay-top":a-=n.offsetHeight-t.offsetHeight}var l=this.getDropDownOffset();n.style.top=a+l.y+"px",e||(n.style.left=i+l.x+"px")}}},{key:"getDropDownOffset",value:function(){var e=this.context._positionedParent,t=void 0,n=void 0;if(e){var r=e.getBoundingClientRect();t=-r.left,n=-r.top}else t=window.pageXOffset,n=window.pageYOffset;return{x:t,y:n}}},{key:"placeOverlay",value:function(){var e=this.context;if(e.dropDownOverlay&&!e._overlay){var t=document.createElement("div");t.classList.add("jqx-drop-down-overlay"),t.style.width=document.documentElement.scrollWidth+"px",t.style.height=document.documentElement.scrollHeight+"px",document.body.appendChild(t),e._overlay=t}}},{key:"removeOverlay",value:function(e){function t(){n.dropDown.getBoundingClientRect().height>0?requestAnimationFrame(t):(document.body.removeChild(r._overlay),delete r._overlay)}var n=this,r=n.context;r._overlay&&(r.hasAnimation&&e?requestAnimationFrame(t):(document.body.removeChild(r._overlay),delete r._overlay))}}]),e}())}();
//# sourceMappingURL=jqxelement.js.map

!function(){"use strict";var t=Number.MAX_SAFE_INTEGER||9007199254740991,r=function(e){var n,i,a;if(this.epochDiffInSeconds=2082844800,"string"==typeof e){var o=e.split(":");this.seconds=Math.floor(parseFloat(o[0]));var s=parseFloat(o[1]);s>0xfffffffffffff800&&(s=0xfffffffffffff800),this.fractions=Math.ceil(s/2048)/(t+1)}else e instanceof Date?(n=e.getTime(),i=Math.floor(n/1e3),this.seconds=i+this.epochDiffInSeconds,a=(n%1e3+1e3)%1e3,this.fractions=a/1e3):"number"==typeof e?(i=Math.floor(e),this.seconds=i,this.fractions=e-i):e instanceof r?(this.seconds=e.seconds,this.fractions=e.fractions):(this.seconds=0,this.fractions=0)},e=r.prototype;e.toString=function(){return Math.floor(this.seconds)+":"+Math.round(this.fractions*(t+1)*2048)},e.toJSON=function(){return this.toString()},e.toDate=function(){return new Date(1e3*(this.seconds-this.epochDiffInSeconds+this.fractions))},e.valueOf=function(){return this.seconds+this.fractions},e.toAbsoluteTime=function(){return this.seconds+this.fractions+62135596800-2082844800},e.compare=function(t){return this.seconds<t.seconds?-1:this.seconds>t.seconds?1:this.fractions<t.fractions?-1:this.fractions>t.fractions?1:0},e.add=function(t){this.seconds+=Math.floor(t);var r=t-Math.floor(t);return r+=this.fractions,r>=1&&(r-=1,this.seconds+=1),this.fractions=r,this},window.NITimestamp=r}(),function(){"use strict";var t=window.NITimestamp,r=function(e){if("string"==typeof e)try{e=JSON.parse(e)}catch(t){throw"Can't create an analog waveform from this value"}if(e instanceof r)this.t0=new t(e.t0||"0:0"),this.channelName=e.channelName,this.dt=e.dt,this.Y=e.Y;else if("object"==typeof e)this.t0=new t(e.t0||"0:0"),this.channelName=e.channelName,this.dt=e.dt||0,this.Y=e.Y;else{if(void 0!==e)throw"Can't create an analog waveform from this value";this.dt=0,this.Y=[],this.t0=new t}},e=r.prototype;e.sampleCount=function(){return this.Y.length},e.toTimeAndValueArray=function(){for(var t=[],r=0,e=this.t0;r<this.Y.length;r++,e=e.add(this.dt))t.push([e.toAbsoluteTime(),this.Y[r]]);return t},e.appendArray=function(t){if(Array.isArray(t))for(var r=0;r<t.length;r++)this.Y.push(t[r])},e.appendWaveform=function(t){if(t instanceof r)if(t.dt!==this.dt)this.t0=t.t0,this.dt=t.dt,this.Y=t.Y.slice(0);else{var e=new window.NITimestamp(this.t0).add(this.dt*this.sampleCount());0===t.t0.compare(e)?this.appendArray(t.Y):(this.t0=t.t0,this.dt=t.dt,this.Y=t.Y.slice(0))}},e.toJSON=function(){return{t0:this.t0.toString(),channelName:this.channelName,dt:this.dt,Y:this.Y}},window.NIAnalogWaveform=r}(),function(){"use strict";window.NIComplex=function(t,r){if("string"==typeof t){var e=this.parseFromString(t);this.realPart=e[0],this.imaginaryPart=e[1]}else{if("number"!=typeof t)throw new Error("Can't create complex number");if(this.realPart=t,"number"==typeof r)this.imaginaryPart=r;else{if(void 0!==r)throw new Error("Can't create complex number: invalid imaginary part");this.imaginaryPart=0}}};var t=/\s+/g,r=/([^eE][-+])|([eE][-+][iInN])/,e=/^[-+]?([0-9]+|[0-9]+\.|[0-9]*\.[0-9]+)$/,n=/^[-+]?([0-9]*|[0-9]+\.|[0-9]*\.[0-9]+)i$/,i=/^[-+]?([0-9]+|[0-9]+\.|[0-9]+\.|[0-9]*\.[0-9]+)[eE][-+]?[0-9]+$/,a=/^[-+]?([0-9]+|[0-9]+\.|[0-9]+\.|[0-9]*\.[0-9]+)[eE][-+]?[0-9]+i$/,o=/^[-+]?Infinity$/,s=/^[-+]?Infinityi$/,u=/[iI]nf(inity)?/g,f=/^[-+]?i$/,c=/^[-+]?NaNi?$/,h=/^[-+]?([0-9]+|[0-9]+\.[0-9]+)([eE][-+]?[0-9]+)?[-+]([0-9]+|[0-9]+\.[0-9]+)([eE][-+]?[0-9]+)?i$/,l=/^[+\-]?(?:0|[1-9]\d*)(?:\.\d*)?(?:[eE][+\-]?\d+)?$/,p=/^[+\-]?((?:0|[1-9]\d*)(?:\.\d*)?(?:[eE][+\-]?\d+)?)?i$/,d=/^([+\-]?(?:0|[1-9]\d*)(?:\.\d*)?(?:[eE][+\-]?\d+)?)(Y|Z|E|P|T|G|M|k|c|m|u|n|p|f|a|z|y){1}(?!i)$/,y=/^([+\-]?(?:0|[1-9]\d*)(?:\.\d*)?(?:[eE][+\-]?\d+)?)(Y|Z|E|P|T|G|M|k|c|m|u|n|p|f|a|z|y){1}i$/,m=/^([+\-]?(?:0|[1-9]\d*)(?:\.\d*)?(?:[eE][+\-]?\d+)?E)(?!i)([+\-]?(?:0|[1-9]\d*)(?:\.\d*)?(?:[eE][+\-]?\d+)?E)i$/,w=/^([+\-]?(?:0|[1-9]\d*)(?:\.\d*)?(?:[eE][+\-]?\d+)?E)i([+\-]?(?:0|[1-9]\d*)(?:\.\d*)?(?:[eE][+\-]?\d+)?E)$/,N=window.NIComplex.prototype,g=function(t){var r;if(""===t)return 0;if(c.test(t))return NaN;if(-1===t.search(/[eE]/)){if(!e.test(t)&&!o.test(t))throw new Error("Invalid real part format");r=parseFloat(t)}else{if(!i.test(t))throw new Error("Invalid real part scientific notation");r=parseFloat(t)}return r},v=function(t){var r;if(""===t)return 0;if(c.test(t))return NaN;var e=t.slice(0,-1);if(-1===t.search(/[eE]/)){if(!n.test(t)&&!s.test(t))throw new Error("Invalid imaginary part format");if(f.test(t))return parseFloat(e+"1");r=parseFloat(e)}else{if(!a.test(t))throw new Error("Invalid imaginary part scientific notation");r=parseFloat(e)}return r},I=function(t){var e=t.search(r);return[parseFloat(t.substring(0,e+1)),parseFloat(t.substring(e+1,t.length-1))]},E=function(t){var e,n;if(""===t||void 0===t||null===t)throw new Error("Invalid number format");if(t=t.replace(u,"Infinity"),m.test(t)){var i=m.exec(t),a=i[1],o=i[2];return[A(a),A(o)]}if(w.test(t)){var i=w.exec(t),a=i[2],o=i[1];return[A(a),A(o)]}var s=t.search(r);s<t.search(/i[-+]|i$/)?(e=t.substring(0,s+1),n=t.substring(s+1)):(n=t.substring(0,s+1),e=t.substring(s+1));var f,c,h=d.test(e),l=y.test(n);if(h&&(f=A(e),isNaN(f)))throw new Error("Invalid real part format");if(l&&(c=A(n.slice(0,n.length-1)),isNaN(c)))throw new Error("Invalid imaginary part format");return void 0!==f&&void 0!==c?[f,c]:void 0!==f?[f,v(n)]:void 0!==c?[g(e),c]:[g(e),v(n)]},A=function(t){var r={Y:24,Z:21,E:18,P:15,T:12,G:9,M:6,k:3,c:-2,m:-3,u:-6,n:-9,p:-12,f:-15,a:-18,z:-21,y:-24},e=d.exec(t),n=e[1],i=e[2];return parseFloat(n)*parseFloat("1e"+r[i])};N.parseFromString=function(r){if(r=r.replace(t,""),l.test(r))return[parseFloat(r),0];if(p.test(r)){var e=r.slice(0,-1);return f.test(r)&&(e+="1"),[0,parseFloat(e)]}return h.test(r)?I(r):E(r)},N.compare=function(t){var r=Math.sqrt(Math.pow(t.realPart,2)+Math.pow(t.imaginaryPart,2)),e=Math.sqrt(Math.pow(this.realPart,2)+Math.pow(this.imaginaryPart,2));return e>r?1:e<r?-1:0},N.toString=function(){return this.imaginaryPart>=0?this.realPart+" + "+this.imaginaryPart+"i":this.realPart+" - "+Math.abs(this.imaginaryPart)+"i"}}(),function(){"use strict";window.NINumericFormatters=function(){};var t=window.NINumericFormatters.prototype,r=function(t){return Math.log(t)*Math.LOG10E},e=function(t){var r=["y","z","a","f","p","n","μ","m","","k","M","G","T","P","E","Z","Y"],e=8;return t>=3?e=t>=24?16:Math.floor(t/3)+8:(t<=-3&&(e=t<=-24?0:Math.round((t-1)/3)+8),-2!==t&&-1!==t||(e=7)),{conversion:parseFloat("1e"+3*(e-8)),extension:r[e]}},n=function(t){var r=t;"string"!=typeof t&&(r=t.toString());var e="";-1!==r.indexOf("e")&&(e=r.substring(r.indexOf("e"),r.length),r=r.substring(0,r.indexOf("e")));var n=r.indexOf(".");if(-1!==n){for(var i=r.lastIndexOf("0");i===r.length-1;)r=r.slice(0,-1),i=r.lastIndexOf("0");n===r.length-1&&(r=r.slice(0,-1))}var a="0";return"0"!==r&&"-0"!==r&&(a=r),a+e.toUpperCase()};t.toSiNotation=function(t,i){var a=0;isFinite(i)&&null!==i&&(a=i>20?20:i<0?0:i);var o,s;if(0===t)return"0";if(null===t||void 0===t)return null===t?"null":"undefined";if(!isFinite(t))return isNaN(t)?"NaN":t.toString();var u=Math.floor(r(Math.abs(t)));s=e(u),o=t/s.conversion,(u>=45||u<=-45)&&(o=o.toExponential(a)),-1===o.toString().indexOf("e")&&(o=o.toFixed(a));var f=n(o),c="";return"0"!==f&&"-0"!==f&&(c=s.extension),f+c},t.toDecPrecisionNotation=function(t,r){if(null===t||void 0===t)return null===t?"null":"undefined";if(!isFinite(t))return isNaN(t)?"NaN":t.toString();var e;if(isFinite(r)&&null!==r){var i=Math.abs(t).toString(),a=i.indexOf("."),o=-1!==i.indexOf("e")||-1!==i.indexOf("E");e=-1!==a&&a<r&&!o?t.toPrecision(r):r<1||21<r||r>i.length?t.toPrecision():t.toPrecision(r)}else e=t.toPrecision();return n(e)},t.toDecFixedNotation=function(t,r){if(null===t||void 0===t)return null===t?"null":"undefined";if(!isFinite(t))return isNaN(t)?"NaN":t.toString();var e="",n=t;t<0&&(e="-",n=Math.abs(t));var i="0";return i=isFinite(r)&&null!==r?r<0||20<r?n.toFixed():n.toFixed(r):n.toFixed(),e+i.toUpperCase()}}(),function(){var t=Object.freeze({VOID:"Void",BOOLEAN:"Boolean",UINT8:"UInt8",UINT16:"UInt16",UINT32:"UInt32",UINT64:"UInt64",INT8:"Int8",INT16:"Int16",INT32:"Int32",INT64:"Int64",SINGLE:"Single",DOUBLE:"Double",COMPLEXSINGLE:"ComplexSingle",COMPLEXDOUBLE:"ComplexDouble",STRING:"String",PATH:"Path",TIMESTAMP:"Timestamp",ENUM:"Enum",CLUSTER:"Cluster",ARRAY:"Array",ANALOGWAVEFORM:"AnalogWaveform",DIGITALWAVEFORM:"DigitalWaveform"}),r=function(r){return r===t.SINGLE||r===t.DOUBLE},e=function(r){switch(r){case t.INT8:case t.INT16:case t.INT32:case t.INT64:return!0;default:return!1}},n=function(r){switch(r){case t.UINT8:case t.UINT16:case t.UINT32:case t.UINT64:return!0;default:return!1}},i=function(r){return r===t.INT64||r===t.UINT64},a=function(t){return e(t)||n(t)},o=function(r){return r===t.COMPLEXSINGLE||r===t.COMPLEXDOUBLE},s=function(t){return a(t)||o(t)||r(t)},u=function(r){return r===t.TIMESTAMP},f=function(r){if(s(r))return!1;switch(r){case t.VOID:case t.BOOLEAN:case t.STRING:case t.PATH:case t.TIMESTAMP:case t.DIGITALWAVEFORM:return!1}return!0},c=function(t,r){return Object.keys(t).length!==r},h=function(t){if(c(t,1))throw new Error(t.name+' must only have the property "name".')},l=function(r){return r.name!==t.ARRAY},p=function(t){var r=t.subtype;if(null===r||"object"!=typeof r)throw new Error("Enum subtype must be a valid descriptor.");if(!1===n(r.name)||!0===i(r.name))throw new Error("Enum unsupported subtype: "+r.name)},d=function(t){var r=t.subtype;if(!1===l(r))throw new Error("Invalid Array subtype: "+r.name);w(r);var e=t.rank;if("number"!=typeof e||isNaN(e)||e<=0)throw new Error('Array type property "rank" must be an integer greater than 0.');var n=t.size;if(void 0!==n){if(!1===Array.isArray(n))throw new Error('Array type property "size" must be an array of integers.');if(!1===n.reduce(function(t,r){return t&&"number"==typeof r&&r>=0},!0))throw new Error('Array type property "size" must contain only natural numbers.')}},y=function(t){var r=t.fields,e=t.subtype;if(!1===Array.isArray(r))throw new Error('Cluster type must have a "fields" property of type array.');if(!1===r.reduce(function(t,r){return t&&"string"==typeof r},!0))throw new Error('Cluster type property "fields", must be an array of strings.');if(void 0!==e){if(!1===Array.isArray(e))throw new Error('Cluster type property "subtype" must be an array of types.');if(r.length!==e.length)throw new Error('Cluster properties "fields" and "subtype", must be arrays with the same length.');var n=0;try{for(;n<e.length;n++){var i=e[n];w(i)}}catch(t){throw new Error('Cluster property "subtype" contains an invalid type descriptor.\n'+t.message)}}},m=function(r){var e=r.subtype;if(void 0===e)throw new Error(t.ANALOGWAVEFORM+' must have a property called "subtype".');if(!1===s(e.name))throw new Error(t.ANALOGWAVEFORM+" subtype only accepts numerics. "+e.name+" was found instead.")},w=function(r){if(null===r||"object"!=typeof r)throw new Error("Descriptor should be a JSON encoded string or a valid format Object. Value found: "+r);var e=r.name;if(f(e))switch(e){case t.ENUM:p(r);break;case t.ARRAY:d(r);break;case t.CLUSTER:y(r);break;case t.ANALOGWAVEFORM:m(r);break;default:throw new Error("Unknown type: "+e)}else h(r)},N=function(t){if("string"==typeof t)return{name:t};for(var r in t)if(t.hasOwnProperty(r)){var e=t[r];"subtype"===r&&(Array.isArray(e)?t[r]=e.map(N):t[r]=N(e))}return t},g=function(t){return null===t||"object"!=typeof t||f(t.name)?t:t.name},v=function(t,r){return"subtype"===t||""===t?Array.isArray(r)?r.map(g):g(r):r},I=function(t,r){return Array.isArray(t)&&Array.isArray(r)?t.length===r.length&&t.reduce(function(t,e,n){return t&&e===r[n]},!0):t===r},E=function(t,r){if(void 0===t&&t===r)return!0;if(t instanceof O&&r instanceof O)return t.equals(r);if(Array.isArray(t)&&Array.isArray(r)){return t.reduce(function(t,e,n){return t&&e.equals(r[n])},!0)}return!1},A=function(t,r){return void 0===t&&t===r||t===r},b=function(t,r){return void 0===t&&t===r||t.length===r.length&&t.reduce(function(t,e,n){return t&&e===r[n]},!0)},T=function(t){var r;return"string"==typeof t&&(r=f(t)?JSON.parse(t):t),null!==t&&"object"==typeof t&&(r=t),r=N(r)},O=function(t){var r=T(t);w(r),this._descriptor=r},S=function(t){var r=function(){return this._descriptor.name===t};try{Object.defineProperty(r,"name",{value:"is"+t})}catch(t){}return r},M=O.prototype;!function(r){var e=r.prototype;for(var n in t)if(t.hasOwnProperty(n)){var i=t[n],a="is"+i;e[a]=S(i)}}(O),M.toJSON=function(){return JSON.stringify(this._descriptor)},M.toShortJSON=function(){return JSON.stringify(this._descriptor,v)},M.isNumeric=function(){return s(this._descriptor.name)},M.isFloat=function(){return r(this._descriptor.name)},M.isSignedInteger=function(){return e(this._descriptor.name)},M.isUnsignedInteger=function(){return n(this._descriptor.name)},M.is64BitInteger=function(){return i(this._descriptor.name)},M.isInteger=function(){return a(this._descriptor.name)},M.isComplex=function(){return o(this._descriptor.name)},M.isTimeStamp=function(){return u(this._descriptor.name)},M.isAggregateType=function(){return f(this._descriptor.name)},M.makeArray=function(r,e){if(this.isArray())throw new Error("Not possible to create an array from an array.");void 0===r&&(r=1);var n=JSON.parse(this.toShortJSON());return new O({name:t.ARRAY,rank:r,subtype:n,size:e})},M.getName=function(){return this._descriptor.name},M.getSubtype=function(){if(void 0!==this._nisubtype)return this._nisubtype;var t=this._descriptor.subtype;return Array.isArray(t)?this._nisubtype=t.map(function(t){return new O(t)}):"object"==typeof t&&null!==t&&(this._nisubtype=new O(t)),this._nisubtype},M.getRank=function(){return this._descriptor.rank},M.getSize=function(){return this._descriptor.size},M.getFields=function(){return this._descriptor.fields},M.equals=function(t){return t instanceof O&&(t.getName()===this.getName()&&(!!I(t.getFields(),this.getFields())&&(!!E(t.getSubtype(),this.getSubtype())&&(!!A(t.getRank(),this.getRank())&&!!b(t.getSize(),this.getSize())))))},window.NITypes=Object.freeze({VOID:new O('"Void"'),BOOLEAN:new O('"Boolean"'),UINT8:new O('"UInt8"'),UINT16:new O('"UInt16"'),UINT32:new O('"UInt32"'),UINT64:new O('"UInt64"'),INT8:new O('"Int8"'),INT16:new O('"Int16"'),INT32:new O('"Int32"'),INT64:new O('"Int64"'),SINGLE:new O('"Single"'),DOUBLE:new O('"Double"'),COMPLEXSINGLE:new O('"ComplexSingle"'),COMPLEXDOUBLE:new O('"ComplexDouble"'),STRING:new O('"String"'),PATH:new O('"Path"'),TIMESTAMP:new O('"Timestamp"'),DIGITALWAVEFORM:new O('"DigitalWaveform"')}),window.NIType=O,window.NITypeNames=t}();
//# sourceMappingURL=ni-data-types.min.js.map

(!window.NationalInstruments||window.NationalInstruments&&!1!==window.NationalInstruments.lazyRegisterWebCharts)&&(window.JQX.Elements.lazyRegister=!0);
!function($){function callbackIfComplete(e){e.async&&(e.filesLoaded+=1,e.filesLoaded===e.totalFiles&&e.callback&&e.callback())}function loadAndParseFile(e,a){$.ajax({url:e,async:a.async,cache:a.cache,dataType:"text",success:function(e,r){parseData(e,a.mode),callbackIfComplete(a)},error:function(r,t,n){console.log("Failed to download or parse "+e),callbackIfComplete(a)}})}function parseData(data,mode){for(var parsed="",parameters=data.split(/\n/),regPlaceHolder=/(\{\d+})/g,regRepPlaceHolder=/\{(\d+)}/g,unicodeRE=/(\\u.{4})/gi,i=0;i<parameters.length;i++)if(parameters[i]=parameters[i].replace(/^\s\s*/,"").replace(/\s\s*$/,""),parameters[i].length>0&&"#"!=parameters[i].match("^#")){var pair=parameters[i].split("=");if(pair.length>0){for(var name=decodeURI(pair[0]).replace(/^\s\s*/,"").replace(/\s\s*$/,""),value=1==pair.length?"":pair[1];"\\"==value.match(/\\$/);)value=value.substring(0,value.length-1),value+=parameters[++i].replace(/\s\s*$/,"");for(var s=2;s<pair.length;s++)value+="="+pair[s];if(value=value.replace(/^\s\s*/,"").replace(/\s\s*$/,""),"map"==mode||"both"==mode){var unicodeMatches=value.match(unicodeRE);if(unicodeMatches)for(var u=0;u<unicodeMatches.length;u++)value=value.replace(unicodeMatches[u],unescapeUnicode(unicodeMatches[u]));$.i18n.map[name]=value}if("vars"==mode||"both"==mode)if(value=value.replace(/"/g,'\\"'),checkKeyNamespace(name),regPlaceHolder.test(value)){for(var parts=value.split(regPlaceHolder),first=!0,fnArgs="",usedArgs=[],p=0;p<parts.length;p++)!regPlaceHolder.test(parts[p])||0!=usedArgs.length&&-1!=usedArgs.indexOf(parts[p])||(first||(fnArgs+=","),fnArgs+=parts[p].replace(regRepPlaceHolder,"v$1"),usedArgs.push(parts[p]),first=!1);parsed+=name+"=function("+fnArgs+"){";var fnExpr='"'+value.replace(regRepPlaceHolder,'"+v$1+"')+'"';parsed+="return "+fnExpr+";};"}else parsed+=name+'="'+value+'";'}}eval(parsed)}function checkKeyNamespace(key){var regDot=/\./;if(regDot.test(key))for(var fullname="",names=key.split(/\./),i=0;i<names.length;i++)i>0&&(fullname+="."),fullname+=names[i],eval("typeof "+fullname+' == "undefined"')&&eval(fullname+"={};")}function getFiles(e){return e&&e.constructor==Array?e:[e]}function unescapeUnicode(e){var a=[],r=parseInt(e.substr(2),16);r>=0&&r<Math.pow(2,16)&&a.push(r);for(var t="",n=0;n<a.length;++n)t+=String.fromCharCode(a[n]);return t}$.i18n={},$.i18n.map={},$.i18n.properties=function(e){var a={name:"Messages",language:"",path:"",mode:"vars",cache:!1,encoding:"UTF-8",async:!1,checkAvailableLanguages:!1,callback:null};e=$.extend(a,e),e.language=this.normaliseLanguageCode(e.language);var r=function(a){e.totalFiles=0,e.filesLoaded=0;var r=getFiles(e.name);if(e.async)for(var t=0,n=r.length;n>t;t++){e.totalFiles+=1;var s=e.language.substring(0,2);if(0!=a.length&&-1==$.inArray(s,a)||(e.totalFiles+=1),e.language.length>=5){var l=e.language.substring(0,5);0!=a.length&&-1==$.inArray(l,a)||(e.totalFiles+=1)}}for(var i=0,g=r.length;g>i;i++){loadAndParseFile(e.path+r[i]+".properties",e);var s=e.language.substring(0,2);if(0!=a.length&&-1==$.inArray(s,a)||loadAndParseFile(e.path+r[i]+"_"+s+".properties",e),e.language.length>=5){var l=e.language.substring(0,5);0!=a.length&&-1==$.inArray(l,a)||loadAndParseFile(e.path+r[i]+"_"+l+".properties",e)}}e.callback&&!e.async&&e.callback()};e.checkAvailableLanguages?$.ajax({url:e.path+"languages.json",async:e.async,cache:!1,success:function(e,a,t){r(e.languages||[])}}):r([])},$.i18n.prop=function(e){var a=$.i18n.map[e];if(null==a)return"["+e+"]";var r;2==arguments.length&&$.isArray(arguments[1])&&(r=arguments[1]);var t;if("string"==typeof a){for(t=0;-1!=(t=a.indexOf("\\",t));)a="t"==a.charAt(t+1)?a.substring(0,t)+"\t"+a.substring(2+t++):"r"==a.charAt(t+1)?a.substring(0,t)+"\r"+a.substring(2+t++):"n"==a.charAt(t+1)?a.substring(0,t)+"\n"+a.substring(2+t++):"f"==a.charAt(t+1)?a.substring(0,t)+"\f"+a.substring(2+t++):"\\"==a.charAt(t+1)?a.substring(0,t)+"\\"+a.substring(2+t++):a.substring(0,t)+a.substring(t+1);var n,s,l=[];for(t=0;t<a.length;)if("'"==a.charAt(t))if(t==a.length-1)a=a.substring(0,t);else if("'"==a.charAt(t+1))a=a.substring(0,t)+a.substring(++t);else{for(n=t+2;-1!=(n=a.indexOf("'",n));){if(n==a.length-1||"'"!=a.charAt(n+1)){a=a.substring(0,t)+a.substring(t+1,n)+a.substring(n+1),t=n-1;break}a=a.substring(0,n)+a.substring(++n)}-1==n&&(a=a.substring(0,t)+a.substring(t+1))}else if("{"==a.charAt(t))if(-1==(n=a.indexOf("}",t+1)))t++;else if(s=parseInt(a.substring(t+1,n)),!isNaN(s)&&s>=0){var i=a.substring(0,t);""!=i&&l.push(i),l.push(s),t=0,a=a.substring(n+1)}else t=n+1;else t++;""!=a&&l.push(a),a=l,$.i18n.map[e]=l}if(0==a.length)return"";if(1==a.length&&"string"==typeof a[0])return a[0];var g="";for(t=0;t<a.length;t++)g+="string"==typeof a[t]?a[t]:r&&a[t]<r.length?r[a[t]]:!r&&a[t]+1<arguments.length?arguments[a[t]+1]:"{"+a[t]+"}";return g},$.i18n.normaliseLanguageCode=function(e){return(!e||e.length<2)&&(e=navigator.languages?navigator.languages[0]:navigator.language||navigator.userLanguage||"en"),e=e.toLowerCase(),e=e.replace(/-/,"_"),e.length>3&&(e=e.substring(0,3)+e.substring(3).toUpperCase()),e};var cbSplit;cbSplit||(cbSplit=function(e,a,r){if("[object RegExp]"!==Object.prototype.toString.call(a))return void 0===cbSplit._nativeSplit?e.split(a,r):cbSplit._nativeSplit.call(e,a,r);var t,n,s,l,i=[],g=0,c=(a.ignoreCase?"i":"")+(a.multiline?"m":"")+(a.sticky?"y":""),a=new RegExp(a.source,c+"g");if(e+="",cbSplit._compliantExecNpcg||(t=new RegExp("^"+a.source+"$(?!\\s)",c)),void 0===r||0>+r)r=1/0;else if(!(r=Math.floor(+r)))return[];for(;(n=a.exec(e))&&!((s=n.index+n[0].length)>g&&(i.push(e.slice(g,n.index)),!cbSplit._compliantExecNpcg&&n.length>1&&n[0].replace(t,function(){for(var e=1;e<arguments.length-2;e++)void 0===arguments[e]&&(n[e]=void 0)}),n.length>1&&n.index<e.length&&Array.prototype.push.apply(i,n.slice(1)),l=n[0].length,g=s,i.length>=r));)a.lastIndex===n.index&&a.lastIndex++;return g===e.length?!l&&a.test("")||i.push(""):i.push(e.slice(g)),i.length>r?i.slice(0,r):i},cbSplit._compliantExecNpcg=void 0===/()??/.exec("")[1],cbSplit._nativeSplit=String.prototype.split),String.prototype.split=function(e,a){return cbSplit(this,e,a)}}(jQuery);
!function(e,r){var t,n,a,s,u,l,i,c,o,f,d,p,h,g,b,y,m,M,v,k,z,F,A,x;t=function(e){return new t.prototype.init(e)},"undefined"!=typeof require&&"undefined"!=typeof exports&&"undefined"!=typeof module?module.exports=t:e.Globalize=t,t.cultures={},t.prototype={constructor:t,init:function(e){return this.cultures=t.cultures,this.cultureSelector=e,this}},t.prototype.init.prototype=t.prototype,t.cultures.default={name:"en",englishName:"English",nativeName:"English",isRTL:!1,language:"en",numberFormat:{pattern:["-n"],decimals:2,",":",",".":".",groupSizes:[3],"+":"+","-":"-",NaN:"NaN",negativeInfinity:"-Infinity",positiveInfinity:"Infinity",percent:{pattern:["-n %","n %"],decimals:2,groupSizes:[3],",":",",".":".",symbol:"%"},currency:{pattern:["($n)","$n"],decimals:2,groupSizes:[3],",":",",".":".",symbol:"$"}},calendars:{standard:{name:"Gregorian_USEnglish","/":"/",":":":",firstDay:0,days:{names:["Sunday","Monday","Tuesday","Wednesday","Thursday","Friday","Saturday"],namesAbbr:["Sun","Mon","Tue","Wed","Thu","Fri","Sat"],namesShort:["Su","Mo","Tu","We","Th","Fr","Sa"]},months:{names:["January","February","March","April","May","June","July","August","September","October","November","December",""],namesAbbr:["Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec",""]},AM:["AM","am","AM"],PM:["PM","pm","PM"],eras:[{name:"A.D.",start:null,offset:0}],twoDigitYearMax:2029,patterns:{d:"M/d/yyyy",D:"dddd, MMMM dd, yyyy",t:"h:mm tt",T:"h:mm:ss tt",f:"dddd, MMMM dd, yyyy h:mm tt",F:"dddd, MMMM dd, yyyy h:mm:ss tt",M:"MMMM dd",Y:"yyyy MMMM",S:"yyyy'-'MM'-'dd'T'HH':'mm':'ss"}}},messages:{}},t.cultures.default.calendar=t.cultures.default.calendars.standard,t.cultures.en=t.cultures.default,t.cultureSelector="en",n=/^0x[a-f0-9]+$/i,a=/^[+\-]?infinity$/i,s=/^[+\-]?\d*\.?\d*(e[+\-]?\d+)?$/,u=/^\s+|\s+$/g,l=function(e,r){if(e.indexOf)return e.indexOf(r);for(var t=0,n=e.length;t<n;t++)if(e[t]===r)return t;return-1},i=function(e,r){return e.substr(e.length-r.length)===r},c=function(){var e,r,t,n,a,s,u=arguments[0]||{},l=1,i=arguments.length,p=!1;for("boolean"==typeof u&&(p=u,u=arguments[1]||{},l=2),"object"==typeof u||f(u)||(u={});l<i;l++)if(null!=(e=arguments[l]))for(r in e)t=u[r],n=e[r],u!==n&&(p&&n&&(d(n)||(a=o(n)))?(a?(a=!1,s=t&&o(t)?t:[]):s=t&&d(t)?t:{},u[r]=c(p,s,n)):void 0!==n&&(u[r]=n));return u},o=Array.isArray||function(e){return"[object Array]"===Object.prototype.toString.call(e)},f=function(e){return"[object Function]"===Object.prototype.toString.call(e)},d=function(e){return"[object Object]"===Object.prototype.toString.call(e)},p=function(e,r){return 0===e.indexOf(r)},h=function(e){return(e+"").replace(u,"")},g=function(e){return isNaN(e)?NaN:Math[e<0?"ceil":"floor"](e)},b=function(e,r,t){var n;for(n=e.length;n<r;n+=1)e=t?"0"+e:e+"0";return e},y=function(e,r){for(var t=0,n=!1,a=0,s=e.length;a<s;a++){var u=e.charAt(a);switch(u){case"'":n?r.push("'"):t++,n=!1;break;case"\\":n&&r.push("\\"),n=!n;break;default:r.push(u),n=!1}}return t},m=function(e,r){r=r||"F";var t,n=e.patterns,a=r.length;if(1===a){if(!(t=n[r]))throw"Invalid date format string '"+r+"'.";r=t}else 2===a&&"%"===r.charAt(0)&&(r=r.charAt(1));return r},M=function(e,r,t){function n(e,r){if(e<0)return"-"+n(-e,r);var t,a=e+"";return r>1&&a.length<r?(t=b[r-2]+a,t.substr(t.length-r,r)):t=a}function a(e,r){if(g)return g[r];switch(r){case 0:return e.getFullYear();case 1:return e.getMonth();case 2:return e.getDate();default:throw"Invalid part value "+r}}var s,u=t.calendar,l=u.convert;if(!r||!r.length||"i"===r){if(t&&t.name.length)if(l)s=M(e,u.patterns.F,t);else{var i=new Date(e.getTime()),c=z(e,u.eras);i.setFullYear(F(e,u,c)),s=i.toLocaleString()}else s=e.toString();return s}var o=u.eras,f="s"===r;r=m(u,r),s=[];var d,p,h,g,b=["0","00","000"],v=/([^d]|^)(d|dd)([^d]|$)/g,A=0,x=k();for(!f&&l&&(g=l.fromGregorian(e));;){var S=x.lastIndex,I=x.exec(r),w=r.slice(S,I?I.index:r.length);if(A+=y(w,s),!I)break;if(A%2)s.push(I[0]);else{var C=I[0],D=C.length;switch(C){case"ddd":case"dddd":var H=3===D?u.days.namesAbbr:u.days.names;s.push(H[e.getDay()]);break;case"d":case"dd":p=!0,s.push(n(a(e,2),D));break;case"MMM":case"MMMM":var O=a(e,1);s.push(u.monthsGenitive&&function(){return p||h?p:(p=v.test(r),h=!0,p)}()?u.monthsGenitive[3===D?"namesAbbr":"names"][O]:u.months[3===D?"namesAbbr":"names"][O]);break;case"M":case"MM":s.push(n(a(e,1)+1,D));break;case"y":case"yy":case"yyyy":O=g?g[0]:F(e,u,z(e,o),f),D<4&&(O%=100),s.push(n(O,D));break;case"h":case"hh":d=e.getHours()%12,0===d&&(d=12),s.push(n(d,D));break;case"H":case"HH":s.push(n(e.getHours(),D));break;case"m":case"mm":s.push(n(e.getMinutes(),D));break;case"s":case"ss":s.push(n(e.getSeconds(),D));break;case"t":case"tt":O=e.getHours()<12?u.AM?u.AM[0]:" ":u.PM?u.PM[0]:" ",s.push(1===D?O.charAt(0):O);break;case"f":case"ff":case"fff":s.push(n(e.getMilliseconds(),3).substr(0,D));break;case"z":case"zz":d=e.getTimezoneOffset()/60,s.push((d<=0?"+":"-")+n(Math.floor(Math.abs(d)),D));break;case"zzz":d=e.getTimezoneOffset()/60,s.push((d<=0?"+":"-")+n(Math.floor(Math.abs(d)),2)+":"+n(Math.abs(e.getTimezoneOffset()%60),2));break;case"g":case"gg":u.eras&&s.push(u.eras[z(e,o)].name);break;case"/":s.push(u["/"]);break;default:throw"Invalid date format pattern '"+C+"'."}}}return s.join("")},function(){var e;e=function(e,r,t){var n=t.groupSizes,a=n[0],s=1,u=Math.pow(10,r),l=Math.round(e*u)/u;isFinite(l)||(l=e),e=l;var i=e+"",c="",o=i.split(/e/i),f=o.length>1?parseInt(o[1],10):0;i=o[0],o=i.split("."),i=o[0],c=o.length>1?o[1]:"";f>0?(c=b(c,f,!1),i+=c.slice(0,f),c=c.substr(f)):f<0&&(f=-f,i=b(i,f+1,!0),c=i.slice(-f,i.length)+c,i=i.slice(0,-f)),c=r>0?t["."]+(c.length>r?c.slice(0,r):b(c,r)):"";for(var d=i.length-1,p=t[","],h="";d>=0;){if(0===a||a>d)return i.slice(0,d+1)+(h.length?p+h+c:c);h=i.slice(d-a+1,d+1)+(h.length?p+h:""),d-=a,s<n.length&&(a=n[s],s++)}return i.slice(0,d+1)+p+h+c},v=function(r,t,n){if(!isFinite(r))return r===1/0?n.numberFormat.positiveInfinity:r===-1/0?n.numberFormat.negativeInfinity:n.numberFormat.NaN;if(!t||"i"===t)return n.name.length?r.toLocaleString():r.toString();t=t||"D";var a,s=n.numberFormat,u=Math.abs(r),l=-1;t.length>1&&(l=parseInt(t.slice(1),10));var i,c=t.charAt(0).toUpperCase();switch(c){case"D":a="n",u=g(u),-1!==l&&(u=b(""+u,l,!0)),r<0&&(u="-"+u);break;case"N":i=s;case"C":i=i||s.currency;case"P":i=i||s.percent,a=r<0?i.pattern[0]:i.pattern[1]||"n",-1===l&&(l=i.decimals),u=e(u*("P"===c?100:1),l,i);break;default:throw"Bad number format specifier: "+c}for(var o=/n|\$|-|%/g,f="";;){var d=o.lastIndex,p=o.exec(a);if(f+=a.slice(d,p?p.index:a.length),!p)break;switch(p[0]){case"n":f+=u;break;case"$":f+=s.currency.symbol;break;case"-":/[1-9]/.test(u)&&(f+=s["-"]);break;case"%":f+=s.percent.symbol}}return f}}(),k=function(){return/\/|dddd|ddd|dd|d|MMMM|MMM|MM|M|yyyy|yy|y|hh|h|HH|H|mm|m|ss|s|tt|t|fff|ff|f|zzz|zz|z|gg|g/g},z=function(e,r){if(!r)return 0;for(var t,n=e.getTime(),a=0,s=r.length;a<s;a++)if(null===(t=r[a].start)||n>=t)return a;return 0},F=function(e,r,t,n){var a=e.getFullYear();return!n&&r.eras&&(a-=r.eras[t].offset),a},function(){var e,r,t,n,a,s,u;e=function(e,r){if(r<100){var t=new Date,n=z(t),a=F(t,e,n),s=e.twoDigitYearMax;s="string"==typeof s?(new Date).getFullYear()%100+parseInt(s,10):s,r+=a-a%100,r>s&&(r-=100)}return r},r=function(e,r,t){var n,a=e.days,i=e._upperDays;return i||(e._upperDays=i=[u(a.names),u(a.namesAbbr),u(a.namesShort)]),r=s(r),t?-1===(n=l(i[1],r))&&(n=l(i[2],r)):n=l(i[0],r),n},t=function(e,r,t){var n=e.months,a=e.monthsGenitive||e.months,i=e._upperMonths,c=e._upperMonthsGen;i||(e._upperMonths=i=[u(n.names),u(n.namesAbbr)],e._upperMonthsGen=c=[u(a.names),u(a.namesAbbr)]),r=s(r);var o=l(t?i[1]:i[0],r);return o<0&&(o=l(t?c[1]:c[0],r)),o},n=function(e,r){var t=e._parseRegExp;if(t){var n=t[r];if(n)return n}else e._parseRegExp=t={};for(var a,s=m(e,r).replace(/([\^\$\.\*\+\?\|\[\]\(\)\{\}])/g,"\\\\$1"),u=["^"],l=[],i=0,c=0,o=k();null!==(a=o.exec(s));){var f=s.slice(i,a.index);if(i=o.lastIndex,(c+=y(f,u))%2)u.push(a[0]);else{var d,p=a[0],h=p.length;switch(p){case"dddd":case"ddd":case"MMMM":case"MMM":case"gg":case"g":d="(\\D+)";break;case"tt":case"t":d="(\\D*)";break;case"yyyy":case"fff":case"ff":case"f":d="(\\d{"+h+"})";break;case"dd":case"d":case"MM":case"M":case"yy":case"y":case"HH":case"H":case"hh":case"h":case"mm":case"m":case"ss":case"s":d="(\\d\\d?)";break;case"zzz":d="([+-]?\\d\\d?:\\d{2})";break;case"zz":case"z":d="([+-]?\\d\\d?)";break;case"/":d="(\\/)";break;default:throw"Invalid date format pattern '"+p+"'."}d&&u.push(d),l.push(a[0])}}y(s.slice(i),u),u.push("$");var g=u.join("").replace(/\s+/g,"\\s+"),b={regExp:g,groups:l};return t[r]=b},a=function(e,r,t){return e<r||e>t},s=function(e){return e.split(" ").join(" ").toUpperCase()},u=function(e){for(var r=[],t=0,n=e.length;t<n;t++)r[t]=s(e[t]);return r},A=function(s,u,l){s=h(s);var i=l.calendar,c=n(i,u),o=new RegExp(c.regExp).exec(s);if(null===o)return null;for(var f,d=c.groups,g=null,b=null,y=null,m=null,M=null,v=0,k=0,z=0,F=0,A=null,x=!1,S=0,I=d.length;S<I;S++){var w=o[S+1];if(w){var C=d[S],D=C.length,H=parseInt(w,10);switch(C){case"dd":case"d":if(m=H,a(m,1,31))return null;break;case"MMM":case"MMMM":if(y=t(i,w,3===D),a(y,0,11))return null;break;case"M":case"MM":if(y=H-1,a(y,0,11))return null;break;case"y":case"yy":case"yyyy":if(b=D<4?e(i,H):H,a(b,0,9999))return null;break;case"h":case"hh":if(v=H,12===v&&(v=0),a(v,0,11))return null;break;case"H":case"HH":if(v=H,a(v,0,23))return null;break;case"m":case"mm":if(k=H,a(k,0,59))return null;break;case"s":case"ss":if(z=H,a(z,0,59))return null;break;case"tt":case"t":if(!(x=i.PM&&(w===i.PM[0]||w===i.PM[1]||w===i.PM[2]))&&(!i.AM||w!==i.AM[0]&&w!==i.AM[1]&&w!==i.AM[2]))return null;break;case"f":case"ff":case"fff":if(F=H*Math.pow(10,3-D),a(F,0,999))return null;break;case"ddd":case"dddd":if(M=r(i,w,3===D),a(M,0,6))return null;break;case"zzz":var O=w.split(/:/);if(2!==O.length)return null;if(f=parseInt(O[0],10),a(f,-12,13))return null;var N=parseInt(O[1],10);if(a(N,0,59))return null;A=60*f+(p(w,"-")?-N:N);break;case"z":case"zz":if(f=H,a(f,-12,13))return null;A=60*f;break;case"g":case"gg":var T=w;if(!T||!i.eras)return null;T=h(T.toLowerCase());for(var j=0,$=i.eras.length;j<$;j++)if(T===i.eras[j].name.toLowerCase()){g=j;break}if(null===g)return null}}}var P,G=new Date,E=i.convert;if(P=E?E.fromGregorian(G)[0]:G.getFullYear(),null===b?b=P:i.eras&&(b+=i.eras[g||0].offset),null===y&&(y=0),null===m&&(m=1),E){if(null===(G=E.toGregorian(b,y,m)))return null}else{if(G.setFullYear(b,y,m),G.getDate()!==m)return null;if(null!==M&&G.getDay()!==M)return null}if(x&&v<12&&(v+=12),G.setHours(v,k,z,F),null!==A){var Y=G.getMinutes()-(A+G.getTimezoneOffset());G.setHours(G.getHours()+parseInt(Y/60,10),Y%60)}return G}}(),x=function(e,r,t){var n,a=r["-"],s=r["+"];switch(t){case"n -":a=" "+a,s=" "+s;case"n-":i(e,a)?n=["-",e.substr(0,e.length-a.length)]:i(e,s)&&(n=["+",e.substr(0,e.length-s.length)]);break;case"- n":a+=" ",s+=" ";case"-n":p(e,a)?n=["-",e.substr(a.length)]:p(e,s)&&(n=["+",e.substr(s.length)]);break;case"(n)":p(e,"(")&&i(e,")")&&(n=["-",e.substr(1,e.length-2)])}return n||["",e]},t.prototype.findClosestCulture=function(e){return t.findClosestCulture.call(this,e)},t.prototype.format=function(e,r,n){return t.format.call(this,e,r,n)},t.prototype.localize=function(e,r){return t.localize.call(this,e,r)},t.prototype.parseInt=function(e,r,n){return t.parseInt.call(this,e,r,n)},t.prototype.parseFloat=function(e,r,n){return t.parseFloat.call(this,e,r,n)},t.prototype.culture=function(e){return t.culture.call(this,e)},t.addCultureInfo=function(e,r,t){var n={},a=!1;"string"!=typeof e?(t=e,e=this.culture().name,n=this.cultures[e]):"string"!=typeof r?(t=r,a=null==this.cultures[e],n=this.cultures[e]||this.cultures.default):(a=!0,n=this.cultures[r]),this.cultures[e]=c(!0,{},n,t),a&&(this.cultures[e].calendar=this.cultures[e].calendars.standard)},t.findClosestCulture=function(e){var r;if(!e)return this.findClosestCulture(this.cultureSelector)||this.cultures.default;if("string"==typeof e&&(e=e.split(",")),o(e)){var t,n,a=this.cultures,s=e,u=s.length,l=[];for(n=0;n<u;n++){e=h(s[n]);var i,c=e.split(";");t=h(c[0]),1===c.length?i=1:(e=h(c[1]),0===e.indexOf("q=")?(e=e.substr(2),i=parseFloat(e),i=isNaN(i)?0:i):i=1),l.push({lang:t,pri:i})}for(l.sort(function(e,r){return e.pri<r.pri?1:e.pri>r.pri?-1:0}),n=0;n<u;n++)if(t=l[n].lang,r=a[t])return r;for(n=0;n<u;n++)for(t=l[n].lang;;){var f=t.lastIndexOf("-");if(-1===f)break;if(t=t.substr(0,f),r=a[t])return r}for(n=0;n<u;n++){t=l[n].lang;for(var d in a){var p=a[d];if(p.language==t)return p}}}else if("object"==typeof e)return e;return r||null},t.format=function(e,r,t){var n=this.findClosestCulture(t);return e instanceof Date?e=M(e,r,n):"number"==typeof e&&(e=v(e,r,n)),e},t.localize=function(e,r){return this.findClosestCulture(r).messages[e]||this.cultures.default.messages[e]},t.parseDate=function(e,r,t){t=this.findClosestCulture(t);var n,a,s;if(r){if("string"==typeof r&&(r=[r]),r.length)for(var u=0,l=r.length;u<l;u++){var i=r[u];if(i&&(n=A(e,i,t)))break}}else{s=t.calendar.patterns;for(a in s)if(n=A(e,s[a],t))break}return n||null},t.parseInt=function(e,r,n){return g(t.parseFloat(e,r,n))},t.parseFloat=function(e,r,t){"number"!=typeof r&&(t=r,r=10);var u=this.findClosestCulture(t),l=NaN,i=u.numberFormat;if(e.indexOf(u.numberFormat.currency.symbol)>-1&&(e=e.replace(u.numberFormat.currency.symbol,""),e=e.replace(u.numberFormat.currency["."],u.numberFormat["."])),e.indexOf(u.numberFormat.percent.symbol)>-1&&(e=e.replace(u.numberFormat.percent.symbol,"")),e=e.replace(/ /g,""),a.test(e))l=parseFloat(e);else if(!r&&n.test(e))l=parseInt(e,16);else{var c=x(e,i,i.pattern[0]),o=c[0],f=c[1];""===o&&"(n)"!==i.pattern[0]&&(c=x(e,i,"(n)"),o=c[0],f=c[1]),""===o&&"-n"!==i.pattern[0]&&(c=x(e,i,"-n"),o=c[0],f=c[1]),o=o||"+";var d,p,h=f.indexOf("e");h<0&&(h=f.indexOf("E")),h<0?(p=f,d=null):(p=f.substr(0,h),d=f.substr(h+1));var g,b,y=i["."],m=p.indexOf(y);m<0?(g=p,b=null):(g=p.substr(0,m),b=p.substr(m+y.length));var M=i[","];g=g.split(M).join("");var v=M.replace(/\u00A0/g," ");M!==v&&(g=g.split(v).join(""));var k=o+g;if(null!==b&&(k+="."+b),null!==d){var z=x(d,i,"-n");k+="e"+(z[0]||"+")+z[1]}s.test(k)&&(l=parseFloat(k))}return l},t.culture=function(e){return void 0!==e&&(this.cultureSelector=e),this.findClosestCulture(e)||this.cultures.default}}(this);
!function(e,n){var i;i="undefined"!=typeof require&&"undefined"!=typeof exports&&"undefined"!=typeof module?require("globalize"):e.Globalize,i.addCultureInfo("en-US","default",{name:"en-US",englishName:"English (United States)"})}(this);
Object.is||Object.defineProperty(Object,"is",{value:function(e,r){return e===r?0!==e||1/e==1/r:e!==e&&r!==r},configurable:!0,enumerable:!1,writable:!0});
!function(){"use strict";var o=o||{};window.NationalInstruments=o,o.HtmlVI={},o.HtmlVI.Elements={},o.JQXElement={},o.HtmlVI.NISupport={};var e=o.HtmlVI.NISupport;e.defineConstReference=function(o,e,n){Object.defineProperty(o,e,{configurable:!1,enumerable:!1,writable:!1,value:n})};var n=function(){};e.log=console.log.bind(console),e.error=console.error.bind(console),e.debug=console.debug.bind(console),e.info=console.info.bind(console),e.group=console.group.bind(console),e.groupEnd=console.groupEnd.bind(console),e.defineConstReference(e,"VERBOSE",!0),e.defineConstReference(e,"VERBOSE_INFO",!0),e.logVerbose=e.VERBOSE?console.log.bind(console):n,e.errorVerbose=e.VERBOSE?console.error.bind(console):n,e.debugVerbose=e.VERBOSE?console.debug.bind(console):n,e.infoVerbose=e.VERBOSE&&e.VERBOSE_INFO?console.info.bind(console):n,e.groupVerbose=e.VERBOSE?console.group.bind(console):n,e.groupEndVerbose=e.VERBOSE?console.groupEnd.bind(console):n,e.uniqueId=function(){return"_"+Math.random().toString(36).substr(2,9)},function(){var o=document.createElement("div");e.escapeHtml=function(e){return o.textContent=e,o.innerHTML}}(),o.HtmlVI.EventsEnum=Object.freeze({NONE:0,CLICK:1,VALUE_CHANGE:2,RIGHT_CLICK:3,BUTTON_CLICK:4})}(),NationalInstruments.HtmlVI.NISupport.inheritFromParent=function(o,e){var n=NationalInstruments.HtmlVI.NISupport;if(Object.keys(o.prototype).length>0)throw new Error("Properties added to the constructor function prototype object are lost during function invocation. Add after function invocation");try{o.prototype=Object.create(e.prototype),o.prototype.constructor=o}catch(o){n.log(o.message)}return o.prototype};
!function(){"use strict";NationalInstruments.HtmlVI.TaskTracker=function(t,e){this.remainingTasks=function(t,e){var n,i=Object.keys(t);if("function"!=typeof e)throw new Error("Completion callback function must be provided");if(i.length<1)throw new Error("Must provide an object with at least one property to use as task names");for(n=0;n<i.length;n+=1)if(t[i[n]]!==i[n])throw new Error("Task name properties and values must be identical; the task names object must be an enum style object");return i}(t,e),this.taskNames=t,this.completionCallback=e},NationalInstruments.HtmlVI.TaskTracker.prototype.complete=function(t){var e;if(void 0===this.taskNames[t])throw new Error("Attempted to complete the following invalid task: "+t);if(0!==this.remainingTasks.length){for(e=0;e<this.remainingTasks.length;e+=1)if(this.remainingTasks[e]===t){this.remainingTasks.splice(e,1);break}0===this.remainingTasks.length&&this.completionCallback.call(void 0)}}}();
!function(n){"use strict";var i=NationalInstruments.HtmlVI.NISupport;window.NIEmbeddedBrowser={},window.NIEmbeddedBrowser.language="en-US",window.NIEmbeddedBrowser.formatLanguage="en-US",i.i18n=void 0,i.InternationalizationInitializer={},i.InternationalizationInitializer.TaskTrackerEnum=Object.freeze({LANGUAGES_LOADED:"LANGUAGES_LOADED",ELEMENT_PROTOTYPES_READY:"ELEMENT_PROTOTYPES_READY"}),i.InternationalizationInitializer.TaskTracker=new NationalInstruments.HtmlVI.TaskTracker(i.InternationalizationInitializer.TaskTrackerEnum,function(){NationalInstruments.JQXElement._registerElements()});var e=i.InternationalizationInitializer.TaskTrackerEnum,a=i.InternationalizationInitializer.TaskTracker;n.i18n.properties({name:window.i18nFiles,language:void 0!==window.engine&&window.engine.IsAttached&&void 0!==window.NIEmbeddedBrowser?window.NIEmbeddedBrowser.language:void 0,path:window.i18nPath,mode:"map",cache:!0,async:!0,callback:function(){if(void 0!==i.i18n)return void i.error("The i18n completion callback is being called multiple times");i.i18n=function(){return n.i18n.prop.apply(n.i18n,arguments)},a.complete(e.LANGUAGES_LOADED)}})}(window.jQuery);
!function(){"use strict";NationalInstruments.Globals={},NationalInstruments.Globals.jQuery=$}();
//# sourceMappingURL=element.min.js.map

"use strict";!function(){NationalInstruments.HtmlVI.DataPipeline={},NationalInstruments.HtmlVI.DataPipeline.decimateAW=function(e,t,n,r){var a=(t-e.start)/e.step,i=(n-e.start)/e.step;return NationalInstruments.HtmlVI.DataPipeline.decimate1D(e,a,i,r)};var e=function(e,t,n,r){for(var a=-1/0,i=-1,o=1/0,s=-1,l=2*t;l<2*n;l+=2)e[l+1]<o&&(s=e[l],o=e[l+1]),e[l+1]>a&&(i=e[l],a=e[l+1]);-1!==i&&(i===s?(r.push(s),r.push(o)):i<s?(r.push(i),r.push(a),r.push(s),r.push(o)):(r.push(s),r.push(o),r.push(i),r.push(a)))},t=function(e,t,n,r){var a,i,o=r.length;0===o?(r.push(Math.floor(e)),r.push(Math.floor(e)+1)):2===o?(r[0]>0&&r[0]--,r[1]<n&&r[1]++):(a=r[0],i=r[o-1],a>0&&(r.unshift(a-1),r.unshift(a-1)),i<n&&(r.push(i+1),r.push(i+1)))};function n(e,t,n,r,a,i,o){var s=n+r*a;i[s]||(o.push(e[t]),o.push(e[t+1]),i[s]=!0)}NationalInstruments.HtmlVI.DataPipeline.decimate1DLog=function(n,r,a,i){var o=[],s=[],l=n.datapoints.points;!function(e,n,r,a,i){var o,s,l,u,h,p=e.datapoints.points.length/2,c=e.xaxis.options.transform,d=e.xaxis.options.inverseTransform;if(s=c(n),0!=(o=((l=c(r))-s)/a)&&0!==p){for(var f=o>0?function(e,t){return e<t}:function(e,t){return e>t},y=s;f(y,l+o);y+=o)u=d(y),(h=d(y+o))<=0||u>=p||(u<0&&(u=0),h>p&&(h=p),(u=Math.ceil(u))>(h=Math.floor(h))||(i.push(u),i.push(h)));t(n,r,p,i)}}(n,r,a,i,o);for(var u=0;u<o.length;u+=2)e(l,o[u],o[u+1]+1,s);return s},NationalInstruments.HtmlVI.DataPipeline.decimate1D=function(e,t,n,r){var a,i=0,o=0,s=r/(n-t),l=e.datapoints.points,u=[],h=!0,p=-1/0,c=-1,d=1/0,f=-1;if(e.xaxis&&"log"===e.xaxis.options.mode)return NationalInstruments.HtmlVI.DataPipeline.decimate1DLog(e,t,n,r);var y,g,v,m=Math.min(Math.max(0,Math.floor(t)),l.length/2),b=n>0?Math.min(l.length/2,Math.floor(n+2)):0,_=function(){f===c?(u[o]=f,u[o+1]=d,o+=2):(f<c?(u[o]=f,u[o+1]=d,u[o+2]=c,u[o+3]=p):(u[o]=c,u[o+1]=p,u[o+2]=f,u[o+3]=d),o+=4)};for(r>b-m&&(s=1),a=2*m;a<2*b;a+=2){if(h&&(p=-1/0,c=-1,d=1/0,f=-1,h=!1),isNaN(l[a+1])){if(a>1&&isNaN(l[a-1])&&o>1)continue;f=c=l[a],d=p=l[a+1]}l[a+1]<d&&(f=l[a],d=l[a+1]),l[a+1]>p&&(c=l[a],p=l[a+1]),(Math.floor(i)!==Math.floor(i+s)||(g=void 0,v=void 0,g=(y=a+1)>2&&isNaN(l[y-2]),v=y<l.length-3&&isNaN(l[y+2]),g||v))&&(_(),h=!0),i+=s}return h||_(),u},NationalInstruments.HtmlVI.DataPipeline.decimatePoints=function(e,t,r,a,i,o,s){if(null==s||null==o||null==i||null==a||null==r||null==t)return e.datapoints.points;if(t>r||i>o)return[];if(e.xaxis&&"log"===e.xaxis.options.mode||e.yaxis&&"log"===e.yaxis.options.mode)return NationalInstruments.HtmlVI.DataPipeline.decimatePointsLog(e,t,r,a,i,o,s);var l,u,h=(r-t)/a,p=(o-i)/s,c=e.datapoints.points,d=[];for(l=new Array(Math.ceil(a)*Math.ceil(s)),u=0;u<c.length;u+=2)c[u]<t||c[u+1]<i||c[u]>r||c[u+1]>o||n(c,u,c[u]===t?0:Math.ceil((c[u]-t)/h-1),c[u+1]===i?0:Math.ceil((c[u+1]-i)/p-1),a,l,d);return d},NationalInstruments.HtmlVI.DataPipeline.decimatePointsLog=function(e,t,r,a,i,o,s){var l,u,h,p,c=e.datapoints.points,d=[],f=e.xaxis.options.transform||function(e){return e},y=e.yaxis.options.transform||function(e){return e},g=f(t),v=y(i),m=(f(r)-g)/a,b=(y(o)-v)/s;for(l=new Array(Math.ceil(a)*Math.ceil(s)),u=0;u<c.length;u+=2)c[u]<t||c[u+1]<i||c[u]>r||c[u+1]>o||(h=f(c[u]),p=y(c[u+1]),n(c,u,h===g?0:Math.ceil((h-g)/m-1),p===v?0:Math.ceil((p-v)/b-1),a,l,d));return d},NationalInstruments.HtmlVI.DataPipeline.decimateLinesXY=function(e,t,n,a,i,o,s){if(null==s||null==o||null==i||null==a||null==n||null==t)return e.datapoints.points;if(t>n||i>o)return[];if(e.xaxis&&"log"===e.xaxis.options.mode||e.yaxis&&"log"===e.yaxis.options.mode)return e.datapoints.points;if(e.datapoints.points<=4)return e.datapoints.points;var l,u,h,p,c,d,f,y,g,v,m,b=(n-t)/a,_=(o-i)/s,O=e.datapoints.points,x=[];for((O[0]<t||O[0]<i||O[1]>n||O[1]>o)&&!r(O[0],O[1],O[2],O[3],t,n,i,o)&&(O[2]<t||O[3]<i||O[2]>n||O[3]>o)||(x.push(O[0]),x.push(O[1])),h=O[0]===t?0:Math.ceil((O[0]-t)/b-1),p=O[1]===i?0:Math.ceil((O[1]-i)/_-1),c=O[0],d=O[1],m=2;m<O.length-2;m+=2)f=O[m],y=O[m+1],g=O[m+2],v=O[m+3],f<t||y<i||f>n||y>o?((c<t||d<i||c>n||d>o)&&(g<t||v<i||g>n||v>o)&&!r(c,d,f,y,t,n,i,o)&&!r(f,y,g,v,t,n,i,o)||(x.push(f),x.push(y)),c=f,d=y,h=f===t?0:Math.ceil((f-t)/b-1),p=y===i?0:Math.ceil((y-i)/_-1)):(l=f===t?0:Math.ceil((f-t)/b-1),p===(u=y===i?0:Math.ceil((y-i)/_-1))&&h===l||(x.push(f),x.push(y),h=l,p=u,c=f,d=y));return x.push(O[O.length-2]),x.push(O[O.length-1]),x};var r=function(e,t,n,r,a,i,o,s){return e<a&&n>a||e>a&&n<a||e<i&&n>i||e>i&&n<i||t<o&&r>o||t>o&&r<o||t<s&&r>s||t>s&&r<s};"function"!=typeof ArrayBuffer.isView&&(ArrayBuffer.isView=function(e){var t=Object.prototype.toString.call(e);return-1!==["[object Int8Array]","[object Uint8Array]","[object Uint8ClampedArray]","[object Int16Array]","[object Uint16Array]","[object Int32Array]","[object Uint32Array]","[object Float32Array]","[object Float64Array]","[object DataView]"].indexOf(t)});var a=Object.freeze({niAnalogWaveform:"niAnalogWaveform",niAnalogWaveformArray:"niAnalogWaveformArray",XYClusterOfArrays:"XYClusterOfArrays",XYArrayOfClusters:"XYArrayOfClusters",XYArrayOfClusterOfArrays:"XYArrayOfClusterOfArrays",XYArrayOfArrayOfClusters:"XYArrayOfArrayOfClusters",XYArrayOfClusterOfArrayOfPoint:"XYArrayOfClusterOfArrayOfPoint",oneDimensionNumericArray:"1DNumericArray",twoDimensionsNumericArray:"2DNumericArray",oneDimensionComplexArray:"1DComplexArray",twoDimensionsComplexArray:"2DComplexArray",numeric:"numeric",clusterOfNumerics:"clusterOfNumerics",arrayOfClusterOfNumerics:"arrayOfClusterOfNumerics",historyBuffer:"HistoryBuffer",categoryData:"categoryData",categoryArray:"categoryArray",empty:"empty",unknown:"unknown"});function i(e){return e.getName()===NITypeNames.CLUSTER&&2===e.getFields().length&&2===e.getSubtype().length&&e.getSubtype()[0].getName()===NITypeNames.ARRAY&&e.getSubtype()[1].getName()===NITypeNames.ARRAY}function o(e){return e.getName()===NITypeNames.CLUSTER&&2===e.getFields().length&&2===e.getSubtype().length&&e.getSubtype().every(function(e){return e.isInteger()||e.isFloat()||e.isTimeStamp()})}function s(e){return e.getName()===NITypeNames.CLUSTER&&e.getSubtype().every(function(e){return e.isInteger()||e.isFloat()})}NationalInstruments.HtmlVI.DataPipeline.DataTypesEnum=a,NationalInstruments.HtmlVI.DataPipeline.inferDataTypeFromNIType=function(e){return e instanceof NIType?e.getName()===NITypeNames.ANALOGWAVEFORM?a.niAnalogWaveform:e.getName()===NITypeNames.ARRAY&&e.getSubtype().getName()===NITypeNames.ANALOGWAVEFORM?a.niAnalogWaveformArray:i(e)?a.XYClusterOfArrays:e.getName()===NITypeNames.ARRAY&&1===e.getRank()&&o(e.getSubtype())?a.XYArrayOfClusters:e.getName()===NITypeNames.ARRAY&&i(e.getSubtype())?a.XYArrayOfClusterOfArrays:e.getName()===NITypeNames.ARRAY&&function(e){return e.getName()===NITypeNames.CLUSTER&&1===e.getFields().length&&e.getSubtype()[0].getName()===NITypeNames.ARRAY&&o(e.getSubtype()[0].getSubtype())}(e.getSubtype())?a.XYArrayOfClusterOfArrayOfPoint:e.getName()===NITypeNames.ARRAY&&2===e.getRank()&&o(e.getSubtype())?a.XYArrayOfArrayOfClusters:e.getName()===NITypeNames.ARRAY&&1===e.getRank()&&(e.getSubtype().isInteger()||e.getSubtype().isFloat())?a.oneDimensionNumericArray:e.getName()===NITypeNames.ARRAY&&2===e.getRank()&&(e.getSubtype().isInteger()||e.getSubtype().isFloat())?a.twoDimensionsNumericArray:e.getName()===NITypeNames.ARRAY&&1===e.getRank()&&e.getSubtype().isComplex()?a.oneDimensionComplexArray:e.getName()===NITypeNames.ARRAY&&2===e.getRank()&&e.getSubtype().isComplex()?a.twoDimensionsComplexArray:e.isInteger()||e.isFloat()?a.numeric:s(e)?a.clusterOfNumerics:e.getName()===NITypeNames.ARRAY&&s(e.getSubtype())?a.arrayOfClusterOfNumerics:a.unknown:a.unknown}}(),function(){var e=NationalInstruments.HtmlVI.DataPipeline,t=NationalInstruments.HtmlVI.DataPipeline.DataTypesEnum;NationalInstruments.HtmlVI.DataPipeline.TypedHistoryBuffer=function(){HistoryBuffer.apply(this,arguments),this.niType=null,this.valueType=t.unknown};var n=NationalInstruments.HtmlVI.DataPipeline.TypedHistoryBuffer;n.prototype=new HistoryBuffer(arguments),n.prototype.setNIType=function(n){var r;switch(this.niType=n,this.valueType=e.inferDataTypeFromNIType(this.niType),this.clear(),this.valueType){case t.numeric:case t.oneDimensionNumericArray:this.setType("numeric"),this.setWidth(1);break;case t.clusterOfNumerics:if(this.setType("numeric"),0===(r=this.niType.getFields().length))return;this.setWidth(r);break;case t.arrayOfClusterOfNumerics:case t.XYArrayOfClusters:if(0===(r=this.niType.getSubtype().getFields().length))return;this.setWidth(r);break;case t.niAnalogWaveform:case t.niAnalogWaveformArray:this.setType("analogWaveform"),this.setWidth(1)}},n.prototype.pushTypedData=function(e){var n,r,a,i,o;switch(this.valueType){case t.numeric:this.push(e);break;case t.oneDimensionNumericArray:this.appendArray(e);break;case t.niAnalogWaveform:this.push(e);break;case t.niAnalogWaveformArray:if(0===(o=e.length))return;this.setWidth(e.length),this.push(e);break;case t.twoDimensionsNumericArray:if(0===(o=e[0].length))return;for(this.setWidth(o),n=0;n<e.length;n++)this.push(e[n]);break;case t.clusterOfNumerics:for(a=[],i=Object.keys(e),n=0;n<i.length;n++)a[n]=e[i[n]];this.push(a);break;case t.arrayOfClusterOfNumerics:case t.XYArrayOfClusters:for(r=0;r<e.length;r++){for(a=[],i=Object.keys(e[r]),n=0;n<i.length;n++)a[n]=e[r][i[n]];this.push(a)}}}}();var _typeof="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol&&e!==Symbol.prototype?"symbol":typeof e};!function(){NationalInstruments.HtmlVI.DataPipeline.GraphDataPipeline=function(){};var e=NationalInstruments.HtmlVI.DataPipeline.DataTypesEnum,t=NationalInstruments.HtmlVI.DataPipeline.GraphDataPipeline,n=window.NIComplex||NationalInstruments.HtmlVI.NIComplex,r=window.NIAnalogWaveform||NationalInstruments.HtmlVI.NIAnalogWaveform,a=window.NITimestamp||NationalInstruments.HtmlVI.NITimestamp,i=t.prototype;i.toFlot=function(e,t,n){return O(e,t,n)};var o=function(e){if("string"!=typeof e)return!1;var t=new a(e);return!isNaN(t.seconds)&&!isNaN(t.fractions)},s=function(e){return new a(e).valueOf()},l=function(e){return e},u=function(e){return!Array.isArray(e)&&"object"===(void 0===e?"undefined":_typeof(e))&&Array.isArray(e.Y)},h=function(e){return Array.isArray(e)&&u(function(e){var t;for(t=0;t<e.length;t++)if(!Array.isArray(e[t])&&"object"===_typeof(e[t])&&Array.isArray(e[t].Y))return e[t]}(e))},p=function(e){return!Array.isArray(e)&&"object"===(void 0===e?"undefined":_typeof(e))&&2===Object.keys(e).length&&Object.keys(e).every(function(t){return Array.isArray(e[t])})},c=function(e){return Array.isArray(e)&&!Array.isArray(e[0])&&"object"===_typeof(e[0])&&2===Object.keys(e[0]).length&&("number"==typeof e[0][Object.keys(e[0])[0]]||o(e[0][Object.keys(e[0])[0]]))},d=function(e){return Array.isArray(e)&&c(function(e){var t;for(t=0;t<e.length;t++)if(Array.isArray(e[t])&&e[t].length>0)return e[t]}(e))},f=function(e){return Array.isArray(e)&&function(e){return!Array.isArray(e)&&"object"===(void 0===e?"undefined":_typeof(e))&&1===Object.keys(e).length&&c(e[Object.keys(e)[0]])}(e[0])},y=function(e){return Array.isArray(e)&&Array.isArray(e[0])&&2===e[0].length&&"string"==typeof e[0][0]&&"number"==typeof e[0][1]},g=function(t){return u(t)?e.niAnalogWaveform:h(t)?e.niAnalogWaveformArray:y(t)?e.categoryData:(r=t,Array.isArray(r)&&y(r[0])?e.categoryArray:p(t)?e.XYClusterOfArrays:c(t)?e.XYArrayOfClusters:"HistoryBuffer"===t.valueType?e.historyBuffer:Array.isArray(t)||ArrayBuffer.isView(t)?0===t.length?e.empty:"number"==typeof t[0]?e.oneDimensionNumericArray:function(e){return Array.isArray(e)&&p(e[0])}(t)?e.XYArrayOfClusterOfArrays:d(t)?e.XYArrayOfArrayOfClusters:f(t)?e.XYArrayOfClusterOfArrayOfPoint:function(e){return Array.isArray(e)&&("string"==typeof e[0]||e[0]instanceof n)}(t)?e.oneDimensionComplexArray:function(e){return Array.isArray(e)&&Array.isArray(e[0])&&("string"==typeof e[0][0]||e[0][0]instanceof n)}(t)?e.twoDimensionsComplexArray:Array.isArray(t[0])||ArrayBuffer.isView(t[0])?e.twoDimensionsNumericArray:e.unknown:e.unknown);var r};i.inferDataType=g;var v=function(e){return{flatdata:!0,data:e.Y,start:e.t0.valueOf(),step:e.dt,decimate:NationalInstruments.HtmlVI.DataPipeline.decimateAW,decimatePoints:NationalInstruments.HtmlVI.DataPipeline.decimatePoints}},m=function(e){for(var t=[],n=Object.keys(e),r=e[n[0]],a=e[n[1]],i=r.length>0&&o(r[0])?s:l,u=a.length>0&&o(a[0])?s:l,h=Math.min(r.length,a.length),p=0;p<h;p++)t.push([i(r[p]),u(a[p])]);return{data:t,decimate:NationalInstruments.HtmlVI.DataPipeline.decimateLinesXY,decimatePoints:NationalInstruments.HtmlVI.DataPipeline.decimatePoints}},b=function(e){for(var t=[],n=Object.keys(e[0]||{}),r=e.length>0&&o(e[0][n[0]])?s:l,a=e.length>0&&o(e[0][n[1]])?s:l,i=0;i<e.length;i++)t.push([r(e[i][n[0]]),a(e[i][n[1]])]);return{data:t,decimate:NationalInstruments.HtmlVI.DataPipeline.decimateLinesXY,decimatePoints:NationalInstruments.HtmlVI.DataPipeline.decimatePoints}},_=function(e){return e.map(function(e){return function(e){for(var t=[],n=e[Object.keys(e)[0]],r=n.length,a=n[0],i=Object.keys(a),u=r>0&&o(a[i[0]])?s:l,h=r>0&&o(a[i[1]])?s:l,p=0;p<r;p++){var c=n[p],d=Object.keys(c);t.push([u(c[d[0]]),h(c[d[1]])])}return{data:t,decimate:NationalInstruments.HtmlVI.DataPipeline.decimateLinesXY,decimatePoints:NationalInstruments.HtmlVI.DataPipeline.decimatePoints}}(e)})},O=function(t,a,i){var o,s,l,u,h=[];switch(i&&i!==e.unknown?i:g(a)){case e.oneDimensionNumericArray:return[{flatdata:!0,data:a,start:0,step:1,decimate:NationalInstruments.HtmlVI.DataPipeline.decimate1D,decimatePoints:NationalInstruments.HtmlVI.DataPipeline.decimatePoints}];case e.twoDimensionsNumericArray:for(o=[],u=0;u<a.length;u++)h=[],o.push({flatdata:!0,start:0,step:1,data:a[u],decimate:NationalInstruments.HtmlVI.DataPipeline.decimate1D,decimatePoints:NationalInstruments.HtmlVI.DataPipeline.decimatePoints});return o;case e.niAnalogWaveform:return"string"==typeof(s=a instanceof r?a:new r(a)).channelName&&s.channelName.length>0&&t.updatePlotName(0,s.channelName,!0),[v(s)];case e.niAnalogWaveformArray:for(o=[],u=0;u<a.length;u++)"string"==typeof(s=a[u]instanceof r?a[u]:new r(a[u])).channelName&&s.channelName.length>0&&t.updatePlotName(u,s.channelName,!0),o.push(v(s));return o;case e.XYClusterOfArrays:return[m(a)];case e.XYArrayOfClusterOfArrays:return a.map(function(e){return m(e)});case e.XYArrayOfClusters:return[b(a)];case e.XYArrayOfArrayOfClusters:return function(e){return e.map(function(e){return b(e)})}(a);case e.XYArrayOfClusterOfArrayOfPoint:return _(a);case e.oneDimensionComplexArray:for(l=0;l<a.length;l++)h.push(n.prototype.parseFromString(a[l]));return[h];case e.twoDimensionsComplexArray:for(o=[],u=0;u<a.length;u++){for(h=[],l=0;l<a[u].length;l++)h.push(n.prototype.parseFromString(a[u][l]));o.push(h)}return o;case e.categoryData:return[a];case e.categoryArray:return a}return o||[h]}}(),function(){NationalInstruments.HtmlVI.DataPipeline.ChartDataPipeline=function(){};var e=NationalInstruments.HtmlVI.DataPipeline.GraphDataPipeline,t=NationalInstruments.HtmlVI.DataPipeline.ChartDataPipeline.prototype;function n(e,t){var n=t.length;if(0!==n){e.setWidth(n);for(var r=0;r<t[0].length;r++){for(var a=[],i=0;i<n;i++)a[i]=t[i][r];e.push(a)}}}t.loadValueIntoHistoryBuffer=function(t,r){switch(e.prototype.inferDataType(t)){case"1DNumericArray":r.appendArray(t);break;case"2DNumericArray":n(r,t);break;case"HistoryBuffer":n(r,t.data)}},t.toFlot=function(e,t,n){for(var r=[],a=e.historyBuffer.width,i=0;i<a;i++)r[i]=[];return r}}(),function(){var e=NationalInstruments.Globals.jQuery,t=window.NINumericFormatters;var n=function(e){return function(n){var r,a,i=t.prototype.toSiNotation(n,e.decimals);return isNaN(Number(i))?(r=Number(i.slice(0,i.length-1)),a=i.slice(i.length-1)):(r=Number(i),a=""),t.prototype.toDecPrecisionNotation(r,Math.min(e.decimals,21))+a}},r=function(e){return function(n){return t.prototype.toSiNotation(n,e.decimals)}},a=function(e,n,r,a){var o,s,h,p=n.tickDecimals;if(n.tickDecimals!==n.options.tickDecimals&&(s=u(n.min),o=0!==n.min?Math.floor(Math.log(Math.abs(n.min))*Math.LOG10E):0,h=u(n.max,o),p=0!==e?Math.abs(a.computeValuePrecision(s,h,n.direction,n.options.ticks)):0),r){var c=Math.abs(r)<=3?Math.abs(r)+1:l(e,r,n.max,n.min);if(c>p)return t.prototype.toSiNotation(e,i(e,c))}return t.prototype.toSiNotation(e,i(e,p))},i=function(e,t){var n=Math.floor(Math.log(Math.abs(e))*Math.LOG10E);return n<-25&&(t+=Math.abs(-25-n)),t},o=function(e){return function(n){return t.prototype.toDecPrecisionNotation(n,Math.min(e,21))}},s=function(e,n){return function(r){var a=n?r:h(Math.floor,r,e);return t.prototype.toDecFixedNotation(a,e)}},l=function(e,t,n,r){var a=Math.log(Math.abs(n))*Math.LOG10E,i=0!==r?Math.log(Math.abs(r))*Math.LOG10E:0,o=Math.floor(Math.abs(a-i)),s=0!==e?Math.log(Math.abs(e))*Math.LOG10E:0,l=Math.abs(s+t);return o>3?Math.ceil(3*l/o):Math.ceil(l)},u=function(e,t){var n=0!==e?Math.floor(Math.log(Math.abs(e))*Math.LOG10E):0,r=Math.pow(10,n),a=e;return t>0?a/=Math.pow(10,3*Math.floor(t/3)):a*=Math.pow(10,n%3)/r,a},h=function(e,t,n){var r=Math.pow(10,n),a=t*r;return(a=e(a))/r},p=function(e,t){return t=t?""+t:"0",1===(e=""+e).length?t+e:e},c=function(e,t,n,r){for(e=""+e,t=t?""+t:"0";e.length<n;)!0===r?e+=t:e=t+e;return e};function d(){return window.NIEmbeddedBrowser&&window.NIEmbeddedBrowser.formatLanguage?window.NIEmbeddedBrowser.formatLanguage:navigator.locale||"en-US"}function f(e,t){var n=navigator.language||navigator.browserLanguage||navigator.languages[0],r=function(e){var t={};return null==e?t:(e.indexOf("#d")>=0?(t.year="numeric",t.month="numeric",t.day="numeric"):(e.indexOf("yyyy")>=0?t.year="numeric":e.indexOf("yy")>=0&&(t.year="2-digit"),t.month="numeric",t.day="numeric"),e.indexOf("#T")>=0?(t.hour="numeric",t.minute="numeric",t.second="numeric"):(t.hour="2-digit",t.minute="2-digit",e.indexOf("ss")>=0&&(t.second="2-digit"),t.hour12=e.indexOf("hh")>=0),t)}(t),a=function(e,t,n,r){var a=t.indexOf("yy")>=0||t.indexOf("#d")>=0;if(!(a||t.indexOf("MM")>=0))return"";if(t.indexOf("#d")>=0)return Intl.DateTimeFormat(r,{year:"numeric",month:"numeric",day:"numeric"}).format(e);var i=Intl.DateTimeFormat(r,n).formatToParts(e),o=i.map(function(e){var t=e.type;return e.value,t}),s=o.indexOf("day"),l=o.indexOf("month"),u=i[(l+s)/2].value,h=p(i[s].value),d=p(i[l].value),f=a?i[o.indexOf("year")].value:"";if(a){var y=t.indexOf("yyyy")>=0?4:2;f=c(f,"0",y)}return t.indexOf("dd")<t.indexOf("MM")?h+u+d+(a?u+f:""):d+u+h+(a?u+f:"")}(e,t,r,n),i=function(e,t,n,r){if(!(t.indexOf("hh")>=0||t.indexOf("HH")>=0||t.indexOf("#T")>=0))return"";var a=g(e.getMilliseconds(),t);if(t.indexOf("#T")>=0){var i=Intl.DateTimeFormat(r,{hour:"numeric",minute:"numeric",second:"numeric"}).format(e);if(""!==a){var o=new RegExp("[0-9](?!.*[0-9])","g");o.test(i),i=[i.slice(0,o.lastIndex),"."+a,i.slice(o.lastIndex)].join("")}return i}var s=Intl.DateTimeFormat(r,n).formatToParts(e),l=s.map(function(e){var t=e.type;return e.value,t.toLowerCase()}),u=l.indexOf("hour"),h=l.indexOf("minute"),c=s[(u+h)/2].value,d=p(s[u].value),f=p(s[h].value),y=t.indexOf("ss")>=0,v=y?p(s[l.indexOf("second")].value):"",m=!0===n.hour12?s[l.indexOf("dayperiod")].value:"";return d+c+f+(y?c+v:"")+(y&&a.length>0?"."+a:"")+(""!==m?" "+m:"")}(e,t,r,n);return i+(""!==a&&""!==i?"<br>":"")+a}function y(e,t,n){var r=t?"."+c(n,"0",3):"",a=Globalize.format(e,"T",d());return a=function(e,t){var n=e.split(" ");if(n.length>1){var r=n[n.length-1];return n.splice(n.length-1,1),n.join(" ")+t+" "+r}return e+t}(a,r)+"<br>"+Globalize.format(e,"d",d())}var g=function(e,t,n){var r=t.indexOf(".S"),a=new RegExp(".S+","g"),i=n?3:0,o=r>0?a.exec(t)[0].length-1:i,s=c(e,"0",3);return s=c(s,"0",o,!0),s=o>0?s.substring(0,o):""};var v=function(t){return function(n,r,a,i){var o=e.plot.dateGenerator(n,r.options);return function(e,t,n){var r="",a=e.valueOf()-(void 0===t.valueOfFirstData?0:t.valueOfFirstData);a<0&&(a=-a,r+="-");var i=Math.floor(a/1e3),o=Math.floor(a%1e3),s=i%60,l=Math.floor(i/60),u=l%60,h=Math.floor(l/60),c=h%24,d=Math.floor(h/24),f=""===n||n.indexOf("ss")>=0;if(d&&""===n&&(r+=d+"."),r+=p(c)+":",r+=p(u),f){r+=":"+p(s);var y="millisecond"===t.tickSize[1]||"microsecond"===t.tickSize[1],v=g(o,n,y);r+=y||v.length>0?"."+v:""}return r}(o.date||o.getDate(),r,t)}},m=function(t){return function(n,r,a,i){var o=e.plot.dateGenerator(n,r.options);return function(t,n,r,a){var i=t.valueOf(),o=Math.floor(i%1e3);o<0&&(o=1e3+o),t<-85778644032e5&&(t=-85778644032e5);var s,l=e.plot.makeUtcWrapper(new Date(t.valueOf()+a)).date,u="millisecond"===n.tickSize[1]||"microsecond"===n.tickSize[1];if(""!==r)try{s=f(l,r)}catch(e){s=y(l,u,o)}else s=y(l,u,o);return s}(o.date||o.getDate(),r,t,r.options.timeEpoch)}};t.parseTickFormatterType=function(e){var t,n,r,a={type:"default"},i=a;if(0===e.indexOf("LVSI")){t=5;var o=e.slice(t);-1===o.indexOf("G")&&-1===o.indexOf("N")?i=-1!==o.indexOf("#")&&o.lastIndexOf("#")===o.length-1?{type:"si",N:!1,G:!1,decimals:n=o.lastIndexOf("#")-o.indexOf("#")+1}:"0"===o?{type:"si",N:!1,G:!1,decimals:0}:{type:"si",N:!1,G:!1,decimals:null}:(n=parseInt(o.slice(1)),i={type:"si",N:0===o.indexOf("N"),G:r=0===o.indexOf("G"),decimals:n})}else if(0===e.indexOf("LVRelativeSeconds")){t=18;var s=e.slice(t);-1===s.indexOf("G")&&-1===s.indexOf("N")?i=-1!==s.lastIndexOf("#")&&s.lastIndexOf("#")===s.length-1?{type:"dec",N:!1,G:!1,decimals:n=s.lastIndexOf("#")-s.indexOf("#")+1}:"0"===s?{type:"dec",N:!1,G:!1,decimals:0}:a:(n=parseInt(s.slice(1)),i={type:"dec",N:0===s.indexOf("N"),G:r=0===s.indexOf("G"),decimals:r?Math.min(n,21):n})}else 0===e.indexOf("LVTime")?i={type:"absTime",timeFormat:e.substring(7)}:0===e.indexOf("LVRelativeTime")&&(i={type:"relTime",timeFormat:e.substring(15)});return i},t.getTickFormatter=function(e){return"si"===e.type&&e.G?n(e):"si"===e.type&&e.N?r(e):"si"===e.type&&"number"==typeof e.decimals?r(e):"si"===e.type&&null===e.decimals?a:"dec"===e.type&&e.G?o(e.decimals):"dec"===e.type&&e.N?s(e.decimals):"dec"===e.type&&0===e.decimals?s(0,!0):"dec"===e.type&&e.decimals>=1?s(e.decimals):"absTime"===e.type?m(e.timeFormat):"relTime"===e.type?v(e.timeFormat):null},t.getTickGenerator=function(t){return 0===t.indexOf("LVRelativeTime")?function(t,n){return void 0===t.valueOfFirstData&&function(e,t){var n=e.getData(),r=n.findIndex(function(e){return e.length>0||e.datapoints.points.length>0});if(n.length>0&&r>=0){var a,i,o,s=n[r].datapoints;for(o=0!==s.points.length?n[r].xaxis===t||n[r].yaxis===t?"x"===t.direction?s.points[0]:s.points[1]:t.max:t.min,a=1;a<n.length;a++)s=n[a].datapoints,n[a].xaxis!==t&&n[a].yaxis!==t||(i="x"===t.direction?s.points[0]:s.points[1],o>i&&(o=i));t.valueOfFirstData=1e3*o}}(n,t),e.plot.dateTickGenerator(t)}:0===t.indexOf("LVTime")?function(t){return e.plot.dateTickGenerator(t)}:null}}();var _createClass=function(){function e(e,t){for(var n=0;n<t.length;n++){var r=t[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(e,r.key,r)}}return function(t,n,r){return n&&e(t.prototype,n),r&&e(t,r),t}}(),_get=function e(t,n,r){null===t&&(t=Function.prototype);var a=Object.getOwnPropertyDescriptor(t,n);if(void 0===a){var i=Object.getPrototypeOf(t);return null===i?void 0:e(i,n,r)}if("value"in a)return a.value;var o=a.get;return void 0!==o?o.call(r):void 0};function _asyncToGenerator(e){return function(){var t=e.apply(this,arguments);return new Promise(function(e,n){return function r(a,i){try{var o=t[a](i),s=o.value}catch(e){return void n(e)}if(!o.done)return Promise.resolve(s).then(function(e){r("next",e)},function(e){r("throw",e)});e(s)}("next")})}}function _classCallCheck(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}function _possibleConstructorReturn(e,t){if(!e)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return!t||"object"!=typeof t&&"function"!=typeof t?e:t}function _inherits(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Super expression must either be null or a function, not "+typeof t);e.prototype=Object.create(t&&t.prototype,{constructor:{value:e,enumerable:!1,writable:!0,configurable:!0}}),t&&(Object.setPrototypeOf?Object.setPrototypeOf(e,t):e.__proto__=t)}function _classCallCheck(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}function _possibleConstructorReturn(e,t){if(!e)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return!t||"object"!=typeof t&&"function"!=typeof t?e:t}function _inherits(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Super expression must either be null or a function, not "+typeof t);e.prototype=Object.create(t&&t.prototype,{constructor:{value:e,enumerable:!1,writable:!0,configurable:!0}}),t&&(Object.setPrototypeOf?Object.setPrototypeOf(e,t):e.__proto__=t)}!function(){var e=NationalInstruments.Globals.jQuery,t=NationalInstruments.HtmlVI.NISupport,n=NationalInstruments.HtmlVI.DataPipeline.GraphDataPipeline,r=!0,a=!1,i=0,o=["rgba(123, 22, 26, 1)","rgba(0, 142, 228, 1)","rgba(226, 182, 131, 1)","rgba(183, 172, 31, 1)","rgba(174, 220, 239, 1)","rgba(160, 139, 176, 1)","rgba(127, 127, 127, 1)","rgba(60, 7, 38, 1)"],s=Promise.resolve(!0),l=function(l){function u(){return _classCallCheck(this,u),_possibleConstructorReturn(this,(u.__proto__||Object.getPrototypeOf(u)).apply(this,arguments))}return _inherits(u,l),_createClass(u,[{key:"getSettings",value:function(){return this.getSettingsWorkaround()}},{key:"getSettingsWorkaround",value:function(){var e=!this.disabled&&!this.disableZoom,t=!this.disabled&&!this.disablePan,n=!this.disabled&&!this.disableRecenter;return{series:{lines:{show:!0,lineWidth:1},shadowSize:0,points:{lineWidth:1},stack:this.stacked,highlights:{show:!0,highlightColor:this.highlightColor,highlightLines:this.highlightLines,highlightPoints:this.highlightPoints,highlightBars:this.highlightBars,highlightLineWidth:this.highlightLineWidth,selectedIndexes:[],selectedRange:[]}},axisLabels:{show:!0},xaxes:[{}],yaxes:[{}],zoom:{interactive:e,active:e,enableTouch:e,trigger:null},pan:{interactive:t,active:t,enableTouch:t,mode:this.panMode,touchMode:this.touchPanMode},recenter:{interactive:n,enableTouch:n},propagateSupportedGesture:this.propagateSupportedGesture,selection:{mode:null},grid:{},colors:o}}},{key:"configureGraph",value:function(){var e,t=this.getSettings();for(""!==this.plotAreaMargin&&(t.grid.margin=JSON.parse(this.plotAreaMargin)),""!==this.highlightedIndexes&&t.series.highlights&&(t.series.highlights.selectedIndexes=JSON.parse(this.highlightedIndexes)),""!==this.highlightedRange&&t.series.highlights&&(t.series.highlights.selectedRange=JSON.parse(this.highlightedRange)),t.xaxes=[],t.yaxes=[],e=0;e<this.axes.length;e++){var n=this.axes[e].getViewConfig();n&&(!n.position||"left"!==n.position&&"right"!==n.position||t.yaxes.push(n),!n.position||"top"!==n.position&&"bottom"!==n.position||t.xaxes.push(n))}return this.graphTools&&(t.zoom.interactive=t.zoom.interactive&&this.graphTools.allowsScrollWheelZoom(),t.pan.interactive=t.pan.interactive&&this.graphTools.allowsPan(),t.selection.mode=this.disabled||"zoom"!==this.graphTools.mode?null:"smart"),Array.from(this.children).filter(function(e){return"function"==typeof e.getEntryInfo}).forEach(function(e){var n=e.getEntryInfo();"array"===n.valueType?(t[n.name]||(t[n.name]=[]),t[n.name].push(e.getViewConfig())):t[n.name]=e.getViewConfig()}),t}},{key:"requestUpdate",value:function(){this._hasRequestedUpdate||this._detaching||this._enqueueUpdateAsync()}},{key:"_enqueueUpdateAsync",value:function(){var e=_asyncToGenerator(regeneratorRuntime.mark(function e(){var t,n,r,a,i=this;return regeneratorRuntime.wrap(function(e){for(;;)switch(e.prev=e.next){case 0:return this._hasRequestedUpdate=!0,t=this._updatePromise,n=function(){},r=function(){},this._updatePromise=new Promise(function(e,t){n=e,r=t}),e.prev=5,e.next=8,t;case 8:e.next=12;break;case 10:e.prev=10,e.t0=e.catch(5);case 12:if(this._isAttached||this._detaching){e.next=16;break}return a=new Promise(function(e){i._attachedResolve=e}),e.next=16,a;case 16:try{this._performUpdate()}catch(e){r(e)}n();case 18:case"end":return e.stop()}},e,this,[[5,10]])}));return function(){return e.apply(this,arguments)}}()},{key:"_performUpdate",value:function(){try{var n=this.graphdiv;if(void 0===n)return;var r=this.createData(this.plots,this.convertToFlotFormat(this.parsedValue)),a=this.configureGraph();this.setClick(r,a),this.setHover(r,a),this.setGridStyle(this.gridEl,a),this.graph=e.plot(n,r,a),this._isInitialized||(this.attachLegends(),this.graph.getPlaceholder().bind("re-center",this.onRecenterPlot),this.dispatchEvent(new CustomEvent("ni-graph-created")),this._isInitialized=!0),this.dispatchEvent(new CustomEvent("ni-graph-updated"))}catch(e){throw t.log(e.message),new Error("Failed to create a flot chart")}finally{this._hasRequestedUpdate=!1}}},{key:"updateGraphConfig",value:function(){console.warn("A synchronous update was requested. Consider using requestUpdate instead"),this._performUpdate()}},{key:"onRecenterPlot",value:function(e){this.parentElement.axes.forEach(function(t){e.detail.axisTouched&&t.getFlotAxis()!==e.detail.axisTouched||t.resetOffset&&t.resetOffset()}),this.parentElement.updateCartesianAxesFromFlot()}},{key:"updateCartesianAxesFromFlot",value:function(){var e=this;this._isInitialized?this._syncAxesWithFlot():this.addEventListener("ni-graph-created",function(){e._syncAxesWithFlot()},{once:!0})}},{key:"_syncAxesWithFlot",value:function(){void 0!==this.graphdiv&&this.axes.forEach(function(e){e instanceof JQX.CartesianAxis&&e.syncWithFlot()})}},{key:"throttlePlotUpdates",value:function(e){(r=!e)&&a&&(this.requestUpdate(),a=!1)}},{key:"updateGraphConfigWhenPlotsUpdatesAreEnabled",value:function(){r?(this.requestUpdate(),a=!1):a=!0}},{key:"convertToFlotFormat",value:function(e){return n.prototype.toFlot(this,e,this.valueType)}},{key:"updatePlotName",value:function(e,t,n){n&&!this.metadataOverridesPlotNames||!t||this.plots[e]&&(this.plots[e].label=t)}},{key:"createData",value:function(e,t){var n=[];return t.forEach(function(t,r){var a=e[r];Array.isArray(t)&&(t={data:t}),a?(n[r]=a.getViewConfig(),n[r].data=a.show?t.data:[],n[r].flatdata=t.flatdata,n[r].start=t.start,n[r].step=t.step,n[r].decimate=!this.stacked&&t.decimate,n[r].decimatePoints=t.decimatePoints):n[r]=t},this),n}},{key:"nextPlotName",value:function(){var e,n,r=t.i18n("msg_defaultplotname"),a=-1;for(var i in this.childNodes)"ni-cartesian-plot"===this.childNodes[i].localName&&(n=this.childNodes[i],(e=parseInt(n.label.substring(r.length)))>a?a=e:a<0&&(a=0));return-1===a?r:r+" "+(a+1)}},{key:"setData",value:function(e){var t=this.graph;if(void 0!==t){var n=this.convertToFlotFormat(e);this.parsedValue=e,(t=this.graph).setData(this.createData(this.plots,n)),t.setupGrid(!0),t.draw(),n.length!==i&&(i=n.length,this.notifyPlotLegend("ni-plot-count-changed",{element:this,plotCount:n.length}))}else this.cachedData=e}},{key:"created",value:function(){_get(u.prototype.__proto__||Object.getPrototypeOf(u.prototype),"created",this).call(this),this.plots=[],this.axes=[],this.cachedData=null,this.plotLegend=null,this.cursorLegend=null,this.scaleLegend=null,this.graphTools=null,this.graphdiv=void 0,this.tooltip=void 0,this.tooltipHolder=void 0,this.parsedValue=null,this.addGraphItemListeners(),this._initializeForAsynchronousUpdate()}},{key:"_initializeForAsynchronousUpdate",value:function(){this._updatePromise=s,this._hasRequestedUpdate=!1,this._isInitialized=!1,this._isAttached=!1,this._detaching=!1,this._attachedResolve=void 0,this.requestUpdate()}},{key:"onResize",value:function(){var e=_asyncToGenerator(regeneratorRuntime.mark(function e(t){var n;return regeneratorRuntime.wrap(function(e){for(;;)switch(e.prev=e.next){case 0:if(!this.isVisibleElement(this)){e.next=12;break}if(void 0!==this.graph){e.next=6;break}return this._prepareForGraph(),this.requestUpdate(),e.next=6,this.updateCompleted;case 6:(n=this.graph).clearTextCache(),n.resize(),this.cachedData?(this.setData(this.cachedData),this.cachedData=null):(n.setupGrid(!0),n.draw()),e.next=13;break;case 12:this.detachChildElement();case 13:case"end":return e.stop()}},e,this)}));return function(t){return e.apply(this,arguments)}}()},{key:"isVisibleElement",value:function(e){for(;null!==e;){if("none"===getComputedStyle(e).display)return!1;e=e.parentElement}return!0}},{key:"_prepareForGraph",value:function(){if(this._isAttached=!0,this._attachedResolve&&(this._attachedResolve(),this._attachedResolve=void 0),this.isVisibleElement(this)){var n=document.createElement("div");n.style.width="100%",n.style.height="100%",n.className="webchart-drawing-layer",this.children.length>0?this.insertBefore(n,this.children[0]):this.appendChild(n);var r=document.createElement("div");r.style.width="0px",r.style.height="0px",r.style.position="relative",r.className="ni-graph-tooltip-base";var a=document.createElement("div");a.id="tooltip"+t.uniqueId(),a.className="ni-graph-tooltip",r.appendChild(a),this.appendChild(r),this.tooltip=a,this.tooltipHolder=r;var i=document.createElement("ni-grid-div");i.style.visibility="hidden",this.appendChild(i),this.gridEl=i,this.graphdiv=n,e(n).bind("plothover",this.hoverEventHandler.bind(this)),e(n).bind("plothovercleanup",function(){e(a).hide()})}}},{key:"attached",value:function(){_get(u.prototype.__proto__||Object.getPrototypeOf(u.prototype),"attached",this).call(this),this.parsedValue=this.value,this._detaching=!1,this.attachChildren(),this._prepareForGraph()}},{key:"detached",value:function(){_get(u.prototype.__proto__||Object.getPrototypeOf(u.prototype),"detached",this).call(this),this._detaching=!0,this.detachChildElement()}},{key:"detachChildElement",value:function(){void 0!==this.graph&&this.graph.destroy(),this.graph=void 0,void 0!==this.graphdiv&&this.removeChild(this.graphdiv),this.graphdiv=void 0,void 0!==this.tooltipHolder&&this.removeChild(this.tooltipHolder),this.tooltip=void 0,this.tooltipHolder=void 0,void 0!==this.gridEl&&this.removeChild(this.gridEl),this.gridEl=void 0,this._isInitialized=!1,this._isAttached=!1}},{key:"addGraphItemListeners",value:function(e){var t=this;t.addEventListener("ni-cartesian-plot-attached",function(e){e.target===t&&(t.plots=function(e,t,n){for(var r=e.getElementsByTagName("ni-cartesian-plot"),a=[],i=0;i<r.length;i++){var o=r[i];(t.find(function(e){return e===o})||o===n)&&a.push(o)}return a}(t,t.plots,e.detail.element),t.updateGraphConfigWhenPlotsUpdatesAreEnabled(),t.notifyPlotLegend("ni-cartesian-plot-attached",e.detail.element))}),t.addEventListener("ni-cartesian-plot-detached",function(e){var n;if(t.notifyPlotLegend("ni-cartesian-plot-detached",e.detail.element),e.target===t){for(n=0;n<t.plots.length;n++)if(t.plots[n]===e.detail.element){t.plots.splice(n,1);break}t.updateGraphConfigWhenPlotsUpdatesAreEnabled()}}),t.addEventListener("ni-cartesian-axis-attached",function(e){e.target===t&&(t.axes.push(e.detail.element),t.requestUpdate(),t.notifyScaleLegend("ni-cartesian-axis-attached",e.detail.element),t.notifyGraphTools("ni-cartesian-axis-attached",e.detail.element))}),t.addEventListener("ni-cartesian-axis-detached",function(e){var n;if(e.target===t){for(n=0;n<t.axes.length;n++)if(t.axes[n]===e.detail.element){t.axes.splice(n,1);break}t.requestUpdate(),t.notifyScaleLegend("ni-cartesian-axis-detached",e.detail.element)}}),t.addEventListener("ni-cursor-attached",function(e){e.target===t&&e.detail.element instanceof window.JQX.Cursor&&t.notifyCursorLegend("ni-cursor-attached",e.detail.element)}),t.addEventListener("ni-cursor-detached",function(e){e.target===t&&e.detail.element instanceof window.JQX.Cursor&&t.notifyCursorLegend("ni-cursor-detached",e.detail.element)}),t.addEventListener("ni-axis-changed",function(e){t.requestUpdate(),t.notifyScaleLegend("ni-axis-changed",e.detail.element),t.notifyGraphTools("ni-axis-changed",e.detail.element)}),t.addEventListener("ni-axis-reset",function(e){t.requestUpdate(),t.notifyScaleLegend("ni-axis-changed",e.detail.element),t.notifyGraphTools("ni-axis-reset")}),t.addEventListener("ni-cursor-changed",function(e){e.detail.element instanceof window.JQX.Cursor&&t.notifyCursorLegend("ni-cursor-changed",e.detail.element)}),t.addEventListener("ni-cartesian-plot-changed",function(e){t.updateGraphConfigWhenPlotsUpdatesAreEnabled(),t.notifyPlotLegend("ni-cartesian-plot-changed",e.detail.element)}),t.addEventListener("ni-cartesian-plot-renderer-changed",function(e){t.updateGraphConfigWhenPlotsUpdatesAreEnabled(),t.notifyPlotLegend("ni-cartesian-plot-renderer-changed",e.detail.originalSource)}),t.addEventListener("ni-cartesian-plot-renderer-attached",function(e){t.updateGraphConfigWhenPlotsUpdatesAreEnabled(),t.notifyPlotLegend("ni-cartesian-plot-renderer-attached",e.detail.originalSource)}),t.addEventListener("ni-cartesian-plot-renderer-detached",function(e){t.updateGraphConfigWhenPlotsUpdatesAreEnabled(),t.notifyPlotLegend("ni-cartesian-plot-renderer-detached",e.detail.originalSource)}),t.addEventListener("ni-graph-tools-changed",function(){t.requestUpdate()})}},{key:"registerPlotLegend",value:function(e){this.plotLegend=e,this.plotLegend.disabled=this.disabled}},{key:"notifyPlotLegend",value:function(e,t){var n;null!==this.plotLegend&&(n={bubbles:!1,cancelable:!0,detail:{element:this,originalSource:t}},this.plotLegend.dispatchEvent(new CustomEvent(e,n)))}},{key:"registerCursorLegend",value:function(e){var t=this;this.cursorLegend=e,Array.from(this.children).filter(function(e){return e instanceof JQX.Cursor}).forEach(function(e){t.notifyCursorLegend("ni-cursor-attached",e)}),this.cursorLegend.disabled=this.disabled}},{key:"notifyCursorLegend",value:function(e,t){if(null!==this.cursorLegend){var n={bubbles:!1,cancelable:!0,detail:{element:this,originalSource:t}};this.cursorLegend.dispatchEvent(new CustomEvent(e,n))}}},{key:"registerScaleLegend",value:function(e){var t;if(this.scaleLegend=e,this.axes.length>0)for(t=0;t<this.axes.length;t++)this.notifyScaleLegend("ni-cartesian-axis-attached",this.axes[t]);this.scaleLegend.disabled=this.disabled}},{key:"notifyScaleLegend",value:function(e,t){var n;null!==this.scaleLegend&&(n={bubbles:!1,cancelable:!0,detail:{element:this,originalSource:t}},this.scaleLegend.dispatchEvent(new CustomEvent(e,n)))}},{key:"registerGraphTools",value:function(t){var n,r=this;if(this.graphTools=t,this.requestUpdate(),e(this.graphdiv).on("plotselected",function(e,t){r.notifyGraphTools("ni-cartesian-graph-box-selected",{ranges:t})}),e(this.graphdiv).on("plotpan",function(e,t){r.notifyGraphTools("ni-cartesian-graph-interaction",{ranges:t})}),e(this.graphdiv).on("plotzoom",function(e,t){r.notifyGraphTools("ni-cartesian-graph-interaction",{ranges:t})}),this.graphTools.disabled=this.disabled,this.axes.length>0)for(n=0;n<this.axes.length;n++)this.notifyGraphTools("ni-cartesian-axis-attached",this.axes[n])}},{key:"notifyGraphTools",value:function(e,t){var n;this.graphTools&&(n={bubbles:!1,cancelable:!0,detail:{element:this,originalSource:t}},this.graphTools.dispatchEvent(new CustomEvent(e,n)))}},{key:"attachChildren",value:function(){for(var e=this.children,t={"NI-COLOR-SCALE":window.JQX.ColorScale,"NI-CARTESIAN-PLOT":window.JQX.CartesianPlot,"NI-CARTESIAN-AXIS":window.JQX.CartesianAxis},n=0;n<e.length;n++){var r=e[n];t[r.tagName]&&r instanceof t[r.tagName]&&r.isReady&&r.attachToGraph(this)}}},{key:"attachLegends",value:function(){for(var e=this,t=["ni-plot-legend".toUpperCase(),"ni-scale-legend".toUpperCase(),"ni-cursor-legend".toUpperCase(),"ni-graph-tools".toUpperCase()],n=this.parentElement.children,r=[],a=0;a<n.length;a++){var i=n[a];-1===t.indexOf(i.tagName)||i.graphRef!==this.graphRef&&i.graphRef!==this.niControlId||r.push(i)}r.forEach(function(t){t.isReady&&t.attachToGraph&&t.attachToGraph(e)})}},{key:"propertyChangedHandler",value:function(e,t,n){switch(_get(u.prototype.__proto__||Object.getPrototypeOf(u.prototype),"propertyChangedHandler",this).call(this,e,t,n),e){case"value":this.setData(this.value);break;case"disabled":this.requestUpdate(),null!==this.cursorLegend&&(this.cursorLegend.disabled=this.disabled),null!==this.graphTools&&(this.graphTools.disabled=this.disabled),null!==this.plotLegend&&(this.plotLegend.disabled=this.disabled),null!==this.scaleLegend&&(this.scaleLegend.disabled=this.disabled);break;default:this.requestUpdate()}}},{key:"format",value:function(){var e=arguments;return e[0].replace(/{(\d+)}/g,function(t,n){var r=parseInt(n)+1,a=e[r];return void 0!==a?a.toFixed(2).length<a.toExponential(2).length?a.toFixed(2):a.toExponential(2):t})}},{key:"setClick",value:function(e,t){for(var n=0;n<e.length;n++)if(e[n].clickable){t.grid=t.grid||{},t.grid.clickable=!0;break}}},{key:"setHover",value:function(t,n){var r,a=!1;for(r=0;r<t.length;r++)if(t[r].hoverable){a=!0;break}!0===a?(void 0===n.grid&&(n.grid={}),n.grid.hoverable=a):null!==this.tooltip&&e(this.tooltip).hide()}},{key:"hoverEventHandler",value:function(n,r,a){if(a&&this.plots[a.seriesIndex]){var i=a.datapoint[0],o=a.datapoint[1],s=this.plots[a.seriesIndex].hoverFormat||"{0}, {1}",l="";if("string"==typeof s)l=this.format(s,i,o);else if("function"==typeof s)try{l=s(i,o,a)}catch(e){return void t.error(e)}var u=a.pageX>=this.clientWidth/2+e(this).offset().left,h=a.pageY>=this.clientHeight/2+e(this).offset().top;e(this.tooltip).html(l).css({top:a.pageY-e(this.tooltipHolder).offset().top+5,left:a.pageX-e(this.tooltipHolder).offset().left+5}).toggleClass("on-left",u).toggleClass("on-top",h).show()}else e(this.tooltip).hide()}},{key:"setGridStyle",value:function(e,t){var n=t.grid,r=window.getComputedStyle(e),a=r.borderStyle,i=r.borderBottomWidth.replace("px",""),o=r.borderTopWidth.replace("px",""),s=r.borderLeftWidth.replace("px",""),l=r.borderRightWidth.replace("px",""),u={top:Number(o),bottom:Number(i),left:Number(s),right:Number(l)},h=r.borderColor,p=r.backgroundColor;n.borderWidth="solid"===a?u:0,n.borderColor=h,n.color=r.color,n.backgroundColor=p}},{key:"getYAxisIndexByNIControlID",value:function(e){for(var t=0,n=0;n<this.axes.length;n++){var r=this.axes[n];if(("left"===r.axisPosition||"right"===r.axisPosition)&&(t++,r.axisRef===e||r.niControlId===e))return t}return 1}},{key:"getXAxisIndexByNIControlID",value:function(e){for(var t=0,n=0;n<this.axes.length;n++){var r=this.axes[n];if(("top"===r.axisPosition||"bottom"===r.axisPosition)&&(t++,r.axisRef===e||r.niControlId===e))return t}return 1}},{key:"getDataRanges",value:function(e,t){var n=this.graph,r=e.getFlotAxis(),a=n.getData().filter(function(e){return e.xaxis===r||e.yaxis===r}).map(function(e){return n.computeRangeForDataSeries(e,!0)}),i={xmin:Number.POSITIVE_INFINITY,ymin:Number.POSITIVE_INFINITY,xmax:Number.NEGATIVE_INFINITY,ymax:Number.NEGATIVE_INFINITY};return a.reduce(function(e,t){return{xmin:Math.min(e.xmin,t.xmin),ymin:Math.min(e.ymin,t.ymin),xmax:Math.max(e.xmax,t.xmax),ymax:Math.max(e.ymax,t.ymax)}},i)}},{key:"takeGraphSnapshot",value:function(e,t){return this.graph.composeImages(e,t)}},{key:"template",value:function(){return""}},{key:"updateCompleted",get:function(){return this._updatePromise}},{key:"cursors",get:function(){return Array.from(this.children).filter(function(e){return e instanceof NationalInstruments.HtmlVI.Elements.CursorBase})}}],[{key:"defaultPlotColors",get:function(){return o}},{key:"properties",get:function(){return Object.assign({},_get(u.__proto__||Object.getPrototypeOf(u),"properties",this),{value:{value:[],type:"object"},graphRef:{value:"",type:"string"},plotAreaMargin:{value:"",type:"string"},stacked:{value:!1,type:"boolean"},disablePan:{value:!1,type:"boolean"},disableZoom:{value:!1,type:"boolean"},disableRecenter:{value:!1,type:"boolean"},panMode:{value:"smart",type:"string"},touchPanMode:{value:"manual",type:"string"},propagateSupportedGesture:{value:!1,type:"boolean"},metadataOverridesPlotNames:{value:!1,type:"boolean"},highlightPoints:{value:!1,type:"boolean"},highlightLines:{value:!1,type:"boolean"},highlightBars:{value:!1,type:"boolean"},highlightColor:{value:"#000000",type:"string"},highlightLineWidth:{value:2,type:"number"},highlightedIndexes:{value:"[[],[],[]]",type:"string"},highlightedRange:{value:"[[],[],[]]",type:"string"}})}},{key:"listeners",get:function(){return{resize:"onResize",resizeEventHack:"onResize"}}}]),u}(window.JQX.BaseElement);Object.assign(window.NationalInstruments.HtmlVI.Elements,{CartesianGraphBase:l})}(),function(){var e=function(e){function t(){return _classCallCheck(this,t),_possibleConstructorReturn(this,(t.__proto__||Object.getPrototypeOf(t)).apply(this,arguments))}return _inherits(t,e),t}(NationalInstruments.HtmlVI.Elements.CartesianGraphBase);JQX("ni-cartesian-graph",e)}();_createClass=function(){function e(e,t){for(var n=0;n<t.length;n++){var r=t[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(e,r.key,r)}}return function(t,n,r){return n&&e(t.prototype,n),r&&e(t,r),t}}(),_get=function e(t,n,r){null===t&&(t=Function.prototype);var a=Object.getOwnPropertyDescriptor(t,n);if(void 0===a){var i=Object.getPrototypeOf(t);return null===i?void 0:e(i,n,r)}if("value"in a)return a.value;var o=a.get;return void 0!==o?o.call(r):void 0};function _classCallCheck(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}function _possibleConstructorReturn(e,t){if(!e)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return!t||"object"!=typeof t&&"function"!=typeof t?e:t}function _inherits(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Super expression must either be null or a function, not "+typeof t);e.prototype=Object.create(t&&t.prototype,{constructor:{value:e,enumerable:!1,writable:!0,configurable:!0}}),t&&(Object.setPrototypeOf?Object.setPrototypeOf(e,t):e.__proto__=t)}!function(){var e=NationalInstruments.HtmlVI.DataPipeline.ChartDataPipeline,t=function(e,t){if(e.historyBuffer.hb instanceof HistoryBufferWaveform){var n=e.historyBuffer.hb.buffers[t];if(0!==n.size){var r=n.data[n.end];if("string"==typeof r.channelName&&0!==r.channelName.length)return r.channelName}}},n=function(n){function r(){_classCallCheck(this,r);var e=_possibleConstructorReturn(this,(r.__proto__||Object.getPrototypeOf(r)).call(this));return e._historyBuffer=void 0,e}return _inherits(r,n),_createClass(r,[{key:"ready",value:function(){this.historyBuffer||(this.historyBuffer=new HistoryBuffer(this.bufferSize,1)),this.value&&e.prototype.loadValueIntoHistoryBuffer(this.value,this.historyBuffer),_get(r.prototype.__proto__||Object.getPrototypeOf(r.prototype),"ready",this).call(this)}},{key:"createData",value:function(e,t){for(var n=[],r=Math.max(t.length,e.length),a=0;a<r;a++){var i=t[a]||[],o=e[a];Array.isArray(i)&&(i={data:i}),o?(n[a]=o.getViewConfig(),n[a].data=o.show?i.data:[]):n[a]=i}return n}},{key:"convertToFlotFormat",value:function(t){return e.prototype.toFlot(this,t)}},{key:"getSettings",value:function(){return this.getSettingsWorkaround()}},{key:"getSettingsWorkaround",value:function(){var e=_get(r.prototype.__proto__||Object.getPrototypeOf(r.prototype),"getSettingsWorkaround",this).call(this);return e.series.historyBuffer=this.historyBuffer,e}},{key:"getDataRanges",value:function(e,t){for(var n=this.graph,r=e.getFlotAxis(),a=n.getData().map(function(e,t){return{series:e,index:t}}).filter(function(e){return e.series.xaxis===r||e.series.yaxis===r}),i=[],o=0;o<a.length;o++){var s=t?a[o].series.xaxis.min:void 0,l=t?a[o].series.xaxis.max:void 0,u=this.historyBuffer.rangeX(a[o].index),h=this.historyBuffer.rangeY(s,l,a[o].index);i.push({xmin:u.xmin,xmax:u.xmax,ymin:h.ymin,ymax:h.ymax})}var p={xmin:Number.POSITIVE_INFINITY,ymin:Number.POSITIVE_INFINITY,xmax:Number.NEGATIVE_INFINITY,ymax:Number.NEGATIVE_INFINITY};return i.reduce(function(e,t){return{xmin:Math.min(e.xmin,t.xmin),ymin:Math.min(e.ymin,t.ymin),xmax:Math.max(e.xmax,t.xmax),ymax:Math.max(e.ymax,t.ymax)}},p)}},{key:"historyBuffer",set:function(e){var n="generate-plots-for-data";this._historyBuffer=e;var r=this;e.deregisterOnChange(n),e.registerOnChange(n,function(){!function(e){var n=e.historyBuffer;if(0!==n.toArray().length)for(var r=e.plots.length;r<n.width;r++){var a=t(e,r);e.addPlot(a)}}(r),function(e){for(var n=0;n<e.plots.length;n++){var r=t(e,n);e.updatePlotName(n,r,!0)}}(r)})},get:function(){return this._historyBuffer}}],[{key:"properties",get:function(){return Object.assign({},_get(r.__proto__||Object.getPrototypeOf(r),"properties",this),{bufferSize:{value:1024,type:"number"}})}}]),r}(NationalInstruments.HtmlVI.Elements.CartesianGraphBase);JQX("ni-chart",n)}();_createClass=function(){function e(e,t){for(var n=0;n<t.length;n++){var r=t[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(e,r.key,r)}}return function(t,n,r){return n&&e(t.prototype,n),r&&e(t,r),t}}(),_get=function e(t,n,r){null===t&&(t=Function.prototype);var a=Object.getOwnPropertyDescriptor(t,n);if(void 0===a){var i=Object.getPrototypeOf(t);return null===i?void 0:e(i,n,r)}if("value"in a)return a.value;var o=a.get;return void 0!==o?o.call(r):void 0};function _classCallCheck(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}function _possibleConstructorReturn(e,t){if(!e)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return!t||"object"!=typeof t&&"function"!=typeof t?e:t}function _inherits(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Super expression must either be null or a function, not "+typeof t);e.prototype=Object.create(t&&t.prototype,{constructor:{value:e,enumerable:!1,writable:!0,configurable:!0}}),t&&(Object.setPrototypeOf?Object.setPrototypeOf(e,t):e.__proto__=t)}!function(){var e=NationalInstruments.Globals.jQuery,t=function(t){function n(){return _classCallCheck(this,n),_possibleConstructorReturn(this,(n.__proto__||Object.getPrototypeOf(n)).apply(this,arguments))}return _inherits(n,t),_createClass(n,[{key:"dataRange",value:function(){var e=this.parsedData;if(null===n||0===e.length)return{dataMin:0,dataMax:100};for(var t=Math.min(),r=Math.max(),a=0;a<e.length;a++)for(var i=e[a],o=0;o<i.length;o++)i[o]===-1/0||i[o]===1/0||isNaN(i[o])||(i[o]>r&&(r=i[o]),i[o]<t&&(t=i[o]));return t===Math.min()&&(t=0),r===Math.max()&&(r=100),{dataMin:t,dataMax:r}}},{key:"created",value:function(){_get(n.prototype.__proto__||Object.getPrototypeOf(n.prototype),"created",this).call(this),this.autoScaleColor=!1,this.parsedData=null}},{key:"getSettings",value:function(){return{series:{intensitygraph:{show:!0}},axisLabels:{show:!0},xaxes:[{}],yaxes:[{}],zoom:{interactive:!this.disabled,trigger:null},pan:{interactive:!this.disabled,enableTouch:!this.disabled},selection:{mode:null},grid:{}}}},{key:"configureGraph",value:function(){var e,t,r,a,i=[],o=_get(n.prototype.__proto__||Object.getPrototypeOf(n.prototype),"configureGraph",this).call(this);""!==this.plotAreaMargin&&(o.grid.margin=this.plotAreaMargin);var s=this.value;for(o.series.intensitygraph.data=s.length>0?s:this.defaultData(),e=0;e<this.axes.length;e++){var l=this.axes[e].getViewConfig();if(l&&l.type===JQX.IntensityGraph.ColorScaleType){var u=JSON.parse(l.markers);for(t=0;t<u.length;t++)i[t]={value:u[t].value,color:u[t].color};if("none"===l.autoScale)r=u[0].value,a=u[u.length-1].value;else{this.autoScaleColor=!0;var h=this.dataRange();a=h.dataMax,r=h.dataMin}for(o.series.intensitygraph.min=r,o.series.intensitygraph.max=a,o.series.intensitygraph.gradient=i,o.series.intensitygraph.lowColor=l.lowColor,o.series.intensitygraph.highColor=l.highColor,t=0;t<o.yaxes.length;t++)o.yaxes[t].type===JQX.IntensityGraph.ColorScaleType&&(o.yaxes[t].min=r,o.yaxes[t].max=a)}}return o}},{key:"attached",value:function(){_get(n.prototype.__proto__||Object.getPrototypeOf(n.prototype),"attached",this).call(this),this.updateCartesianAxesFromFlot()}},{key:"updateColorScaleLimits",value:function(){var e=this.graph;if(e){var t=e.getYAxes().filter(function(e){return e.options.type===JQX.IntensityGraph.ColorScaleType})[0];if(t&&"none"!==t.options.autoScale){var n=this.dataRange();t.options.min=n.dataMin,t.options.max=n.dataMax}}}},{key:"defaultData",value:function(){return[[]]}},{key:"createData",value:function(e,t){var n=t.length>0?t:this.defaultData(),r=this.axes.filter(function(e){return"left"===e.axisPosition||"right"===e.axisPosition}).findIndex(function(e){return"NI-CARTESIAN-AXIS"===e.tagName}),a={data:n,yaxis:-1===r?void 0:r+1};return this.parsedData=n,this.updateColorScaleLimits(),[a]}},{key:"convertToFlotFormat",value:function(e){return e}}],[{key:"ColorScaleType",get:function(){return e.plot.IntensityGraph.ColorScaleType}}]),n}(NationalInstruments.HtmlVI.Elements.CartesianGraphBase);JQX("ni-intensity-graph",t)}();_createClass=function(){function e(e,t){for(var n=0;n<t.length;n++){var r=t[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(e,r.key,r)}}return function(t,n,r){return n&&e(t.prototype,n),r&&e(t,r),t}}(),_get=function e(t,n,r){null===t&&(t=Function.prototype);var a=Object.getOwnPropertyDescriptor(t,n);if(void 0===a){var i=Object.getPrototypeOf(t);return null===i?void 0:e(i,n,r)}if("value"in a)return a.value;var o=a.get;return void 0!==o?o.call(r):void 0};function _classCallCheck(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}function _possibleConstructorReturn(e,t){if(!e)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return!t||"object"!=typeof t&&"function"!=typeof t?e:t}function _inherits(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Super expression must either be null or a function, not "+typeof t);e.prototype=Object.create(t&&t.prototype,{constructor:{value:e,enumerable:!1,writable:!0,configurable:!0}}),t&&(Object.setPrototypeOf?Object.setPrototypeOf(e,t):e.__proto__=t)}!function(){var e=function(e){function t(){return _classCallCheck(this,t),_possibleConstructorReturn(this,(t.__proto__||Object.getPrototypeOf(t)).apply(this,arguments))}return _inherits(t,e),_createClass(t,[{key:"getSettings",value:function(){var e=!this.disabled&&!this.disableZoom,t=!this.disabled&&!this.disablePan,n=!this.disabled&&!this.disableRecenter;return{buses:this._buses.map(function(e){return e.getViewConfig()}),series:{digitalWaveform:{show:!0,lineWidth:this.lineWidth,signal:{show:!1}}},xaxis:{showTicks:!1,showMinorTicks:!1,showTickLabels:!1},yaxis:{show:!1},zoom:{interactive:e,active:e,enableTouch:e,trigger:null},pan:{interactive:t,active:t,enableTouch:t,mode:this.panMode,touchMode:this.touchPanMode},recenter:{interactive:n,enableTouch:n},selection:{mode:null},grid:{}}}},{key:"created",value:function(){_get(t.prototype.__proto__||Object.getPrototypeOf(t.prototype),"created",this).call(this),this._signals=[],this._buses=[]}},{key:"attached",value:function(){_get(t.prototype.__proto__||Object.getPrototypeOf(t.prototype),"attached",this).call(this),this.addDigitalGraphEventListeners(),this.attachDigitalChildren()}},{key:"attachDigitalChildren",value:function(){for(var e=0;e<this.children.length;e++){var t=this.children[e];(t instanceof JQX.DigitalSignal||t instanceof JQX.DigitalBus||t instanceof JQX.DigitalAxis)&&t.isReady&&t.attachToGraph(this)}}},{key:"addDigitalGraphEventListeners",value:function(){var e=this;e.addEventListener("ni-digital-signal-attached",function(t){t.target===e&&(e.addSignal(t.detail.element),e.updateGraphConfigWhenPlotsUpdatesAreEnabled())}),e.addEventListener("ni-digital-signal-detached",function(t){t.target===e&&(e.removeSignal(t.detail.element),e.updateGraphConfigWhenPlotsUpdatesAreEnabled())}),e.addEventListener("ni-digital-signal-changed",function(t){t.target===e&&e.updateGraphConfigWhenPlotsUpdatesAreEnabled()}),e.addEventListener("ni-digital-bus-attached",function(t){t.target===e&&(e.addBus(t.detail.element),e.updateGraphConfigWhenPlotsUpdatesAreEnabled())}),e.addEventListener("ni-digital-bus-detached",function(t){t.target===e&&(e.removeBus(t.detail.element),e.updateGraphConfigWhenPlotsUpdatesAreEnabled())}),e.addEventListener("ni-digital-bus-changed",function(t){t.target===e&&e.updateGraphConfigWhenPlotsUpdatesAreEnabled()})}},{key:"addSignal",value:function(e){for(var t=this,n=this.getElementsByTagName("ni-digital-signal"),r=[],a=function(a){var i=n[a];(t._signals.find(function(e){return e===i})||i===e)&&r.push(i)},i=0;i<n.length;i++)a(i);this._signals=r}},{key:"removeSignal",value:function(e){for(var t=0;t<this._signals.length;t++)if(this._signals[t]===e){this._signals.splice(t,1);break}}},{key:"addBus",value:function(e){for(var t=this,n=this.getElementsByTagName("ni-digital-bus"),r=[],a=function(a){var i=n[a];(t._buses.find(function(e){return e===i})||i===e)&&r.push(i)},i=0;i<n.length;i++)a(i);this._buses=r}},{key:"removeBus",value:function(e){for(var t=0;t<this._buses.length;t++)if(this._buses[t]===e){this._buses.splice(t,1);break}}},{key:"getBusIndex",value:function(e){return this._buses.indexOf(e)}},{key:"createData",value:function(e,t){var n=[];return this._signals.forEach(function(e,r){var a=t[r];a&&(Array.isArray(a)&&(a={data:a}),n[r]=e.getViewConfig(),n[r].data=a.data,n[r].flatdata=a.flatdata,n[r].start=a.start,n[r].step=a.step,n[r].decimate=!1)},this),n}}],[{key:"properties",get:function(){return Object.assign({},_get(t.__proto__||Object.getPrototypeOf(t),"properties",this),{lineWidth:{value:1,type:"number"}})}}]),t}(NationalInstruments.HtmlVI.Elements.CartesianGraphBase);JQX("ni-digital-graph",e)}();_createClass=function(){function e(e,t){for(var n=0;n<t.length;n++){var r=t[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(e,r.key,r)}}return function(t,n,r){return n&&e(t.prototype,n),r&&e(t,r),t}}(),_get=function e(t,n,r){null===t&&(t=Function.prototype);var a=Object.getOwnPropertyDescriptor(t,n);if(void 0===a){var i=Object.getPrototypeOf(t);return null===i?void 0:e(i,n,r)}if("value"in a)return a.value;var o=a.get;return void 0!==o?o.call(r):void 0};function _classCallCheck(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}function _possibleConstructorReturn(e,t){if(!e)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return!t||"object"!=typeof t&&"function"!=typeof t?e:t}function _inherits(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Super expression must either be null or a function, not "+typeof t);e.prototype=Object.create(t&&t.prototype,{constructor:{value:e,enumerable:!1,writable:!0,configurable:!0}}),t&&(Object.setPrototypeOf?Object.setPrototypeOf(e,t):e.__proto__=t)}!function(){var e=function(e){function t(){return _classCallCheck(this,t),_possibleConstructorReturn(this,(t.__proto__||Object.getPrototypeOf(t)).apply(this,arguments))}return _inherits(t,e),_createClass(t,[{key:"validateWidth",value:function(e,t){return"automatic"===t||"number"==typeof t&&t>=0?t:e}},{key:"created",value:function(){_get(t.prototype.__proto__||Object.getPrototypeOf(t.prototype),"created",this).call(this),this._parentGraph=void 0}},{key:"attached",value:function(){_get(t.prototype.__proto__||Object.getPrototypeOf(t.prototype),"attached",this).call(this),this.parentElement instanceof JQX.DigitalGraph&&this.parentElement.isReady&&this.attachToGraph(this.parentElement)}},{key:"attachToGraph",value:function(e){this._parentGraph||(this._parentGraph=e,this.sendEventToParentGraph("ni-cartesian-axis-attached"))}},{key:"detached",value:function(){_get(t.prototype.__proto__||Object.getPrototypeOf(t.prototype),"detached",this).call(this),this.sendEventToParentGraph("ni-cartesian-axis-detached"),this._parentGraph=void 0}},{key:"propertyChangedHandler",value:function(e,n,r){_get(t.prototype.__proto__||Object.getPrototypeOf(t.prototype),"propertyChangedHandler",this).call(this,e,n,r),this.sendEventToParentGraph("ni-axis-changed")}},{key:"sendEventToParentGraph",value:function(e,t){if(this._parentGraph){var n={bubbles:!1,cancelable:!0,detail:{element:t||this}};this._parentGraph.dispatchEvent(new CustomEvent(e,n))}}},{key:"getViewConfig",value:function(){return{type:"digital",show:this.show,position:this.axisPosition,width:this.width,signalSymbol:this.signalSymbol,busSymbolExpanded:this.busSymbolExpanded,busSymbolCollapsed:this.busSymbolCollapsed}}},{key:"template",value:function(){return""}}],[{key:"properties",get:function(){return Object.assign({},_get(t.__proto__||Object.getPrototypeOf(t),"properties",this),{show:{value:!1,type:"boolean"},axisPosition:{value:"left",type:"string",allowedValues:["left","right"]},width:{value:"automatic",type:"any",validator:"validateWidth"},signalSymbol:{value:null,type:"string?"},busSymbolExpanded:{value:null,type:"string?"},busSymbolCollapsed:{value:null,type:"string?"}})}}]),t}(window.JQX.BaseElement);JQX("ni-digital-axis",e)}();_createClass=function(){function e(e,t){for(var n=0;n<t.length;n++){var r=t[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(e,r.key,r)}}return function(t,n,r){return n&&e(t.prototype,n),r&&e(t,r),t}}(),_get=function e(t,n,r){null===t&&(t=Function.prototype);var a=Object.getOwnPropertyDescriptor(t,n);if(void 0===a){var i=Object.getPrototypeOf(t);return null===i?void 0:e(i,n,r)}if("value"in a)return a.value;var o=a.get;return void 0!==o?o.call(r):void 0};function _classCallCheck(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}function _possibleConstructorReturn(e,t){if(!e)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return!t||"object"!=typeof t&&"function"!=typeof t?e:t}function _inherits(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Super expression must either be null or a function, not "+typeof t);e.prototype=Object.create(t&&t.prototype,{constructor:{value:e,enumerable:!1,writable:!0,configurable:!0}}),t&&(Object.setPrototypeOf?Object.setPrototypeOf(e,t):e.__proto__=t)}!function(){var e=function(e){function t(){return _classCallCheck(this,t),_possibleConstructorReturn(this,(t.__proto__||Object.getPrototypeOf(t)).apply(this,arguments))}return _inherits(t,e),_createClass(t,[{key:"created",value:function(){_get(t.prototype.__proto__||Object.getPrototypeOf(t.prototype),"created",this).call(this),this._parentGraph=void 0,this._parentBus=void 0}},{key:"attached",value:function(){_get(t.prototype.__proto__||Object.getPrototypeOf(t.prototype),"attached",this).call(this),this.parentElement instanceof JQX.DigitalGraph&&this.parentElement.isReady?this.attachToGraph(this.parentElement):this.parentElement instanceof JQX.DigitalBus&&this.parentElement.isReady&&this.attachToBus(this.parentElement)}},{key:"attachToGraph",value:function(e){this._parentGraph||(this._parentGraph=e),this.sendEventToParent("ni-digital-signal-attached")}},{key:"attachToBus",value:function(e){this._parentBus||(this._parentBus=e),this.sendEventToParent("ni-digital-signal-attached")}},{key:"detached",value:function(){_get(t.prototype.__proto__||Object.getPrototypeOf(t.prototype),"detached",this).call(this),this.sendEventToParent("ni-digital-signal-detached"),this._parentGraph=void 0,this._parentBus=void 0}},{key:"propertyChangedHandler",value:function(e,n,r){_get(t.prototype.__proto__||Object.getPrototypeOf(t.prototype),"propertyChangedHandler",this).call(this,e,n,r),this.sendEventToParent("ni-digital-signal-changed")}},{key:"sendEventToParent",value:function(e){var t=this._parentGraph||this._parentBus;if(t){var n={bubbles:!1,cancelable:!0,detail:{element:this}};t.dispatchEvent(new CustomEvent(e,n))}}},{key:"getAssignedBusIndex",value:function(){return this._parentBus?this._parentBus.getIndex():null}},{key:"getViewConfig",value:function(){return{digitalWaveform:{signal:{show:this.show,bus:this.getAssignedBusIndex()}},label:this.label}}},{key:"template",value:function(){return""}}],[{key:"properties",get:function(){return Object.assign({},_get(t.__proto__||Object.getPrototypeOf(t),"properties",this),{show:{value:!1,type:"boolean"},label:{value:"",type:"string"}})}}]),t}(window.JQX.BaseElement);JQX("ni-digital-signal",e)}();_createClass=function(){function e(e,t){for(var n=0;n<t.length;n++){var r=t[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(e,r.key,r)}}return function(t,n,r){return n&&e(t.prototype,n),r&&e(t,r),t}}(),_get=function e(t,n,r){null===t&&(t=Function.prototype);var a=Object.getOwnPropertyDescriptor(t,n);if(void 0===a){var i=Object.getPrototypeOf(t);return null===i?void 0:e(i,n,r)}if("value"in a)return a.value;var o=a.get;return void 0!==o?o.call(r):void 0};function _classCallCheck(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}function _possibleConstructorReturn(e,t){if(!e)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return!t||"object"!=typeof t&&"function"!=typeof t?e:t}function _inherits(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Super expression must either be null or a function, not "+typeof t);e.prototype=Object.create(t&&t.prototype,{constructor:{value:e,enumerable:!1,writable:!0,configurable:!0}}),t&&(Object.setPrototypeOf?Object.setPrototypeOf(e,t):e.__proto__=t)}!function(){var e=function(e){function t(){return _classCallCheck(this,t),_possibleConstructorReturn(this,(t.__proto__||Object.getPrototypeOf(t)).apply(this,arguments))}return _inherits(t,e),_createClass(t,[{key:"created",value:function(){_get(t.prototype.__proto__||Object.getPrototypeOf(t.prototype),"created",this).call(this),this._parentGraph=void 0}},{key:"attached",value:function(){_get(t.prototype.__proto__||Object.getPrototypeOf(t.prototype),"attached",this).call(this),this.parentElement instanceof JQX.DigitalGraph&&this.parentElement.isReady&&this.attachToGraph(this.parentElement)}},{key:"attachToGraph",value:function(e){this._parentGraph||(this._parentGraph=e,this.addDigitalBusEventListeners()),this.attachSignals(),this.sendEventToParentGraph("ni-digital-bus-attached")}},{key:"attachSignals",value:function(){for(var e=0;e<this.children.length;e++){var t=this.children[e];t instanceof JQX.DigitalSignal&&t.isReady&&t.attachToBus(this)}}},{key:"addDigitalBusEventListeners",value:function(){var e=this;e.addEventListener("ni-digital-signal-attached",function(t){t.target===e&&this.sendEventToParentGraph("ni-digital-signal-attached",t.detail.element)}),e.addEventListener("ni-digital-signal-detached",function(t){t.target===e&&this.sendEventToParentGraph("ni-digital-signal-detached",t.detail.element)}),e.addEventListener("ni-digital-signal-changed",function(t){t.target===e&&this.sendEventToParentGraph("ni-digital-signal-changed",t.detail.element)})}},{key:"detached",value:function(){_get(t.prototype.__proto__||Object.getPrototypeOf(t.prototype),"detached",this).call(this),this.sendEventToParentGraph("ni-digital-bus-detached"),this._parentGraph=void 0}},{key:"propertyChangedHandler",value:function(e,n,r){_get(t.prototype.__proto__||Object.getPrototypeOf(t.prototype),"propertyChangedHandler",this).call(this,e,n,r),this.sendEventToParentGraph("ni-digital-bus-changed")}},{key:"sendEventToParentGraph",value:function(e,t){if(this._parentGraph){var n={bubbles:!1,cancelable:!0,detail:{element:t||this}};this._parentGraph.dispatchEvent(new CustomEvent(e,n))}}},{key:"getIndex",value:function(){return this._parentGraph?this._parentGraph.getBusIndex(this):null}},{key:"getViewConfig",value:function(){return{label:this.label,collapsed:this.collapse,bitNumbering:this.bitNumbering,showLabels:this.showLabels,labelPosition:this.labelPosition,labelFormatter:this.labelFormat}}},{key:"template",value:function(){return""}}],[{key:"properties",get:function(){return Object.assign({},_get(t.__proto__||Object.getPrototypeOf(t),"properties",this),{label:{value:"",type:"string"},collapse:{value:!1,type:"boolean"},bitNumbering:{value:"lsb",type:"string",allowedValues:["lsb","msb"]},showLabels:{value:!1,type:"boolean"},labelPosition:{value:"center",type:"string",allowedValues:["center","left","right"]},labelFormat:{value:"binary",type:"string",allowedValues:["binary","decimal","hex"]}})}}]),t}(window.JQX.BaseElement);JQX("ni-digital-bus",e)}();_createClass=function(){function e(e,t){for(var n=0;n<t.length;n++){var r=t[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(e,r.key,r)}}return function(t,n,r){return n&&e(t.prototype,n),r&&e(t,r),t}}(),_get=function e(t,n,r){null===t&&(t=Function.prototype);var a=Object.getOwnPropertyDescriptor(t,n);if(void 0===a){var i=Object.getPrototypeOf(t);return null===i?void 0:e(i,n,r)}if("value"in a)return a.value;var o=a.get;return void 0!==o?o.call(r):void 0};function _classCallCheck(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}function _possibleConstructorReturn(e,t){if(!e)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return!t||"object"!=typeof t&&"function"!=typeof t?e:t}function _inherits(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Super expression must either be null or a function, not "+typeof t);e.prototype=Object.create(t&&t.prototype,{constructor:{value:e,enumerable:!1,writable:!0,configurable:!0}}),t&&(Object.setPrototypeOf?Object.setPrototypeOf(e,t):e.__proto__=t)}!function(){var e=function(e){function t(){return _classCallCheck(this,t),_possibleConstructorReturn(this,(t.__proto__||Object.getPrototypeOf(t)).apply(this,arguments))}return _inherits(t,e),_createClass(t,[{key:"created",value:function(){_get(t.prototype.__proto__||Object.getPrototypeOf(t.prototype),"created",this).call(this)}},{key:"getSettings",value:function(){var e=!this.disabled&&!this.disableZoom,t=!this.disabled&&!this.disablePan,n=!this.disabled&&!this.disableRecenter;return{series:{scattergraph:{show:!0,lineWidth:this.lineWidth,filled:this.filled,drawLines:this.drawLines,defaultColor:this.defaultColor,defaultShape:this.defaultShape,defaultSize:this.defaultSize,colors:this.colors,shapes:this.shapes,sizes:this.sizes},highlights:{show:!0,highlightColor:this.highlightColor,highlightLines:this.highlightLines,highlightPoints:this.highlightPoints,highlightBars:this.highlightBars,lineWidth:this.highlightLineWidth,selectedIndexes:[[],[],[]],selectedRange:[[],[],[]]}},axisLabels:{show:!0},xaxes:[{}],yaxes:[{}],zoom:{interactive:e,active:e,enableTouch:e,trigger:null},pan:{interactive:t,active:t,enableTouch:t,mode:this.panMode,touchMode:this.touchPanMode},recenter:{interactive:n,enableTouch:n},selection:{mode:null},grid:{}}}},{key:"configureGraph",value:function(){var e=_get(t.prototype.__proto__||Object.getPrototypeOf(t.prototype),"configureGraph",this).call(this),n=this.value;return e.series.scattergraph.data=n.length>0?n:this.defaultData(),e}},{key:"attached",value:function(){_get(t.prototype.__proto__||Object.getPrototypeOf(t.prototype),"attached",this).call(this),this.updateCartesianAxesFromFlot()}},{key:"propertyChangedHandler",value:function(e,n,r){_get(t.prototype.__proto__||Object.getPrototypeOf(t.prototype),"propertyChangedHandler",this).call(this,e,n,r),this.requestUpdate()}},{key:"defaultData",value:function(){return[[]]}},{key:"createData",value:function(e,t){return t}},{key:"convertToFlotFormat",value:function(e){return e}}],[{key:"properties",get:function(){return Object.assign({},_get(t.__proto__||Object.getPrototypeOf(t),"properties",this),{lineWidth:{value:2,type:"number"},filled:{value:!1,type:"boolean"},drawLines:{value:!1,type:"boolean"},defaultColor:{value:"black",type:"string"},defaultShape:{value:"circle",type:"string"},defaultSize:{value:5,type:"number"},colors:{value:"",type:"string"},shapes:{value:"",type:"string"},sizes:{value:"",type:"string"}})}}]),t}(NationalInstruments.HtmlVI.Elements.CartesianGraphBase);JQX("ni-scatter-graph",e)}();_typeof="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol&&e!==Symbol.prototype?"symbol":typeof e},_createClass=function(){function e(e,t){for(var n=0;n<t.length;n++){var r=t[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(e,r.key,r)}}return function(t,n,r){return n&&e(t.prototype,n),r&&e(t,r),t}}(),_get=function e(t,n,r){null===t&&(t=Function.prototype);var a=Object.getOwnPropertyDescriptor(t,n);if(void 0===a){var i=Object.getPrototypeOf(t);return null===i?void 0:e(i,n,r)}if("value"in a)return a.value;var o=a.get;return void 0!==o?o.call(r):void 0};function _classCallCheck(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}function _possibleConstructorReturn(e,t){if(!e)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return!t||"object"!=typeof t&&"function"!=typeof t?e:t}function _inherits(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Super expression must either be null or a function, not "+typeof t);e.prototype=Object.create(t&&t.prototype,{constructor:{value:e,enumerable:!1,writable:!0,configurable:!0}}),t&&(Object.setPrototypeOf?Object.setPrototypeOf(e,t):e.__proto__=t)}!function(){var e=window.NINumericFormatters,t=function(e,t){return"auto"===t?"NI-INTENSITY-GRAPH"===e._parentGraph.nodeName?"exact":"NI-CHART"===e._parentGraph.nodeName?"bottom"===e.axisPosition||"top"===e.axisPosition?"sliding-window":"loose":"bottom"===e.axisPosition||"top"===e.axisPosition?"exact":"loose":t},n=function(e){if("NI-CHART"===e._parentGraph.nodeName&&("bottom"===e.axisPosition||"top"===e.axisPosition)){var t=e.maximum-e.minimum;return t>0&&t<Number.POSITIVE_INFINITY?t:1024}},r=function(r){function a(){return _classCallCheck(this,a),_possibleConstructorReturn(this,(a.__proto__||Object.getPrototypeOf(a)).apply(this,arguments))}return _inherits(a,r),_createClass(a,[{key:"created",value:function(){_get(a.prototype.__proto__||Object.getPrototypeOf(a.prototype),"created",this).call(this),this._defaultMin=this.minimum,this._defaultMax=this.maximum,this._parentGraph=void 0}},{key:"sendEventToParentGraph",value:function(e,t,n){var r;void 0!==this._parentGraph&&(r={bubbles:!1,cancelable:!0,detail:{element:this}},t&&n&&(r.detail[t]=n),this._parentGraph.dispatchEvent(new CustomEvent(e,r)))}},{key:"attached",value:function(){_get(a.prototype.__proto__||Object.getPrototypeOf(a.prototype),"attached",this).call(this),this.parentElement instanceof NationalInstruments.HtmlVI.Elements.CartesianGraphBase&&this.parentElement.isReady?this.attachToGraph(this.parentElement):this._parentGraph=void 0,this._defaultMin=this.minimum,this._defaultMax=this.maximum}},{key:"attachToGraph",value:function(e){this._parentGraph||(this._parentGraph=e,this.sendEventToParentGraph("ni-cartesian-axis-attached"))}},{key:"propertyChangedHandler",value:function(e,t,n){_get(a.prototype.__proto__||Object.getPrototypeOf(a.prototype),"propertyChangedHandler",this).call(this,e,t,n);var r=this._navigationOffset||{below:0,above:0};if("maximum"===e){var i=this.dispatchEvent(new CustomEvent("axisoffsetresetting",{cancelable:!0}));this._navigationOffset={above:i?0:r.above,below:r.below}}if("minimum"===e){var o=this.dispatchEvent(new CustomEvent("axisoffsetresetting",{cancelable:!0}));this._navigationOffset={above:r.above,below:o?0:r.below}}this.sendEventToParentGraph("ni-axis-changed")}},{key:"detached",value:function(){_get(a.prototype.__proto__||Object.getPrototypeOf(a.prototype),"detached",this).call(this),this.sendEventToParentGraph("ni-cartesian-axis-detached"),this._parentGraph=void 0}},{key:"setFont",value:function(e,t,n,r,a){this.style.fontSize=e,this.style.fontFamily=t,this.style.fontWeight=n,this.style.fontStyle=r,this.style.textDecoration=a,this.sendEventToParentGraph("ni-axis-changed")}},{key:"getViewConfig",value:function(){var r=window.getComputedStyle(this),a=/grow/.test(this.autoScale),i=a?this.autoScale.replace(/grow/,""):this.autoScale;return{axisLabel:this.showLabel?this.label:void 0,show:this.show,position:this.axisPosition,min:this.minimum,max:this.maximum,autoScale:t(this,i),windowSize:n(this),growOnly:a,mode:this.mode||(this.logScale?"log":"linear"),timeBase:this.timeBase||"seconds",element:this,timeEpoch:this.timeFormatEpoch,tickFormatter:e.getTickFormatter(e.parseTickFormatterType(this.format)),tickGenerator:e.getTickGenerator(this.format),tickSize:this.tickSize&&JSON.parse(this.tickSize),minTickSize:this.minTickSize&&JSON.parse(this.minTickSize),showTickLabels:this.showTickLabels,ticks:this.ticks?JSON.parse(this.ticks):void 0,gridLines:this.gridLines,showTicks:this.showTicks,showMinorTicks:this.showMinorTicks,color:r.color,offset:this._navigationOffset||{below:0,above:0},font:{size:parseFloat(r.fontSize),style:r.fontStyle,weight:r.fontWeight,family:r.fontFamily,color:"inherit"},axisZoom:"axis"===this.zoom||"all"===this.zoom,plotZoom:"plot"===this.zoom||"all"===this.zoom,axisPan:"axis"===this.pan||"all"===this.pan,plotPan:"plot"===this.pan||"all"===this.pan,inverted:this.inverted,labelWidth:this.labelWidth,reserveSpace:this.reserveSpace||void 0}}},{key:"getFlotAxis",value:function(){var e=this._parentGraph.graph;if(void 0!==e){var t=e.getAxes(),n=this,r=Object.keys(t).filter(function(e){return t[e].options.element===n})[0];return t[r]}}},{key:"getMinimum",value:function(){var e=this.minimum;if(this.isAttached){var t=this.getFlotAxis();e=void 0!==t&&void 0!==t.min?t.min:e}return e}},{key:"getMaximum",value:function(){var e=this.maximum;if(this.isAttached){var t=this.getFlotAxis();e=void 0!==t&&void 0!==t.max?t.max:e}return e}},{key:"resetOffset",value:function(e,t){var n=this._parentGraph.graph,r=this.getFlotAxis(),a=n.getData(),i=a.filter(function(e){return e.xaxis===r||e.yaxis===r});if(0!==a.length&&0!==i.length&&i.some(function(e){return 0!==e.datapoints.points.length})){var o=e?"x"===r.direction?{xmin:r.min,xmax:r.max}:{ymin:r.min,ymax:r.max}:this._parentGraph.getDataRanges(this,t);this._navigationOffset=r.options.offset={below:0,above:0};var s="x"===r.direction?o.xmin:o.ymin,l="x"===r.direction?o.xmax:o.ymax;this.minimum=s!==Number.POSITIVE_INFINITY?s:this._defaultMin,this.maximum=l!==Number.NEGATIVE_INFINITY?l:this._defaultMax,this.sendEventToParentGraph("ni-axis-reset","keepExistingRange",e)}}},{key:"syncWithFlot",value:function(){var e=this.getFlotAxis();"number"==typeof e.options.min&&(this.minimum=e.options.min,this.maximum=e.options.max),"object"===_typeof(e.options.offset)&&(this._navigationOffset={below:e.options.offset.below,above:e.options.offset.above}),void 0!==this._parentGraph&&this._parentGraph.notifyScaleLegend("ni-axis-changed",this)}},{key:"template",value:function(){return""}}],[{key:"properties",get:function(){return Object.assign({},_get(a.__proto__||Object.getPrototypeOf(a),"properties",this),{axisRef:{value:"",type:"string"},show:{value:!1,type:"boolean"},label:{value:"",type:"string"},axisPosition:{value:"left",type:"string"},showLabel:{value:!1,type:"boolean"},minimum:{value:0,type:"number"},maximum:{value:1,type:"number"},autoScale:{value:"auto",type:"string"},logScale:{value:!1,type:"boolean"},mode:{value:"",type:"string"},timeBase:{value:"seconds",type:"string"},format:{value:"",type:"string"},timeFormatEpoch:{value:-621355968e5,type:"number"},showTickLabels:{value:"all",type:"string"},ticks:{value:void 0,type:"string"},gridLines:{value:!1,type:"boolean"},showTicks:{value:!1,type:"boolean"},showMinorTicks:{value:!1,type:"boolean"},tickSize:{value:void 0,type:"string"},minTickSize:{value:void 0,type:"string"},inverted:{value:!1,type:"boolean"},labelWidth:{value:void 0,type:"number"},pan:{value:"all",type:"string"},reserveSpace:{value:!1,type:"boolean"},zoom:{value:"all",type:"string"}})}}]),a}(window.JQX.BaseElement);JQX("ni-cartesian-axis",r)}();_createClass=function(){function e(e,t){for(var n=0;n<t.length;n++){var r=t[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(e,r.key,r)}}return function(t,n,r){return n&&e(t.prototype,n),r&&e(t,r),t}}(),_get=function e(t,n,r){null===t&&(t=Function.prototype);var a=Object.getOwnPropertyDescriptor(t,n);if(void 0===a){var i=Object.getPrototypeOf(t);return null===i?void 0:e(i,n,r)}if("value"in a)return a.value;var o=a.get;return void 0!==o?o.call(r):void 0};function _classCallCheck(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}function _possibleConstructorReturn(e,t){if(!e)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return!t||"object"!=typeof t&&"function"!=typeof t?e:t}function _inherits(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Super expression must either be null or a function, not "+typeof t);e.prototype=Object.create(t&&t.prototype,{constructor:{value:e,enumerable:!1,writable:!0,configurable:!0}}),t&&(Object.setPrototypeOf?Object.setPrototypeOf(e,t):e.__proto__=t)}!function(){var e=function(e){function t(){return _classCallCheck(this,t),_possibleConstructorReturn(this,(t.__proto__||Object.getPrototypeOf(t)).apply(this,arguments))}return _inherits(t,e),_createClass(t,[{key:"created",value:function(){_get(t.prototype.__proto__||Object.getPrototypeOf(t.prototype),"created",this).call(this),this._parentGraph=void 0}},{key:"sendEventToParentGraph",value:function(e){var t;void 0!==this._parentGraph&&(t={bubbles:!0,cancelable:!0,detail:{element:this}},this._parentGraph.dispatchEvent(new CustomEvent(e,t)))}},{key:"attached",value:function(){_get(t.prototype.__proto__||Object.getPrototypeOf(t.prototype),"attached",this).call(this),this.parentElement instanceof JQX.IntensityGraph&&this.parentElement.isReady?this.attachToGraph(this.parentElement):this._parentGraph=void 0}},{key:"attachToGraph",value:function(e){this._parentGraph||(this._parentGraph=this.parentElement,this.sendEventToParentGraph("ni-cartesian-axis-attached"))}},{key:"propertyChangedHandler",value:function(e,n,r){_get(t.prototype.__proto__||Object.getPrototypeOf(t.prototype),"propertyChangedHandler",this).call(this,e,n,r),this.sendEventToParentGraph("ni-axis-changed")}},{key:"detached",value:function(){_get(t.prototype.__proto__||Object.getPrototypeOf(t.prototype),"detached",this).call(this),this.sendEventToParentGraph("ni-cartesian-axis-detached"),this._parentGraph=void 0}},{key:"setFont",value:function(e,t,n,r,a){this.style.fontSize=e,this.style.fontFamily=t,this.style.fontWeight=n,this.style.fontStyle=r,this.style.textDecoration=a,this.sendEventToParentGraph("ni-axis-changed")}},{key:"getViewConfig",value:function(){var e=window.getComputedStyle(this),t=/grow/.test(this.autoScale),n=t?this.autoScale.replace(/grow/,""):this.autoScale;return{type:JQX.IntensityGraph.ColorScaleType,axisLabel:this.showLabel?this.label:void 0,show:this.show,autoScale:"auto"===n?"none":n,growOnly:t,min:this.minimum,max:this.maximum,position:this.axisPosition,lowColor:this.lowColor,highColor:this.highColor,markers:this.markers,showTickLabels:this.showTickLabels,font:{size:parseFloat(e.fontSize),style:e.fontStyle,weight:e.fontWeight,family:e.fontFamily,color:"inherit"},axisZoom:!1,plotZoom:!1,axisPan:!1,plotPan:!1,gridLines:!1}}},{key:"template",value:function(){return""}},{key:"getFlotAxis",value:function(){if(this._parentGraph)return this._parentGraph.graph.getYAxes().filter(function(e){return e.options.type===JQX.IntensityGraph.ColorScaleType})[0]}}],[{key:"properties",get:function(){return Object.assign({},_get(t.__proto__||Object.getPrototypeOf(t),"properties",this),{label:{value:"",type:"string"},show:{value:!1,type:"boolean"},showLabel:{value:!1,type:"boolean"},axisPosition:{value:"right",type:"string"},showTickLabels:{value:"all",type:"string"},highColor:{value:"#ffffff",type:"string"},lowColor:{value:"#000000",type:"string"},markers:{value:'[{\n                        "value": 0,\n                        "color": "#3182bd"\n                    }, {\n                        "value": 50,\n                        "color": "#9ecae1"\n                    }, {\n                        "value": 100,\n                        "color": "#deebf7"\n                    }]',type:"string"},autoScale:{value:"auto",type:"string"},minimum:{value:0,type:"number"},maximum:{value:1,type:"number"}})}}]),t}(window.JQX.BaseElement);JQX("ni-color-scale",e)}();_createClass=function(){function e(e,t){for(var n=0;n<t.length;n++){var r=t[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(e,r.key,r)}}return function(t,n,r){return n&&e(t.prototype,n),r&&e(t,r),t}}(),_get=function e(t,n,r){null===t&&(t=Function.prototype);var a=Object.getOwnPropertyDescriptor(t,n);if(void 0===a){var i=Object.getPrototypeOf(t);return null===i?void 0:e(i,n,r)}if("value"in a)return a.value;var o=a.get;return void 0!==o?o.call(r):void 0};function _classCallCheck(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}function _possibleConstructorReturn(e,t){if(!e)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return!t||"object"!=typeof t&&"function"!=typeof t?e:t}function _inherits(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Super expression must either be null or a function, not "+typeof t);e.prototype=Object.create(t&&t.prototype,{constructor:{value:e,enumerable:!1,writable:!0,configurable:!0}}),t&&(Object.setPrototypeOf?Object.setPrototypeOf(e,t):e.__proto__=t)}!function(){var e={lines:{show:!1}},t=function(t){function n(){return _classCallCheck(this,n),_possibleConstructorReturn(this,(n.__proto__||Object.getPrototypeOf(n)).apply(this,arguments))}return _inherits(n,t),_createClass(n,[{key:"reset",value:function(e){var t,n=this._parentGraph.axes;e.axisRef&&(t=n.filter(function(t){return t.axisRef===e.axisRef})),t||(t=n),"none"!==e.autoScale?t.forEach(function(t){t.autoScale=e.autoScale,t.resetOffset()}):e.minimum&&e.maximum?t.forEach(function(t){t.minimum=e.minimum,t.maximum=e.maximum,t.sendEventToParentGraph("ni-axis-changed")}):t.forEach(function(t){t.autoScale=e.autoScale,t.resetOffset();var n=t.getFlotAxis();n.min=t.minimum,n.max=t.maximum})}},{key:"created",value:function(){_get(n.prototype.__proto__||Object.getPrototypeOf(n.prototype),"created",this).call(this),this._parentGraph=void 0}},{key:"sendEventToParentGraph",value:function(e,t){var n;void 0!==this._parentGraph&&(n={bubbles:!1,cancelable:!0,detail:{element:this,originalSource:t}},this._parentGraph.dispatchEvent(new CustomEvent(e,n)))}},{key:"attached",value:function(){_get(n.prototype.__proto__||Object.getPrototypeOf(n.prototype),"attached",this).call(this),(this.parentElement instanceof JQX.CartesianGraph||this.parentElement instanceof JQX.Chart)&&this.parentElement.isReady?this.attachToGraph(this.parentElement):this._parentGraph=void 0}},{key:"attachToGraph",value:function(e){this._parentGraph||(this._parentGraph=e,this.addPlotItemListeners(),this.attachChildren(),this.sendEventToParentGraph("ni-cartesian-plot-attached"))}},{key:"attachChildren",value:function(){for(var e=this.children,t=0;t<e.length;t++){var n=e[t];"NI-CARTESIAN-PLOT-RENDERER"===n.tagName&&n instanceof window.JQX.CartesianPlotRenderer&&n.isReady&&n.attachToPlot(this)}}},{key:"addPlotItemListeners",value:function(){var e=this;e.addEventListener("ni-cartesian-plot-renderer-attached",function(t){t.target===e&&(this.plotRenderer=t.detail.element,this.sendEventToParentGraph("ni-cartesian-plot-renderer-attached",t.detail.element))}),e.addEventListener("ni-cartesian-plot-renderer-detached",function(t){t.target===e&&(this.plotRenderer=void 0,this.sendEventToParentGraph("ni-cartesian-plot-renderer-detached",t.detail.element))}),e.addEventListener("ni-cartesian-plot-renderer-changed",function(t){t.target===e&&this.sendEventToParentGraph("ni-cartesian-plot-renderer-changed",t.detail.element)})}},{key:"detached",value:function(){_get(n.prototype.__proto__||Object.getPrototypeOf(n.prototype),"detached",this).call(this),this.sendEventToParentGraph("ni-cartesian-plot-detached"),this._parentGraph=void 0}},{key:"propertyChangedHandler",value:function(e,t,r){_get(n.prototype.__proto__||Object.getPrototypeOf(n.prototype),"propertyChangedHandler",this).call(this,e,t,r),this.sendEventToParentGraph("ni-cartesian-plot-changed")}},{key:"getViewConfig",value:function(){var t=e;return void 0!==this.plotRenderer&&!0===this.show&&(t=this.plotRenderer.getViewConfig()),t.label=this.label,t.hoverable=this.enableHover,t.clickable=this.enableClick,t.xaxis=this._parentGraph.getXAxisIndexByNIControlID(this.xaxis),t.yaxis=this._parentGraph.getYAxisIndexByNIControlID(this.yaxis),t}},{key:"template",value:function(){return""}}],[{key:"properties",get:function(){return Object.assign({},_get(n.__proto__||Object.getPrototypeOf(n),"properties",this),{show:{value:!1,type:"boolean"},label:{value:"",type:"string"},xaxis:{value:"",type:"string"},yaxis:{value:"",type:"string"},enableHover:{value:!1,type:"boolean"},enableClick:{value:!1,type:"boolean"},hoverFormat:{value:"",type:"any",reflectToAttribute:!1}})}}]),n}(window.JQX.BaseElement);JQX("ni-cartesian-plot",t)}();_createClass=function(){function e(e,t){for(var n=0;n<t.length;n++){var r=t[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(e,r.key,r)}}return function(t,n,r){return n&&e(t.prototype,n),r&&e(t,r),t}}(),_get=function e(t,n,r){null===t&&(t=Function.prototype);var a=Object.getOwnPropertyDescriptor(t,n);if(void 0===a){var i=Object.getPrototypeOf(t);return null===i?void 0:e(i,n,r)}if("value"in a)return a.value;var o=a.get;return void 0!==o?o.call(r):void 0};function _classCallCheck(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}function _possibleConstructorReturn(e,t){if(!e)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return!t||"object"!=typeof t&&"function"!=typeof t?e:t}function _inherits(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Super expression must either be null or a function, not "+typeof t);e.prototype=Object.create(t&&t.prototype,{constructor:{value:e,enumerable:!1,writable:!0,configurable:!0}}),t&&(Object.setPrototypeOf?Object.setPrototypeOf(e,t):e.__proto__=t)}!function(){var e=function(e){switch(e){case"zero":return 0;case"infinity":case"positiveinfinity":return 1/0;case"-infinity":case"negativeinfinity":return-1/0;default:return}},t=function(t){function n(){return _classCallCheck(this,n),_possibleConstructorReturn(this,(n.__proto__||Object.getPrototypeOf(n)).apply(this,arguments))}return _inherits(n,t),_createClass(n,[{key:"created",value:function(){_get(n.prototype.__proto__||Object.getPrototypeOf(n.prototype),"created",this).call(this),this._parentPlot=void 0}},{key:"sendEventToParentPlot",value:function(e){var t;void 0!==this._parentPlot&&(t={bubbles:!1,cancelable:!0,detail:{element:this}},this._parentPlot.dispatchEvent(new CustomEvent(e,t)))}},{key:"attached",value:function(){_get(n.prototype.__proto__||Object.getPrototypeOf(n.prototype),"attached",this).call(this),this.parentElement instanceof JQX.CartesianPlot&&this.parentElement.isReady?this.attachToPlot(this.parentElement):this._parentPlot=void 0}},{key:"attachToPlot",value:function(e){this._parentPlot=e,this.sendEventToParentPlot("ni-cartesian-plot-renderer-attached")}},{key:"propertyChangedHandler",value:function(e,t,r){_get(n.prototype.__proto__||Object.getPrototypeOf(n.prototype),"propertyChangedHandler",this).call(this,e,t,r),this.sendEventToParentPlot("ni-cartesian-plot-renderer-changed")}},{key:"detached",value:function(){_get(n.prototype.__proto__||Object.getPrototypeOf(n.prototype),"detached",this).call(this),this.sendEventToParentPlot("ni-cartesian-plot-renderer-detached")}},{key:"toFlotLineStyle",value:function(e){switch(e){case"solid":return;case"dot":return[this.lineWidth,2*this.lineWidth];case"mediumdash":return[3*this.lineWidth,2*this.lineWidth];case"dashdot":return[3*this.lineWidth,2*this.lineWidth,this.lineWidth,2*this.lineWidth];case"largedash":return[5*this.lineWidth,3*this.lineWidth];default:return}}},{key:"getColor",value:function(){var e=this.lineStroke||this.pointColor||this.areaFill||this.barFill;return"auto"===e?null:e}},{key:"getViewConfig",value:function(){return{color:this.getColor(),lines:{show:""!==this.lineStroke||""!==this.areaFill,lineWidth:this.lineWidth,fill:""!==this.areaFill&&this.fillOpacity,zero:!1,fillTowards:e(this.areaBaseLine),dashes:this.toFlotLineStyle(this.lineStyle)},points:{show:""!==this.pointColor,radius:this.pointSize?this.pointSize/2:2,symbol:this.pointShape,fillColor:this.fillPoints?this.pointColor:"#ffffff"},bars:{show:""!==this.barFill,barWidth:[this.barWidth,this.absoluteBarWidth],horizontal:"horizontal"===this.orientation,align:"center",zero:!1,fill:this.fillOpacity,fillTowards:e(this.barBaseLine)}}}},{key:"template",value:function(){return""}}],[{key:"properties",get:function(){return Object.assign({},_get(n.__proto__||Object.getPrototypeOf(n),"properties",this),{lineStroke:{value:"auto",type:"string"},lineWidth:{value:1,type:"number"},lineStyle:{value:"solid",type:"string"},areaFill:{value:"",type:"string"},areaBaseLine:{value:"zero",type:"string"},barFill:{value:"",type:"string"},barWidth:{value:.75,type:"number"},absoluteBarWidth:{value:!1,type:"boolean"},orientation:{value:"vertical",type:"string"},barBaseLine:{value:"zero",type:"string"},pointColor:{value:"",type:"string"},pointSize:{value:5,type:"number"},pointShape:{value:"ellipse",type:"string"},fillPoints:{value:!1,type:"boolean"},fillOpacity:{value:.6,type:"number"}})}}]),n}(window.JQX.BaseElement);JQX("ni-cartesian-plot-renderer",t)}();_createClass=function(){function e(e,t){for(var n=0;n<t.length;n++){var r=t[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(e,r.key,r)}}return function(t,n,r){return n&&e(t.prototype,n),r&&e(t,r),t}}(),_get=function e(t,n,r){null===t&&(t=Function.prototype);var a=Object.getOwnPropertyDescriptor(t,n);if(void 0===a){var i=Object.getPrototypeOf(t);return null===i?void 0:e(i,n,r)}if("value"in a)return a.value;var o=a.get;return void 0!==o?o.call(r):void 0};function _classCallCheck(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}function _possibleConstructorReturn(e,t){if(!e)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return!t||"object"!=typeof t&&"function"!=typeof t?e:t}function _inherits(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Super expression must either be null or a function, not "+typeof t);e.prototype=Object.create(t&&t.prototype,{constructor:{value:e,enumerable:!1,writable:!0,configurable:!0}}),t&&(Object.setPrototypeOf?Object.setPrototypeOf(e,t):e.__proto__=t)}!function(){var e=function(e){function t(){return _classCallCheck(this,t),_possibleConstructorReturn(this,(t.__proto__||Object.getPrototypeOf(t)).apply(this,arguments))}return _inherits(t,e),_createClass(t,[{key:"created",value:function(){_get(t.prototype.__proto__||Object.getPrototypeOf(t.prototype),"created",this).call(this),this.cursor=null,this._parentGraph=void 0,this.onCursorUpdates=this.onCursorUpdates.bind(this),this.onCursorDragUpdates=this.onCursorDragUpdates.bind(this),this.handleGraphUpdated=this.handleGraphUpdated.bind(this)}},{key:"setCursor",value:function(e){this.cursor=e}},{key:"sendEventToParentGraph",value:function(e){if(void 0!==this._parentGraph){var t={bubbles:!0,cancelable:!0,detail:{element:this}};this._parentGraph.dispatchEvent(new CustomEvent(e,t))}}},{key:"attached",value:function(){_get(t.prototype.__proto__||Object.getPrototypeOf(t.prototype),"attached",this).call(this),(this.parentElement instanceof JQX.CartesianGraph||this.parentElement instanceof JQX.Chart||this.parentElement instanceof JQX.DigitalGraph||this.parentElement instanceof JQX.ScatterGraph)&&this.parentElement.isReady?this.attachToGraph(this.parentElement):this._parentGraph=void 0}},{key:"attachToGraph",value:function(e){var t=this;this._parentGraph||(this._parentGraph=e,this._parentGraph.requestUpdate(),this.sendEventToParentGraph("ni-cursor-attached"),this.graphCreatedHandler=function(){t._parentGraph.graph.getPlaceholder().bind("cursorupdates",t.onCursorUpdates),t._parentGraph.graph.getPlaceholder().bind("cursordragstart",t.onCursorDragUpdates),t._parentGraph.graph.getPlaceholder().bind("cursordrag",t.onCursorDragUpdates),t._parentGraph.graph.getPlaceholder().bind("cursordragend",t.onCursorDragUpdates)},e.addEventListener("ni-graph-created",this.graphCreatedHandler),e.addEventListener("ni-graph-updated",this.handleGraphUpdated),this._parentGraph._isInitialized&&this.graphCreatedHandler())}},{key:"handleGraphUpdated",value:function(){}},{key:"onCursorUpdates",value:function(e,t){}},{key:"onCursorDragUpdates",value:function(e,t){t.cookie===this&&this.updateCursorElement(e,t)}},{key:"propertyChangedHandler",value:function(e,n,r){_get(t.prototype.__proto__||Object.getPrototypeOf(t.prototype),"propertyChangedHandler",this).call(this,e,n,r),this._parentGraph.requestUpdate(),this.sendEventToParentGraph("ni-cursor-changed")}},{key:"detached",value:function(){_get(t.prototype.__proto__||Object.getPrototypeOf(t.prototype),"detached",this).call(this),this._parentGraph.removeEventListener("ni-graph-created",this.graphCreatedHandler),this._parentGraph.removeEventListener("ni-graph-updated",this.handleGraphUpdated),this._parentGraph.requestUpdate(),this._parentGraph&&this._parentGraph.graph&&(this._parentGraph.graph.getPlaceholder().unbind("cursorupdates",this.onCursorUpdates),this._parentGraph.graph.getPlaceholder().unbind("cursordragstart",this.onCursorDragUpdates),this._parentGraph.graph.getPlaceholder().unbind("cursordrag",this.onCursorDragUpdates),this._parentGraph.graph.getPlaceholder().unbind("cursordragend",this.onCursorDragUpdates)),this.sendEventToParentGraph("ni-cursor-detached"),this._parentGraph=void 0}},{key:"setFont",value:function(e,t,n,r,a){this.style.fontSize=e,this.style.fontFamily=t,this.style.fontWeight=n,this.style.textDecoration=a,this._parentGraph&&this._parentGraph.requestUpdate(),this.sendEventToParentGraph("ni-cursor-changed")}},{key:"setColor",value:function(e){this.style.color=e,this._parentGraph&&this._parentGraph.requestUpdate(),this.sendEventToParentGraph("ni-cursor-changed")}},{key:"template",value:function(){return""}}]),t}(window.JQX.BaseElement);Object.assign(window.NationalInstruments.HtmlVI.Elements,{CursorBase:e})}();_createClass=function(){function e(e,t){for(var n=0;n<t.length;n++){var r=t[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(e,r.key,r)}}return function(t,n,r){return n&&e(t.prototype,n),r&&e(t,r),t}}();function _classCallCheck(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}function _possibleConstructorReturn(e,t){if(!e)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return!t||"object"!=typeof t&&"function"!=typeof t?e:t}function _inherits(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Super expression must either be null or a function, not "+typeof t);e.prototype=Object.create(t&&t.prototype,{constructor:{value:e,enumerable:!1,writable:!0,configurable:!0}}),t&&(Object.setPrototypeOf?Object.setPrototypeOf(e,t):e.__proto__=t)}!function(){var e=NationalInstruments.Globals.jQuery,t=function(t){function n(){return _classCallCheck(this,n),_possibleConstructorReturn(this,(n.__proto__||Object.getPrototypeOf(n)).apply(this,arguments))}return _inherits(n,t),_createClass(n,[{key:"onCursorUpdates",value:function(e,t){var n=t[this._parentGraph.graph.getCursors().indexOf(this.cursor)];this.updateCursorElement(e,n)}},{key:"handleGraphUpdated",value:function(){var e=Array.from(this._parentGraph.children).filter(function(e){return e instanceof JQX.Cursor}).indexOf(this),t=this._parentGraph.graph.getCursors()[e];t.cookie=this,this.setCursor(t)}},{key:"updateCursorElement",value:function(t,n){if(n&&(this.x=this.cursor.position.relativeX,this.y=this.cursor.position.relativeY,this.xPosition=this.cursor.position.x,this.yPosition=this.cursor.position.y),this._parentGraph)switch(t.type){case"cursorupdates":e(this).trigger("cursorUpdated",n);break;case"cursordragstart":e(this).trigger("cursorDragStart");break;case"cursordrag":e(this).trigger("cursorDrag");break;case"cursordragend":e(this).trigger("cursorDragEnd")}}},{key:"getViewConfig",value:function(){var e,t=window.getComputedStyle(this),n=this.crosshairStyle;e="both"===n?"xy":"horizontal"===n?"y":"vertical"===n?"x":"none"===n?"":null;var r=!(this.disabled||this._parentGraph.disabled);return{show:this.show,showLabel:this.showLabel,showValues:this.showValue,name:this.label,snapToPlot:this.snapToPlot,interpolate:this.interpolate,defaultxaxis:this._parentGraph.getXAxisIndexByNIControlID(this.xaxis),defaultyaxis:this._parentGraph.getYAxisIndexByNIControlID(this.yaxis),mode:e,symbol:this.targetShape,symbolSize:this.targetSize,color:t.color,fontSize:t.fontSize,fontFamily:t.fontFamily,fontStyle:t.fontStyle,fontWeight:t.fontWeight,position:{relativeX:this.x,relativeY:this.y,x:this.xPosition,y:this.yPosition},showThumbs:this.showThumbs,dashes:this.dashes,thumbAbbreviation:this.thumbLabel,thumbOffset:this.thumbOffset,thumbColor:this.thumbColor,thumbClassList:r?["draggable"]:[],movable:r}}},{key:"getEntryInfo",value:function(){return{name:"cursors",valueType:"array"}}}],[{key:"properties",get:function(){return{show:{value:!1,type:"boolean"},label:{value:"",type:"string"},showLabel:{value:!1,type:"boolean"},targetShape:{value:"ellipse",type:"string"},targetSize:{value:8,type:"number"},crosshairStyle:{value:"both",type:"string"},showValue:{value:!1,type:"boolean"},snapToPlot:{value:void 0,type:"number?"},interpolate:{value:!1,type:"boolean"},xaxis:{value:"",type:"string"},yaxis:{value:"",type:"string"},x:{value:.5,type:"number"},y:{value:.5,type:"number"},xPosition:{value:void 0,type:"number"},yPosition:{value:void 0,type:"number"},fontFamily:{value:"sans-serif",type:"string"},fontSize:{value:"10px",type:"string"},fontStyle:{value:"",type:"string"},showThumbs:{value:"none",type:"string"},dashes:{value:[],type:"object"},thumbLabel:{value:"",type:"string"},thumbOffset:{value:"0",type:"string"},thumbColor:{value:void 0,type:"string"}}}}]),n}(NationalInstruments.HtmlVI.Elements.CursorBase);JQX("ni-cursor",t)}();_createClass=function(){function e(e,t){for(var n=0;n<t.length;n++){var r=t[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(e,r.key,r)}}return function(t,n,r){return n&&e(t.prototype,n),r&&e(t,r),t}}();function _classCallCheck(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}function _possibleConstructorReturn(e,t){if(!e)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return!t||"object"!=typeof t&&"function"!=typeof t?e:t}function _inherits(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Super expression must either be null or a function, not "+typeof t);e.prototype=Object.create(t&&t.prototype,{constructor:{value:e,enumerable:!1,writable:!0,configurable:!0}}),t&&(Object.setPrototypeOf?Object.setPrototypeOf(e,t):e.__proto__=t)}!function(){var e=NationalInstruments.Globals.jQuery,t=function(t){function n(){return _classCallCheck(this,n),_possibleConstructorReturn(this,(n.__proto__||Object.getPrototypeOf(n)).apply(this,arguments))}return _inherits(n,t),_createClass(n,[{key:"onCursorUpdates",value:function(e,t){var n=t[this._parentGraph.graph.getRangeCursors().indexOf(this.cursor)];this.updateCursorElement(e,n)}},{key:"handleGraphUpdated",value:function(){var e=Array.from(this._parentGraph.children).filter(function(e){return e instanceof JQX.RangeCursor}).indexOf(this),t=this._parentGraph.graph.getRangeCursors()[e];t.cookie=this,this.setCursor(t)}},{key:"updateCursorElement",value:function(t,n){if("cursorupdates"===t.type){if(void 0===n.rangecursor)return;n.positionMode?(this.xstart=n.position.xstart,this.xend=n.position.xend,this.relativeXEnd=void 0,this.relativeXStart=void 0,this.ystart=n.position.ystart,this.yend=n.position.yend,this.relativeYEnd=void 0,this.relativeYStart=void 0):(this.relativeXStart=n.position.relativeXStart,this.relativeXEnd=n.position.relativeXEnd,this.xstart=void 0,this.xend=void 0,this.relativeYStart=n.position.relativeYStart,this.relativeYEnd=n.position.relativeYEnd,this.ystart=void 0,this.yend=void 0)}else this.xstart=n.position.xstart,this.xend=n.position.xend,this.relativeXStart=n.position.relativeXStart,this.relativeXEnd=n.position.relativeXEnd,this.ystart=n.position.ystart,this.yend=n.position.yend,this.relativeYStart=n.position.relativeYStart,this.relativeYEnd=n.position.relativeYEnd;if(this._parentGraph)switch(t.type){case"cursorupdates":e(this).trigger("cursorUpdated",n);break;case"cursordragstart":e(this).trigger("cursorDragStart");break;case"cursordrag":e(this).trigger("cursorDrag");break;case"cursordragend":e(this).trigger("cursorDragEnd")}}},{key:"getViewConfig",value:function(){var e=window.getComputedStyle(this),t=!(this.disabled||this._parentGraph.disabled);return{show:this.show,name:this.label,xstart:void 0,xend:void 0,ystart:void 0,yend:void 0,showLabel:this.showLabel,showValue:this.showValue,showBorders:this.showBorders,orientation:this.orientation,halign:this.halign,defaultxaxis:this._parentGraph.getXAxisIndexByNIControlID(this.xaxis),defaultyaxis:this._parentGraph.getYAxisIndexByNIControlID(this.yaxis),transparentRange:this.transparentRange,constrainToEdge:this.constrainToEdge,color:e.color,fillColor:this.fillColor,fontSize:e.fontSize,fontFamily:e.fontFamily,fontStyle:e.fontStyle,fontWeight:e.fontWeight,lineWidth:this.lineWidth,position:{relativeXStart:this.relativeXStart,relativeXEnd:this.relativeXEnd,xstart:this.xstart,xend:this.xend,relativeYStart:this.relativeYStart,relativeYEnd:this.relativeYEnd,ystart:this.ystart,yend:this.yend},dashes:this.dashes,movable:t}}},{key:"getEntryInfo",value:function(){return{name:"rangecursors",valueType:"array"}}}],[{key:"properties",get:function(){return{show:{value:!1,type:"boolean"},label:{value:"",type:"string"},showLabel:{value:!1,type:"boolean"},showValue:{value:!1,type:"boolean"},showBorders:{value:!0,type:"boolean"},orientation:{value:"vertical",type:"string"},halign:{value:"top",type:"string"},transparentRange:{value:!1,type:"boolean"},lineWidth:{value:1,type:"number"},fillColor:{value:"#4F4F4F4F",type:"string"},constrainToEdge:{value:!1,type:"boolean"},xaxis:{value:"",type:"string"},yaxis:{value:"",type:"string"},xstart:{value:void 0,type:"number"},xend:{value:void 0,type:"number"},relativeXStart:{value:.45,type:"number"},relativeXEnd:{value:.55,type:"number"},ystart:{value:void 0,type:"number"},yend:{value:void 0,type:"number"},relativeYStart:{value:.45,type:"number"},relativeYEnd:{value:.55,type:"number"},dashes:{value:[],type:"object"}}}}]),n}(NationalInstruments.HtmlVI.Elements.CursorBase);JQX("ni-range-cursor",t)}();_createClass=function(){function e(e,t){for(var n=0;n<t.length;n++){var r=t[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(e,r.key,r)}}return function(t,n,r){return n&&e(t.prototype,n),r&&e(t,r),t}}();function _classCallCheck(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}!function(){var e=NationalInstruments.HtmlVI.DataPipeline,t=NationalInstruments.HtmlVI.DataPipeline.GraphDataPipeline,n=NationalInstruments.HtmlVI.DataPipeline.DataTypesEnum,r=NationalInstruments.HtmlVI.DataPipeline.TypedHistoryBuffer,a=function(e,t){var n=document.createElement("ni-cartesian-plot"),r=document.createElement("ni-cartesian-plot-renderer"),a=e.getSettings().colors;r.lineStroke=a[e.plots.length%a.length],n.show=!0,n.label=void 0===t?e.nextPlotName():t,e.appendChild(n),n.appendChild(r)},i=function(e,r){var i,o=0;i=r,Array.isArray(i)&&Array.isArray(i[0])||t.prototype.inferDataType(r)===n.niAnalogWaveformArray||t.prototype.inferDataType(r)===n.XYArrayOfClusterOfArrays||t.prototype.inferDataType(r)===n.XYArrayOfClusterOfArrayOfPoint?o=r.length:function(e){return!(!Array.isArray(e)||Array.isArray(e[0]))}(r)&&r.length>0&&(o=1);for(var s=e.plots.length;s<o;s++){var l,u=r[s];"string"==typeof u.channelName&&u.channelName.length>0&&(l=u.channelName),a(e,l)}},o=function(){function t(){_classCallCheck(this,t)}return _createClass(t,[{key:"addPlot",value:function(e){a(this.ownerElement,e)}},{key:"setNIType",value:function(e,t){this.ownerElement.valueTypeNeedsUpdate=!0}},{key:"created",value:function(){this.ownerElement.valueType=e.DataTypesEnum.unknown,this.ownerElement.valueTypeNeedsUpdate=!1}},{key:"attached",value:function(){this.ownerElement.valueType=e.inferDataTypeFromNIType(u(this.ownerElement.niType)),this.ownerElement.valueTypeNeedsUpdate=!1}},{key:"setData",value:function(t){this.ownerElement.valueTypeNeedsUpdate&&(this.ownerElement.valueType=e.inferDataTypeFromNIType(u(this.ownerElement.niType)),this.ownerElement.valueTypeNeedsUpdate=!1),i(this.ownerElement,t),window.NationalInstruments.HtmlVI.Elements.CartesianGraphBase.prototype.setData.call(this.ownerElement,t)}}],[{key:"properties",get:function(){return{niType:{value:void 0,type:"string?",observer:"setNIType"}}}},{key:"moduleName",get:function(){return"NITypedCartesianGraphModule"}}]),t}(),s=function(){function e(){_classCallCheck(this,e)}return _createClass(e,[{key:"addPlot",value:function(e){a(this.ownerElement,e)}},{key:"setNIType",value:function(e,t){h(this.ownerElement.historyBuffer,this.ownerElement.niType)}},{key:"ready",value:function(){this.ownerElement.historyBuffer=new r(this.ownerElement.bufferSize,1),h(this.ownerElement.historyBuffer,this.ownerElement.niType)}},{key:"setHistoryBuffer",value:function(e){this.ownerElement.historyBuffer=e,h(this.ownerElement.historyBuffer,this.ownerElement.niType)}},{key:"getHistoryBuffer",value:function(){return this.ownerElement.historyBuffer}}],[{key:"properties",get:function(){return{niType:{value:void 0,type:"string?",observer:"setNIType"}}}},{key:"moduleName",get:function(){return"NITypedChartModule"}}]),e}(),l=function(){function e(){_classCallCheck(this,e)}return _createClass(e,null,[{key:"properties",get:function(){return{niType:{value:NITypes.DOUBLE.makeArray(2).toJSON(),type:"string?"}}}},{key:"moduleName",get:function(){return"NITypedIntensityGraphModule"}}]),e}();function u(e){var t=null;try{e&&(t=new NIType(e))}catch(e){}return t}function h(e,t){"function"==typeof e.setNIType&&e.setNIType(u(t))}JQX.Elements.whenRegistered("ni-cartesian-graph",function(e){e.addModule(o)}),JQX.Elements.whenRegistered("ni-chart",function(e){e.addModule(s)}),JQX.Elements.whenRegistered("ni-intensity-graph",function(e){e.addModule(l)})}();_createClass=function(){function e(e,t){for(var n=0;n<t.length;n++){var r=t[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(e,r.key,r)}}return function(t,n,r){return n&&e(t.prototype,n),r&&e(t,r),t}}(),_get=function e(t,n,r){null===t&&(t=Function.prototype);var a=Object.getOwnPropertyDescriptor(t,n);if(void 0===a){var i=Object.getPrototypeOf(t);return null===i?void 0:e(i,n,r)}if("value"in a)return a.value;var o=a.get;return void 0!==o?o.call(r):void 0};function _classCallCheck(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}function _possibleConstructorReturn(e,t){if(!e)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return!t||"object"!=typeof t&&"function"!=typeof t?e:t}function _inherits(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Super expression must either be null or a function, not "+typeof t);e.prototype=Object.create(t&&t.prototype,{constructor:{value:e,enumerable:!1,writable:!0,configurable:!0}}),t&&(Object.setPrototypeOf?Object.setPrototypeOf(e,t):e.__proto__=t)}!function(){var e=function(e){function t(){return _classCallCheck(this,t),_possibleConstructorReturn(this,(t.__proto__||Object.getPrototypeOf(t)).apply(this,arguments))}return _inherits(t,e),_createClass(t,[{key:"onAxisHandleUpdates",value:function(e,t){this.syncPropertiesWithFlotAxisHandle()}},{key:"onAxisHandlePanStart",value:function(e,t){t.cookie===this&&(this.dispatchEvent(new CustomEvent("ni-axis-handle-pan-start",{bubbles:!0,cancelable:!0})),e.preventDefault(),e.stopImmediatePropagation())}},{key:"onAxisHandlePan",value:function(e,t,n,r,a){a.cookie===this&&(this.dispatchEvent(new CustomEvent("ni-axis-handle-pan",{bubbles:!0,cancelable:!0,detail:t})),e.preventDefault(),e.stopImmediatePropagation())}},{key:"onAxisHandlePanEnd",value:function(e,t){t.cookie===this&&(this.dispatchEvent(new CustomEvent("ni-axis-handle-pan-end",{bubbles:!0,cancelable:!0})),e.preventDefault(),e.stopImmediatePropagation())}},{key:"created",value:function(){_get(t.prototype.__proto__||Object.getPrototypeOf(t.prototype),"created",this).call(this),this.axisHandle=null,this._parentGraph=void 0}},{key:"sendEventToParentGraph",value:function(e){if(void 0!==this._parentGraph){var t={bubbles:!0,cancelable:!0,detail:{element:this}};this._parentGraph.dispatchEvent(new CustomEvent(e,t))}}},{key:"attached",value:function(){_get(t.prototype.__proto__||Object.getPrototypeOf(t.prototype),"attached",this).call(this),(this.parentElement instanceof JQX.CartesianGraph||this.parentElement instanceof JQX.Chart)&&this.parentElement.isReady?this.attachToGraph(this.parentElement):this._parentGraph=void 0}},{key:"attachToGraph",value:function(e){var t=this;this._parentGraph||(this._parentGraph=e,this._parentGraph.requestUpdate(),this.graphCreatedHandler=function(){t._parentGraph.graph.getPlaceholder().bind("axisHandleUpdates",t.onAxisHandleUpdates.bind(t)),t._parentGraph.graph.getPlaceholder().bind("axisHandlePanStart",t.onAxisHandlePanStart.bind(t)),t._parentGraph.graph.getPlaceholder().bind("axisHandlePan",t.onAxisHandlePan.bind(t)),t._parentGraph.graph.getPlaceholder().bind("axisHandlePanEnd",t.onAxisHandlePanEnd.bind(t))},this.graphUpdatedHandler=function(){var e=Array.from(t._parentGraph.children).filter(function(e){return e instanceof JQX.AxisHandle}).indexOf(t),n=t._parentGraph.graph.getAxisHandles()[e];n.cookie=t,t.setFlotAxisHandle(n)},e.addEventListener("ni-graph-created",this.graphCreatedHandler),this._parentGraph._isInitialized&&this.graphCreatedHandler(),e.addEventListener("ni-graph-updated",this.graphUpdatedHandler))}},{key:"propertyChangedHandler",value:function(e,n,r){_get(t.prototype.__proto__||Object.getPrototypeOf(t.prototype),"propertyChangedHandler",this).call(this,e,n,r),this._parentGraph.requestUpdate(),this.sendEventToParentGraph("ni-axis-handle-changed")}},{key:"detached",value:function(){_get(t.prototype.__proto__||Object.getPrototypeOf(t.prototype),"detached",this).call(this),this._parentGraph.removeEventListener("ni-graph-created",this.graphCreatedHandler),this._parentGraph.removeEventListener("ni-graph-updated",this.graphUpdatedHandler),this._parentGraph.requestUpdate(),this._parentGraph=void 0}},{key:"getViewConfig",value:function(){var e=this.disabled||this._parentGraph.disabled,t=("horizontal"===this.orientation?this._parentGraph.getXAxisIndexByNIControlID:this._parentGraph.getYAxisIndexByNIControlID).call(this._parentGraph,this.axis)-1;return{position:this.position,absolutePosition:this.absolutePosition,show:this.show,orientation:this.orientation,location:this.location,axisIndex:t,handleLabel:this.label,fill:this.fill,handleClassList:e?[]:["draggable"]}}},{key:"template",value:function(){return""}},{key:"setFlotAxisHandle",value:function(e){this.axisHandle=e}},{key:"syncPropertiesWithFlotAxisHandle",value:function(){this.position=this.axisHandle.position}},{key:"getEntryInfo",value:function(){return{name:"axisHandles",valueType:"array"}}}],[{key:"properties",get:function(){return{position:{value:.5,type:"number"},absolutePosition:{value:void 0,type:"number"},show:{value:!1,type:"boolean"},orientation:{value:"vertical",type:"string",allowedValues:["vertical","horizontal"]},location:{value:"far",type:"string",allowedValues:["far","near"]},axisIndex:{value:0,type:"number"},label:{value:"",type:"string"},fill:{value:void 0,type:"string"},axis:{value:"",type:"string"}}}}]),t}(window.JQX.BaseElement);JQX("ni-axis-handle",e)}();_createClass=function(){function e(e,t){for(var n=0;n<t.length;n++){var r=t[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(e,r.key,r)}}return function(t,n,r){return n&&e(t.prototype,n),r&&e(t,r),t}}(),_get=function e(t,n,r){null===t&&(t=Function.prototype);var a=Object.getOwnPropertyDescriptor(t,n);if(void 0===a){var i=Object.getPrototypeOf(t);return null===i?void 0:e(i,n,r)}if("value"in a)return a.value;var o=a.get;return void 0!==o?o.call(r):void 0};function _classCallCheck(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}function _possibleConstructorReturn(e,t){if(!e)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return!t||"object"!=typeof t&&"function"!=typeof t?e:t}function _inherits(e,t){if("function"!=typeof t&&null!==t)throw new TypeError("Super expression must either be null or a function, not "+typeof t);e.prototype=Object.create(t&&t.prototype,{constructor:{value:e,enumerable:!1,writable:!0,configurable:!0}}),t&&(Object.setPrototypeOf?Object.setPrototypeOf(e,t):e.__proto__=t)}!function(){var e=function(e){function t(){return _classCallCheck(this,t),_possibleConstructorReturn(this,(t.__proto__||Object.getPrototypeOf(t)).apply(this,arguments))}return _inherits(t,e),_createClass(t,[{key:"created",value:function(){_get(t.prototype.__proto__||Object.getPrototypeOf(t.prototype),"created",this).call(this),this._parentGraph=void 0}},{key:"attached",value:function(){_get(t.prototype.__proto__||Object.getPrototypeOf(t.prototype),"attached",this).call(this),(this.parentElement instanceof JQX.CartesianGraph||this.parentElement instanceof JQX.Chart)&&this.parentElement.isReady?this.attachToGraph(this.parentElement):this._parentGraph=void 0}},{key:"attachToGraph",value:function(e){this._parentGraph||(e.getElementsByTagName("ni-parking-lot").length>1&&console.warn("A single parking lot can be added to the graph"),this._parentGraph=e,this._parentGraph.requestUpdate())}},{key:"propertyChangedHandler",value:function(e,n,r){_get(t.prototype.__proto__||Object.getPrototypeOf(t.prototype),"propertyChangedHandler",this).call(this,e,n,r),this._parentGraph&&this._parentGraph.requestUpdate()}},{key:"detached",value:function(){_get(t.prototype.__proto__||Object.getPrototypeOf(t.prototype),"detached",this).call(this),this._parentGraph.requestUpdate(),this._parentGraph=void 0}},{key:"getViewConfig",value:function(){return{offset:this.offset,show:this.show}}},{key:"getEntryInfo",value:function(){return{name:"parkingLot",valueType:"object"}}},{key:"template",value:function(){return""}}],[{key:"properties",get:function(){return Object.assign({},_get(t.__proto__||Object.getPrototypeOf(t),"properties",this),{offset:{value:35,type:"number"},show:{value:!0,type:"boolean"}})}}]),t}(window.JQX.BaseElement);JQX("ni-parking-lot",e)}();
//# sourceMappingURL=webcharts.min.js.map

"use strict";JQX("jqx-button",function(e){function t(){return babelHelpers.classCallCheck(this,t),babelHelpers.possibleConstructorReturn(this,(t.__proto__||Object.getPrototypeOf(t)).apply(this,arguments))}return babelHelpers.inherits(t,e),babelHelpers.createClass(t,[{key:"template",value:function(){return"<button class='jqx-button' inner-h-t-m-l='[[innerHTML]]' id='button' type='[[type]]' name='[[name]]' value='[[value]]' disabled='[[disabled]]' role='button'></button>"}},{key:"focus",value:function(){var e=this;if(!e.$.button)return void HTMLElement.prototype.focus.call(e);e.$.button.focus()}},{key:"blur",value:function(){var e=this;if(!e.$.button)return void HTMLElement.prototype.blur.call(e);e.$.button.blur()}},{key:"_upHandler",value:function(e){var t=this;e.stopPropagation(),t.$.setAttributeValue("active",!1)}},{key:"_focusHandler",value:function(){this.$.setAttributeValue("focus",!0)}},{key:"_blurHandler",value:function(){this.$.setAttributeValue("focus",!1)}},{key:"_clickHandler",value:function(e){var t=this;("release"!==t.clickMode&&"pressAndRelease"!==t.clickMode||t.readonly)&&(e.preventDefault(),e.stopPropagation())}},{key:"_downHandler",value:function(e){var t=this;if(!(t.disabled||(t.hasRippleAnimation&&JQX.Utilities.Animation.Ripple.animate(t,e.pageX,e.pageY),t.$.setAttributeValue("active",!0),"press"!==t.clickMode&&"pressAndRelease"!==t.clickMode||t.readonly))){var n="buttons"in e?e.buttons:e.which;t.$.fireEvent("click",{buttons:n,clientX:e.clientX,clientY:e.clientY,pageX:e.pageX,pageY:e.pageY,screenX:e.screenX,screenY:e.screenY})}}},{key:"_mouseEnterHandler",value:function(e){var t=this;if(!t.readonly&&(t.$button.setAttributeValue("hover",!0),t.$.setAttributeValue("hover",!0),"hover"===t.clickMode)){var n="buttons"in e?e.buttons:e.which;t.$.fireEvent("click",{buttons:n,clientX:e.clientX,clientY:e.clientY,pageX:e.pageX,pageY:e.pageY,screenX:e.screenX,screenY:e.screenY})}}},{key:"_touchEndHandler",value:function(){var e=this;setTimeout(function(){e.$button.setAttributeValue("hover",!1),e.$.setAttributeValue("hover",!1)},300)}},{key:"_mouseLeaveHandler",value:function(){var e=this;e.$button.setAttributeValue("hover",!1),e.$.setAttributeValue("hover",!1)}},{key:"propertyChangedHandler",value:function(e,n,a){babelHelpers.get(t.prototype.__proto__||Object.getPrototypeOf(t.prototype),"propertyChangedHandler",this).call(this,e,n,a);var r=this;"disabled"===e?(r._setFocusable(),r.$button&&r.$button.setAttributeValue("hover",!1),r.$.setAttributeValue("hover",!1),r instanceof JQX.RepeatButton&&r._stopRepeat()):"unfocusable"===e&&r._setFocusable()}},{key:"_setFocusable",value:function(){var e=this,t=e.$.button?e.$.button:e;if(e.disabled||e.unfocusable)return t.removeAttribute("tabindex"),void(t.tabIndex=-1);t.tabIndex=e.tabIndex>0?e.tabIndex:0}},{key:"ready",value:function(){var e=this;babelHelpers.get(t.prototype.__proto__||Object.getPrototypeOf(t.prototype),"ready",this).call(this),e._setFocusable()}}],[{key:"properties",get:function(){return{value:{type:"string"},name:{type:"string"},type:{value:"button",type:"string"},clickMode:{allowedValues:["hover","press","release","pressAndRelease"],type:"string",value:"release"}}}},{key:"styleUrls",get:function(){return["jqx.button.css"]}},{key:"listeners",get:function(){return{"button.down":"_downHandler","button.mouseenter":"_mouseEnterHandler","button.mouseleave":"_mouseLeaveHandler","button.touchend":"_touchEndHandler","button.click":"_clickHandler","button.up":"_upHandler",up:"_upHandler","button.focus":"_focusHandler","button.blur":"_blurHandler"}}}]),t}(JQX.ContentElement)),JQX("jqx-repeat-button",function(e){function t(){return babelHelpers.classCallCheck(this,t),babelHelpers.possibleConstructorReturn(this,(t.__proto__||Object.getPrototypeOf(t)).apply(this,arguments))}return babelHelpers.inherits(t,e),babelHelpers.createClass(t,[{key:"_clickHandler",value:function(e){var t=this;("release"!==t.clickMode||t.preventDefaultClick||t.readonly||t.disabled)&&(e.preventDefault(),e.stopPropagation(),t.preventDefaultClick=!1)}},{key:"_updateInBoundsFlag",value:function(e){var t=this;t._isPointerInBounds=!0,"mouseleave"===e.type?(t._isPointerInBounds=!1,t.$button.setAttributeValue("hover",!1),t.$.setAttributeValue("hover",!1)):(t.$button.setAttributeValue("hover",!0),t.$.setAttributeValue("hover",!0)),1!==("buttons"in e?e.buttons:e.which)&&t._stopRepeat(e)}},{key:"_startRepeat",value:function(e){var t=this;t._initialTimer||t.readonly||(t._initialTimer=setTimeout(function(){t._repeatTimer=setInterval(function(){if(t._isPointerInBounds){var n="buttons"in e?e.buttons:e.which;t.$.fireEvent("click",{buttons:n,clientX:e.clientX,clientY:e.clientY,pageX:e.pageX,pageY:e.pageY,screenX:e.screenX,screenY:e.screenY}),t.preventDefaultClick=!0}},t.delay)},t.initialDelay))}},{key:"_stopRepeat",value:function(){var e=this;e.readonly||(e.$.setAttributeValue("active",!1),e._repeatTimer&&(clearInterval(e._repeatTimer),e._repeatTimer=null),e._initialTimer&&(clearTimeout(e._initialTimer),e._initialTimer=null))}}],[{key:"properties",get:function(){return{delay:{value:50,type:"number"},initialDelay:{value:150,type:"number"}}}},{key:"listeners",get:function(){return{"button.mousedown":"_startRepeat","button.mouseenter":"_updateInBoundsFlag","button.mouseleave":"_updateInBoundsFlag","document.mouseup":"_stopRepeat"}}}]),t}(JQX.Button)),JQX("jqx-toggle-button",function(e){function t(){return babelHelpers.classCallCheck(this,t),babelHelpers.possibleConstructorReturn(this,(t.__proto__||Object.getPrototypeOf(t)).apply(this,arguments))}return babelHelpers.inherits(t,e),babelHelpers.createClass(t,[{key:"ready",value:function(){babelHelpers.get(t.prototype.__proto__||Object.getPrototypeOf(t.prototype),"ready",this).call(this)}},{key:"_buttonClickHandler",value:function(){}},{key:"_buttonMouseLeaveHandler",value:function(){this.removeAttribute("hover")}},{key:"_buttonMouseEnterHandler",value:function(){var e=this;e.setAttribute("hover",""),e.disabled||e.readonly||"hover"!==e.clickMode||(e._changeCheckState("pointer"),e.focus(),e._updateHidenInputNameAndValue())}},{key:"_documentUpHandler",value:function(){var e=this;e._pressed&&(e._pressed=!1,e.disabled||e.readonly||"press"===e.clickMode||(e._changeCheckState("pointer"),e.focus(),e._updateHidenInputNameAndValue()))}},{key:"_downHandler",value:function(e){var t=this;t.disabled||t.readonly||(t.hasRippleAnimation&&JQX.Utilities.Animation.Ripple.animate(t,e.pageX,e.pageY),t._pressed=!0,"press"!==t.clickMode&&"pressAndRelease"!==t.clickMode||(t._changeCheckState("pointer"),t.$.fireEvent("click"),t._updateHidenInputNameAndValue()),"press"===t.clickMode&&(e.preventDefault(),e.stopPropagation()))}},{key:"_dragStartHandler",value:function(e){e.preventDefault()}},{key:"_keyHandler",value:function(e){var t=this;if(!0!==t.disabled&&!t.readonly&&32===e.keyCode){if("keydown"===e.type)return void e.preventDefault();if("none"===t.switchMode)return;t._changeCheckState("keyboard"),t._updateHidenInputNameAndValue()}}},{key:"_changeCheckState",value:function(e){var t=this,n=null;null===t.checked?t.checked=!0:(n=t.checked,t.checked=!t.checked),t._handleTextSelection(),t.$.fireEvent("change",{value:t.checked,oldValue:n,changeType:e})}},{key:"_handleTextSelection",value:function(){var e=this;e.$.addClass("jqx-unselectable"),e.timer&&clearTimeout(e.timer),e.timer=setTimeout(function(){return e.$.removeClass("jqx-unselectable")},500)}},{key:"propertyChangedHandler",value:function(e,n,a){babelHelpers.get(t.prototype.__proto__||Object.getPrototypeOf(t.prototype),"propertyChangedHandler",this).call(this,e,n,a);var r=this;switch("checked"===e&&r.$.fireEvent("change",{value:a,oldValue:n,changeType:"api"}),e){case"trueTemplate":r._handleTemplate(!0);break;case"falseTemplate":r._handleTemplate(!1);break;case"indeterminateTemplate":r._handleTemplate()}}},{key:"_htmlBindOnInitialization",value:function(){var e=this;e._bindContentProperty("trueContent","jqx-true-content"),e._bindContentProperty("falseContent","jqx-false-content"),e._bindContentProperty("indeterminateContent","jqx-indeterminate-content")}},{key:"_bindContentProperty",value:function(e,t){var n=this;if(n.$[e+"Container"]){var a=document.createElement("div");a.innerHTML=n.innerHTML;var r=a.getElementsByClassName(t),o=void 0;if(r.length>0)for(var i=0;i<r.length;i++)o=r[i];""===n[e]&&(n[e]=void 0===o?"":o.outerHTML),n.$[e+"Container"].innerHTML=n[e]}}},{key:"_updateContentProperties",value:function(){function e(e){t.$[e+"Container"]&&(t[e]=t.$[e+"Container"].innerHTML)}var t=this;e("trueContent"),e("falseContent"),e("indeterminateContent")}},{key:"_updateHidenInputValue",value:function(){var e=this;if(e.$.hiddenInput){var t=void 0;t=null===e.checked?"null":!1===e.checked?"off":e.value||"on",e.$.hiddenInput.setAttribute("value",t)}}},{key:"_updateHidenInputName",value:function(){var e=this;if(e.$.hiddenInput){var t=!1===e.checked?"":e.name||"";e.$.hiddenInput.setAttribute("name",t)}}},{key:"_updateHidenInputNameAndValue",value:function(){var e=this;e._updateHidenInputName(),e._updateHidenInputValue()}},{key:"_handleTemplate",value:function(e,t){var n=this,a=void 0,r=void 0,o=void 0;if(!0===e?(a=n.trueTemplate,r=n.$.trueContentContainer,o=n.trueContent):!1===e?(a=n.falseTemplate,r=n.$.falseContentContainer,o=n.falseContent):(a=n.indeterminateTemplate,r=n.$.indeterminateContentContainer,o=n.indeterminateContent),t&&(r.innerHTML=o||""),null!==a&&a){if("function"==typeof a)return void a(r,{value:o});if(!("content"in document.createElement("template")))return void n.error(n.localize("htmlTemplateNotSuported",{elementType:n.nodeName.toLowerCase()}));if(null===(a=document.getElementById(a))||!("content"in a))return void n.error(n.localize("invalidTemplate",{elementType:n.nodeName.toLowerCase(),property:"template"}));for(var i=a.content,l=i.childNodes.length,u=/{{\w+}}/g,s=void 0,c=[],d=0;d<l;d++)for(s=u.exec(i.childNodes[d].innerHTML);s;)c.push({childNodeIndex:d,bindingString:s[0]}),s=u.exec(i.childNodes[d].innerHTML);for(var p=c.length,b=document.importNode(a.content,!0),v=void 0,h=void 0,y=0;y<p;y++){v=b.childNodes[c[y].childNodeIndex],h=c.length;for(var f=0;f<h;f++)v.innerHTML=v.innerHTML.replace(c[y].bindingString,o)}r.innerHTML="";for(var _=0;_<b.childNodes.length;_++)b.childNodes[_].outerHTML&&(r.innerHTML+=b.childNodes[_].outerHTML)}}}],[{key:"properties",get:function(){return{checked:{value:!1,type:"boolean?"},falseContent:{value:"",reflectToAttribute:!1,type:"string"},indeterminateContent:{value:"",reflectToAttribute:!1,type:"string"},indeterminate:{value:!1,type:"boolean"},trueContent:{value:"",reflectToAttribute:!1,type:"string"},indeterminateTemplate:{value:null,type:"any"},trueTemplate:{value:null,type:"any"},falseTemplate:{value:null,type:"any"},type:{value:"toggle",type:"string",defaultReflectToAttribute:!0,readonly:!0}}}},{key:"listeners",get:function(){return{keydown:"_keyHandler",keyup:"_keyHandler",dragstart:"_dragStartHandler","button.click":"_buttonClickHandler","button.mouseenter":"_buttonMouseEnterHandler","button.mouseleave":"_buttonMouseLeaveHandler","document.up":"_documentUpHandler"}}}]),t}(JQX.Button));
//# sourceMappingURL=jqxbutton.js.map

"use strict";JQX("jqx-check-box",function(e){function t(){return babelHelpers.classCallCheck(this,t),babelHelpers.possibleConstructorReturn(this,(t.__proto__||Object.getPrototypeOf(t)).apply(this,arguments))}return babelHelpers.inherits(t,e),babelHelpers.createClass(t,[{key:"template",value:function(){return"<div id='container' class='jqx-container'>\n                 <div class ='jqx-overlay'></div>\n                 <span id='checkBoxInput' class ='jqx-input'></span>\n                 <span id='checkBoxLabel' inner-h-t-m-l='[[innerHTML]]' class ='jqx-label'><content></content></span>\n                 <input id='hiddenInput' class ='jqx-hidden-input' type='hidden'>\n               </div>"}},{key:"_focusHandler",value:function(){this.$.setAttributeValue("focus",!0)}},{key:"_blurHandler",value:function(){this.$.setAttributeValue("focus",!1)}},{key:"_mouseEnterHandler",value:function(){this.$.setAttributeValue("hover",!0)}},{key:"_mouseLeaveHandler",value:function(){this.$.setAttributeValue("hover",!1)}},{key:"ready",value:function(){var e=this;babelHelpers.get(t.prototype.__proto__||Object.getPrototypeOf(t.prototype),"ready",this).call(this),e.indeterminate&&(e._valueCashe=e.checked,e.checked=null),e._updateHidenInputNameAndValue()}},{key:"propertyChangedHandler",value:function(e,n,a){babelHelpers.get(t.prototype.__proto__||Object.getPrototypeOf(t.prototype),"propertyChangedHandler",this).call(this,e,n,a);var l=this;switch(l._updateContentProperties(),e){case"indeterminate":a?(l._valueCashe=l.checked,l.checked=null):l.checked=l._valueCashe,l._updateHidenInputNameAndValue();break;case"value":case"checked":l._updateHidenInputNameAndValue();break;case"name":l._updateHidenInputName()}}},{key:"_documentUpHandler",value:function(e){var t=this,n=t.enableShadowDOM?e.originalEvent.composedPath()[0]:e.originalEvent.target;if(t._pressed&&(t._pressed=!1,t.$.setAttributeValue("active",!1),!(t.disabled||t.readonly||"input"===t.checkMode&&n!==t.$.checkBoxInput||"label"===t.checkMode&&n!==t.$.checkBoxLabel))){if("press"===t.clickMode)return e.preventDefault(),void e.stopPropagation();t._changeCheckState("pointer"),t.focus(),t._handleTextSelection(),t._updateHidenInputNameAndValue()}}},{key:"_downHandler",value:function(e){var t=this,n=t.enableShadowDOM?e.originalEvent.composedPath()[0]:e.originalEvent.target;if(!(t.disabled||t.readonly||"input"===t.checkMode&&n!==t.$.checkBoxInput||"label"===t.checkMode&&n!==t.$.checkBoxLabel)){if(t.$.setAttributeValue("active",!0),t.hasRippleAnimation){var a=t.$.checkBoxInput.getBoundingClientRect(),l=window.scrollX||window.pageXOffset,o=window.scrollY||window.pageYOffset;JQX.Utilities.Animation.Ripple.animate(t.$.checkBoxInput,a.left+a.width/2+l,a.top+a.height/2+o)}t._pressed=!0,"press"!==t.clickMode&&"pressAndRelease"!==t.clickMode||(t._changeCheckState("pointer"),t.$.fireEvent("click"),t.focus(),t._updateHidenInputNameAndValue())}}}],[{key:"properties",get:function(){return{checkMode:{value:"both",allowedValues:["both","input","label"],type:"string"},type:{value:"checkbox",type:"string",defaultReflectToAttribute:!0,readonly:!0}}}},{key:"listeners",get:function(){return{down:"_downHandler","document.up":"_documentUpHandler","checkBoxInput.mouseenter":"_mouseEnterHandler","checkBoxInput.mouseleave":"_mouseLeaveHandler",focus:"_focusHandler",blur:"_blurHandler"}}},{key:"styleUrls",get:function(){return["jqx.checkbox.css"]}}]),t}(JQX.ToggleButton));
//# sourceMappingURL=jqxcheckbox.js.map

"use strict";JQX("jqx-accordion-item",function(e){function t(){return babelHelpers.classCallCheck(this,t),babelHelpers.possibleConstructorReturn(this,(t.__proto__||Object.getPrototypeOf(t)).apply(this,arguments))}return babelHelpers.inherits(t,e),babelHelpers.createClass(t,[{key:"template",value:function(){return'<div id="container">\n                    <div id="accordionItemHeader" class ="jqx-accordion-item-header jqx-unselectable">\n                        <span id="arrow" class ="jqx-arrow"></span>\n                        <span id="label" class ="jqx-label" inner-h-t-m-l=\'[[label]]\'></span>\n                    </div>\n                    <div id="accordionItemContent" class ="jqx-accordion-item-content">\n                        <div id="contentContainer" class ="jqx-content-container"><content></content></div>\n                    </div>\n                </div>'}},{key:"propertyChangedHandler",value:function(e,n,a){if(babelHelpers.get(t.prototype.__proto__||Object.getPrototypeOf(t.prototype),"propertyChangedHandler",this).call(this,e,n,a),n=parseInt(n),a=parseInt(a),"index"===e&&!isNaN(n)&&!isNaN(a)){var i=this,r=i.parentElement.parentElement._items.length;a<0?a=0:a>=r&&(a=r-1),a!==n&&i.$.fireEvent("indexChange",{newIndex:a,oldIndex:n}),i.index=a}}},{key:"_headerMouseEnterHandler",value:function(){var e=this;e.disabled||e.setAttribute("hovered","")}},{key:"_headerMouseLeaveHandler",value:function(){var e=this;e.disabled||e.removeAttribute("hovered")}},{key:"_ripple",value:function(e){var t=this;t.disabled||t.hasRippleAnimation&&JQX.Utilities.Animation.Ripple.animate(t.$.container,e.pageX,e.pageY)}},{key:"_setIndex",value:function(e){var t=this,n=t.context;t.context=t,t.index=e,t.context=n}},{key:"enableShadowDOM",get:function(){return!1}}],[{key:"properties",get:function(){return{dragged:{value:!1,type:"boolean"},expanded:{value:!1,type:"boolean"},focused:{value:!1,type:"boolean"},index:{value:null,type:"number?"},label:{value:"",type:"string"}}}},{key:"listeners",get:function(){return{"accordionItemHeader.mouseenter":"_headerMouseEnterHandler","accordionItemHeader.mouseleave":"_headerMouseLeaveHandler","accordionItemHeader.down":"_ripple"}}}]),t}(JQX.ContentElement)),JQX("jqx-accordion",function(e){function t(){return babelHelpers.classCallCheck(this,t),babelHelpers.possibleConstructorReturn(this,(t.__proto__||Object.getPrototypeOf(t)).apply(this,arguments))}return babelHelpers.inherits(t,e),babelHelpers.createClass(t,[{key:"template",value:function(){return'<div id="container">\n                    <content></content>\n                </div>'}},{key:"ready",value:function(){babelHelpers.get(t.prototype.__proto__||Object.getPrototypeOf(t.prototype),"ready",this).call(this),this._createElement()}},{key:"propertyChangedHandler",value:function(e,n,a){function i(){r._toggleItems("expand",[0]),r.expandedIndexes=[0]}var r=this;if("expandedIndexes"===e){if(n.toString()===a.toString())return;var o=[];if(r._items.length>0)for(var d=0;d<a.length;d++){var s=parseInt(a[d]);if(!isNaN(s)){if(r._expandModeIs(["single","singleFitHeight","toggle"])){o.length<1&&s>=0&&s<r._items.length&&o.push(s);break}s>=0&&s<=r._items.length&&-1===o.indexOf(s)&&o.push(s)}}if(0===o.length&&r._expandModeIs(["single","singleFitHeight"]))return a=n.slice(),void(r.expandedIndexes=a);a=o;var l=r._compareExpandedIndexes(n,a);return r._toggleItems("collapse",l.collapse),r._toggleItems("expand",l.expand),void(r.expandedIndexes=a)}switch(babelHelpers.get(t.prototype.__proto__||Object.getPrototypeOf(t.prototype),"propertyChangedHandler",this).call(this,e,n,a),e){case"disabled":r._setFocusable(),r._enableDisableHandler();break;case"expandMode":if(0===r._items.length)break;if("multiple"===n&&"none"!==a||"none"===n&&"multiple"!==a){var c=r.expandedIndexes.slice(1);r._toggleItems("collapse",c),0===r.expandedIndexes.length&&r._expandModeIs(["single","singleFitHeight"])&&i()}else"toggle"===n&&r._expandModeIs(["single","singleFitHeight"])&&0===r.expandedIndexes.length&&i();if(!r._supportCSSVariables||!r._usedCSSVariables){var p=r.expandedIndexes[0];"singleFitHeight"===n?r._items[p].$.accordionItemContent.style.height="":"singleFitHeight"===a&&(r._items[p].$.accordionItemContent.style.height=r._expandedItemsContainerHeight-1+"px")}break;case"unfocusable":r._setFocusable()}}},{key:"appendChild",value:function(e){var t=this;if(!t.isCompleted||e instanceof HTMLElement&&(e.classList.contains("jqx-resize-trigger-container")||e.classList.contains("jqx-measure-element"))){var n=Array.prototype.slice.call(arguments,2);return HTMLElement.prototype.appendChild.apply(t,n.concat(Array.prototype.slice.call(arguments)))}e instanceof JQX.AccordionItem||t.error(t.localize("accordionItemRequired",{method:"appendChild"})),t.insert(t._items.length,e)}},{key:"collapse",value:function(e,t){var n=this;if(e=n._validateItemsIndex(e,"collapse"),!isNaN(e)){!n._items[e].expanded||n._expandModeIs(["single","singleFitHeight"])&&n.expandedIndexes.indexOf(e)>-1||n._collapseItem(e,t)}}},{key:"expand",value:function(e,t){var n=this;if(e=n._validateItemsIndex(e,"expand"),!isNaN(e)){n._items[e].expanded||(n._expandModeIs(["single","singleFitHeight","toggle"])&&n._toggleItems("collapse",n.expandedIndexes),n._expandItem(e,t))}}},{key:"insert",value:function(e,t){var n=this,a=0===n._items.length,i=void 0,r=void 0;if(t||("number"==typeof e?t=[{label:"",content:""}]:(t=[{label:e?e.toString():"",content:e?e.toString():""}],e=0)),t instanceof HTMLElement)t instanceof JQX.AccordionItem?i=t:n.error(n.localize("accordionItemRequired",{method:"insert"}));else if(Array.isArray(t)){r=document.createDocumentFragment();for(var o=0;o<t.length;o++){var d=n._createItem(t[o]);r.appendChild(d)}}else i=t instanceof Object?n._createItem(t):"string"==typeof t||"number"==typeof t?n._createItem({label:t.toString(),content:t.toString()}):n._createItem({label:"",content:""});e>n._items.length?i?n.$.container.appendChild(i):n.$.container.appendChild(r):i?n.$.container.insertBefore(i,n._items[e]):n.$.container.insertBefore(r,n._items[e]),i&&(i.tabIndex=n._tabIndex),n._storeItems(),a&&n._expandModeIs(["single","singleFitHeight"])?n._expandItem(0):n.expandedIndexes=n._getExpandedIndexes(),n._updateExpanedContentHeight(),n._updateInlineHeight(),n._storeItemsCoordinates(),n._updateItemsIndexProperty()}},{key:"insertBefore",value:function(e,t){var n=this;if(!n.isCompleted){var a=Array.prototype.slice.call(arguments,2);return HTMLElement.prototype.insertBefore.apply(n,a.concat(Array.prototype.slice.call(arguments)))}void 0!==e&&void 0!==t&&e instanceof JQX.AccordionItem&&t instanceof JQX.AccordionItem||n.error(n.localize("accordionItemRequired",{method:"insertBefore"})),void 0!==t&&null!==t?(n.contains(t)||n.error(n.localize("referenceNodeNotChild",{argument:"referenceNode"})),n.insert(n._items.indexOf(t),e)):n.insert(n._items.indexOf(t),e)}},{key:"remove",value:function(e){var t=this,n=void 0;if(e instanceof HTMLElement)e instanceof JQX.AccordionItem?t.contains(e)||t.error(t.localize("referenceNodeNotChild",{argument:"node"})):t.error(t.localize("accordionItemRequired",{method:"remove"})),n=e,e=n.index;else{if(e=t._validateItemsIndex(e,"remove"),isNaN(e))return;n=t._items[e]}n&&(n.parentNode.removeChild(n),t._storeItems(),t._expandModeIs(["singleFitHeight"])&&(t._preventAnimation=!0),t._expandModeIs(["single","singleFitHeight"])&&e===t.expandedIndexes[0]&&t._items.length>0&&(t._expandItem(0),t._selectedItem=t._items[0],t._selectedItemIndex=0,t._itemIsFocussed=!0),t.expandedIndexes=t._getExpandedIndexes(),t._updateExpanedContentHeight(),t._updateInlineHeight(),t._storeItemsCoordinates(),t._updateItemsIndexProperty())}},{key:"removeChild",value:function(e){var n=this;if(!n.isCompleted){var a=Array.prototype.slice.call(arguments,2);return HTMLElement.prototype.removeChild.apply(n,a.concat(Array.prototype.slice.call(arguments)))}if(e instanceof HTMLElement||n.error(n.localize("accordionItemRequired",{method:"removeChild"})),"jqx-resize-trigger-container"===e.className)return void babelHelpers.get(t.prototype.__proto__||Object.getPrototypeOf(t.prototype),"removeChild",this).call(this,e);e instanceof JQX.AccordionItem||n.error(n.localize("accordionItemRequired",{method:"removeChild"})),n.contains(e)||n.error(n.localize("referenceNodeNotChild",{argument:"node"})),n.remove(e)}},{key:"_setFocusable",value:function(){var e=this;if(e.disabled||e.unfocusable){e.removeAttribute("tabindex");for(var t=0;t<e._items.length;t++)e._items[t].removeAttribute("tabindex")}else{e.tabIndex=e._tabIndex;for(var n=0;n<e._items.length;n++)e._items[n].tabIndex=e._tabIndex}}},{key:"update",value:function(e,t){var n=this;if(e=n._validateItemsIndex(e,"update"),!isNaN(e)){var a=n._items[e];if(t||n.error(n.localize("invalidSettings",{elementType:n.nodeName.toLowerCase(),method:"update"})),a)if(Array.isArray(t)&&(t=0===t.length?{label:"",content:""}:t[0]),"string"==typeof t)a.content=t;else for(var i in t)a[i]=t[i];var r=n._getItemsHeights(e);n._updateExpanedContentLocalHeight(n._items[e],r),n._updateInlineHeight(),n._storeItemsCoordinates()}}},{key:"_adjustHeightValue",value:function(e){for(var t=this,n=t._items.length,a=void 0,i=void 0,r=0;r<n&&(t._items[r].expanded?a=t._items[r]:i=t._items[r],!a||!i);r++);if(a||(a=t._items[0]),a||i){var o=a.expanded;a.expanded=!0;var d=window.getComputedStyle(a,null),s=!!i&&window.getComputedStyle(i,null),l=parseInt(d.getPropertyValue("margin-top"))+parseInt(d.getPropertyValue("margin-bottom")),c=s?parseInt(s.getPropertyValue("margin-top"))+parseInt(s.getPropertyValue("margin-bottom")):0;return a.expanded=o,e-((n-1)*c+l)}}},{key:"_collapseItem",value:function(e,t){var n=this,a=n._items[e];if(a.expanded&&("none"!==n.expandMode||!t)){if(a.expanded=!1,n.$.fireEvent("collapsing",{index:e,label:a.label,content:a.content.innerHTML}),n.expandedIndexes.indexOf(e)>-1){var i=n.expandedIndexes.indexOf(e),r=n.expandedIndexes.slice();r.splice(i,1),n.expandedIndexes=r}a.$.accordionItemContent.style.height="",n._handleAnimationsDuration(a,e,"collapsed")}}},{key:"_compareExpandedIndexes",value:function(e,t){for(var n=[],a=[],i=[],r=e.length,o=t.length,d=0;d<r;d++)-1===t.indexOf(e[d])?-1===n.indexOf(e[d])&&n.push(e[d]):-1===a.indexOf(e[d])&&a.push(e[d]);for(var s=0;s<o;s++)-1===a.indexOf(t[s])&&i.push(t[s]);return{collapse:n,expand:i}}},{key:"_createElement",value:function(){var e=this;e._reorderItemsByIndex(),e._usedCSSVariables=Boolean(window.getComputedStyle(e.$.container).getPropertyValue("--jqx-accordion-animation-duration")),e._supportCSSVariables=JQX.Utilities.Core.CSSVariablesSupport(),e._storeItems(),e._enableDisableHandler(),e._expandedIndexesHandler(),e._updateExpanedContentHeight(),e._tabIndex=e.tabIndex<=0?0:e.tabIndex,e._setFocusable(),e._updateItemsIndexProperty(),e._updateInlineHeight();for(var t=0;t<e._items.length;t++)e._items[t].$.arrow.classList.add("jqx-animate-trigger")}},{key:"_createItem",value:function(e){var t=this,n=document.createElement("jqx-accordion-item");if(e)return n.disabled=t.disabled,t._tabIndex>-1&&(n.tabIndex=t._tabIndex),"string"==typeof e||"number"==typeof e?(n.label=e+"",n.content=e+"",n):(n.label=e.label||"",n.content=e.content||"",n)}},{key:"_downHandler",value:function(e){var t=this;if(!(t.disabled||t.readonly||"none"===t.expandMode||t._toggled)){var n=t.enableShadowDOM?t.shadowRoot.elementFromPoint(e.pageX,e.pageY):e.originalEvent.target,a=n.closest(".jqx-accordion-item-header"),i=n.closest("jqx-accordion-item");if(!a)return void(i&&(i.focused=!0));t._selectedItem=i,t._itemIsPressed=t._itemIsFocussed=!0,t._reorderedIndex=t._selectedItemIndex=t._items.indexOf(i),t._storeItemsCoordinates()}}},{key:"_enableDisableHandler",value:function(){var e=this;if(e.disabled)for(var t=0;t<e._items.length;t++)e._items[t].disabled=!0;else for(var n=0;n<e._items.length;n++)e._items[n].disabled=!1}},{key:"_expandedIndexesHandler",value:function(){var e=this,t=e._getExpandedIndexes("initial"),n=t.length,a=e.expandedIndexes.length;if(0!==e._items.length){if(0===a&&n>0&&(e.expandedIndexes=t,a=n),e._expandModeIs(["multiple","none"])||1===a)return void e._toggleItems("expand",e.expandedIndexes);switch(e.expandMode){case"single":case"singleFitHeight":0===a?e._toggleItems("expand",[0]):a>1&&(e._toggleItems("collapse",e.expandedIndexes.splice(0,1)),e._toggleItems("expand",e.expandedIndexes));break;case"toggle":a>1&&(e._toggleItems("collapse",e.expandedIndexes.splice(0,1)),e._toggleItems("expand",e.expandedIndexes))}}}},{key:"_expandItem",value:function(e,t){var n=this,a=n._items[e];if(!(a.expanded||"none"===n.expandMode&&t)){if(a.$.container.style.getPropertyValue("--jqx-accordion-expanded-content-local-height")||(a.expanded=!0,a.$.container.style.setProperty("--jqx-accordion-expanded-content-local-height",a.$.accordionItemContent.scrollHeight+"px"),a.expanded=!1),a.expanded=!0,n.$.fireEvent("expanding",{index:e,label:a.label,content:a.content.innerHTML}),-1===n.expandedIndexes.indexOf(e)){var i=n.expandedIndexes.slice();i.push(e),n.expandedIndexes=i}n._supportCSSVariables&&n._usedCSSVariables||"singleFitHeight"!==n.expandMode||(a.$.accordionItemContent.style.height=n._expandedItemsContainerHeight-1+"px"),n._handleAnimationsDuration(a,e,"expanded")}}},{key:"_expandModeIs",value:function(e){var t=this;return e.indexOf(t.expandMode)>-1}},{key:"_focusHandler",value:function(){var e=this;e.disabled||0===e._items.length||(e._itemIsFocussed?e._selectedItem.focused=!1:e._items[0].focused=!1)}},{key:"_getExpandedIndexes",value:function(e){for(var t=this,n=[],a=0;a<t._items.length;a++)"initial"===e?t._items[a].hasAttribute("expanded")&&(n.push(a),t._items[a].removeAttribute("expanded")):t._items[a].expanded&&n.push(a);return n.slice()}},{key:"_getItemsHeights",value:function(e){var t=this,n=t._items,a=n.length,i=[];if(0!==a){if(!isNaN(e)&&e>=0&&e<a){var r=n[e],o=0;return r.expanded?o=r.$.accordionItemContent.scrollHeight:(r.expanded=!0,o=r.$.accordionItemContent.scrollHeight,r.expanded=!1),o+"px"}for(var d=0;d<a;d++){var s=n[d],l=0;s.expanded?l=s.$.accordionItemContent.scrollHeight:(s.expanded=!0,l=s.$.accordionItemContent.scrollHeight,s.expanded=!1),i.push(l+"px")}return t._heightCalcAfterInitialization=!0,i}}},{key:"_handleAnimationsDuration",value:function(e,t,n){var a=this;if(!a._animationAfterInitialization)return void(a._animationAfterInitialization=!0);if(1===a._items.length&&"singleFitHeight"===a.expandMode)return void a.$.fireEvent(n,{index:t,label:e.label,content:e.content.innerHTML});if(!1===a.hasAnimation||!a._supportCSSVariables)return void a.$.fireEvent(n,{index:t,label:e.label,content:e.content.innerHTML});if(a._preventAnimation)return a.$.fireEvent(n,{index:t,label:e.label,content:e.content.innerHTML}),void(a._preventAnimation=!1);a._toggled=!0;var i=window.getComputedStyle(a).animationDuration,r=void 0;if(i.indexOf("ms")>-1)i=parseFloat(i.substring(0,i.length-2)),r=isNaN(i)||i<0?0:i-50;else{if(!(i.indexOf("s")>-1))return void a.$.fireEvent(n,{index:t,label:e.label,content:e.content.innerHTML});i=parseFloat(i.substring(0,i.length-1)),r=isNaN(i)||i<0?0:1e3*i-50}e instanceof JQX.AccordionItem&&(e.$.addClass("jqx-toggled-item"),a.$container.addClass("jqx-toggling"),setTimeout(function(){e.$.removeClass("jqx-toggled-item"),a.$container.removeClass("jqx-toggling"),a.$.fireEvent(n,{index:t}),a._toggled=!1},r))}},{key:"_indexChangeHandler",value:function(e){var t=this,n=t._items,a=n.length,i=e.detail;i.newIndex>=a?t.$.container.appendChild(n[i.oldIndex]):i.newIndex>i.oldIndex?t.$.container.insertBefore(n[i.oldIndex],n[i.newIndex+1]):t.$.container.insertBefore(n[i.oldIndex],n[i.newIndex]);var r=t.enableShadowDOM?t.shadowRoot.querySelectorAll("jqx-accordion-item"):t.getElementsByTagName("jqx-accordion-item");t._items=Array.from(r),t._updateItemsIndexProperty()}},{key:"_keyDownHandler",value:function(e){function t(e){e===o||isNaN(e)||(r.focused=!1,o=e,r=a._items[o],r.focused=!0)}function n(e){if("up"===e)return void t(o-1<0?0:o-1);t(o+1>s?s:o+1)}var a=this,i=e.key;if(!("none"===a.expandMode||a.disabled||a.readonly||a._toggled)&&-1!==["ArrowLeft","ArrowDown","ArrowRight","ArrowUp","End","Home"," ","Enter","Tab"].indexOf(i)&&document.activeElement instanceof JQX.AccordionItem){"Tab"!==i&&e.preventDefault();for(var r=void 0,o=void 0,d=a._items.length,s=d-1,l=0;l<d;l++){var c=a._items[l];c.focused&&(r=c,o=l)}switch(i){case"Tab":n(e.shiftKey?"up":"down");break;case"ArrowLeft":a.collapse(o);break;case"ArrowDown":n("down");break;case"ArrowRight":a.expand(o);break;case"ArrowUp":n("up");break;case"End":t(s);break;case"Home":t(0);break;case" ":case"Enter":if(r.expanded)return void a.collapse(o);a.expand(o);break;default:return}}}},{key:"_moveHandler",value:function(e){var t=this;if(t._itemIsPressed&&t.reorder&&!t.readonly&&!(t._items.length<2))if(t._dragStart){if(t.$container.addClass("jqx-reordering"),!t._dragging){var n=t._selectedItem;t.$.fireEvent("dragStart",{position:{left:e.pageX,top:e.pageY},target:e.originalEvent.target,index:t._selectedItemIndex,label:n.label,content:n.content.innerHTML}),t._selectedItem.dragged=t._dragging=!0}for(var a=e.clientY,i=!1,r=0;r<t._itemsCoordinates.length;r++){var o=t._itemsCoordinates[r];if(a>=o.fromY&&a<=o.toY){i=r;break}}if(!0!==t._preventReorder&&!1!==i&&i!==t._reorderedIndex){if(Math.abs(t._reorderedIndex-i)>1){var d=t._reorderedIndex-i<0?-1:1;t._swapItems(t._reorderedIndex,i+d)}t._swapItems(t._reorderedIndex,i),t._reorderedIndex=i,t._storeItemsCoordinates()}a<t._itemsCoordinates[t._reorderedIndex].fromY||a>t._itemsCoordinates[t._reorderedIndex].toY?t._preventReorder=!0:t._preventReorder=!1,Math.abs(t._reorderedIndex-i)>1&&(t._preventReorder=!1)}else t._dragStart=!0}},{key:"_reorderItemsByIndex",value:function(){var e=this,t=e.enableShadowDOM?e.shadowRoot.querySelectorAll("jqx-accordion-item"):e.getElementsByTagName("jqx-accordion-item"),n=Array.from(t),a=!1,i=n.map(function(e){return null!==e.index?a=!0:e.index=0,e.index});if(a){var r=n.length;if(!(r<2)){var o=i.slice();if(o.sort(function(e,t){return parseInt(e)-parseInt(t)}),i.toString()!==o.toString())for(var d=0;d<r;d++){for(var s=void 0,l=0;l<r;l++)t[l].index===o[d]&&(s=t[l]);e.$.container.insertBefore(s,t[d])}}}}},{key:"_resizeHandler",value:function(){var e=this;e._updateExpanedContentHeight(),e._updateInlineHeight(),e._storeItemsCoordinates()}},{key:"_storeItems",value:function(){var e=this,t=e.enableShadowDOM?e.shadowRoot.querySelectorAll("jqx-accordion-item"):e.getElementsByTagName("jqx-accordion-item");if(e._items=Array.from(t),0===e._items.length)return void e.$container.addClass("jqx-empty");e.$container.removeClass("jqx-empty");for(var n=e._getItemsHeights(),a=0;a<e._items.length;a++)e._updateExpanedContentLocalHeight(e._items[a],n[a])}},{key:"_storeItemsCoordinates",value:function(){var e=this;if(!e.disabled&&e.reorder){for(var t=[],n=0;n<e._items.length;n++){var a=e._items[n],i=a.getBoundingClientRect();t.push({fromY:i.top+(window.scrollY||window.pageYOffset),toY:i.bottom+(window.scrollY||window.pageYOffset)})}e._itemsCoordinates=t}}},{key:"_swapItems",value:function(e,t){var n=this,a=Math.min(e,t),i=Math.max(e,t),r=n._items,o=n.expandedIndexes.slice();if(n._items[e].expanded&&!n._items[t].expanded){o[o.indexOf(e)]=t,n.expandedIndexes=o.slice()}else if(n._items[t].expanded&&!n._items[e].expanded){var d=o.indexOf(t);o[d]=e,n.expandedIndexes=o.slice()}n.selectedIndex=n.selectedIndex===e?t:e,n.$.container.insertBefore(r[i],r[a]),function(e,t,n){var a=e[n];e[n]=e[t],e[t]=a}(r,e,t),n._items[e].$.removeClass("hovered"),n._reorderedIndex=t}},{key:"_toggleItems",value:function(e,t){var n=this,a=t.length;if(a>0)for(var i=0;i<a;i++)n["_"+e+"Item"](t[i])}},{key:"_updateExpanedContentHeight",value:function(){var e=this;e.$.container.style.setProperty("--jqx-accordion-item-header-height","");var t=e._items.length,n=e.$.container.offsetHeight,a=e._items[e.expandedIndexes[0]],i=0,r=0,o=0,d=0;if(1===t){var s=e._items[0];s.expanded=!1,i=s.offsetHeight,r=s.$.accordionItemHeader.offsetHeight,s.expanded=!0}else for(;0===i&&d<t;){var l=e._items[d];l instanceof JQX.AccordionItem&&!l.expanded&&(i=l.offsetHeight,r=l.$.accordionItemHeader.offsetHeight),d++}if(t>1&&a instanceof JQX.AccordionItem){o=a.$.accordionItemHeader.offsetHeight-r}var c=getComputedStyle(e.$.root),p=i*t,m=n-p-o-parseFloat(c.paddingBottom)-parseFloat(c.paddingTop);"singleFitHeight"===e.expandMode&&(m=e._adjustHeightValue(m)),m=m>=0?m:0,e.$.container.style.setProperty("--jqx-accordion-expanded-content-height",m+"px"),e.$.container.style.setProperty("--jqx-accordion-item-header-height",r+"px"),e._expandedItemsContainerHeight=m}},{key:"_updateExpanedContentLocalHeight",value:function(e,t){var n=this;n._supportCSSVariables&&n._usedCSSVariables&&e.$.container.style.setProperty("--jqx-accordion-expanded-content-local-height",t)}},{key:"_updateInlineHeight",value:function(){var e=this;e._supportCSSVariables&&e._usedCSSVariables||"singleFitHeight"!==e.expandMode||0===e._items.length||(e._items[e.expandedIndexes[0]].$.accordionItemContent.style.height=e._expandedItemsContainerHeight-1+"px")}},{key:"_updateItemsIndexProperty",value:function(){for(var e=this,t=[],n=0;n<e._items.length;n++)e._items[n]._setIndex(n),e._items[n].expanded&&t.push(n);e.expandedIndexes=t.slice()}},{key:"_upHandler",value:function(e){var t=this;if(t._itemIsPressed&&!t.disabled&&!t.readonly){for(var n=0;n<t._items.length;n++)n!==t._selectedItemIndex&&(t._items[n].focused=!1);if(t._selectedItem.focused=!0,t._dragging){var a=t._selectedItem;t.$container.removeClass("jqx-reordering"),t.$.fireEvent("dragEnd",{position:{left:e.pageX,top:e.pageY},target:e.originalEvent.target,index:t._selectedItemIndex,label:a.label,content:a.content.innerHTML})}else t._selectedItem.expanded?t.collapse(t._selectedItemIndex,!0):t.expand(t._selectedItemIndex,!0);t._reorderedIndex=void 0,t._dragStart=!1,t._dragging=!1,t._itemIsPressed=!1,t._selectedItem.dragged=!1,t._updateItemsIndexProperty()}}},{key:"_validateItemsIndex",value:function(e,t){var n=this;return isNaN(parseInt(e))||e<0||e>n._items.length-1?void n.log(n.localize("indexOutOfBound",{elementType:n.nodeName.toLowerCase(),method:t})):parseInt(e)}}],[{key:"properties",get:function(){return{expandedIndexes:{value:[],type:"array"},expandMode:{allowedValues:["single","singleFitHeight","multiple","toggle","none"],value:"singleFitHeight",type:"string"},messages:{extend:!0,value:{en:{accordionItemRequired:'{{elementType}}: "{{method}}" requires an item from type "jqx-accordion-item".',indexOutOfBound:'{{elementType}}: Out of bound index/indexes in "{{method}}" method.',invalidSettings:'{{elementType}}: "{{method}}" method accepts a string or an object as it\'s second parameter.',missingReference:"{{elementType}}: Missing reference to {{files}}.",noItems:"{{elementType}}: No child elements found.",overridingProperties:'{{elementType}}: Overriding properties {{property1}} and {{property2}} applied. The "{{property1}}" property is used by default.'}},type:"object"},reorder:{value:!1,type:"boolean"}}}},{key:"listeners",get:function(){return{down:"_downHandler",focus:"_focusHandler",indexChange:"_indexChangeHandler",keydown:"_keyDownHandler",move:"_moveHandler",resize:"_resizeHandler",styleChanged:"_resizeHandler","document.up":"_upHandler"}}},{key:"styleUrls",get:function(){return["jqx.accordion.css"]}}]),t}(JQX.BaseElement));
//# sourceMappingURL=jqxaccordion.js.map

"use strict";JQX("jqx-scroll-bar",function(t){function e(){return babelHelpers.classCallCheck(this,e),babelHelpers.possibleConstructorReturn(this,(e.__proto__||Object.getPrototypeOf(e)).apply(this,arguments))}return babelHelpers.inherits(e,t),babelHelpers.createClass(e,[{key:"template",value:function(){return'<div id="container" class="jqx-container">\n                    <div id="nearButton" class ="jqx-scroll-button jqx-arrow-left"></div>\n                    <div  id="track" class ="jqx-track">\n                        <div id="thumb" class="jqx-thumb"></div>\n                    </div>\n                    <div id="farButton" class ="jqx-scroll-button jqx-arrow-right"></div>\n            </div>'}},{key:"_updateInBoundsFlag",value:function(t){var e=this,a=t.target;a._isPointerInBounds=!0,"mouseleave"===t.type&&(a._isPointerInBounds=!1),1!==("buttons"in t?t.buttons:t.which)&&e._stopRepeat(t)}},{key:"_startRepeat",value:function(t){var e=this;if(!e.disabled){var a=t.target;a._initialTimer||(a._initialTimer=setTimeout(function(){a._repeatTimer=setInterval(function(){if(a._isPointerInBounds){var e="buttons"in t?t.buttons:t.which;a.$.fireEvent("click",{buttons:e,clientX:t.clientX,clientY:t.clientY,pageX:t.pageX,pageY:t.pageY,screenX:t.screenX,screenY:t.screenY})}},e.clickRepeatDelay)},3*e.clickRepeatDelay))}}},{key:"_stopRepeat",value:function(t){if(!this.disabled){var e=t.target;e._repeatTimer&&(clearInterval(e._repeatTimer),e._repeatTimer=null),e._initialTimer&&(clearTimeout(e._initialTimer),e._initialTimer=null)}}},{key:"_calculateThumbSize",value:function(t){var e=this,a=e.max-e.min,n="horizontal"===e.orientation?e.$.track.offsetWidth>10:e.$.track.offsetHeight>10,r=0;return a>=1&&n?(r=t/(a+t)*t,e.$.thumb.className.indexOf("jqx-hidden")>=0&&e.$thumb.removeClass("jqx-hidden")):e.$thumb.addClass("jqx-hidden"),Math.max(10,Math.min(r,t))}},{key:"_dragStartHandler",value:function(t){var e=this;e.disabled||(e.thumbCapture=!0,e.dragStartX=t.clientX,e.dragStartY=t.clientY,e.dragStartValue=e.value,t.stopPropagation(),t.preventDefault())}},{key:"_dragHandler",value:function(t){var e=this;if(!0===e.thumbCapture){e._isThumbDragged=!0;var a=(e.max-e.min)/(e.scrollBarSize-e.thumbSize),n="horizontal"===e.orientation?(t.clientX-e.dragStartX)*a:(t.clientY-e.dragStartY)*a,r=n;e.rightToLeft&&"horizontal"===e.orientation&&(r=-n),e._updateValue(e.dragStartValue+r),t.stopPropagation(),t.preventDefault(),t.originalEvent&&(t.originalEvent.stopPropagation(),t.originalEvent.preventDefault())}}},{key:"_dragEndHandler",value:function(t){var e=this;e._trackDownTimer&&(clearInterval(e._trackDownTimer),e._trackDownTimer=null),e.thumbCapture&&(e.thumbCapture=!1,e._isThumbDragged=!1,"switchWhenReleased"===e.mechanicalAction?e._updateValue(e.dragStartValue,e.value):"switchUntilReleased"===this.mechanicalAction&&e._updateValue(e.dragStartValue),t.preventDefault(),t.stopPropagation(),t.originalEvent.preventDefault(),t.originalEvent.stopPropagation())}},{key:"_farButtonClickHandler",value:function(){var t=this;if(!t.disabled){var e=t.value;t._updateValue(t.value+t.step),"switchUntilReleased"===t.mechanicalAction&&t._updateValue(e)}}},{key:"_nearButtonClickHandler",value:function(){var t=this;if(!t.disabled){var e=t.value;t._updateValue(t.value-t.step),"switchUntilReleased"===t.mechanicalAction&&t._updateValue(e)}}},{key:"propertyChangedHandler",value:function(t,a,n){babelHelpers.get(e.prototype.__proto__||Object.getPrototypeOf(e.prototype),"propertyChangedHandler",this).call(this,t,a,n);var r=this;switch(t){case"min":case"max":case"orientation":case"showButtons":r._layout();break;case"value":r._updateValue(a,n)}}},{key:"ready",value:function(){babelHelpers.get(e.prototype.__proto__||Object.getPrototypeOf(e.prototype),"ready",this).call(this),this._layout()}},{key:"_resizeHandler",value:function(){this._layout()}},{key:"refresh",value:function(){this._layout()}},{key:"_layout",value:function(){var t=this;t.scrollBarSize="horizontal"===t.orientation?t.$.track.offsetWidth:t.$.track.offsetHeight,t.thumbSize=t._calculateThumbSize(t.scrollBarSize),"horizontal"===t.orientation&&t.$.thumb.style.width!==t.thumbSize+"px"?t.$.thumb.style.width=t.thumbSize+"px":"vertical"===t.orientation&&t.$.thumb.style.height!==t.thumbSize+"px"&&(t.$.thumb.style.height=t.thumbSize+"px"),"horizontal"===t.orientation?(t.$.nearButton.classList.contains("jqx-arrow-up")&&t.$.nearButton.classList.remove("jqx-arrow-up"),t.$.farButton.classList.contains("jqx-arrow-down")&&t.$.farButton.classList.remove("jqx-arrow-down"),t.$.nearButton.classList.contains("jqx-arrow-left")||t.$.nearButton.classList.add("jqx-arrow-left"),t.$.farButton.classList.contains("jqx-arrow-right")||t.$.farButton.classList.add("jqx-arrow-right")):(t.$.nearButton.classList.contains("jqx-arrow-left")&&t.$.nearButton.classList.remove("jqx-arrow-left"),t.$.farButton.classList.contains("jqx-arrow-right")&&t.$.farButton.classList.remove("jqx-arrow-right"),t.$.nearButton.classList.contains("jqx-arrow-up")||t.$.nearButton.classList.add("jqx-arrow-up"),t.$.farButton.classList.contains("jqx-arrow-down")||t.$.farButton.classList.add("jqx-arrow-down")),t._updateThumbPosition(),(t.value>t.max||t.value<t.min)&&t._updateValue(t.value,t.value>t.max?t.max:t.min)}},{key:"_selectStartHandler",value:function(t){this.thumbCapture&&t.preventDefault()}},{key:"_trackDownHandler",value:function(t){var e=this;t.target===e.$.track&&(e._trackDownTimer=setInterval(function(){e._trackClickHandler(t)},e.clickRepeatDelay),t.stopPropagation(),t.preventDefault())}},{key:"_trackClickHandler",value:function(t){var e=this;if(!e.disabled){if(e._isThumbDragged)return clearInterval(e._trackDownTimer),void(e._trackDownTimer=null);var a=e.$.thumb.getBoundingClientRect(),n=t.pageX-window.pageXOffset,r=t.pageY-window.pageYOffset,i=e.value;"horizontal"===e.orientation?n>(e._isThumbDragged?e.dragStartX:a.right)?e._updateValue(e.value+e.largeStep):n<(e._isThumbDragged?e.dragStartX:a.left)&&e._updateValue(e.value-e.largeStep):r>(e._isThumbDragged?e.dragStartY:a.bottom)?e._updateValue(e.value+e.largeStep):r<(e._isThumbDragged?e.dragStartY:a.top)&&e._updateValue(e.value-e.largeStep),"switchUntilReleased"===e.mechanicalAction&&e._updateValue(i)}}},{key:"_updateValue",value:function(t,e){var a=this;if(1===arguments.length&&(e=t,t=a.value),(void 0===e||isNaN(e))&&(e=a.min),e>a.max&&(e=a.max),e<a.min&&(e=a.min),a.value=e,t!==e){if(a._updateThumbPosition(),a.thumbCapture&&"switchWhenReleased"===a.mechanicalAction)return;if(a.onChange)return void a.onChange({value:a.value,oldValue:t,min:a.min,max:a.max});a.$.fireEvent("change",{value:a.value,oldValue:t,min:a.min,max:a.max})}}},{key:"_updateThumbPosition",value:function(){var t=this,e=t.$.track.offsetHeight,a=t.$.track.offsetWidth,n="horizontal"===t.orientation?a:e,r=t._calculateThumbSize(n),i="horizontal"===t.orientation?a-r:e-r,l=(n-r)/(t.max-t.min)*(t.value-t.min);t.rightToLeft&&"horizontal"===t.orientation&&(l=(n-r)/(t.max-t.min)*(t.max-t.value-t.min)),l=Math.min(i,Math.max(0,l)),"vertical"===t.orientation&&t.$.thumb.style.top!==l+"px"?t.$.thumb.style.top=l+"px":"horizontal"===t.orientation&&t.$.thumb.style.left!==l+"px"&&(t.$.thumb.style.left=l+"px")}}],[{key:"properties",get:function(){return{clickRepeatDelay:{type:"integer",value:50},largeStep:{type:"integer",value:100},min:{type:"integer",value:0},max:{type:"integer",value:1e3},mechanicalAction:{value:"switchWhileDragging",allowedValues:["switchUntilReleased","switchWhenReleased","switchWhileDragging"],type:"string"},orientation:{type:"string",value:"horizontal",allowedValues:["horizontal","vertical"]},step:{type:"integer",value:10},showButtons:{type:"boolean",value:!0,defaultReflectToAttribute:!0},value:{type:"integer",value:0}}}},{key:"styleUrls",get:function(){return["jqx.scrollbar.css"]}},{key:"listeners",get:function(){return{"nearButton.click":"_nearButtonClickHandler","nearButton.mousedown":"_startRepeat","nearButton.mouseup":"_stopRepeat","nearButton.mouseenter":"_updateInBoundsFlag","nearButton.mouseleave":"_updateInBoundsFlag","farButton.click":"_farButtonClickHandler","farButton.mousedown":"_startRepeat","farButton.mouseup":"_stopRepeat","farButton.mouseenter":"_updateInBoundsFlag","farButton.mouseleave":"_updateInBoundsFlag","track.down":"_trackDownHandler","track.click":"_trackClickHandler","thumb.down":"_dragStartHandler","document.move":"_dragHandler","document.up":"_dragEndHandler",up:"_dragEndHandler","document.selectstart":"_selectStartHandler",resize:"_resizeHandler"}}}]),e}(JQX.BaseElement));
//# sourceMappingURL=jqxscrollbar.js.map

"use strict";JQX("jqx-list-item",function(e){function t(){return babelHelpers.classCallCheck(this,t),babelHelpers.possibleConstructorReturn(this,(t.__proto__||Object.getPrototypeOf(t)).apply(this,arguments))}return babelHelpers.inherits(t,e),babelHelpers.createClass(t,[{key:"template",value:function(){return'<div id="container">\n                   <span id=\'itemInput\' class =\'jqx-input jqx-hidden\'></span>\n                    <span class ="jqx-overlay" id="overlay"></span>\n                    <div id="itemContainer" class ="jqx-content jqx-list-item-container"><span class="jqx-content-label" inner-h-t-m-l=\'[[innerHTML]]\'><content></content></span><span inner-h-t-m-l=\'[[details]]\' id="details" class="jqx-content-details"></span></div>\n                </div>'}},{key:"appendChild",value:function(e){var t=this;if(!t.isCompleted||e.classList.contains("jqx-ripple")){var i=Array.prototype.slice.call(arguments,2);return HTMLElement.prototype.appendChild.apply(t,i.concat(Array.prototype.slice.call(arguments)))}t.$.itemContainer.innerHTML="",e instanceof HTMLElement&&t.$.itemContainer.appendChild(e)}},{key:"insertBefore",value:function(e,t){var i=this;if(!i.isCompleted){var r=Array.prototype.slice.call(arguments,2);return HTMLElement.prototype.insertBefore.apply(i,r.concat(Array.prototype.slice.call(arguments)))}t.parentNode.insertBefore(e,t)}},{key:"removeChild",value:function(e){var t=this;if(!t.isCompleted||e.classList.contains("jqx-ripple")){var i=Array.prototype.slice.call(arguments,2);return HTMLElement.prototype.removeChild.apply(t,i.concat(Array.prototype.slice.call(arguments)))}e instanceof HTMLElement&&t.$.itemContainer.removeChild(e)}},{key:"attached",value:function(){var e=this;babelHelpers.get(t.prototype.__proto__||Object.getPrototypeOf(t.prototype),"attached",this).call(this),e.ownerListBox=e.getListBox()}},{key:"ready",value:function(){babelHelpers.get(t.prototype.__proto__||Object.getPrototypeOf(t.prototype),"ready",this).call(this);var e=this;""!==e.label?e.innerHTML=e.label:""!==e.innerHTML&&(e.label=e.innerHTML),e._setDisplayMode(e.displayMode),e.$.container.noRipple=!0}},{key:"propertyChangedHandler",value:function(e,i,r){var n=this;if(babelHelpers.get(t.prototype.__proto__||Object.getPrototypeOf(t.prototype),"propertyChangedHandler",this).call(this,e,i,r),"hidden"===e&&(r?n.$.addClass("jqx-hidden"):n.$.removeClass("jqx-hidden")),"displayMode"===e&&n._setDisplayMode(r),"label"===e){var o=n.context;n.context=document,n.innerHTML=r;n.getListBox().onItemUpdated(n),n.context=o}if("details"===e){var l=n.context;n.context=document,n.$.details.innerHTML=r;n.getListBox().onItemUpdated(n),n.context=l}if("innerHTML"===e){n.getListBox().onItemUpdated(n)}}},{key:"getListBox",value:function(){for(var e=this,t=e.parentNode;t instanceof JQX.ListBox==!1&&null!==t;)t=t.parentNode;return!t&&JQX.EnableShadowDOM?e.getRootNode().host:t}},{key:"_itemOnMouseEnter",value:function(){var e=this;!e.disabled&&e.ownerListBox&&(JQX.ListBox.DragDrop.Dragging&&e.ownerListBox.allowDrop&&(JQX.ListBox.DragDrop.DropDetails={item:e,position:"bottom"}),e.ownerListBox.$.verticalScrollBar.thumbCapture||e.ownerListBox.$.horizontalScrollBar.thumbCapture||e.setAttribute("hover",""))}},{key:"_itemOnMouseMove",value:function(e){var t=this;if(t.ownerListBox&&JQX.ListBox.DragDrop.Dragging&&t.ownerListBox.allowDrop&&!JQX.Utilities.Core.isMobile){for(var i=[].slice.call(t.ownerListBox.getElementsByClassName("jqx-list-item-bottom-line-feedback")),r=0;r<i.length;r++)i[r].$.removeClass("jqx-list-item-line-feedback"),i[r].$.removeClass("jqx-list-item-bottom-line-feedback");if(JQX.ListBox.DragDrop.DropDetails={item:t,position:"top"},!t.ownerListBox._areCSSVarsSupported){if(t.ownerListBox._indexOf(t)===t.ownerListBox._items.length-1||t.parentNode.lastElementChild===t){var n=t.getBoundingClientRect();e.pageY-window.pageYOffset>n.top+n.height/2-1&&(JQX.ListBox.DragDrop.DropDetails={item:t,position:"bottom"})}return}if(t.$.removeClass("jqx-list-item-line-feedback"),t.$.removeClass("jqx-list-item-bottom-line-feedback"),t.ownerListBox.sorted&&t.ownerListBox.autoSort)return;var o=t.ownerListBox._items.filter(function(e){return!e.hidden});if(o.indexOf(t)===o.length-1||t.parentNode.lastElementChild===t){var l=t.getBoundingClientRect();e.pageY-window.pageYOffset>l.top+l.height/2-1?(t.$.addClass("jqx-list-item-bottom-line-feedback"),JQX.ListBox.DragDrop.DropDetails={item:t,position:"bottom"}):arguments[1]||t.$.addClass("jqx-list-item-line-feedback")}else arguments[1]||t.$.addClass("jqx-list-item-line-feedback")}}},{key:"_itemOnMouseLeave",value:function(){var e=this;e.ownerListBox&&(JQX.ListBox.DragDrop.Dragging&&(e.$.removeClass("jqx-list-item-line-feedback"),e.$.removeClass("jqx-list-item-bottom-line-feedback")),e.removeAttribute("hover"))}},{key:"_setDisplayMode",value:function(e){var t=this,i=t.getListBox();if(i){var r="checkBox"===i.selectionMode||"radioButton"===i.selectionMode?i.selectionMode:"plain";t.displayMode=e=r}if("plain"===e)return void t.$itemInput.addClass("jqx-hidden");t.$itemInput.removeClass("jqx-hidden")}},{key:"hasStyleObserver",get:function(){return!1}},{key:"enableShadowDOM",get:function(){return!1}},{key:"_focused",get:function(){var e=this;return void 0===e.__focused&&(e.__focused=!1),e.__focused},set:function(e){var t=this;t.__focused=e,e?t.setAttribute("focus",""):t.removeAttribute("focus")}}],[{key:"properties",get:function(){return{alternationIndex:{value:-1,type:"int"},displayMode:{allowedValues:["plain","checkBox","radioButton"],value:"plain",type:"string"},grouped:{value:!1,type:"boolean"},selected:{value:!1,type:"boolean"},value:{value:"",type:"string"},label:{value:"",type:"string"},details:{value:"",type:"string"},group:{value:"",type:"string"},hidden:{value:!1,type:"boolean"},readonly:{value:!1,type:"boolean"}}}},{key:"listeners",get:function(){return{mouseenter:"_itemOnMouseEnter",mouseleave:"_itemOnMouseLeave"}}}]),t}(JQX.ContentElement)),JQX("jqx-list-items-group",function(e){function t(){return babelHelpers.classCallCheck(this,t),babelHelpers.possibleConstructorReturn(this,(t.__proto__||Object.getPrototypeOf(t)).apply(this,arguments))}return babelHelpers.inherits(t,e),babelHelpers.createClass(t,[{key:"template",value:function(){return'<div id="container">\n                 <span id="itemsLabel" class ="jqx-list-items-group-label">[[label]]</span>\n                 <div id="listItemsGroupContainer" inner-h-t-m-l=\'[[innerHTML]]\' class ="jqx-list-items-group-container">\n                    <content></content>\n                 </div>\n               </div>'}},{key:"appendChild",value:function(e){var t=this;if(!t.isCompleted){var i=Array.prototype.slice.call(arguments,2);return HTMLElement.prototype.appendChild.apply(t,i.concat(Array.prototype.slice.call(arguments)))}e instanceof HTMLElement&&t.$.listItemsGroupContainer.appendChild(e)}},{key:"removeChild",value:function(e){var t=this;if(!t.isCompleted){var i=Array.prototype.slice.call(arguments,2);return HTMLElement.prototype.removeChild.apply(t,i.concat(Array.prototype.slice.call(arguments)))}e instanceof HTMLElement&&t.$.listItemsGroupContainer.removeChild(e)}},{key:"getListBox",value:function(){for(var e=this,t=e.parentNode;t instanceof JQX.ListBox==!1&&null!==t;)t=t.parentNode;return t}},{key:"attached",value:function(){var e=this;babelHelpers.get(t.prototype.__proto__||Object.getPrototypeOf(t.prototype),"attached",this).call(this),e.ownerListBox||(e.ownerListBox=e.getListBox())}},{key:"enableShadowDOM",get:function(){return!1}}],[{key:"properties",get:function(){return{label:{value:"",type:"string"}}}}]),t}(JQX.ContentElement)),JQX("jqx-list-box",function(e){function t(){return babelHelpers.classCallCheck(this,t),babelHelpers.possibleConstructorReturn(this,(t.__proto__||Object.getPrototypeOf(t)).apply(this,arguments))}return babelHelpers.inherits(t,e),babelHelpers.createClass(t,[{key:"template",value:function(){return'<div id="container" class="jqx-container">\n                 <div class="jqx-list-box-filter-input-container jqx-hidden" id="filterInputContainer">\n                     <input id="filterInput" disabled="[[disabled]]" placeholder=\'[[filterInputPlaceholder]]\'>\n                 </div>\n                 <div id="itemsContainer" class="jqx-list-items-container">\n                      <div id="placeholder" class ="jqx-placeholder">[[placeholder]]</div>\n                      <div id="itemsInnerContainer" inner-h-t-m-l=\'[[innerHTML]]\' class ="jqx-list-items-inner-container">\n                          <content></content>\n                      </div>\n                      <input type="text" id="editInput" class= "jqx-hidden"/>\n                 </div>\n                 <jqx-scroll-bar wait id="verticalScrollBar" disabled="[[disabled]]" orientation="vertical"></jqx-scroll-bar>\n                 <jqx-scroll-bar wait id="horizontalScrollBar" disabled="[[disabled]]" ></jqx-scroll-bar>\n                 <div id="loadingIndicatorContainer" class ="jqx-loader-container">\n                    <span id="loadingIndicator" class="jqx-loader"></span>\n                    <span id="loadingIndicatorPlaceHolder" class ="jqx-loader-label jqx-hidden">[[loadingIndicatorPlaceholder]]</span>\n                 </div>\n                <input id="hiddenInput" type="hidden" name="[[name]]">\n                </div>'}},{key:"_mouseLeaveHandler",value:function(){for(var e=this,t=[].slice.call(e.getElementsByClassName("jqx-list-item-bottom-line-feedback")),i=0;i<t.length;i++)t[i].$.removeClass("jqx-list-item-line-feedback"),t[i].$.removeClass("jqx-list-item-bottom-line-feedback")}},{key:"_downHandler",value:function(e){var t=this;if(!(t.disabled||t.displayLoadingIndicator||t.readonly)){var i=e.originalEvent.target,r=null;if(!(i instanceof JQX.ListItem)||i.disabled||i.hidden||i instanceof JQX.ListItemsGroup)for(;i.parentElement;){if(i instanceof JQX.ListItem&&!i.disabled&&!i.hidden&&!(i instanceof JQX.ListItemsGroup)){r=i.dataItem;break}i=i.parentElement}else r=i.dataItem;JQX.ListBox.DragDrop.StartTime=new Date,JQX.ListBox.DragDrop.StartPosition={left:e.pageX,top:e.pageY},r&&(e.stopPropagation(),t.hasRippleAnimation&&(r.readonly||r.disabled||JQX.Utilities.Animation.Ripple.animate(i.$.overlay,e.pageX,e.pageY)),JQX.Utilities.Core.isMobile||"press"!==t.selectionChangeAction||(t._focus(r),t.select(r)),!JQX.ListBox.DragDrop.Feedback&&t.allowDrag&&(JQX.ListBox.DragDrop.Feedback=document.createElement("span"),t.dragFeedbackFormatFunction?JQX.ListBox.DragDrop.Feedback.innerHTML=t.dragFeedbackFormatFunction(r):JQX.ListBox.DragDrop.Feedback.appendChild(r.offsetHeight?r.cloneNode(!0):t._createItem(r)),JQX.ListBox.DragDrop.Item=r,JQX.Utilities.Extend(JQX.ListBox.DragDrop.Feedback).addClass("jqx-popup jqx-list-item jqx-list-item-feedback")))}}},{key:"_dblclickEventHandler",value:function(e){var t=this;if(t.editable){var i=e.target.closest("jqx-list-item");if(!(i instanceof JQX.ListItem)||i.disabled||i.readonly)return void t.$editInput.addClass("jqx-hidden");t.$.editInput.owner=i,t.$.editInput.value=i.label,t.$.editInput.style.height=i.offsetHeight+"px",t.$.editInput.style.top=i.offsetTop+"px",t.$editInput.hasClass("jqx-hidden")&&t.$editInput.removeClass("jqx-hidden"),t.$.editInput.focus()}}},{key:"_editInputEventHandler",value:function(e){var t=this;if("blur"===e.type||"keydown"===e.type&&"Escape"===e.key)return t.$editInput.hasClass("jqx-hidden")||t.$editInput.addClass("jqx-hidden"),void t.focus();if("keydown"!==e.type&&!t.$editInput.hasClass("jqx-hidden")){var i=e.target;if(e.stopPropagation(),i.owner.label!==i.value&&(i.owner.label=i.value,t.itemTemplate&&t._applyTemplate(i.owner),t.dataSource)){var r=i.owner.dataIndex,n=t.dataSource[r];n&&(t.displayMember?n[t.displayMember]=i.value:n.label=i.value)}t.$editInput.addClass("jqx-hidden"),t.$.fireEvent("itemLabelChange",{selected:i.owner.selected,disabled:i.owner.disabled,index:t._indexOf(i.owner),label:i.owner.label,value:i.owner.value})}}},{key:"_pointerUpHandler",value:function(e){var t=this,i=e.originalEvent,r=i.target,n=function(i){var n=i.ownerListBox;n.disabled||n!==t||n.displayLoadingIndicator||"none"===n.selectionMode||i.grouped||i.readonly||(n._focus(i),n.select(i),e.preventDefault(),JQX.ListBox.DragDrop.StartPosition=null,t.$.fireEvent("itemClick",{selected:r.selected,disabled:r.disabled,index:t._indexOf(r),label:r.label,value:r.value}))};if(i.target instanceof JQX.ListItem&&!i.target.disabled&&!(i.target instanceof JQX.ListItemsGroup))return void n(r.dataItem);for(;r.parentElement;){if(r instanceof JQX.ListItem&&!r.disabled&&!(r instanceof JQX.ListItemsGroup)){n(r.dataItem);break}r=r.parentElement}if(this.enableShadowDOM&&"shadow"===this.shadowDomMode)for(var o=i.composedPath(),l=0;l<o.length;l++){var a=o[l];a instanceof JQX.ListItem&&!a.disabled&&n(a.dataItem)}}},{key:"_upHandler",value:function(e){var t=this;if(!t.disabled&&!t.readonly&&JQX.ListBox.DragDrop.StartPosition){if(JQX.Utilities.Core.isMobile&&!JQX.ListBox.DragDrop.Dragging){var i=Math.abs(e.pageX-JQX.ListBox.DragDrop.StartPosition.left),r=Math.abs(e.pageY-JQX.ListBox.DragDrop.StartPosition.top),n=i>=0&&i<=3&&r>=0&&r<=3;if(JQX.Utilities.Core.isMobile&&new Date-JQX.ListBox.DragDrop.StartTime>=300&&(n=!1,JQX.ListBox.DragDrop.StartTime=null),n){var o=e.originalEvent.target.closest("jqx-list-box");o?o._pointerUpHandler(e):t._pointerUpHandler(e),JQX.ListBox.DragDrop.StartPosition=null}else{var l=e.originalEvent.target;if(!(e.target instanceof JQX.ListItem)||l.readonly||e.target.disabled||e.target instanceof JQX.ListItemsGroup)for(;l.parentElement;){if(l instanceof JQX.ListItem&&!l.readonly&&!l.disabled&&!(l instanceof JQX.ListItemsGroup)){e.preventDefault(),e.stopPropagation();break}l=l.parentElement}else e.preventDefault(),e.stopPropagation()}}else if(!JQX.Utilities.Core.isMobile&&!JQX.ListBox.DragDrop.Dragging&&"release"===t.selectionChangeAction){var a=e.originalEvent.target.closest("jqx-list-box");a?a._pointerUpHandler(e):t._pointerUpHandler(e)}if(JQX.ListBox.DragDrop.Feedback){JQX.ListBox.DragDrop.Feedback.parentNode&&JQX.ListBox.DragDrop.Feedback.parentNode.removeChild(JQX.ListBox.DragDrop.Feedback),JQX.ListBox.DragDrop.Feedback=null;var s=void 0;if(JQX.Utilities.Core.isMobile&&JQX.ListBox.DragDrop.Dragging)for(var d=0;d<JQX.ListBox.DragDrop.ListBoxes.length;d++){var c=JQX.ListBox.DragDrop.ListBoxes[d],p=c.getBoundingClientRect();if(c.allowDrop&&!c.closest(".jqx-visibility-hidden")&&(p.left<=e.pageX&&e.pageX<=p.left+p.width&&p.top<=e.pageY&&e.pageY<=p.top+p.height)){s=c;for(var u=c._items.filter(function(e){return!e.hidden}),f=0;f<u.length;f++){var h=u[f],m=h.getBoundingClientRect();if((u.indexOf(h)===u.length-1||h.parentNode.lastElementChild===h)&&e.pageY>=p.top+h.offsetTop-c.scrollTop+m.height/2&&e.pageY<=p.top-c.scrollTop+h.offsetTop+m.height){JQX.ListBox.DragDrop.DropDetails={item:h,position:"bottom"};break}if(e.pageY>=p.top+h.offsetTop-c.scrollTop&&e.pageY<=p.top+h.offsetTop+m.height-c.scrollTop){JQX.ListBox.DragDrop.DropDetails={item:h,position:"top"};break}}}}if(JQX.ListBox.DragDrop.Dragging){if(JQX.ListBox.DragDrop.DropDetails){var g=JQX.ListBox.DragDrop.DropDetails.item,v=JQX.ListBox.DragDrop.Item,_=v.ownerListBox;if(s=!s&&e.originalEvent.target.closest?e.originalEvent.target.closest("jqx-list-box"):s,document.body.classList.remove("jqx-dragging"),g.$.removeClass("jqx-list-item-line-feedback"),g.$.removeClass("jqx-list-item-bottom-line-feedback"),s&&g.ownerListBox!==s&&s.items.length>0&&(g=s.items[s.items.length-1]),JQX.ListBox.DragDrop.Item===g||s!==g.ownerListBox&&!JQX.Utilities.Core.isMobile)s&&0===s._items.length&&"none"!==s.dropAction&&("move"===s.dropAction?JQX.ListBox.DragDrop.Item.ownerListBox.removeChild(JQX.ListBox.DragDrop.Item):"copy"===s.dropAction&&(v=v.cloneNode(!0)),s.appendChild(v));else if("none"!==v.ownerListBox.dropAction){g.ownerListBox!==v.ownerListBox&&"move"===v.ownerListBox.dropAction&&JQX.ListBox.DragDrop.Item.ownerListBox.removeChild(JQX.ListBox.DragDrop.Item),"copy"===v.ownerListBox.dropAction&&(v=v.cloneNode(!0)),JQX.ListBox.DragDrop.Item.group=g.group;var y=g.ownerListBox;"checkBox"!==y.selectionMode&&"radioButton"!==y.selectionMode&&y.clearSelection(),"top"===JQX.ListBox.DragDrop.DropDetails.position?y.insertBefore(v,g):g.parentNode.lastElementChild===g?y.appendChild(v):y.appendChild(v,g),y.ensureVisible(v),"checkBox"===y.selectionMode||"radioButton"===y.selectionMode?(y._focus(v),y._refreshSelection()):(y.clearSelection(),y.select(v))}v.selected&&s!==_&&_._refreshSelection();var x=JQX.ListBox.DragDrop.Item,b=x.ownerListBox;x.displayMode="checkBox"===b.selectionMode||"radioButton"===b.selectionMode?b.selectionMode:"plain",b.$.fireEvent("dragEnd",{item:x,target:g,data:JQX.ListBox.DragDrop,previousContainer:_,container:s,originalEvent:e}),b._focus(x)}else{var I=JQX.ListBox.DragDrop.Item,C=I.ownerListBox;I.displayMode="checkBox"===C.selectionMode||"radioButton"===C.selectionMode?C.selectionMode:"plain",C.$.fireEvent("dragEnd",{item:I,target:null,data:JQX.ListBox.DragDrop,previousContainer:C,container:C,originalEvent:e}),C._focus(I)}e.preventDefault()}JQX.ListBox.DragDrop.Dragging=!1,JQX.ListBox.DragDrop.Item=null,JQX.ListBox.DragDrop.DropDetails=null}for(var L=0;L<JQX.ListBox.DragDrop.ListBoxes.length;L++){var D=JQX.ListBox.DragDrop.ListBoxes[L];D._dragInterval&&clearInterval(D._dragInterval)}}}},{key:"_itemsContainerMoveHandler",value:function(e){var t=this;if(JQX.ListBox.DragDrop.Dragging)return t._applyItemFeedback(e),t._moveHandler(e),e.originalEvent.preventDefault(),e.originalEvent.stopPropagation(),!1}},{key:"_applyItemFeedback",value:function(e){var t=this,i=e.originalEvent.target,r=i.closest?i.closest("jqx-list-item"):i;if(JQX.Utilities.Core.isMobile)return void(JQX.ListBox.DragDrop.DropDetails={item:JQX.ListBox.DragDrop.Item,position:"bottom"});if(0!==t.items.length)return r?void r._itemOnMouseMove(e):void t.items[t.items.length-1]._itemOnMouseMove(e,!0)}},{key:"_moveHandler",value:function(e){var t=this;if(JQX.ListBox.DragDrop.Feedback){var i=t.dragOffset;if(JQX.ListBox.DragDrop.Dragging){JQX.ListBox.DragDrop.Feedback.style.left=i[0]+e.pageX+"px",JQX.ListBox.DragDrop.Feedback.style.top=i[1]+e.pageY+"px",t.$.fireEvent("dragging",{item:JQX.ListBox.DragDrop.Item,data:JQX.ListBox.DragDrop,originalEvent:e.originalEvent});for(var r=0;r<JQX.ListBox.DragDrop.ListBoxes.length;r++)!function(t){var i=JQX.ListBox.DragDrop.ListBoxes[t];i._dragInterval&&clearInterval(i._dragInterval),i._dragInterval=setInterval(function(){var t=i.getBoundingClientRect();t.left<=e.clientX&&t.left+t.width>=e.clientX&&(e.clientY>=t.top&&e.clientY<=t.top+20?i.scrollTop-=2:e.clientY>=t.top+t.height-20&&e.clientY<=t.top+t.height&&(i.scrollTop+=2))},1)}(r);return e.preventDefault(),e.stopPropagation(),e.originalEvent.preventDefault(),e.originalEvent.stopPropagation(),!1}var n=Math.abs(e.pageX-JQX.ListBox.DragDrop.StartPosition.left),o=Math.abs(e.pageY-JQX.ListBox.DragDrop.StartPosition.top),l=new Date-JQX.ListBox.DragDrop.StartTime,a=n>=5&&n<=15||o>=5&&o<=15;if(JQX.Utilities.Core.isMobile&&(l<300||l>1e3)&&(a=!1),a){JQX.ListBox.DragDrop.Dragging=!0,JQX.ListBox.DragDrop.Feedback.style.left=i[0]+e.pageX+"px",JQX.ListBox.DragDrop.Feedback.style.top=i[1]+e.pageY+"px",document.body.appendChild(JQX.ListBox.DragDrop.Feedback),e.preventDefault(),e.stopPropagation(),e.originalEvent.preventDefault(),e.originalEvent.stopPropagation();var s=JQX.ListBox.DragDrop.Item,d=s.ownerListBox;d.$.fireEvent("dragStart",{item:s,data:JQX.ListBox.DragDrop,container:d,previousContainer:d,originalEvent:e.originalEvent}),document.body.classList.add("jqx-dragging")}}}},{key:"_focusHandler",value:function(){var e=this;e._focused=!0,e.setAttribute("focus","")}},{key:"_blurHandler",value:function(){var e=this;e._focused=!1,e.removeAttribute("focus")}},{key:"appendChild",value:function(e){var t=this;if(!t.isCompleted){var i=Array.prototype.slice.call(arguments,2);return HTMLElement.prototype.appendChild.apply(t,i.concat(Array.prototype.slice.call(arguments)))}t.isVirtualized?(t._items.indexOf(e)>-1&&t._items.splice(t._items.indexOf(e),1),t._items.push(e)):(e.dataItem=e,t.enableShadowDOM&&"light"===t.shadowDomMode?t.appendChild(e):t.$.itemsInnerContainer.appendChild(e),t._items.indexOf(e)>-1&&t._items.splice(t._items.indexOf(e),1),t._items.push(e)),t._refreshItems(),t._refreshSelection()}},{key:"insertBefore",value:function(e,t){var i=this;if(!i.isCompleted){var r=Array.prototype.slice.call(arguments,2);return HTMLElement.prototype.insertBefore.apply(i,r.concat(Array.prototype.slice.call(arguments)))}i.isVirtualized?(i._items.indexOf(e)>-1&&i._items.splice(i._items.indexOf(e),1),i._items.splice(i._indexOf(t),0,e)):(e.dataItem=e,t.parentNode.insertBefore(e,t),i._items.indexOf(e)>-1&&i._items.splice(i._items.indexOf(e),1),i._items.splice(i._indexOf(t),0,e)),i._refreshItems(),i._refreshSelection()}},{key:"removeChild",value:function(e){var t=this;if(!t.isCompleted){var i=Array.prototype.slice.call(arguments,2);return HTMLElement.prototype.removeChild.apply(t,i.concat(Array.prototype.slice.call(arguments)))}if(t.isVirtualized)t._items.splice(t._indexOf(e),1);else if(e.parentNode){var r=t.selectedIndexes.slice(0),n=t.selectedValues.slice(0),o=r.indexOf(e.dataIndex);e.parentNode.removeChild(e),o>-1&&(r.splice(o,1),n.splice(o,1),t.selectedIndexes=r,t.selectedValues=n)}t._refreshItems()}},{key:"propertyChangedHandler",value:function(e,i,r){babelHelpers.get(t.prototype.__proto__||Object.getPrototypeOf(t.prototype),"propertyChangedHandler",this).call(this,e,i,r);var n=this;switch(e){case"innerHTML":n.clearSelection(),n._dataBind(),n.innerHTML=n.content=JQX.Utilities.Core.html(n.$.content);break;case"dataSource":case"valueMember":case"groupMember":case"displayMember":n.clearSelection(),n._dataBind();break;case"disabled":case"unfocusable":n._setFocusable();break;case"displayLoadingIndicator":n._setLoadingIndicatorVisibility();break;case"filterable":n._refreshFilter(),n._refreshLayout();break;case"grouped":if(r?n._group():n._ungroup(),"radioButton"===n.selectionMode){if(n.selectedValues.length>0){var o=n.selectedValues;n.clearSelection(),n.select(o[0])}}else n._refreshSelection();n._refreshLayout();break;case"itemTemplate":if(null===r||""===r)return n._items.map(function(e){return e.innerHTML=e.label}),delete n._bindingDetails,void n._refreshLayout();var l=n.querySelectorAll("jqx-list-item"),a=function(){n._handleItemTemplate(r)&&(n._items.map(function(e){return n._applyTemplate(e)}),n._refreshLayout()),n.ownerElement&&n.ownerElement._setDropDownSize&&n.ownerElement._setDropDownSize(),n.$.fireEvent("bindingComplete")};0===l.length?a():n._ensureItemsReady(l,a);break;case"selectedIndexes":case"selectedValues":var s=n.selectedIndexes.slice(0),d=n.selectedValues.slice(0);if(!n._items||0===n._items.length)return n.selectedIndexes=[],n.selectedValues=[],void(n.$.hiddenInput.value=n.selectedValues.toString());if(n._propertyChanging=!0,"selectedIndexes"===e){s=i.slice(0),n.clearSelection();for(var c=0;c<r.length;c++){var p=r[c],u=n._items[p];u&&("oneOrManyExtended"===n.selectionMode||"oneOrMany"===n.selectionMode?(n.selectedIndexes.length>0&&0===c&&n.clearSelection(),n._select(u)):n.select(u))}}else{d=i.slice(0),n.selectedValues=[],n.clearSelection();for(var f=0;f<r.length;f++){var h=r[f],m=n.getItem(h);m&&("oneOrManyExtended"===n.selectionMode?n._select(m):n.select(m))}}if(n.selectedIndexes.length>0&&n._focus(n._items[n.selectedIndexes[0]]),n._propertyChanging=!1,JSON.stringify(d)!==JSON.stringify(n.selectedValues.slice(0))){for(var g=[],v=[],_=0;_<s.length;_++)n.selectedIndexes.indexOf(s[_])<0&&v.push(n._items[s[_]]);for(var y=0;y<n.selectedIndexes.length;y++)s.indexOf(n.selectedIndexes[y])<0&&g.push(n._items[n.selectedIndexes[y]]);var x={addedItems:g,removedItems:v};if(n.selectedIndexes.length>0){var b=n._items[n.selectedIndexes[n.selectedIndexes.length-1]];void 0!==b&&(x.selected=b.selected,x.disabled=b.disabled,x.index=n._indexOf(b),x.label=b.label,x.value=b.value)}else x.selected=!1,x.disabled=!1,x.index=-1,x.label="",x.value="";n.$.fireEvent("change",x)}break;case"selectionMode":var I="checkBox"===n.selectionMode||"radioButton"===n.selectionMode?n.selectionMode:"plain",C=n.selectedIndexes.slice(0),L=n.selectedValues.slice(0);n._propertyChanging=!0;var D=n.selectedValues;n.selectedValues=[],n.clearSelection();for(var S=0;S<D.length;S++){var k=D[S],B=n.getItem(k);B&&("oneOrManyExtended"===n.selectionMode?n._select(B):n.select(B))}if(n._items.forEach(function(e){return e.displayMode=I}),n._recycle(),n._propertyChanging=!1,JSON.stringify(L)!==JSON.stringify(n.selectedValues.slice(0))){for(var M=[],w=[],H=0;H<C.length;H++)n.selectedIndexes.indexOf(C[H])<0&&w.push(n._items[C[H]]);for(var O=0;O<n.selectedIndexes.length;O++)C.indexOf(n.selectedIndexes[O])<0&&M.push(n._items[n.selectedIndexes[O]]);var T={addedItems:M,removedItems:w};if(C.length>0){var $=n._items[C[C.length-1]];$&&(T.selected=$.selected,T.disabled=$.disabled,T.index=n._indexOf($),T.label=$.label,T.value=$.value)}n.$.fireEvent("change",T)}break;case"topVisibleIndex":n._setTopVisibleIndex(r);break;case"autoSort":n._canSort=r;break;case"sortDirection":case"sorted":n._canSort=!0,r?n._sort():n._unsort();var V=n.selectedValues;n.selectedValues=[],n._refreshSelection();for(var Q=0;Q<V.length;Q++){var X=V[Q],q=n.getItem(X);q&&("oneOrManyExtended"===n.selectionMode?n._select(q):n.select(q))}n._refreshLayout(),n._canSort=n.autoSort}}},{key:"_refreshSelection",value:function(){var e=this;if(e._items&&0!==e._items.length){var t=e.selectedValues;e.selectedIndexes=[],e.selectedValues=[];for(var i=0;i<e._items.length;i++){var r=e._items[i];r.selected=!1,t.indexOf(r.value)>-1&&e.select(r)}e._recycle()}}},{key:"clearSelection",value:function(){var e=this;if(e._items&&0!==e._items.length){for(var t=[],i=0;i<e._items.length;i++)e._items[i].selected&&t.push(e._items[i]);e._items.map(function(e){return e.selected=!1});var r=(e.selectedValues.slice(0),e.selectedIndexes.slice(0));if(e.selectedIndexes=[],e.selectedValues=[],e.$.hiddenInput.value=e.selectedValues.toString(),e._recycle(),e.context!==e){var n={addedItems:[],removedItems:t};if(r.length>0){var o=e._items[r[r.length-1]];o&&(n.selected=o.selected,n.disabled=o.disabled,n.index=e._indexOf(o),n.label=o.label,n.value=o.value)}e.$.fireEvent("change",n)}}}},{key:"ensureVisible",value:function(e){var t=this;if(e)return!("string"==typeof e&&!(e=t.getItem(e)))&&(t.isVirtualized||t.$.itemsContainer.scrollTop===t.scrollTop||(t.scrollTop=t.$.itemsContainer.scrollTop),e.top+e.height>=t.scrollTop+t.offsetHeight&&(t.scrollTop=t.scrollTop+e.height,t.isVirtualized||(t.$.itemsContainer.scrollTop=t.scrollTop)),(e.top<=t.scrollTop||e.top>=t.scrollTop+t.$.itemsContainer.offsetHeight)&&(t.scrollTop=e.top,t.isVirtualized||(t.$.itemsContainer.scrollTop=t.scrollTop)),0===t._indexOf(e)||1===t._indexOf(e)&&t._items.length>1&&t._items[0].grouped?(t.scrollTop=0,t.isVirtualized||(t.$.itemsContainer.scrollTop=t.scrollTop)):t._indexOf(e)===t._items.length-1&&(t.scrollTop=t.scrollHeight,t.isVirtualized||(t.$.itemsContainer.scrollTop=t.scrollTop)),!0)}},{key:"ready",value:function(){babelHelpers.get(t.prototype.__proto__||Object.getPrototypeOf(t.prototype),"ready",this).call(this);var e=this;if(e.enableShadowDOM&&"light"===e.shadowDomMode){var i=document.createDocumentFragment();[].slice.call(e.$.itemsInnerContainer.children).map(function(e){return i.appendChild(e)}),e.appendChild(i),e.$.itemsInnerContainer.appendChild(document.createElement("slot"))}e._areCSSVarsSupported=JQX.Utilities.Core.CSSVariablesSupport(),e._keysPressed={},e._incrementalSearchQuery="",e._incrementalSearchItems=[],e._canSort=!0,e._previousEntry="",e.isUpdating=0,e._scrollView&&(e._scrollView=new JQX.Utilities.Scroll(e,e.$.horizontalScrollBar,e.$.verticalScrollBar),e._scrollView.hScrollBar.$.addClass("jqx-hidden"),e._scrollView.vScrollBar.$.addClass("jqx-hidden"));var r=e._scrollView.vScrollBar,n=e._scrollView.hScrollBar;r.hasStyleObserver=!1,n.hasStyleObserver=!1,r.hasResizeObserver=!1,n.hasResizeObserver=!1,r.wait=!1,n.wait=!1,e._setFocusable(),e._setLoadingIndicatorVisibility(),e._refreshFilter(),e._initializeInnerHTML(),e._dataBind()}},{key:"attached",value:function(){var e=this;babelHelpers.get(t.prototype.__proto__||Object.getPrototypeOf(t.prototype),"attached",this).call(this),JQX.ListBox.DragDrop||(JQX.ListBox.DragDrop={ListBoxes:[]}),JQX.ListBox.DragDrop.ListBoxes.push(e),e._scrollView||(e._scrollView=new JQX.Utilities.Scroll(e,e.$.horizontalScrollBar,e.$.verticalScrollBar)),e.selectedIndexes.length>0&&e.ensureVisible(e._items[e.selectedIndexes[0]])}},{key:"detached",value:function(){var e=this;if(babelHelpers.get(t.prototype.__proto__||Object.getPrototypeOf(t.prototype),"detached",this).call(this),e._scrollView&&(e._scrollView.unlisten(),delete e._scrollView),JQX.ListBox.DragDrop&&JQX.ListBox.DragDrop.ListBoxes){var i=JQX.ListBox.DragDrop.ListBoxes.indexOf(e);JQX.ListBox.DragDrop.ListBoxes.splice(i,1)}}},{key:"_createItem",value:function(e,t,i){var r=this,n="checkBox"===r.selectionMode||"radioButton"===r.selectionMode?r.selectionMode:"plain",o=i?{}:document.createElement("jqx-list-item");o.ownerListBox=r,"number"==typeof e&&(e=""+e);var l=function(t,i){return void 0!==e[t]?""+e[t]:e[i]},a="string"==typeof e?e:l(r.displayMember,"label"),s="string"==typeof e?e:l(r.valueMember,"value"),d=l(r.groupMember,"group");return void 0===a&&(a=void 0!==t?""+t:""),o.label=o.innerHTML=""+a,void 0===s&&(s=void 0!==t?""+t:a),o.value=""+s,o.displayMode=n,o.selected=!!e.selected&&e.selected,o.disabled=!!e.disabled&&e.disabled,o.dataItem=o,void 0!==t&&(o.dataIndex=t),r._alternateItem(o),e.title&&(o.title=e.title),d&&(o.group=""+d),o}},{key:"_alternateItem",value:function(e){var t=this,i=t.alternationStart,r=t.alternationEnd>0?t.alternationEnd:1/0;t.alternationCount<=0||(void 0===t._alternationIndexCounter&&(t._alternationIndexCounter=0),e.dataIndex>=i&&e.dataIndex<=r&&(e.alternationIndex=t._alternationIndexCounter++,t._alternationIndexCounter===t.alternationCount&&(t._alternationIndexCounter=0)))}},{key:"_beginUpdate",value:function(){this.isUpdating++}},{key:"_isUpdating",value:function(){return this.isUpdating>0}},{key:"_endUpdate",value:function(){this.isUpdating--}},{key:"_initializeRecyclingItems",value:function(){var e=this;if(e.dataSource&&(!e.dataSource||0!==e.dataSource.length)&&e.isVirtualized){var t=0,i=e.offsetHeight;e.$.itemsInnerContainer.innerHTML="",e._recyclingItems=[];var r=function(){for(var r=0;r<e.dataSource.length;r++){var n=e.dataSource[r],o=e._createItem(n);if(e.itemHeight&&"auto"!==e.itemHeight&&(o.style.height=e.itemHeight+"px"),e.$.itemsInnerContainer.appendChild(o),t+=o.offsetHeight,o.dataItem=e._items[r],e._recyclingItems.push(o),t>1.5*i)break}};r();for(var n=0;t<1.5*i&&++n<5;)r()}}},{key:"_dataBind",value:function(){var e=this;if(e._scrollView||(e._scrollView=new JQX.Utilities.Scroll(e,e.$.horizontalScrollBar,e.$.verticalScrollBar)),"function"==typeof e.dataSource&&(e._items=[]),"string"==typeof e.dataSource&&(e.dataSource=JSON.parse(e.dataSource)),null!==e.dataSource&&Array.isArray(e.dataSource)){e.isUpdating++;var t=function(t){e._items=[],e._groups=[];for(var i=0;i<e.dataSource.length;i++){var r=e.dataSource[i],n=t?e._createItem(r,i):e._createItem(r,i,!0);e._items[i]=n,t&&t.appendChild(n)}};if(e.isVirtualized)t(),e._initializeRecyclingItems();else{var i=document.createDocumentFragment();e.$.itemsInnerContainer.innerHTML="",t(i),e.$.itemsInnerContainer.appendChild(i)}e.isUpdating--}var r=e.enableShadowDOM?e.shadowRoot.querySelectorAll("jqx-list-item"):e.querySelectorAll("jqx-list-item"),n=function(){e.isUpdating++,e.dataSource||(e._initializeHtmlListItems(),e._initializeHtmlListGroups()),e.grouped&&e._group(),e.sorted&&e._sort(),e._refreshLayout(),e._initializeSelection(),e.isInitialized=!0,e._canSort=e.autoSort,e.isUpdating--,e.itemTemplate&&e._handleItemTemplate(e.itemTemplate)&&(e._items.map(function(t){return e._applyTemplate(t)}),e._refreshLayout()),e.__onCompleted&&(e._onCompleted=e.__onCompleted,
e.__onCompleted=null,e._onCompleted()),e.topVisibleIndex>-1&&e._setTopVisibleIndex(e.topVisibleIndex),e.$.fireEvent("bindingComplete"),e._updateTopVisibleIndex(),0===e._items.length&&e.clearItems()};0===r.length?n():(e._onCompleted&&(e.__onCompleted=e._onCompleted,e._onCompleted=null),e._ensureItemsReady(r,n))}},{key:"_ensureItemsReady",value:function(e,t){var i=this,r=function(){var i=function(t){for(var i=0;i<e.length;i++)e[i].context="node"===t?e[i]:document};i("node"),t(),i()};if(0===e.length)r();else{i._nodesReadyListeners=0;for(var n=0;n<e.length;n++){var o=e[n],l=function(){0===--i._nodesReadyListeners&&(r(),delete i._nodesReadyListeners)}.bind(i);o.isCompleted||(i._nodesReadyListeners++,o._onCompleted=l)}0===i._nodesReadyListeners&&r()}}},{key:"_initializeInnerHTML",value:function(){var e=this;e.$.itemsInnerContainer.innerHTML.indexOf("<option")>=0?e.$.itemsInnerContainer.innerHTML=e.$.itemsInnerContainer.innerHTML.replace(/<optgroup/gi,"<jqx-list-items-group").replace(/<\/optgroup/gi,"</jqx-list-items-group").replace(/<option/gi,"<jqx-list-item").replace(/<\/option/gi,"</jqx-list-item"):e.$.itemsInnerContainer.innerHTML.indexOf("<ul")>=0&&(e.$.itemsInnerContainer.innerHTML=e.$.itemsInnerContainer.innerHTML.replace(/<ul/gi,"<jqx-list-items-group").replace(/<\/ul/gi,"</jqx-list-items-group").replace(/<li/gi,"<jqx-list-item").replace(/<\/li/gi,"</jqx-list-item"))}},{key:"_initializeHtmlListItems",value:function(){var e=this,t=e.enableShadowDOM&&"shadow"===e.shadowDomMode?e.shadowRoot.querySelectorAll("jqx-list-item"):e.querySelectorAll("jqx-list-item"),i="checkBox"===e.selectionMode||"radioButton"===e.selectionMode?e.selectionMode:"plain",r=function(e,t,i){return void 0!==e[t]?""+e[t]:e[i]};e._items=[];for(var n=0,o=0;o<t.length;o++){var l=t[o];l.dataIndex=o,l.label=l.innerHTML,l.dataItem=l,l.top||(l.top=n),l.height||(l.height=l.offsetHeight),n+=l.height,l.value||(l.value=""+o);var a=r(l,e.displayMember,"label"),s=r(l,e.valueMember,"value"),d=r(l,e.groupMember,"group");l.label!==a&&(l.label=a),l.value!==s&&(l.value=s),l.group!==d&&(l.group=d);var c=l.context;l.context=document,l.displayMode=i,l.context=c,e._alternateItem(l),l.selected&&(e.selectedIndexes.push(o),e.selectedValues.push(l.value)),e._items.push(l)}e.itemTemplate&&e._handleItemTemplate(e.itemTemplate)&&e._items.map(function(t){return e._applyTemplate(t)})}},{key:"_group",value:function(){var e=this;e.isUpdating++;var t=[],i=[];e._canSort&&e._unsort();for(var r=0;r<e._items.length;r++){var n=e._items[r],o=n.group?n.group.trim():n.innerHTML.charAt(0)||n.label.charAt(0);o+=" ",t[o]?t[o].items.push(n):t[t.length++]=t[o]={items:[n],label:o}}if(e.isVirtualized){e._groups=[];for(var l=0;l<t.length;l++){var a=t[l];a.dataIndex=l,a.grouped=!0,a.hidden=!1,a.displayMode="plain",i.push(a);for(var s=0;s<t[l].items.length;s++){var d=a.items[s];d.group=a,i.push(d)}}e._groups=t,e._items=i}else{for(;e.$.itemsInnerContainer.firstChild;)e.$.itemsInnerContainer.removeChild(e.$.itemsInnerContainer.firstChild);var c=document.createDocumentFragment();e._groups=[];for(var p=0;p<t.length;p++){var u=t[p],f=document.createElement("jqx-list-items-group");f.label=u.label,f.dataIndex=p;for(var h=0;h<t[p].items.length;h++){var m=u.items[h];i.push(m),m.group=u.label,f.appendChild(m)}e._groups.push(f),c.appendChild(f)}e._items=i;/Trident|Edge/.test(navigator.userAgent)?setTimeout(function(){e.$.itemsInnerContainer.appendChild(c)},50):e.$.itemsInnerContainer.appendChild(c)}e.sorted&&e._sort(),e.isUpdating--}},{key:"_ungroup",value:function(){var e=this;e.isUpdating++,e._groups=[],e._canSort&&e._unsort();var t=[];if(e.isVirtualized)for(var i=0;i<e._items.length;i++){var r=e._items[i];r.grouped||t.push(r)}else{for(var n=document.createDocumentFragment(),o=0;o<e._items.length;o++){var l=e._items[o];n.appendChild(l),t.push(l)}t.length>0&&(e.$.itemsInnerContainer.innerHTML="",e.$.itemsInnerContainer.appendChild(n))}e._items=t,e.sorted&&e._sort(),e.isUpdating--}},{key:"_initializeHtmlListGroups",value:function(){var e=this,t=e.$.itemsInnerContainer.querySelectorAll("jqx-list-items-group");e._groups=[];for(var i=0;i<t.length;i++){var r=t[i];r.dataIndex=i,e._groups.push(r)}}},{key:"_initializeSelection",value:function(){var e=this,t=e.selectedIndexes.slice(0),i=e.selectedValues.slice(0);e.clearSelection(),"oneOrManyExtended"===e.selectionMode&&(e._keysPressed.Control=!0);for(var r=0;r<e._items.length;r++){var n=e._items[r];(t.indexOf(r)>=0||i.indexOf(n.value||n.label)>=0)&&(e._focusedItem&&(e._focusedItem._focused=!1),e._focusedItem=null,e.select(n))}"oneOrManyExtended"===e.selectionMode&&(e._keysPressed.Control=!1)}},{key:"onItemUpdated",value:function(){var e=this;e.isInitialized&&!e._isUpdating()&&(e.isUpdating++,e._refreshLayout(),e.isUpdating--)}},{key:"_refreshItems",value:function(){var e=this;if(e.isInitialized&&!e._isUpdating()){if(e.isUpdating++,e.grouped?e._ungroup():e.sorted&&e._canSort&&e._unsort(),!e.isVirtualized){e._items=[];for(var t=e.enableShadowDOM?e.shadowRoot.querySelectorAll("jqx-list-item"):e.querySelectorAll("jqx-list-item"),i=0;i<t.length;i++)t[i].dataIndex=i,e._alternateItem(t[i]),e._items.push(t[i])}e.grouped?e._group():e.sorted&&e._sort(),e._refreshLayout(),e.isUpdating--}}},{key:"_applyIncrementalSearch",value:function(e){var t=this;null===t.incrementalSearchDelay||isNaN(t.incrementalSearchDelay)||["Shift","ArrowUp","ArrowDown","ArrowLeft","ArrowRight","Control","Home","End","PageUp","PageDown"].indexOf(e)>-1||(0!==t._incrementalSearchQuery.indexOf(e)&&(t._incrementalSearchQuery+=e),t._incrementalSearchTimer&&clearTimeout(t._incrementalSearchTimer),t._incrementalSearch(),t._incrementalSearchTimer=setTimeout(function(){t._incrementalSearchQuery=""},t.incrementalSearchDelay))}},{key:"select",value:function(e){var t=this;if(("string"!=typeof e||(e=t.getItem(e)))&&("number"!=typeof e||(e=t.getItem(e)))&&!e.grouped&&!e.readonly){if("none"===t.selectionMode)return t.selectedIndexes=[],void(t.selectedValues=[]);switch(!t._focusedItem!==e&&"none"!==t.selectionMode&&(t._focusedItem&&(t._focusedItem._focused=!1),t._focusedItem=e,e._focused=!0),t.selectionMode){case"one":return(1!==t.selectedIndexes.length||t.selectedIndexes[0]!==t._indexOf(e))&&(t._previouslySelectedIndexes=t.selectedIndexes,t.selectedIndexes.length>=1&&t.clearSelection(),t._select(e),delete t._previouslySelectedIndexes,!0);case"zeroOrOne":return 1===t.selectedIndexes.length&&t.selectedIndexes[0]===t._indexOf(e)?(t.unselect(e),!0):(t._previouslySelectedIndexes=t.selectedIndexes,t.selectedIndexes.length>=1&&t.clearSelection(),t._select(e),delete t._previouslySelectedIndexes,!0);case"radioButton":if(t._previouslySelectedIndexes=t.selectedIndexes,t.$.itemsInnerContainer.querySelectorAll("jqx-list-items-group").length>0){var i=e.parentNode;if(!e.selected){for(var r in i.children){var n=i.children[r];n.selected&&t.unselect(n)}t._select(e)}return delete t._previouslySelectedIndexes,!0}if(t.isVirtualized&&t._groups.length>0){var o=e.group;if(!e.selected){for(var l in o.items){var a=o.items[l];a.selected&&t.unselect(a)}t._select(e)}return delete t._previouslySelectedIndexes,!0}return e.selected||(t.selectedIndexes.length>=1&&t.clearSelection(),t._select(e)),delete t._previouslySelectedIndexes,!0;case"oneOrMany":return e.selected?t.selectedIndexes.length>1&&t.unselect(e):t._select(e),!0;case"zeroOrMany":case"checkBox":return e.selected?t.unselect(e):t._select(e),!0;case"oneOrManyExtended":var s=t.selectedValues;if(t._keysPressed.Control)return t.selectedIndexes.length>1&&e.selected?(t.unselect(e),t._focus(t._items[t.selectedIndexes[0]])):t._select(e),!0;if(t._keysPressed.Shift){var d=t._items[t.selectedIndexes[0]],c=void 0;t.clearSelection();var p=s.indexOf(d.value)>=0||d.selected;if(t._select(d,p),t._indexOf(d)>t._indexOf(e))for(c=t._indexOf(d)-1;c>=t._indexOf(e);){var u=t._items[c],f=s.indexOf(u.value)>=0||u.selected;t._select(u,f),c--}else for(c=t._indexOf(d)+1;c<=t._indexOf(e);){var h=t._items[c],m=s.indexOf(h.value)>=0||h.selected;t._select(h,m),c++}for(var g=[],v=0;v<s.length;v++)g.push(t.getItem(s[v]));if(g.length>0&&!t._propertyChanging){for(var _=[],y=0;y<t.selectedValues.length;y++){var x=t.selectedValues[y];s.indexOf(x)<0&&_.push(t.getItem(x))}t.$.fireEvent("change",{addedItems:_,removedItems:g,selected:e.selected,disabled:e.disabled,index:t._indexOf(e),label:e.label,value:e.value})}return!0}for(var b=0;b<s.length;b++){var I=s[b],C=t.getItem(I);e!==C&&t.unselect(C)}return t.clearSelection(),t._select(e,s.indexOf(e.value)>=0),!0}return!1}}},{key:"_applyTemplate",value:function(e,t){var i=this;if(null!==i.itemTemplate){if("function"==typeof i.itemTemplate)return void i.itemTemplate(e,{label:e.label,value:e.value,index:i._items.indexOf(e)});if(i._bindingDetails&&0!==i._bindingDetails.length){for(var r=i._bindingDetails.length,n=document.importNode(i._template.content,!0),o=void 0,l=void 0,a=0;a<r;a++){o=n.childNodes[i._bindingDetails[a].childNodeIndex],l=i._bindingDetails[a].bindingString.length;for(var s=0;s<l;s++){var d=i._bindingDetails[a].bindingString[s],c=d.indexOf("label")>=0?e.label:e.value;o.innerHTML=o.innerHTML.replace(d,c)}}e.innerHTML="";for(var p=0;p<n.childNodes.length;p++)n.childNodes[p].outerHTML&&(e.innerHTML+=n.childNodes[p].outerHTML);!1!==t&&(i._scrollHeightTimer&&(clearInterval(i._scrollHeightTimer),i._scrollHeightCounter=0),i._scrollHeightTimer=setInterval(function(){i._lastScrollHeight===i.$.itemsInnerContainer.scrollHeight&&10!==i._scrollHeightCounter||(i._refreshLayout(),clearInterval(i._scrollHeightTimer)),i._lastScrollHeight=i.$.itemsInnerContainer.scrollHeight,i._scrollHeightCounter++},50))}}}},{key:"_filterItems",value:function(e,t){var i=this,r=i.$.filterInput.value,n=void 0,o=void 0,l=function(){if(0===o.length)return i._filteredItems=[],void(t&&t());n=i._queryItems(r,i.filterMode);for(var l=0;l<o.length;l++)o[l].hidden=!0,o[l].$.addClass("jqx-hidden");for(var a=0;a<n.length;a++){var s=n[a];s.hidden=!1,s.$.removeClass("jqx-hidden")}if(i.grouped&&i.isVirtualized)for(var d=0;d<i._groups.length;d++){for(var c=i._groups[d],p=c.items,u=!0,f=0;f<p.length;f++)p[f].hidden||(u=!1);u&&(c.hidden=!0)}if(i.grouped&&!i.isVirtualized)for(var h=0;h<i._groups.length;h++){for(var m,g=i._groups[h],v=(m=[]).concat.apply(m,babelHelpers.toConsumableArray(g.querySelectorAll("jqx-list-item"))),_=!0,y=0;y<v.length;y++)v[y].$.hasClass("jqx-hidden")||(_=!1);_?g.$.addClass("jqx-hidden"):g.$.removeClass("jqx-hidden")}i._filteredItems=n,i._refreshLayout(),t&&t(),e||i._refreshSelection()};if("function"==typeof i.dataSource)if(r){var a=function(e){r&&i.isAttached&&(i._updateListBoxAfterQuery=function(){n=o=i._items,l()},i.clearItems(),i.insert(0,e))},s=i.dataSource(r,a);if(s){if(!r)return;i._updateListBoxAfterQuery=function(){n=o=i._items,l()},i.clearItems(),i.insert(0,s)}}else i.clearItems(),n=o=i._items,l();else{if(o=i._items,0===o.length)return;l()}}},{key:"_getNextItem",value:function(e){for(var t=this,i=t._items,r=t._items.length,n=Math.max(e+1,0);n<r;){var o=i[n];if(!(o.disabled||o.hidden||o.grouped||o.readonly))return o;n++}return i[e]}},{key:"_getPreviousItem",value:function(e){for(var t=this,i=t._items,r=Math.max(e-1,0);r>-1;){var n=i[r];if(!(n.disabled||n.hidden||n.grouped||n.readonly))return n;r--}return i[e]}},{key:"update",value:function(e,t){var i=this,r=i._items[e];if(r){if("string"==typeof t)r.label=t,void 0===r.value&&(r.value=t);else for(var n in t)"selected"===n&&r[n]!==t[n]?i.select(r):r[n]=t[n],"group"===n&&i._refreshItems();(i.sorted||i.grouped||i.isVirtualized)&&(i._refreshItems(),i._refreshSelection())}else i.error(i.localize("indexOutOfBound",{elementType:i.nodeName.toLowerCase(),method:"update"}))}},{key:"insert",value:function(e,t){function i(){r._refreshItems(),0!==r._items.length&&(r._updateListBoxAfterQuery&&(r._updateListBoxAfterQuery(),delete r._updateListBoxAfterQuery),r._refreshSelection(),r.$.fireEvent("bindingComplete"))}var r=this,n=[];if(e||(e=0),Array.isArray(t)){r.isUpdating++;for(var o=0;o<t.length;o++){var l=t[o],a=r._createItem(l);n.push(a),e>=r._items.length||0===r._items.length?r.appendChild(a):r.insertBefore(a,r._items[e])}r.isUpdating--}else{var s=r._createItem(t);n.push(s),e>=r._items.length||0===r._items.length?r.appendChild(s):r.insertBefore(s,r._items[e])}n.length>0&&(n.map(function(e){return r._applyTemplate(e)}),r._ensureItemsReady(n,i))}},{key:"remove",value:function(e){var t=this,i=t._items[e];i?(t.isVirtualized?t._items.splice(e,1):i.parentNode.removeChild(i),i.selected&&t.unselect(i),t._refreshItems(),t._refreshSelection(),0===t.selectedIndexes.length&&t._items.length>0&&("oneOrMany"!==t.selectionMode&&"one"!==t.selectionMode&&"oneOrManyExtended"!==t.selectionMode||t.select(t._items[0]))):t.error(t.localize("indexOutOfBound",{elementType:t.nodeName.toLowerCase(),method:"remove"}))}},{key:"_queryItems",value:function(e,t){var i=this,r=[];if(0===e.length)return i._items;for(var n=0;n<i._items.length;n++){var o=function(r,n){if(r.grouped)return r;switch(t){case"startsWith":if(0===r.label.indexOf(n))return r;break;case"startsWithIgnoreCase":if(0===r.label.toLowerCase().indexOf(n.toLowerCase()))return r;break;case"doesNotContain":if(r.label.indexOf(n)<0)return r;break;case"doesNotContainIgnoreCase":if(r.label.toLowerCase().indexOf(n.toLowerCase())<0)return r;break;case"contains":if(r.label.indexOf(n)>-1)return r;break;case"containsIgnoreCase":if(r.label.toLowerCase().indexOf(n.toLowerCase())>-1)return r;break;case"equals":if(0===r.label.localeCompare(n))return r;break;case"equalsIgnoreCase":if(0===r.label.toLowerCase().localeCompare(n.toLowerCase()))return r;break;case"endsWith":if(r.label.endsWith(n))return r;break;case"endsWithIgnoreCase":if(r.label.toLowerCase().endsWith(n.toLowerCase()))return r;break;case"custom":if(i.filterCallback(r,e))return r}return null}(i._items[n],e);o&&r.push(o)}return r}},{key:"_select",value:function(e,t){var i=this,r=i.selectedIndexes.indexOf(i._indexOf(e)),n=i.selectedIndexes.slice(0),o=i.selectedValues.slice(0);if(e.selected=!0,-1!==r)return i._recycle(),!1;if(n.push(i._indexOf(e)),o.push(e.value||e.label),i.selectedIndexes=n,i.selectedValues=o,i._recycle(),i.$.hiddenInput.value=o.toString(),i.isCompleted&&!t&&i.isInitialized&&!i._propertyChanging){var l=[];if(i._previouslySelectedIndexes){for(var a=0;a<i._previouslySelectedIndexes.length;a++)i.selectedIndexes.indexOf(i._previouslySelectedIndexes[a])<0&&l.push(i._items[i._previouslySelectedIndexes[a]]);delete i._previouslySelectedIndexes}return i.$.fireEvent("change",{addedItems:[e],removedItems:l,selected:e.selected,disabled:e.disabled,index:i._indexOf(e),label:e.label,value:e.value}),!0}}},{key:"_setTopVisibleIndex",value:function(e){var t=this;if("number"==typeof e&&(t.topVisibleIndex=Math.max(0,e),e=t._items[t.topVisibleIndex]),!e)return!1;e.top!==t.scrollTop&&(t.scrollTop=e.top,t.isVirtualized||(t.$.itemsContainer.scrollTop=t.scrollTop),t.scrollHeight===t.scrollTop&&t._updateTopVisibleIndex())}},{key:"_updateTopVisibleIndex",value:function(){var e=this,t=e.scrollTop+e._scrollView.verticalScrollBar.offsetHeight-e.offsetHeight,i=void 0;if(e.scrollTop<e.scrollHeight/2){for(var r=0;r<e._items.length;r++)if(e._items[r].top>t){i=e._items[r];break}}else for(var n=e._items.length-1;n>=0&&!(e._items[n].top<t);n--)i=e._items[n];i&&(e.topVisibleIndex=i.dataIndex)}},{key:"unselect",value:function(e){var t=this;if(e&&("string"!=typeof e||(e=t.getItem(e)))){if("none"===t.selectionMode)return void t.clearSelection();var i=t.selectedIndexes.indexOf(t._indexOf(e)),r=t.selectedIndexes.slice(0),n=t.selectedValues.slice(0);if(e.selected=!1,!(i>=0))return!1;if(r.splice(i,1),n.splice(i,1),t.selectedIndexes=r,t.selectedValues=n,t.$.hiddenInput.value=n.toString(),t.isCompleted&&!t._propertyChanging)return t.$.fireEvent("change",{addedItems:[],removedItems:[e],selected:e.selected,disabled:e.disabled,index:t._indexOf(e),label:e.label,value:e.value}),t._recycle(),!0}}},{key:"_handleItemTemplate",value:function(e){if(null!==e&&e){if("function"==typeof e)return e;var t=this;if(!("content"in document.createElement("template")))return t.error(t.localize("htmlTemplateNotSuported",{elementType:t.nodeName.toLowerCase()})),void(t.itemTemplate=null);if(null===(e=document.getElementById(e))||!("content"in e))return t.error(t.localize("invalidTemplate",{elementType:t.nodeName.toLowerCase(),property:"itemTemplate"})),void(t.itemTemplate=null);var i=e.content,r=i.childNodes.length,n=/{{\w+}}/g,o=void 0,l=void 0;t._bindingDetails=[],t._template=e;for(var a=0;a<r;a++){for(l=[];o=n.exec(i.childNodes[a].innerHTML);)l.push(o[0]);l.length>0&&t._bindingDetails.push({childNodeIndex:a,bindingString:l})}return!0}}},{key:"_handleKeyStrokes",value:function(e){var t=this,i="radioButton"===t.selectionMode||"checkBox"===t.selectionMode||"zeroOrMany"===t.selectionMode||"oneOrMany"===t.selectionMode||"zeroOrOne"===t.selectionMode,r=t._items;if(t.filterable&&t.$.filterInput.value.length>0&&(r=t._filteredItems),!t.disabled&&!t.readonly){switch(e){case"ArrowLeft":case"ArrowUp":t._handleArrowKeys(!0);break;case"ArrowRight":case"ArrowDown":t._handleArrowKeys(!1);break;case" ":if(t.selectedIndexes.length<1&&!t._focusedItem)return;var n=t._focusedItem?t._focusedItem:t._items[t.selectedIndexes[t.selectedIndexes.length-1]],o=function(e){e.selected&&"radioButton"!==t.selectionMode?t.unselect(e):t.select(e)};if("oneOrMany"===t.selectionMode)return void(n.selected&&t.selectedIndexes.length>1?o(n):n.selected||o(n));o(n);break;case"Home":if(0===r.length)return;i?t._focus(r[0]):(t._keysPressed.Shift||t.clearSelection(),t.select(r[0]),t._focus(r[0])),t.scrollTop=0;break;case"End":if(0===r.length)return;i?t._focus(r[r.length-1]):(t._keysPressed.Shift||t.clearSelection(),t.select(r[r.length-1]),t._focus(r[r.length-1])),t.scrollTop=t.scrollHeight;break;case"PageUp":t._pageUpKeyHandler(r);break;case"PageDown":t._pageDownKeyHandler(r)}t._recycle()}}},{key:"_horizontalScrollbarHandler",value:function(e){var t=this;e.stopPropagation(),t.isVirtualized?t._recycle():t.$.itemsContainer.scrollLeft=e.detail.value}},{key:"_unsort",value:function(){var e=this;e.isUpdating++;var t=function(e,t){var i=e.dataIndex,r=t.dataIndex;return i<r?-1:i>r?1:0};if(e.isVirtualized)if(e._groups.length>0){e._groups.sort(t);for(var i=[],r=0;r<e._groups.length;r++){var n,o=e._groups[r],l=(n=[]).concat.apply(n,babelHelpers.toConsumableArray(o.items));l.sort(t),i.push(o),i=i.concat(l)}e._items=i}else e._items.sort(t);else{if(e._groups.length>0){e._groups.sort(t);for(var a=[],s=0;s<e._groups.length;s++){var d,c=e._groups[s],p=(d=[]).concat.apply(d,babelHelpers.toConsumableArray(c.querySelectorAll("jqx-list-item")));p.sort(t),a=a.concat(p)}e._items=a}else e._items.sort(t);e._applySortOrder()}e.isUpdating--}},{key:"_applySortOrder",value:function(){var e=this,t=function(e){for(var t=0;t<e.length;t++){var i=e[t],r=i.parentNode;r&&r.appendChild(i)}};t(e._items),t(e._groups)}},{key:"_sort",value:function(){var e=this;if(e._canSort){e.isUpdating++;var t=function(t,i){var r=t.label,n=i.label;if("asc"===e.sortDirection){if(r<n)return-1;if(r>n)return 1}else{if(r<n)return 1;if(r>n)return-1}return 0};if(e._groups.sort(t),e.isVirtualized)if(e._groups.length>0){for(var i=[],r=0;r<e._groups.length;r++){var n,o=e._groups[r],l=(n=[]).concat.apply(n,babelHelpers.toConsumableArray(o.items));i.push(o),l.sort(t),i=i.concat(l)}e._items=i}else e._items.sort(t);else{if(e._groups.length>0){for(var a=[],s=0;s<e._groups.length;s++){var d,c=e._groups[s],p=(d=[]).concat.apply(d,babelHelpers.toConsumableArray(c.querySelectorAll("jqx-list-item")));p.sort(t),a=a.concat(p)}e._items=a}else e._items.sort(t);e._applySortOrder()}e.isUpdating--}}},{key:"getItem",value:function(e){for(var t=this,i=0;i<t._items.length;i++)if(t._items[i].value===e)return t._items[i];return null}},{key:"_focus",value:function(e){var t=this;!e||"none"===t.selectionMode||t.disabled||t.readonly||(t._focusedItem&&(t._focusedItem._focused=!1),t._focusedItem=e,t._focusedItem._focused=!0)}},{key:"_keyDownHandler",value:function(e){var t=this,i=t.enableShadowDOM?t.shadowRoot.activeElement:document.activeElement,r=e.key;if(!t.disabled&&!t.readonly&&(!t.filterable||t.$.filterInput!==i)&&t._focused&&0!==t._items.length&&!t.disabled&&!t.displayLoadingIndicator){if(t.editable){if("F2"===r)return void t._dblclickEventHandler({target:t._focusedItem});if(t.$.editInput===i)return}if("none"!==t.selectionMode){switch(e.stopPropagation(),r){case"Down":case"Right":case"Left":case"Up":r="Arrow"+r}if(t.filterable)switch(r){case"ArrowLeft":case"ArrowRight":return;case"ArrowUp":case"ArrowDown":e.preventDefault()}if(t._applyIncrementalSearch(r),!(["Shift","ArrowUp","ArrowDown","ArrowLeft","ArrowRight","Control"," ","Home","End","PageUp","PageDown"].indexOf(r)<0)){if(e.preventDefault(),!t._focusedItem&&t._items.length>0)return void("one"===t.selectionMode||"oneOrMany"===t.selectionMode||"oneOrManyExtended"===t.selectionMode?t.select(t._items[0]):t._focus(t._items[0]));switch(t.selectionMode){case"one":if("Shift"===r||"Control"===r||" "===r)return;t._handleKeyStrokes(r);break;case"oneOrMany":case"zeroOrOne":case"zeroOrMany":case"radioButton":case"checkBox":if("Shift"===r||"Control"===r)return;t._handleKeyStrokes(r);break;case"oneOrManyExtended":if(" "===r)return;t._keysPressed[r]="keydown"===e.type,t._handleKeyStrokes(r)}}}}}},{key:"_keyUpHandler",value:function(e){var t=this,i=t.enableShadowDOM?t.shadowRoot.activeElement:document.activeElement;if(!t.editable||t.$.editInput!==i){if(t.filterable&&t.$.filterInput===i)return t._filterTimer&&clearTimeout(t._filterTimer),void(t._filterTimer=setTimeout(function(){var e=t.context;t.context=t,t._filterItems(),t.scrollTop=t.$.itemsContainer.scrollTop=0,t.scrollLeft=t.$.itemsContainer.scrollLeft=0,t.context=e},300));if(t._focused){if(t._focusedItem&&t._focusedItem.hidden&&t._filteredItems.length>0){var r=t._filteredItems[0];r.grouped&&t._filteredItems.length>1&&(r=t._filteredItems[1]),t._focus(r),t._recycle()}e.stopPropagation(),e.preventDefault(),t.disabled||["Shift","ArrowUp","ArrowDown","ArrowLeft","ArrowRight","Control"," ","PageUp","PageDown"].indexOf(e.key)<0||(t._keysPressed[e.key]=!1)}}}},{key:"_mouseWheelHandler",value:function(e){var t=this;(t.computedHorizontalScrollBarVisibility||t.computedVerticalScrollBarVisibility)&&!t.disabled&&t.computedVerticalScrollBarVisibility&&(e.stopPropagation(),e.preventDefault(),t.scrollTo(t.scrollTop+t._getScrollCoefficient(e,t.offsetHeight)))}},{key:"_pageDownKeyHandler",value:function(e){var t=this;if(0!==e.length){var i=t._items[t.selectedIndexes[t.selectedIndexes.length-1]];"checkBox"!==t.selectionMode&&"radioButton"!==t.selectionMode&&"zeroOrMany"!==t.selectionMode&&"oneOrMany"!==t.selectionMode&&"zeroOrOne"!==t.selectionMode||t._focusedItem&&(i=t._focusedItem);for(var r=void 0,n=t._indexOf(i),o=i.top+t.$.itemsContainer.offsetHeight-i.height,l=n;l<e.length;l++)if(e[l].top>=o){r=e[l];break}r||(r=e[e.length-1]),"checkBox"===t.selectionMode||"radioButton"===t.selectionMode||"zeroOrMany"===t.selectionMode||"oneOrMany"===t.selectionMode||"zeroOrOne"===t.selectionMode?t._focus(r):r.selected||(t._keysPressed.Shift||t.clearSelection(),t.select(r),t._focus(r)),(r.height+r.top>t.$.itemsContainer.scrollTop+t.$.itemsContainer.offsetHeight||r.top<t.$.itemsContainer.scrollTop)&&(t.scrollTop=r.top-t.$.itemsContainer.offsetHeight+r.height)}}},{key:"_pageUpKeyHandler",value:function(e){var t=this;if(0!==e.length){var i=t._items[t.selectedIndexes[t.selectedIndexes.length-1]];"checkBox"!==t.selectionMode&&"radioButton"!==t.selectionMode&&"zeroOrMany"!==t.selectionMode&&"oneOrMany"!==t.selectionMode&&"zeroOrOne"!==t.selectionMode||t._focusedItem&&(i=t._focusedItem);for(var r=i.top-t.$.itemsContainer.offsetHeight,n=t._indexOf(i),o=void 0,l=n;l>0;l--)if(e[l].top<=r){o=e[l];break}o||(o=e[0]),"checkBox"===t.selectionMode||"radioButton"===t.selectionMode||"zeroOrMany"===t.selectionMode||"oneOrMany"===t.selectionMode||"zeroOrOne"===t.selectionMode?t._focus(o):o.selected||(t._keysPressed.Shift||t.clearSelection(),t.select(o),t._focus(o)),t.scrollTop=o.top;0===t._indexOf(o)&&(t.scrollTop=0)}}},{key:"clearItems",value:function(){var e=this;e.$.itemsInnerContainer.innerHTML="",e.clearSelection(),e._items=[],e.$placeholder.removeClass("jqx-hidden")}},{key:"_resizeHandler",value:function(e){var t=this;e.target!==t||t._isUpdatingScrollBars||(t._isUpdatingScrollBars=!0,t._initializeRecyclingItems(),t._refreshLayout(),t._isUpdatingScrollBars=!1)}},{key:"_indexOf",value:function(e){var t=this;if(!e)return-1;var i=t._items.indexOf(e);return-1===i&&(i=t._items.indexOf(t.getItem(e.value))),i}},{key:"_incrementalSearch",value:function(){var e=this,t="radioButton"!==e.selectionMode&&"checkBox"!==e.selectionMode&&"zeroOrMany"!==e.selectionMode&&"oneOrMany"!==e.selectionMode&&"zeroOrOne"!==e.selectionMode,i=void 0,r=0;switch(e.incrementalSearchMode){case"containsIgnoreCase":case"equalsIgnoreCase":case"startsWithIgnoreCase":case"endsWithIgnoreCase":i=e._incrementalSearchQuery.toLowerCase();break;default:i=e._incrementalSearchQuery}var n=function(i){i.grouped||i.readonly||(t?(e.selectedIndexes.length>0&&e.clearSelection(),e._focus(i),e.select(i)):e._focus(i),(i.height+i.top>e.$.itemsContainer.scrollTop+e.$.itemsContainer.offsetHeight||i.top<e.scrollTop)&&(e.scrollTop=i.top),0===e._indexOf(i)&&(e.scrollTop=0),e._indexOf(i)===e._items.length-1&&(e.scrollTop=e.scrollHeight))};0!==e._previousEntry.localeCompare(i)&&(e._incrementalSearchItems=e._queryItems(e._incrementalSearchQuery,e.incrementalSearchMode),delete e._itemPosition),e._previousEntry=i;var o=e._incrementalSearchItems.length;if(0!==o){if(1===o)return void n(e._incrementalSearchItems[0]);for(void 0!==e._itemPosition?e._itemPosition<o-1?r=e._itemPosition:(r=0,t?(e._incrementalSearchItems[e._itemPosition].selected=!1,e.selectedIndexes=[],e.selectedValues=[]):e._incrementalSearchItems[e._itemPosition]._focused=!1):t&&e.clearSelection(),r;r<o;r++)if(e._incrementalSearchItems[r].selected&&t)e._incrementalSearchItems[r].selected=!1,e.selectedIndexes=[],e.selectedValues=[];else{if(t||!e._incrementalSearchItems[r]._focused)return n(e._incrementalSearchItems[r]),void(e._itemPosition=r);e._incrementalSearchItems[r]._focused=!1}}}},{key:"_selectStartHandler",value:function(e){var t=this,i=t.enableShadowDOM?t.shadowRoot.activeElement:document.activeElement;t.$.filterInput!==i&&t.$.editInput!==i&&e.preventDefault()}},{key:"_handleArrowKeys",value:function(e){var t=this,i="radioButton"!==t.selectionMode&&"checkBox"!==t.selectionMode&&"zeroOrMany"!==t.selectionMode&&"oneOrMany"!==t.selectionMode&&"zeroOrOne"!==t.selectionMode;if(!t.disabled&&!t.readonly){var r=void 0;if(t._focusedItem&&!t._keysPressed.Shift)r=t._indexOf(t._focusedItem),t._focusedItem._focused=!1;else{if(0===t.selectedIndexes.length)return;r=t.selectedIndexes[t.selectedIndexes.length-1]}var n=e?t._getPreviousItem(r):t._getNextItem(r);t._focus(n),i&&(t._keysPressed.Shift?t.select(n):t._items[r]!==n&&(t.clearSelection(),t.select(n))),t.ensureVisible(n)}}},{key:"_refreshFilter",value:function(){var e=this;if(e.filterable)return e.$.filterInput.disabled=!(!e.disabled&&!e.displayLoadingIndicator),e.$filterInputContainer.removeClass("jqx-hidden"),void e.$itemsContainer.addClass("filter");e.$.filterInput.disabled=!0,e.$filterInputContainer.addClass("jqx-hidden"),e.$itemsContainer.removeClass("filter")}},{key:"_setFocusable",value:function(){var e=this;if(e.disabled||e.unfocusable)return void e.removeAttribute("tabindex");e.tabIndex=e.tabIndex>0?e.tabIndex:0}},{key:"_setLoadingIndicatorVisibility",value:function(){var e=this;if(e.displayLoadingIndicator)return void(e.$loadingIndicatorContainer.hasClass("jqx-visibility-hidden")?e.$loadingIndicatorContainer.removeClass("jqx-visibility-hidden"):e.$loadingIndicatorContainer.removeClass("jqx-hidden"));e._areCSSVarsSupported?e.$loadingIndicatorContainer.addClass("jqx-hidden"):e.$loadingIndicatorContainer.addClass("jqx-visibility-hidden")}},{key:"_refreshLayout",value:function(){var e=this,t=e._items;if(e.__scrollHeight=null,e.__scrollWidth=null,e._height=null,e._scrollView||(e._scrollView=new JQX.Utilities.Scroll(e,e.$.horizontalScrollBar,e.$.verticalScrollBar)),e.$itemsContainer.removeClass("hscroll"),e.$itemsContainer.removeClass("vscroll"),!t||null===t||0===t.length)return e.scrollWidth=0,e.scrollHeight=0,e.$filterInputContainer.removeClass("vscroll"),e.$placeholder.removeClass("jqx-hidden"),void(e.isVirtualized&&e._recycle());e.$placeholder.addClass("jqx-hidden");var i=2*(parseInt(getComputedStyle(e.$.itemsInnerContainer).getPropertyValue("--jqx-list-item-horizontal-offset"))||0),r=e._scrollWidth-e.$.itemsContainer.offsetWidth-i,n=e._scrollHeight;if(e._refreshHorizontalScrollBarVisibility(r),e._refreshVerticalScrollBarVisibility(n),"hidden"===e.horizontalScrollBarVisibility?e.$.itemsInnerContainer.style.width=e.$.itemsContainer.offsetWidth-i:e.$.itemsInnerContainer.style.width=Math.max(e.$.itemsContainer.offsetWidth-i,-i+e.__scrollWidth)+"px",e.computedVerticalScrollBarVisibility)return r=e._scrollWidth-e.$.itemsContainer.offsetWidth-e._scrollView.vScrollBar.offsetWidth,e._refreshHorizontalScrollBarVisibility(r),"hidden"!==e.horizontalScrollBarVisibility&&(e.$.itemsInnerContainer.style.width=Math.max(e.$.itemsContainer.offsetWidth-i,-i+e.__scrollWidth-e._scrollView.vScrollBar.offsetWidth)+"px"),e.computedHorizontalScrollBarVisibility&&("visible"!==e.horizontalScrollBarVisibility||0!==e.scrollWidth?e.__scrollHeight+=e._scrollView.hScrollBar.offsetHeight:"visible"===e.horizontalScrollBarVisibility&&(e.__scrollHeight+=e._scrollView.hScrollBar.offsetHeight),e.scrollHeight=e.__scrollHeight),void(e.isVirtualized&&e._recycle());r=e._scrollWidth-e.$.itemsContainer.offsetWidth-i,e._refreshHorizontalScrollBarVisibility(r),e.computedHorizontalScrollBarVisibility&&(e.scrollHeight=e._scrollHeight,e._refreshVerticalScrollBarVisibility(e.scrollHeight)),e.isVirtualized&&e._recycle();var o=/Trident|Edge/.test(navigator.userAgent);!e.isRefreshing&&o&&setTimeout(function(){e.isRefreshing=!0,e._refreshLayout(),e.isRefreshing=!1},50)}},{key:"_styleChangedHandler",value:function(){this._refreshLayout()}},{key:"_swipeLeftHandler",value:function(){}},{key:"_swipeRightHandler",value:function(){}},{key:"_refreshHorizontalScrollBarVisibility",value:function(e){var t=this;t.scrollWidth=e,t.computedHorizontalScrollBarVisibility?(t.scrollLeft=t.$.itemsContainer.scrollLeft,t.$itemsContainer.addClass("hscroll")):t.$itemsContainer.removeClass("hscroll")}},{key:"_refreshVerticalScrollBarVisibility",value:function(e){var t=this;t.scrollHeight=e,t.computedVerticalScrollBarVisibility?(t.$itemsContainer.addClass("vscroll"),t.$filterInputContainer.addClass("vscroll")):(t.$itemsContainer.removeClass("vscroll"),t.$filterInputContainer.removeClass("vscroll"))}},{key:"_validateTemplate",value:function(e,t){if(null!==t&&t){var i=this;return"content"in document.createElement("template")?(t=document.getElementById(t),null!==t&&"content"in t?t:(i.error(i.localize("invalidTemplate",{elementType:i.nodeName.toLowerCase(),property:e})),void(i[e]=null))):(i.error(i.localize("htmlTemplateNotSuported",{elementType:i.nodeName.toLowerCase()})),void(i[e]=null))}}},{key:"_getItemIndexByPosition",value:function(e){var t=this,i=t.filterable&&t.$.filterInput.value.length>0?t._filteredItems:t._items;return function(i){var r=0,n=i.length-1;if(e<=0)return 0;if(i[i.length-1].top<=e)return i.length-1;for(;;){var o=Math.floor((r+n)/2),l=i[o];if(t._isItemInPosition(l,e))return o;l.top<e?r=o+1:l.top>e&&(n=o-1)}}(i)}},{key:"_isItemInPosition",value:function(e,t){var i=e.top,r=e.top+e.height;return i<=t&&r>t}},{key:"_recycle",value:function(){var e=this;if(e._recyclingItems){var t=e._height;e._height||(t=e._height=e.$.itemsContainer.offsetHeight);var i=0,r=e.scrollTop,n=e._getItemIndexByPosition(r),o=e.filterable&&e.$.filterInput.value.length>0?e._filteredItems:e._items,l=o[n],a=l?l.top:0;if(e.$.itemsInnerContainer.style.left=-e.scrollLeft+"px",e.$.itemsInnerContainer.style.top=-r+a+"px",
e.isUpdating++,n>=0)for(var s=n;s<o.length;s++){var d=o[s];if(0!==d.height){if(!(a+d.height>=r&&a<=r+t))break;var c=e._recyclingItems[i++];if(!c)break;c.context=document,c.dataItem=d,c.label=d.label,c.value=d.value,c.selected=d.selected,c._focused=d._focused,c.hidden=d.hidden,c.grouped=d.grouped,c.readonly=d.readonly,c.style.height=d.height+"px",e._alternateItem(c),d.title?c.title=d.title:c.title="",d.grouped?c.displayMode="plain":c.displayMode=d.displayMode,e.scrollWidth>0&&(c.style.width=e.$.itemsInnerContainer.offsetWidth+e.scrollWidth+"px"),e.itemTemplate&&e._handleItemTemplate(e.itemTemplate)&&e._applyTemplate(c,!1),a+=d.height}}if(i<e._recyclingItems.length)for(var p=i;p<e._recyclingItems.length;p++){var u=e._recyclingItems[i++],f=u.context;u.context=document,u.hidden=!0,u.context=f}e.isUpdating--}}},{key:"_verticalScrollbarHandler",value:function(e){var t=this,i=e.detail.value;if(e.stopPropagation(),t.isVirtualized?t._recycle():t.$.itemsContainer.scrollTop=i,t._updateTopVisibleIndex(),e.context.max===e.context.value)return void t.$.fireEvent("scrollBottomReached");e.context.min===e.context.value&&t.$.fireEvent("scrollTopReached")}},{key:"enableShadowDOM",get:function(){return JQX.EnableShadowDOM}},{key:"items",get:function(){var e=this;return e._filteredItems?e._filteredItems:e._items}},{key:"_scrollHeight",get:function(){var e=this,t=0;if(e.isVirtualized){if(e.__scrollHeight)return e.__scrollHeight;if(0===e._items.length)return 0;e.isUpdating++;var i=e._createItem(e.dataSource[0]);e.$.itemsInnerContainer.appendChild(i);for(var r=0;r<e._items.length;r++){var n=e._items[r];n.hidden?(n.height=0,n.top=t):(e.itemHeight?(e.itemHeight<32&&(e.itemHeight=32),n.height=e.itemHeight):(i.label=n.label,n.height=i.offsetHeight),n.top=t,t+=n.height)}e.$.itemsInnerContainer.removeChild(i),e.__scrollHeight=t-e.$.itemsInnerContainer.offsetHeight,e.filterable&&(e.__scrollHeight+=e.$.filterInput.offsetHeight),t=e.__scrollHeight,e.isUpdating--}else{for(var o=0;o<e._items.length;o++){var l=e._items[o];l.hidden?(l.height=0,l.top=t):(e.itemHeight?"auto"!==e.itemHeight&&(l.height=e.itemHeight,l.style.height=l.height+"px"):l.height=l.offsetHeight,l.top=l.offsetTop,t+=l.height)}t=e.$.itemsInnerContainer.scrollHeight-e.$.itemsInnerContainer.offsetHeight,e.filterable&&t>0&&(t+=e.$.filterInput.offsetHeight),e.__scrollHeight=t}return 0+t}},{key:"_scrollWidth",get:function(){var e=this,t=this,i=t._items;return t.__scrollWidth?t.__scrollWidth:(t.__scrollWidth=function(){for(var t=e,r=void 0,n="",o=0;o<i.length;o++)if(!i[o].hidden){var l=i[o].label;l.length>n.length&&(n=l)}var a=t._createItem({label:n});t.$.itemsContainer.appendChild(a),a.label=n,a.style.width="auto",a.isCompleted&&(a.$.itemContainer.style.width="auto");var s=getComputedStyle(a),d=parseInt(s.paddingLeft)+parseInt(s.paddingRight);return r=(a.$.itemContainer||a).offsetWidth+d,a.parentNode.removeChild(a),r}(),t.__scrollWidth)}},{key:"isVirtualized",get:function(){var e=this;return e.virtualized&&e.dataSource&&e.dataSource.length>0}}],[{key:"properties",get:function(){return{allowDrag:{value:!1,type:"boolean"},allowDrop:{value:!1,type:"boolean"},alternationStart:{value:0,type:"int"},alternationEnd:{value:0,type:"int"},alternationCount:{value:0,type:"int"},autoSort:{value:!0,type:"boolean"},dataSource:{value:null,type:"any?",reflectToAttribute:!1},dragFeedbackFormatFunction:{value:null,type:"function?"},dragOffset:{value:[10,10],type:"array"},displayLoadingIndicator:{value:!1,type:"boolean"},displayMember:{value:"",type:"string"},shadowDomMode:{allowedValues:["light","shadow"],value:"shadow",type:"string"},dropAction:{value:"move",type:"string",allowedValues:["copy","move","none"]},editable:{value:!1,type:"boolean"},filterable:{value:!1,type:"boolean"},filterCallback:{value:null,type:"function?"},filterMode:{value:"containsIgnoreCase",allowedValues:["contains","containsIgnoreCase","doesNotContain","doesNotContainIgnoreCase","equals","equalsIgnoreCase","startsWith","startsWithIgnoreCase","endsWith","endsWithIgnoreCase","custom"],type:"string"},filterInputPlaceholder:{value:"",type:"string"},grouped:{value:!1,type:"boolean"},groupMember:{value:"",type:"string"},itemTemplate:{value:null,type:"any"},itemHeight:{value:null,type:"number?"},incrementalSearchDelay:{value:700,type:"number?"},incrementalSearchMode:{value:"startsWithIgnoreCase",allowedValues:["contains","containsIgnoreCase","doesNotContain","doesNotContainIgnoreCase","equals","equalsIgnoreCase","startsWith","startsWithIgnoreCase","endsWith","endsWithIgnoreCase"],type:"string"},loadingIndicatorPlaceholder:{value:"Loading...",type:"string"},loadingIndicatorPosition:{value:"center",allowedValues:["bottom","center","top"],type:"string"},messages:{extend:!0,value:{en:{overridingProperties:'{{elementType}}: Overriding properties {{property1}} and {{property2}} applied. The "{{property1}}" property is used by default.',invalidIndex:'{{elementType}}: "{{method}}" method accepts an index of type number or an Array of numbers.',indexOutOfBound:'{{elementType}}: Out of bound index/indexes in "{{method}}" method.',invalidItem:'{{elementType}}: "{{method}}" method accepts an object or an array of objects as it\'s second parameter.',invalidSettings:'{{elementType}}: "{{method}}" method accepts a string or an object as it\'s second parameter.'}},type:"object"},name:{value:"",type:"string"},placeholder:{value:"No Items",type:"string"},selectedIndexes:{value:[],type:"array"},selectedValues:{value:[],type:"array"},selectionMode:{value:"oneOrManyExtended",allowedValues:["none","oneOrManyExtended","zeroOrMany","oneOrMany","zeroOrOne","one","checkBox","radioButton"],type:"string"},selectionChangeAction:{value:"release",allowedValues:["press","release"],type:"string"},sorted:{value:!1,type:"boolean"},sortDirection:{value:"asc",type:"string"},topVisibleIndex:{value:-1,type:"int"},type:{value:"list",type:"string",defaultReflectToAttribute:!0,readonly:!0},valueMember:{value:"",type:"string"},virtualized:{value:!1,type:"boolean"}}}},{key:"requires",get:function(){return{"JQX.ScrollBar":"jqxscrollbar.js"}}},{key:"styleUrls",get:function(){return["jqx.listbox.css"]}},{key:"listeners",get:function(){return{focus:"_focusHandler",blur:"_blurHandler","container.wheel":"_mouseWheelHandler","editInput.change":"_editInputEventHandler","editInput.blur":"_editInputEventHandler","editInput.keydown":"_editInputEventHandler","horizontalScrollBar.change":"_horizontalScrollbarHandler","itemsInnerContainer.down":"_downHandler","itemsInnerContainer.dblclick":"_dblclickEventHandler","itemsInnerContainer.move":"_itemsContainerMoveHandler","itemsContainer.mouseleave":"_mouseLeaveHandler","document.up":"_upHandler","document.move":"_moveHandler",keydown:"_keyDownHandler",keyup:"_keyUpHandler",resize:"_resizeHandler",selectstart:"_selectStartHandler",styleChanged:"_styleChangedHandler",swipeleft:"_swipeLeftHandler",swiperight:"_swipeRightHandler","verticalScrollBar.change":"_verticalScrollbarHandler"}}}]),t}(JQX.ScrollViewer));
//# sourceMappingURL=jqxlistbox.js.map

"use strict";JQX("jqx-drop-down-list",function(e){function t(){return babelHelpers.classCallCheck(this,t),babelHelpers.possibleConstructorReturn(this,(t.__proto__||Object.getPrototypeOf(t)).apply(this,arguments))}return babelHelpers.inherits(t,e),babelHelpers.createClass(t,[{key:"template",value:function(){return'<div id="container">\n                    <span class="jqx-label" id="label">[[label]]</span>\n                    <div id="content" class="jqx-content">\n                        <div class="jqx-buttons-container" id="buttonsContainer">\n                            <span id="actionButton" class="jqx-input jqx-action-button"></span>\n                            <span id="dropDownButton" class="jqx-drop-down-button">\n                                <span id="arrow"></span>\n                            </span>\n                        </div>\n                        <div id="dropDownContainer" class="jqx-drop-down jqx-drop-down-container jqx-visibility-hidden">\n                            <jqx-list-box id="listBox" unfocusable\n                                    animation="[[animation]]"\n                                    data-source="[[dataSource]]"\n                                    disabled="[[disabled]]"\n                                    display-loading-indicator="[[displayLoadingIndicator]]"\n                                    display-member="[[displayMember]]"\n                                    filterable="[[filterable]]"\n                                    filter-mode="[[filterMode]]"\n                                    filter-input-placeholder="[[filterInputPlaceholder]]"\n                                    grouped="[[grouped]]"\n                                    group-member="[[groupMember]]"\n                                    item-height="[[itemHeight]]"\n                                    item-template="[[itemTemplate]]"\n                                    incremental-search-delay="[[incrementalSearchDelay]]"\n                                    incremental-search-mode="[[incrementalSearchMode]]"\n                                    loading-indicator-placeholder="[[loadingIndicatorPlaceholder]]"\n                                    loading-indicator-position="[[loadingIndicatorPosition]]"\n                                    name="[[name]]"\n                                    placeholder="[[dropDownPlaceholder]]"\n                                    readonly="[[readonly]]"\n                                    selected-indexes="{{selectedIndexes}}"\n                                    selection-mode="[[selectionMode]]"\n                                    selected-values="{{selectedValues}}"\n                                    sorted="[[sorted]]"\n                                    theme="[[theme]]"\n                                    value-member="[[valueMember]]"\n                                    horizontal-scroll-bar-visibility="[[horizontalScrollBarVisibility]]"\n                                    vertical-scroll-bar-visibility="[[verticalScrollBarVisibility]]"\n                                    virtualized="[[virtualized]]">\n                                <content></content>\n                            </jqx-list-box>\n                            <div id="resizeBar" class="jqx-drop-down-resize-bar">\n                                <div></div>\n                            </div>\n                         </div>\n                    </div>\n                    <span class="jqx-hint" id="hint">[[hint]]</span>\n                </div>'}},{key:"propertyChangedHandler",value:function(e,o,n){babelHelpers.get(t.prototype.__proto__||Object.getPrototypeOf(t.prototype),"propertyChangedHandler",this).call(this,e,o,n);var i=this;switch(e){case"animation":i.$.dropDownContainer.setAttribute("animation",i.animation);break;case"disabled":i._setFocusable(),i.close(),i._positionDetection.handleAutoPositioning();break;case"dataSource":case"displayMember":i.$.actionButton&&(i.$.actionButton.innerHTML=i.placeholder),i._setDropDownSize(),i._positionDetection.checkBrowserBounds("vertically"),i._positionDetection.positionDropDown(),i._positionDetection.checkBrowserBounds("horizontally");break;case"dropDownAppendTo":i._positionDetection.dropDownAppendToChangedHandler();break;case"dropDownOpenMode":i._setFocusable(),i.$dropDownContainer.addClass("jqx-visibility-hidden"),i.$.dropDownButton.removeAttribute("selected"),i.removeAttribute("drop-down-button-focus"),i.removeAttribute("action-button-focus"),i.opened=!1;break;case"dropDownOverlay":n||i._positionDetection.removeOverlay();break;case"dropDownPosition":i._positionDetection.dropDownPositionChangedHandler();break;case"dropDownMinWidth":case"dropDownWidth":case"dropDownMaxWidth":case"dropDownHeight":case"dropDownMinHeight":case"dropDownMaxHeight":i._setDropDownSize();break;case"opened":if(i.disabled||i.readonly)return;n?i.open():i.close();break;case"placeholder":i._applySelection();break;case"readonly":i.close();break;case"resizeIndicator":n?i.$.dropDownContainer.setAttribute("resize-indicator",""):i.$.dropDownContainer.removeAttribute("resize-indicator");break;case"resizeMode":i.$.dropDownContainer.setAttribute("resize-mode",i.resizeMode);break;case"selectedValues":case"selectedIndexes":0===n.length?i.$.actionButton.innerHTML=i.placeholder:i._applySelection();break;case"selectionDisplayMode":i._applySelection();break;case"tokenTemplate":i._tokenTemplate=i._validateTemplate(i.tokenTemplate),i._applySelection();break;case"unfocusable":i._setFocusable()}}},{key:"appendChild",value:function(e){var t=this;if(!t.isCompleted||e instanceof HTMLElement&&e.classList.contains("jqx-resize-trigger-container")){var o=Array.prototype.slice.call(arguments,2);return HTMLElement.prototype.appendChild.apply(t,o.concat(Array.prototype.slice.call(arguments)))}if(!e)return void t.error(t.localize("invalidNode",{elementType:t.nodeName.toLowerCase(),method:"appendChild",node:"node"}));t.$.listBox.appendChild(e),t._dropDownSize&&"auto"===t._dropDownSize.height&&t._setDropDownSize()}},{key:"attached",value:function(){var e=this;babelHelpers.get(t.prototype.__proto__||Object.getPrototypeOf(t.prototype),"attached",this).call(this),e.isCompleted&&e.$.dropDownContainer&&(e._positionDetection.dropDownAttached("_setDropDownSize"),e._positionDetection.checkBrowserBounds())}},{key:"detached",value:function(){var e=this;babelHelpers.get(t.prototype.__proto__||Object.getPrototypeOf(t.prototype),"detached",this).call(this),e.$.dropDownContainer&&(e.close(),e._positionDetection.dropDownDetached())}},{key:"clearItems",value:function(){var e=this;e.$.listBox&&(e.$.listBox.clearItems(),e.$.actionButton.innerHTML=e.placeholder)}},{key:"clearSelection",value:function(){var e=this;e.$.listBox&&(e.$.listBox.clearSelection(),e.$.actionButton.innerHTML=e.placeholder)}},{key:"close",value:function(){var e=this;if(!e.$dropDownContainer.hasClass("jqx-visibility-hidden")){e.$.fireEvent("closing").defaultPrevented||(e.$dropDownContainer.addClass("jqx-visibility-hidden"),e.$.fireEvent("close"),e.$.dropDownButton&&e.$.dropDownButton.removeAttribute("selected"),e.opened=!1,e._preventDropDownClose=!1,e._positionDetection.removeOverlay(!0),e._edgeMacFF&&!e.hasAnimation&&e.$.dropDownContainer&&(e.$.dropDownContainer.style.top=e.$.dropDownContainer.style.left="",e.$dropDownContainer.addClass("not-in-view")))}}},{key:"cloneNode",value:function(){var e=this;if(e.$.listBox){var t=HTMLElement.prototype.cloneNode.apply(e,Array.prototype.slice.call(arguments,0,1));return t.dataSource=e.dataSource,t}}},{key:"ensureVisible",value:function(e){var t=this;t.$.listBox&&t.$.listBox.ensureVisible(e)}},{key:"getItem",value:function(e){var t=this;if(t.$.listBox)return t.$.listBox.getItem(e)}},{key:"insert",value:function(e,t){var o=this;o.$.listBox&&(o.$.listBox.insert(e,t),o._applySelection(),o._dropDownSize&&"auto"===o._dropDownSize.height&&o._setDropDownSize())}},{key:"insertBefore",value:function(e,t){var o=this;if(!o.isCompleted){var n=Array.prototype.slice.call(arguments,2);return HTMLElement.prototype.insertBefore.apply(o,n.concat(Array.prototype.slice.call(arguments)))}if(!e||!t)return void o.error(o.localize("invalidNode",{elementType:o.nodeName.toLowerCase(),method:"insertBefore",node:"newNode/referenceNode"}));o.$.listBox&&(o.$.listBox.insertBefore(e,t),o._dropDownSize&&"auto"===o._dropDownSize.height&&o._setDropDownSize())}},{key:"open",value:function(){var e=this,t=function(){for(var t=0;t<e.items.length;t++)if(!e.items[t].disabled)return e.items[t]};if(!e.disabled&&e.offsetHeight&&e.$dropDownContainer.hasClass("jqx-visibility-hidden")){if(e.$dropDownContainer.hasClass("not-in-view")&&e.$dropDownContainer.removeClass("not-in-view"),e.$.dropDownContainer.style.transition=null,e.dropDownAppendTo&&e.dropDownAppendTo.length>0){var o=e.getBoundingClientRect();if(e.$.container.contains(e.$.dropDownContainer)){var n=0,i=setInterval(function(){var t=e.getBoundingClientRect();n++,t.top===e._positionTop&&n<10||(e.open(),clearInterval(i),e._positionTop=t.top)},100);return}o.top!==e._positionTop&&(e._positionTop=o.top)}e.$.fireEvent("opening").defaultPrevented||(e.opened=!0,e._positionDetection.placeOverlay(),e._positionDetection.checkBrowserBounds("vertically"),e._positionDetection.positionDropDown(),e._positionDetection.checkBrowserBounds("horizontally"),e.$dropDownContainer.removeClass("jqx-visibility-hidden"),e.$.fireEvent("open"),e.$.dropDownButton&&("dropDownButton"===e.dropDownOpenMode?e.$.dropDownButton.setAttribute("selected",""):e.$.dropDownButton.removeAttribute("selected")),(e.$.listBox&&!e._focusedItem||e._focusedItem&&!e._focusedItem._focused)&&(e.selectedIndexes.length>0?e._focus(e.items[e.selectedIndexes[0]]):e._focus(t)),e.$.input&&!JQX.Utilities.Core.isMobile&&e.$.input.focus())}}},{key:"ready",value:function(){babelHelpers.get(t.prototype.__proto__||Object.getPrototypeOf(t.prototype),"ready",this).call(this);var e=this;e.$.dropDownContainer&&(e._positionDetection=new JQX.Utilities.PositionDetection(e,e.$.dropDownContainer,e.$.container,"close"),e._positionDetection.getDropDownParent(!0),e._positionDetection.setDropDownPosition(),e._calculateDropDownSize(),e.$.dropDownContainer.setAttribute("resize-mode",e.resizeMode),e.resizeIndicator&&e.$.dropDownContainer.setAttribute("resize-indicator",""),e._positionDetection.handleAutoPositioning()),e.opened&&e.open(),e._positionTop=e.getBoundingClientRect().top,e._edgeMacFF=JQX.Utilities.Core.Browser.Edge||JQX.Utilities.Core.Browser.Firefox&&-1!==navigator.platform.toLowerCase().indexOf("mac"),e._edgeMacFF&&e.hasAnimation&&e.$.dropDownContainer&&e.$dropDownContainer.addClass("not-in-view"),e._createElement()}},{key:"remove",value:function(e){var t=this;t.$.listBox&&(t.$.listBox.remove(e),t._applySelection(),t._dropDownSize&&"auto"===t._dropDownSize.height&&t._setDropDownSize())}},{key:"removeChild",value:function(e){var t=this;if(!t.isCompleted||e instanceof HTMLElement&&e.classList.contains("jqx-resize-trigger-container")){var o=Array.prototype.slice.call(arguments,2);return HTMLElement.prototype.removeChild.apply(t,o.concat(Array.prototype.slice.call(arguments)))}if(!(e&&e instanceof JQX.ListItem))return void t.error(t.localize("invalidNode",{elementType:t.nodeName.toLowerCase(),method:"removeChild",node:"node"}));t.$.listBox.removeChild(e),t._dropDownSize&&"auto"===t._dropDownSize.height&&t._setDropDownSize()}},{key:"select",value:function(e){var t=this;t.$.listBox&&t.$.listBox.select(e)}},{key:"_setFocusable",value:function(){var e=this;if(e.disabled||e.unfocusable)return e.removeAttribute("tabindex"),e.$.actionButton.removeAttribute("tabindex"),void e.$.dropDownButton.removeAttribute("tabindex");var t=e.tabIndex>0?e.tabIndex:0;"dropDownButton"===e.dropDownOpenMode?(e.removeAttribute("tabindex"),e.$.actionButton.setAttribute("tabindex",t),e.$.dropDownButton.setAttribute("tabindex",t)):(e.$.actionButton.removeAttribute("tabindex"),e.$.dropDownButton.removeAttribute("tabindex"),e.tabIndex=t)}},{key:"unselect",value:function(e){var t=this;t.$.listBox&&t.$.listBox.unselect(e)}},{key:"update",value:function(e,t){var o=this;o.$.listBox&&(o.$.listBox.update(e,t),o._applySelection())}},{key:"_resizeBarMoveHandler",value:function(e){"touchmove"===e.originalEvent.type&&e.originalEvent.preventDefault()}},{key:"_createToken",value:function(){var e=this,t=void 0,o=document.createDocumentFragment(),n=e.selectedIndexes[e.selectedIndexes.length-1];t="plain"!==e.selectionDisplayMode||"one"!==e.selectionMode&&"zeroOrOne"!==e.selectionMode&&"radioButton"!==e.selectionMode?"tokens"===e.selectionDisplayMode?1===e.selectedIndexes.length&&["oneOrManyExtended","oneOrMany","one","radioButton"].indexOf(e.selectionMode)>-1?"":"&#10006":1===e.selectedIndexes.length?"":",":"";for(var i=e.selectedIndexes,r=e.$.listBox._items,a=0;a<i.length;a++){var l=i[a];r[l]&&o.appendChild(e._applyTokenTemplate(r[l].label,"tokens"!==e.selectionDisplayMode&&l===n?"":t))}return o}},{key:"_applySelection",value:function(){var e=this;if("placeholder"===e.selectionDisplayMode||0===e.selectedIndexes.length)return void(e.$.actionButton.innerHTML=e.placeholder);e.$.listBox._items&&0!==e.$.listBox._items.length&&(e.$.actionButton.innerHTML="",e.$.actionButton.appendChild(e._createToken()))}},{key:"_applyTokenTemplate",value:function(e,t){var o=this,n=document.createElement("span"),i=function(){return"<span class='jqx-drop-down-list-selection-label'>"+e+"</span><span class='jqx-drop-down-list-unselect-button'>"+t+"</span>"};if(n.classList.add("jqx-token"),o._tokenTemplate)for(var r=document.importNode(o._tokenTemplate.content,!0),a=r.childNodes.length,l=/{{\w+}}/g,s=void 0,d=0;d<a;d++)s=l.exec(r.childNodes[d].innerHTML),s&&(r.childNodes[d].innerHTML=r.childNodes[d].innerHTML.replace(s[0],i())),r.childNodes[d].outerHTML&&(n.innerHTML+=r.childNodes[d].outerHTML);else"function"==typeof o.tokenTemplate?o.tokenTemplate(n,{label:e,iconSeparator:t}):n.innerHTML=i();return n}},{key:"_bindingCompleteHandler",value:function(){var e=this;e.$.listBox&&requestAnimationFrame(function(){e._setDropDownSize(),e._positionDetection.checkBrowserBounds()})}},{key:"_buttonsDownHandler",value:function(e){var t=this;if(!t.disabled){if(t.hasRippleAnimation)if(t.$.buttonsContainer&&"dropDownButton"!==t.dropDownOpenMode){var o=t.$.buttonsContainer;o.firstElementChild.noRipple=!0,JQX.Utilities.Animation.Ripple.animate(o,e.pageX,e.pageY),o.firstElementChild.noRipple=!1}else JQX.Utilities.Animation.Ripple.animate(e.target,e.pageX,e.pageY);t._preventsSelectStart=!0,"dropDownButton"===t.dropDownOpenMode&&e.target===t.$.actionButton&&t.$.actionButton.setAttribute("active",""),t.opened&&(t._preventDropDownClose=!0)}}},{key:"_buttonsMouseEventsHandler",value:function(e){var t=this;t.disabled||("mouseenter"===e.type?(t.setAttribute("hover",""),e.target.setAttribute("hover","")):(t.removeAttribute("hover"),e.target.removeAttribute("hover")))}},{key:"_calculateDropDownSize",value:function(){var e=this;e._dropDownSize={};var t=window.getComputedStyle(e.$.dropDownContainer),o=parseFloat(t.getPropertyValue("border-top-width").trim()),n=parseFloat(t.getPropertyValue("border-bottom-width").trim()),i=parseFloat(t.getPropertyValue("margin-top").trim()),r=parseFloat(t.getPropertyValue("margin-bottom").trim()),a=parseFloat(t.getPropertyValue("padding-top").trim()),l=parseFloat(t.getPropertyValue("padding-bottom").trim());JQX.Utilities.Core.CSSVariablesSupport()&&(e._dropDownSize.width=t.getPropertyValue("--jqx-drop-down-list-drop-down-width").trim(),e._dropDownSize.height=t.getPropertyValue("--jqx-drop-down-list-drop-down-height").trim()),(!e._dropDownSize.width||e._dropDownSize.width.indexOf("initial")>-1)&&(e._dropDownSize.width=e.offsetWidth),e._dropDownSize.height||(e._dropDownSize.height="auto"),e._dropDownSize.minHeight=parseFloat(t.getPropertyValue("min-height").trim()),e._dropDownSize.maxHeight=parseFloat(t.getPropertyValue("max-height").trim()),e._dropDownSize.borderWidth=(isNaN(o)?0:o)+(isNaN(n)?0:n),e._dropDownSize.paddingWidth=(isNaN(a)?0:a)+(isNaN(l)?0:l),e._dropDownSize.marginWidth=(isNaN(i)?0:i)+(isNaN(r)?0:r)}},{key:"_createElement",value:function(){var e=this;e._tokenTemplate=e._validateTemplate(e.tokenTemplate),e._applySelection(),e._setDropDownSize(),e._setFocusable(),e.$.arrow.noRipple=!0}},{key:"_documentDownHandler",value:function(e){var t=this;if(!t.disabled&&!t.readonly){var o=e.originalEvent.target;if(o===t._overlay&&(t._overlayDown=!0),t.enableShadowDOM){o=e.originalEvent.composedPath()[0];for(var n=o.getRootNode().host;n;)n.closest(".jqx-drop-down-container")===t.$.dropDownContainer&&(t._isDropDownClicked=!0),n=n.getRootNode().host}else t._isDropDownClicked=o.closest(".jqx-drop-down-container")===t.$.dropDownContainer;if(t._buttonClicked=o.closest(".jqx-action-button")||o.closest(".jqx-drop-down-button"),t.$.listBox){var i=o.closest("jqx-list-item");t.$.listBox.contains(i)||(i=void 0),t.hasRippleAnimation&&i&&JQX.Utilities.Animation.Ripple.animate(i,e.pageX,e.pageY),(i||o===t.$.listBox.$.filterInput||o.closest(".jqx-token"))&&(t._preventDropDownClose=!0)}if(t._isDropDownClicked&&(t._preventDropDownClose=!0),o===t.$.resizeBar&&"none"!==t.resizeMode){t._resizeDetails||(t._resizeDetails={});var r=t.$.dropDownContainer.getBoundingClientRect();t._resizeDetails.started=!0,t._resizeDetails.x=e.pageX,t._resizeDetails.y=e.pageY,t._resizeDetails.width=t.$.dropDownContainer.offsetWidth,t._resizeDetails.height=t.$.dropDownContainer.offsetHeight,t._resizeDetails.offsetXL=e.clientX-r.left,t._resizeDetails.offsetXR=r.left+t.$.dropDownContainer.offsetWidth-e.clientX,t._resizeDetails.offsetY=r.top+t.$.dropDownContainer.offsetHeight-e.clientY,t._resizeDetails.offsetYtop=e.clientY-r.top,t._preventDropDownClose=!0}}}},{key:"_documentMoveHandler",value:function(e){function t(){if(d=e.pageY-n._resizeDetails.y,"bottom"===s)n._resizeDetails.height=Math.min(r.clientHeight-a.top-6,Math.max(0,n._resizeDetails.height+d)),n._resizeDetails.y=Math.max(a.top+r.scrollTop-n._resizeDetails.offsetY,Math.min(r.clientHeight+r.scrollTop-1.5*n._resizeDetails.offsetY,e.pageY));else{if(n._resizeDetails.height=Math.min(n._dropDownSize.maxHeight,Math.max(0,Math.min(l.top,n._resizeDetails.height-d))),d=Math.max(0,a.top+(a.height-Math.max(n._dropDownSize.minHeight,n._resizeDetails.height))),n.dropDownAppendTo&&n.dropDownAppendTo.length>0){var t=Math.abs(parseFloat(getComputedStyle(n.$.dropDownContainer).getPropertyValue("margin-bottom")))||0;n.$.dropDownContainer.style.top=n.dropDownAppendTo&&n.dropDownAppendTo.length>0?t+d+"px":""}var o=l.top+r.scrollTop+n._resizeDetails.offsetYtop;n._resizeDetails.y=Math.max(n._resizeDetails.offsetYtop,Math.min(o,Math.max(o-n._dropDownSize.maxHeight,e.pageY)))}n.$.dropDownContainer.style.height=n._resizeDetails.height+"px"}function o(){d=e.pageX-n._resizeDetails.x,n._resizeDetails.width=Math.min(r.clientWidth-a.left-6,Math.max(0,n._resizeDetails.width+d)),n.$.dropDownContainer.style.width=n._resizeDetails.width+"px",n._resizeDetails.x=Math.max(a.left+r.scrollLeft-n._resizeDetails.offsetXR,Math.min(r.clientWidth+r.scrollLeft-1.5*n._resizeDetails.offsetXR,e.pageX))}var n=this,i=n.enableShadowDOM?e.originalEvent.composedPath()[0]:e.originalEvent.target;if("auto"===n.dropDownOpenMode&&null!==n.dropDownAppendTo&&(n.contains(i)||n.$.dropDownContainer.contains(i)?n._isElementHovered=!0:(n._isElementHovered=!1,n._autoClose())),n._resizeDetails&&(!n._resizeDetails||n._resizeDetails.started)){n.setAttribute("resizing",""),n._resizeDetails.resizeEventFired||(n.$.fireEvent("resizeStart",{position:{left:e.pageX,top:e.pageY}}),n._resizeDetails.resizeEventFired=!0);var r=document.documentElement,a=n.$.dropDownContainer.getBoundingClientRect(),l=n.getBoundingClientRect(),s=n.$.dropDownContainer.hasAttribute("top")?"top":"bottom",d=void 0;switch(n.resizeMode){case"vertical":t();break;case"horizontal":o();break;case"both":o(),t()}}}},{key:"_documentUpHandler",value:function(e){var t=this;if(t.$.actionButton.removeAttribute("active"),t._resizeDetails&&t._resizeDetails.started)return t._resizeDetails.started=t._resizeDetails.resizeEventFired=!1,t.removeAttribute("resizing"),t._preventDropDownClose=!1,t.focus(),void t.$.fireEvent("resizeEnd",{position:{left:e.pageX,top:e.pageY}});if(t.disabled||t._isDropDownClicked||t.readonly)return void delete t._isDropDownClicked;if(t._overlayDown)return t.close(),void delete t._overlayDown;var o=e.originalEvent.target,n=o.closest?o.closest("jqx-drop-down-list"):void 0;if(t.enableShadowDOM&&(o=e.originalEvent.composedPath()[0],n=o.getRootNode().host),t._preventsSelectStart=!1,void 0!==o&&o!==t.$.resizeBar){if("tokens"===t.selectionDisplayMode&&o.classList.contains("jqx-drop-down-list-selection-label")&&n===t){"none"!==t.dropDownOpenMode&&t.open();var i=t.$.listBox._items.filter(function(e){return e.label.toString()===o.textContent})[0];return t.$.listBox._scrollView.scrollTop=i.offsetTop,void t._focus(i)}if("tokens"===t.selectionDisplayMode&&o.classList.contains("jqx-drop-down-list-unselect-button")&&n===t){if(1===t.selectedIndexes.length&&["zeroOrMany","zeroOrOne","checkBox"].indexOf(t.selectionMode)<0)return;return void t.unselect(t.$.listBox._items.filter(function(e){return e.label.toString()===o.previousElementSibling.textContent})[0])}var r=o.closest(".jqx-action-button");if(t._buttonClicked&&("dropDownButton"===t.dropDownOpenMode&&r&&t._buttonClicked===t.$.actionButton?t.$.fireEvent("actionButtonClick"):o.closest(".jqx-drop-down-button")!==t._buttonClicked&&r!==t._buttonClicked||t.$.fireEvent("dropDownButtonClick")),t._buttonClicked=void 0,r===t.$.actionButton||o.closest(".jqx-drop-down-button")===t.$.dropDownButton)return"dropDownButton"===t.dropDownOpenMode&&r===t.$.actionButton?void t.close():void(t.$dropDownContainer.hasClass("jqx-visibility-hidden")&&"none"!==t.dropDownOpenMode?t.open():t.close());o=t._getUpEventTarget(o),void 0!==o&&("dropDownContainer"!==o&&"item"!==o||"item"===o&&"checkBox"!==t.selectionMode&&t.selectionMode.indexOf("Many")<0)&&t.close()}}},{key:"_dragStartHandler",value:function(e){var t=this;t._resizeDetails&&t._resizeDetails.started&&e.preventDefault()}},{key:"_dropDownTransitionendHandler",value:function(){var e=this;e._edgeMacFF&&!e.opened&&e.hasAnimation&&(e.$.dropDownContainer.style.top=e.$.dropDownContainer.style.left="",e.$dropDownContainer.addClass("not-in-view"))}},{key:"_focus",value:function(e){this.$.listBox._focus(e)}},{key:"_blurEventHandler",value:function(){var e=this;e.$.dropDownButton&&(e.removeAttribute("focus"),e.$.dropDownButton.removeAttribute("focus")),e.$.actionButton&&(e.removeAttribute("focus"),e.$.actionButton.removeAttribute("focus")),e.nodeName&&"JQX-DROP-DOWN-LIST"===e.nodeName&&!e._preventDropDownClose&&e.close()}},{key:"_focusEventHandler",value:function(){var e=this;e.$.dropDownButton&&(e.setAttribute("focus",""),e.$.dropDownButton.setAttribute("focus","")),e.$.actionButton&&(e.setAttribute("focus",""),e.$.actionButton.setAttribute("focus","")),e.removeAttribute("drop-down-button-focus"),e.removeAttribute("action-button-focus")}},{key:"_buttonsFocusHandler",value:function(e){var t=this;e.target===t.$.dropDownButton?"focus"===e.type?t.setAttribute("drop-down-button-focus",""):(t.removeAttribute("drop-down-button-focus"),t.nodeName&&"JQX-DROP-DOWN-LIST"===t.nodeName&&!t._preventDropDownClose&&t.close()):"focus"===e.type?t.setAttribute("action-button-focus",""):t.removeAttribute("action-button-focus")}},{key:"_getUpEventTarget",value:function(e){for(var t=this,o=e;o;){if(o instanceof JQX.ListItem&&o.ownerListBox===t.$.listBox){if(o.unselectable||o.disabled)return;o="item";break}if(o===t.$.dropDownContainer){o="dropDownContainer";break}o=o.parentElement}if(t.enableShadowDOM&&null!==o)for(o=e.getRootNode().host;o;){if(o===t.$.dropDownContainer){o="dropDownContainer";break}o=o.parentElement}return o}},{key:"_keyDownHandler",value:function(e){var t=this,o=t.enableShadowDOM?t.shadowRoot.activeElement||document.activeElement:document.activeElement,n=t.enableShadowDOM?e.composedPath()[0]:e.target;if(!(t.$.listBox&&n===t.$.listBox.$.filterInput||o!==t&&o!==t.$.dropDownButton&&o!==t.$.actionButton))switch(e.key){case"Enter":case" ":n.setAttribute("active",""),e.preventDefault(),n!==t.$.actionButton&&(t._keyPressed=!0,t.opened?(t._focusedItem&&t.select(t._focusedItem),("Enter"===e.key&&["none"].indexOf(t.selectionMode)<0||" "===e.key&&["none","one","radioButton"].indexOf(t.selectionMode)>-1)&&t.close()):t.opened||t.readonly||"none"===t.dropDownOpenMode||t.open());break;case"End":case"Home":case"PageUp":case"PageDown":case"ArrowUp":case"ArrowDown":if(t.readonly)return;if(e.altKey)return t._keyPressed=!1,void(t.$dropDownContainer.hasClass("jqx-visibility-hidden")?t.open():t.close());e.preventDefault(),t.$.listBox._handleKeyStrokes(e.key);break;case"Escape":e.preventDefault(),t.close();break;default:if(t.readonly)return;"oneOrManyExtended"===t.selectionMode&&(t.$.listBox._keysPressed[e.key]=!0),t.$.listBox._applyIncrementalSearch(e.key)}}},{key:"_keyUpHandler",value:function(e){var t=this,o=t.enableShadowDOM?e.composedPath()[0]:e.target;t.$.listBox&&o===t.$.listBox.$.filterInput||("Enter"!==e.key&&" "!==e.key||(o.removeAttribute("active"),t.$dropDownContainer.hasClass("jqx-visibility-hidden")||(t._keyPressed=!1)),t.$.listBox&&"oneOrManyExtended"===t.selectionMode&&(t.$.listBox._keysPressed[e.key]=!1))}},{key:"_listBoxChangeHandler",value:function(e){var t=this;(t.dropDownAppendTo&&t.dropDownAppendTo.length>0||t.enableShadowDOM)&&t.$.fireEvent("change",e.detail),t._applySelection(t.selectionMode,e.detail)}},{key:"_listBoxItemClickHandler",value:function(e){var t=this;(t.dropDownAppendTo&&t.dropDownAppendTo.length>0||t.enableShadowDOM)&&t.$.fireEvent(e.type,e.detail),"checkBox"!==t.selectionMode&&t.selectionMode.indexOf("Many")<0&&t.close(),"JQX-COMBO-BOX"!==t.nodeName||JQX.Utilities.Core.isMobile||t.$.input.focus()}},{key:"_listBoxKeyDownHandler",value:function(e){var t=this;return"Enter"===e.key?(t.close(),"dropDownButton"===t.dropDownOpenMode?t.$.dropDownButton.focus():t.focus(),void e.stopPropagation()):"Escape"===e.key?void t.close():void 0}},{key:"_mouseEnterHandler",value:function(){var e=this;e._isElementHovered=!0,e.tagName.indexOf("JQX-DROP-DOWN-")>-1&&"auto"===e.dropDownOpenMode&&!e.disabled&&!e.readonly&&e.open()}},{key:"_mouseLeaveHandler",value:function(){var e=this;e.removeAttribute("hover"),e._isElementHovered=!1,"auto"!==e.dropDownOpenMode||e.disabled||e.readonly||e._autoClose()}},{key:"_autoClose",value:function(){var e=this;e._autoCloseTimeout=setTimeout(function(){e._isElementHovered||e.close(),clearTimeout(e._autoCloseTimeout)}.bind(e),e.autoCloseDelay)}},{key:"_propertyValidator",value:function(e,t){return"number"!=typeof t&&"string"!=typeof t?e:t}},{key:"_resizeHandler",value:function(){var e=this;"none"===e.resizeMode&&(e._calculateDropDownSize(),e._setDropDownSize())}},{key:"_selectStartHandler",value:function(e){this._preventsSelectStart&&e.preventDefault()}},{key:"_setDropDownSize",value:function(){var e=this;if(e._dropDownSize||e._calculateDropDownSize(),["dropDownMinWidth","dropDownMinHeight","dropDownMaxWidth","dropDownMaxHeight"].forEach(function(t){e.$.dropDownContainer.style[t.replace("dropDown","").replace(/^./,"m")]=e[t]?e[t]+(e[t].toString().endsWith("%")?"%":"px"):null}),e.dropDownWidth){if("auto"!==e.dropDownWidth)e.$.dropDownContainer.style.width=("initial"===e.dropDownWidth?e.offsetWidth:parseFloat(e.dropDownWidth))+"px";else if(e.$.dropDownContainer.style.width="auto",e.$.listBox){var t=2+2*parseInt(window.getComputedStyle(e.$.listBox.$.itemsContainer).getPropertyValue("--jqx-list-item-horizontal-offset"));e.$.dropDownContainer.style.width=t+e.$.listBox._scrollWidth+"px"}}else e.$.dropDownContainer.style.width="auto"===e._dropDownSize.width?"auto":(parseFloat(e._dropDownSize.width)||0)+"px";if(e.dropDownHeight&&"auto"!==e.dropDownHeight)e.$.dropDownContainer.style.height=parseFloat(e.dropDownHeight)+((e.dropDownHeight+"").indexOf("%")>-1?"%":"px");else if(!e.$.listBox||"auto"!==e._dropDownSize.height&&"auto"!==e.dropDownHeight)e.$.dropDownContainer.style.height=e._dropDownSize.height;else{e.$.dropDownContainer.style.height="";var o=2*parseInt(window.getComputedStyle(e.$.listBox.$.itemsContainer).getPropertyValue("--jqx-list-item-vertical-offset"));isNaN(o)&&(o=6);var n=o;e.$.listBox.items.length>0&&e.$.listBox.items.map(function(e){return n+=e.height||e.offsetHeight}),n=n+e._dropDownSize.paddingWidth+e._dropDownSize.borderWidth,e.$.dropDownContainer.style.height=n+"px"}e.$.listBox&&e.$.listBox._refreshLayout()}},{key:"_styleChangedHandler",value:function(e){var t=this;if(t.dropDownAppendTo&&t.dropDownAppendTo.length>0)for(var o=e.detail.styleProperties,n=["font-size","font-family","font-style","font-weight"],i=0;i<n.length;i++)o[n[i]]&&(t.$.dropDownContainer.style[n[i]]=o[n[i]].value);"auto"===t._dropDownSize.height&&t._setDropDownSize()}},{key:"_validateTemplate",value:function(e){var t=this;if(e&&"function"!=typeof e)return"content"in document.createElement("template")?(e instanceof HTMLTemplateElement||(e=document.getElementById(e)),null!==e&&"content"in e?e:void t.error(t.localize("invalidTemplate",{elementType:t.nodeName.toLowerCase(),property:"tokenTemplate"}))):void t.error(t.localize("htmlTemplateNotSuported",{elementType:t.nodeName.toLowerCase()}))}},{key:"items",get:function(){var e=this;if(e.$&&e.$.listBox)return e.$.listBox.items}},{key:"_focusedItem",get:function(){var e=this;if(e.$&&e.$.listBox)return e.$.listBox._focusedItem}}],[{key:"properties",get:function(){return{autoCloseDelay:{value:100,type:"number"},dataSource:{value:null,type:"any",reflectToAttribute:!1},displayLoadingIndicator:{value:!1,type:"boolean"},displayMember:{value:"",type:"string"},dropDownAppendTo:{value:null,type:"any"},dropDownButtonPosition:{allowedValues:["none","left","right","top","bottom"],value:"right",type:"string"},dropDownMinHeight:{value:"",type:"any",validator:"_propertyValidator"},dropDownHeight:{value:"",type:"any",validator:"_propertyValidator"},dropDownMaxHeight:{value:"",type:"any",validator:"_propertyValidator"},dropDownOpenMode:{allowedValues:["none","default","dropDownButton","auto"],value:"default",type:"string"},dropDownOverlay:{value:!1,type:"boolean"},dropDownPlaceholder:{value:"No Items",type:"string"},dropDownPosition:{allowedValues:["auto","top","bottom","overlay-top","overlay-center","overlay-bottom","center-bottom","center-top"],value:"auto",type:"string"},dropDownMinWidth:{value:"",type:"any",validator:"_propertyValidator"},dropDownWidth:{value:"",type:"any",validator:"_propertyValidator"},dropDownMaxWidth:{value:"",type:"any",validator:"_propertyValidator"},filterable:{value:!1,type:"boolean"},filterInputPlaceholder:{value:"",type:"string"},filterMode:{value:"startsWithIgnoreCase",allowedValues:["contains","containsIgnoreCase","doesNotContain","doesNotContainIgnoreCase","equals","equalsIgnoreCase","startsWith","startsWithIgnoreCase","endsWith","endsWithIgnoreCase"],type:"string"},grouped:{value:!1,type:"boolean"},groupMember:{value:"",type:"string"},hint:{value:"",type:"string"},horizontalScrollBarVisibility:{type:"string",value:"auto",allowedValues:["auto","disabled","hidden","visible"]},incrementalSearchDelay:{value:700,type:"number?"},incrementalSearchMode:{value:"startsWithIgnoreCase",allowedValues:["contains","containsIgnoreCase","doesNotContain","doesNotContainIgnoreCase","equals","equalsIgnoreCase","startsWith","startsWithIgnoreCase","endsWith","endsWithIgnoreCase"],type:"string"},itemTemplate:{value:null,type:"any"},itemHeight:{value:null,type:"number?"},label:{value:"",type:"string"},loadingIndicatorPlaceholder:{value:"Loading...",type:"string"},loadingIndicatorPosition:{value:"center",allowedValues:["bottom","center","top"],type:"string"},messages:{extend:!0,value:{en:{invalidNode:'{{elementType}}: Invalid parameter "{{node}}" when calling {{method}}.'}},type:"object"},name:{value:"",type:"string"},opened:{value:!1,type:"boolean"},placeholder:{value:"",
type:"string"},renderMode:{allowedValues:["outlined","filled","underlined"],value:"outlined",type:"string"},resizeMode:{value:"none",allowedValues:["none","horizontal","vertical","both"],type:"string"},resizeIndicator:{value:!1,type:"boolean"},selectionDisplayMode:{value:"plain",allowedValues:["plain","placeholder","tokens"],type:"string"},selectionMode:{value:"one",allowedValues:["none","oneOrManyExtended","zeroOrMany","oneOrMany","zeroOrOne","one","checkBox","radioButton"],type:"string"},selectedIndexes:{value:[],type:"array"},selectedValues:{value:[],type:"array"},sorted:{value:!1,type:"boolean"},tokenTemplate:{value:null,type:"any"},type:{value:"list",type:"string",defaultReflectToAttribute:!0,readonly:!0},valueMember:{value:"",type:"string"},virtualized:{value:!1,type:"boolean"},verticalScrollBarVisibility:{type:"string",value:"auto",allowedValues:["auto","disabled","hidden","visible"]}}}},{key:"listeners",get:function(){return{"actionButton.down":"_buttonsDownHandler","actionButton.mouseenter":"_buttonsMouseEventsHandler","actionButton.mouseleave":"_buttonsMouseEventsHandler","actionButton.focus":"_buttonsFocusHandler","actionButton.blur":"_buttonsFocusHandler","document.selectstart":"_selectStartHandler","document.dragstart":"_dragStartHandler","document.down":"_documentDownHandler","document.up":"_documentUpHandler","document.move":"_documentMoveHandler","dropDownButton.down":"_buttonsDownHandler","dropDownButton.mouseenter":"_buttonsMouseEventsHandler","dropDownButton.mouseleave":"_buttonsMouseEventsHandler",keydown:"_keyDownHandler",keyup:"_keyUpHandler",focus:"_focusEventHandler",blur:"_blurEventHandler","dropDownButton.focus":"_buttonsFocusHandler","dropDownButton.blur":"_buttonsFocusHandler","dropDownContainer.transitionend":"_dropDownTransitionendHandler","listBox.change":"_listBoxChangeHandler","listBox.itemClick":"_listBoxItemClickHandler","listBox.keydown":"_listBoxKeyDownHandler","listBox.bindingComplete":"_bindingCompleteHandler",mouseenter:"_mouseEnterHandler",mouseleave:"_mouseLeaveHandler",resize:"_resizeHandler","resizeBar.move":"_resizeBarMoveHandler",styleChanged:"_styleChangedHandler"}}},{key:"styleUrls",get:function(){return["jqx.dropdownlist.css","jqx.dropdown.css"]}},{key:"requires",get:function(){return{"JQX.ListBox":"jqxlistbox.js"}}}]),t}(JQX.ContentElement));
//# sourceMappingURL=jqxdropdownlist.js.map

"use strict";JQX("jqx-drop-down-button",function(e){function t(){return babelHelpers.classCallCheck(this,t),babelHelpers.possibleConstructorReturn(this,(t.__proto__||Object.getPrototypeOf(t)).apply(this,arguments))}return babelHelpers.inherits(t,e),babelHelpers.createClass(t,[{key:"template",value:function(){return'<div id="container">\n                    <span class="jqx-label" id="label">[[label]]</span>\n                    <div id="content" class="jqx-content">\n                        <div id="buttonsContainer" class="jqx-buttons-container">\n                            <span id="actionButton" class="jqx-input jqx-action-button">[[placeholder]]</span>\n                            <span id="dropDownButton" class="jqx-drop-down-button">\n                                <span id="arrow"></span>\n                            </span>\n                        </div>\n                        <div id="dropDownContainer" class="jqx-drop-down jqx-drop-down-container jqx-visibility-hidden">\n                            <jqx-scroll-viewer id="scrollViewer"                            \n                                right-to-left="[[right-to-left]]"\n                                horizontal-scroll-bar-visibility="[[horizontalScrollBarVisibility]]"\n                                vertical-scroll-bar-visibility="[[verticalScrollBarVisibility]]">\n                                <content></content>\n                            </jqx-scroll-viewer>\n                            <div id="resizeBar" class="jqx-drop-down-resize-bar">\n                                <div></div>\n                            </div>\n                         </div>\n                    </div>\n                    <span class="jqx-hint" id="hint">[[hint]]</span>\n                </div>'}},{key:"attached",value:function(){var e=this;babelHelpers.get(t.prototype.__proto__||Object.getPrototypeOf(t.prototype),"attached",this).call(this),e.isCompleted&&e.$.dropDownContainer&&(e._positionDetection.dropDownAttached("_setDropDownSize"),e._positionDetection.checkBrowserBounds())}},{key:"detached",value:function(){var e=this;babelHelpers.get(t.prototype.__proto__||Object.getPrototypeOf(t.prototype),"detached",this).call(this),e.$.dropDownContainer&&(e.close(),e._positionDetection.dropDownDetached())}},{key:"propertyChangedHandler",value:function(e,t,o){var n=this;switch(e){case"disabled":case"unfocusable":n._setFocusable();break;case"dropDownAppendTo":n._positionDetection.dropDownAppendToChangedHandler();break;case"dropDownHeight":case"dropDownMaxHeight":case"dropDownMaxWidth":case"dropDownMinHeight":case"dropDownMinWidth":case"dropDownWidth":n._setDropDownSize();break;case"dropDownOpenMode":n._setFocusable(),n.close();break;case"dropDownOverlay":o||n._positionDetection.removeOverlay();break;case"dropDownPlaceholder":n.$.dropDownContainer.hasAttribute("empty")&&(n.$.scrollViewer.$.scrollViewerContentContainer.innerHTML=o,n.opened&&n.$.scrollViewer.refresh());break;case"dropDownPosition":n._positionDetection.dropDownPositionChangedHandler();break;case"innerHTML":""===o.trim()?(n.$.dropDownContainer.setAttribute("empty",""),requestAnimationFrame(function(){return n.$.scrollViewer.$.scrollViewerContentContainer.innerHTML=n.dropDownPlaceholder})):(n.$.dropDownContainer.removeAttribute("empty"),n.$.scrollViewer.$.scrollViewerContentContainer.innerHTML=o),n.opened&&n.$.scrollViewer.refresh();break;case"opened":o?n.open():n.close();break;case"placeholder":""!==t&&""!==o||n._setFocusable();break;case"resizeIndicator":o?n.$.dropDownContainer.setAttribute("resize-indicator",""):n.$.dropDownContainer.removeAttribute("resize-indicator");break;case"resizeMode":n.$.dropDownContainer.setAttribute("resize-mode",n.resizeMode),n.opened&&n.$.scrollViewer.refresh()}}},{key:"appendChild",value:function(e){var t=this;if(!t.isCompleted||e instanceof HTMLElement&&e.classList.contains("jqx-resize-trigger-container")){var o=Array.prototype.slice.call(arguments,2);return HTMLElement.prototype.appendChild.apply(t,o.concat(Array.prototype.slice.call(arguments)))}if(!e)return void t.error(t.localize("invalidNode",{method:"removeChild",node:"node"}));t.$.scrollViewer.appendChild(e)}},{key:"removeChild",value:function(e){var t=this;if(!t.isCompleted||e instanceof HTMLElement&&e.classList.contains("jqx-resize-trigger-container")){var o=Array.prototype.slice.call(arguments,2);return HTMLElement.prototype.removeChild.apply(t,o.concat(Array.prototype.slice.call(arguments)))}if(!e)return void t.error(t.localize("invalidNode",{method:"removeChild",node:"node"}));t.$.dropDownContainer.contains(e)&&t.$.scrollViewer.removeChild(e)}},{key:"removeAll",value:function(){var e=this;e.isCompleted&&e.$.scrollViewer.removeAll()}},{key:"_open",value:function(){var e=this;if(!e.disabled&&e.offsetHeight&&e.$dropDownContainer.hasClass("jqx-visibility-hidden")){if(e.$dropDownContainer.hasClass("not-in-view")&&e.$dropDownContainer.removeClass("not-in-view"),e.$.dropDownContainer.style.transition=null,e.dropDownAppendTo&&e.dropDownAppendTo.length>0){var t=e.getBoundingClientRect();if(e.$.container.contains(e.$.dropDownContainer)){var o=0,n=setInterval(function(){var t=e.getBoundingClientRect();o++,t.top===e._positionTop&&o<10||(e.open(),clearInterval(n),e._positionTop=t.top)},100);return}t.top!==e._positionTop&&(e._positionTop=t.top)}e.$.fireEvent("opening").defaultPrevented||(e.opened=!0,e._positionDetection.placeOverlay(),e._positionDetection.checkBrowserBounds("vertically"),e._positionDetection.positionDropDown(),e._positionDetection.checkBrowserBounds("horizontally"),e.$dropDownContainer.removeClass("jqx-visibility-hidden"),e.$.fireEvent("open"),e.$.dropDownButton&&("dropDownButton"===e.dropDownOpenMode?e.$.dropDownButton.setAttribute("selected",""):e.$.dropDownButton.removeAttribute("selected")),e.$.input&&e.$.input.focus())}}},{key:"open",value:function(){for(var e=this,t=document.querySelectorAll("jqx-drop-down-button, jqx-color-picker"),o=0;o<t.length;o++)t[o]!==e&&t[o].opened&&t[o].close();e._open(),e.$.scrollViewer.refresh()}},{key:"scrollTo",value:function(e,t){var o=this;o.isCompleted&&o.$.scrollViewer.scrollTo(e,t)}},{key:"ready",value:function(){babelHelpers.get(t.prototype.__proto__||Object.getPrototypeOf(t.prototype),"ready",this).call(this);var e=this;e._edgeMacFF=JQX.Utilities.Core.Browser.Edge||JQX.Utilities.Core.Browser.Firefox&&-1!==navigator.platform.toLowerCase().indexOf("mac"),e._positionDetection=new JQX.Utilities.PositionDetection(e,e.$.dropDownContainer,e.$.container,"close"),e._positionDetection.getDropDownParent(!0),e._positionDetection.setDropDownPosition(),e._calculateDropDownSize(),e.$.dropDownContainer.setAttribute("resize-mode",e.resizeMode),e.resizeIndicator&&e.$.dropDownContainer.setAttribute("resize-indicator",""),e._positionDetection.handleAutoPositioning(),e._createElement(),e.opened?e.open():e.hasAnimation&&e._edgeMacFF&&e.$dropDownContainer.addClass("not-in-view"),e._positionTop=e.getBoundingClientRect().top}},{key:"_setDropDownSize",value:function(){var e=this;e._dropDownSize||e._calculateDropDownSize(),["dropDownMinWidth","dropDownMinHeight","dropDownMaxWidth","dropDownMaxHeight"].forEach(function(t){e.$.dropDownContainer.style[t.replace("dropDown","").replace(/^./,"m")]=e[t]?e[t]+(e[t].toString().endsWith("%")?"%":"px"):null}),e.dropDownWidth?"auto"!==e.dropDownWidth?e.$.dropDownContainer.style.width=("initial"===e.dropDownWidth?e.offsetWidth:parseFloat(e.dropDownWidth))+"px":e.$.dropDownContainer.style.width="auto":e.$.dropDownContainer.style.width="auto"===e._dropDownSize.width?"auto":(parseFloat(e._dropDownSize.width)||0)+"px",e.dropDownHeight&&"auto"!==e.dropDownHeight?e.$.dropDownContainer.style.height=parseFloat(e.dropDownHeight)+((e.dropDownHeight+"").indexOf("%")>-1?"%":"px"):e.$.dropDownContainer.style.height=e._dropDownSize.height}},{key:"_setFocusable",value:function(){var e=this;if(e.disabled||e.unfocusable)return e.removeAttribute("tabindex"),e.$.actionButton.removeAttribute("tabindex"),void e.$.dropDownButton.removeAttribute("tabindex");var t=e.tabIndex>0?e.tabIndex:0;"dropDownButton"===e.dropDownOpenMode?(e.removeAttribute("tabindex"),""===e.placeholder?e.$.actionButton.removeAttribute("tabindex"):e.$.actionButton.setAttribute("tabindex",t),e.$.dropDownButton.setAttribute("tabindex",t)):(e.$.actionButton.removeAttribute("tabindex"),e.$.dropDownButton.removeAttribute("tabindex"),e.tabIndex=t)}},{key:"_calculateDropDownSize",value:function(){var e=this;e._dropDownSize={};var t=window.getComputedStyle(e.$.dropDownContainer),o=parseFloat(t.getPropertyValue("border-top-width").trim()),n=parseFloat(t.getPropertyValue("border-bottom-width").trim()),r=parseFloat(t.getPropertyValue("margin-top").trim()),i=parseFloat(t.getPropertyValue("margin-bottom").trim()),a=parseFloat(t.getPropertyValue("padding-top").trim()),l=parseFloat(t.getPropertyValue("padding-bottom").trim());JQX.Utilities.Core.CSSVariablesSupport()&&(e._dropDownSize.width=t.getPropertyValue("--jqx-drop-down-list-drop-down-width").trim(),e._dropDownSize.height=t.getPropertyValue("--jqx-drop-down-list-drop-down-height").trim()),(!e._dropDownSize.width||e._dropDownSize.width.indexOf("initial")>-1)&&(e._dropDownSize.width=e.offsetWidth),e._dropDownSize.height||(e._dropDownSize.height="auto"),e._dropDownSize.minHeight=parseFloat(t.getPropertyValue("min-height").trim()),e._dropDownSize.maxHeight=parseFloat(t.getPropertyValue("max-height").trim()),e._dropDownSize.borderWidth=(isNaN(o)?0:o)+(isNaN(n)?0:n),e._dropDownSize.paddingWidth=(isNaN(a)?0:a)+(isNaN(l)?0:l),e._dropDownSize.marginWidth=(isNaN(r)?0:r)+(isNaN(i)?0:i)}},{key:"_createElement",value:function(){var e=this;""===e.innerHTML.trim()&&(e.$.dropDownContainer.setAttribute("empty",""),e.$.scrollViewer.$.scrollViewerContentContainer.innerHTML=e.dropDownPlaceholder),e._setDropDownSize(),e._setFocusable(),e.$.arrow.noRipple=!0}},{key:"_dragStartHandler",value:function(e){var t=this;t._resizeDetails&&t._resizeDetails.started&&e.preventDefault()}},{key:"_dropDownTransitionendHandler",value:function(){var e=this;e._edgeMacFF&&!e.opened&&e.hasAnimation&&(e.$.dropDownContainer.style.top=e.$.dropDownContainer.style.left="",e.$dropDownContainer.addClass("not-in-view"))}},{key:"_blurEventHandler",value:function(){var e=this;e.$.dropDownButton&&(e.removeAttribute("focus"),e.$.dropDownButton.removeAttribute("focus")),e.$.actionButton&&(e.removeAttribute("focus"),e.$.actionButton.removeAttribute("focus"))}},{key:"_focusEventHandler",value:function(){var e=this;e.$.dropDownButton&&(e.setAttribute("focus",""),e.$.dropDownButton.setAttribute("focus","")),e.$.actionButton&&(e.setAttribute("focus",""),e.$.actionButton.setAttribute("focus","")),e.removeAttribute("drop-down-button-focus"),e.removeAttribute("action-button-focus")}},{key:"_buttonsFocusHandler",value:function(e){var t=this;e.target===t.$.dropDownButton?"focus"===e.type?t.setAttribute("drop-down-button-focus",""):t.removeAttribute("drop-down-button-focus"):"focus"===e.type?t.setAttribute("action-button-focus",""):t.removeAttribute("action-button-focus")}},{key:"_getUpEventTarget",value:function(e){for(var t=this,o=e;o;){if(o===t.$.dropDownContainer){o="dropDownContainer";break}o=o.parentElement}if(t.enableShadowDOM&&null!==o)for(o=e.getRootNode().host;o;){if(o===t.$.dropDownContainer){o="dropDownContainer";break}o=o.parentElement}return o}},{key:"close",value:function(){var e=this;if(!e.$dropDownContainer.hasClass("jqx-visibility-hidden")){e.$.fireEvent("closing").defaultPrevented||(e.$dropDownContainer.addClass("jqx-visibility-hidden"),e.$.fireEvent("close"),e.$.dropDownButton&&e.$.dropDownButton.removeAttribute("selected"),e.opened=!1,e._preventDropDownClose=!1,e._positionDetection.removeOverlay(!0),e._edgeMacFF&&!e.hasAnimation&&(e.$.dropDownContainer.style.top=e.$.dropDownContainer.style.left="",e.$dropDownContainer.addClass("not-in-view")))}}},{key:"_documentUpHandler",value:function(e){var t=this,o=t.hasAttribute("resizing");if(t._resizeDetails&&t._resizeDetails.started)return t._resizeDetails.started=t._resizeDetails.resizeEventFired=!1,t.removeAttribute("resizing"),t._preventDropDownClose=!1,t.focus(),void t.$.fireEvent("resizeEnd",{position:{left:e.pageX,top:e.pageY}});if(t.disabled||t._isDropDownClicked||t.readonly)return void delete t._isDropDownClicked;if(t._overlayDown)return t.close(),void delete t._overlayDown;var n=e.originalEvent.target;if(t.enableShadowDOM&&(n=e.originalEvent.composedPath()[0]),t._preventsSelectStart=!1,void 0!==n&&n!==t.$.resizeBar){var r=n.closest(".jqx-action-button");if(t._buttonClicked&&("dropDownButton"===t.dropDownOpenMode&&r&&t._buttonClicked===t.$.actionButton?t.$.fireEvent("actionButtonClick"):n.closest(".jqx-drop-down-button")!==t._buttonClicked&&r!==t._buttonClicked||t.$.fireEvent("dropDownButtonClick")),t._buttonClicked=void 0,!t.editable&&r===t.$.actionButton||n.closest(".jqx-drop-down-button")===t.$.dropDownButton)return"dropDownButton"===t.dropDownOpenMode&&r===t.$.actionButton?void t.close():void(t.$dropDownContainer.hasClass("jqx-visibility-hidden")&&"none"!==t.dropDownOpenMode?t.open():t.close());n=t._getUpEventTarget(n),void 0!==n&&(("dropDownContainer"!==n&&"item"!==n||"item"===n&&"checkBox"!==t.selectionMode&&t.selectionMode.indexOf("Many")<0)&&t.close(),o&&t.$.scrollViewer&&t.$.scrollViewer.refresh())}}},{key:"_keyDownHandler",value:function(e){var t=this,o=document.activeElement;if(!(t.disabled||t.readonly||o!==t&&o!==t.$.dropDownButton&&o!==t.$.actionButton))switch(e.key){case"Enter":case" ":e.preventDefault(),e.target!==t.$.actionButton&&(t.opened&&"Enter"===e.key?t.close():t.opened||t.readonly||"none"===t.dropDownOpenMode||t.open());break;case"End":t.$.scrollViewer.scrollTop=t.$.scrollViewer.scrollHeight;break;case"Home":t.$.scrollViewer.scrollTop=0;break;case"PageUp":case"PageDown":t.$.scrollViewer.scrollTop+=(e.key.indexOf("Down")>-1?1:-1)*t.$.dropDownContainer.offsetHeight;break;case"ArrowUp":case"ArrowDown":if(e.altKey)return void(t.disabled||t.readonly||"none"===t.dropDownOpenMode||(t.$dropDownContainer.hasClass("jqx-visibility-hidden")?t.open():t.close()));e.preventDefault(),t.$.scrollViewer.scrollTop+=10*(e.key.indexOf("Down")>-1?1:-1);break;case"Escape":e.preventDefault(),t.close()}}},{key:"_propertyValidator",value:function(e,t){return"number"!=typeof t&&"string"!=typeof t?e:t}},{key:"_mouseEnterHandler",value:function(){var e=this;e._isElementHovered=!0,"auto"!==e.dropDownOpenMode||e.disabled||e.readonly||e.open()}},{key:"_mouseLeaveHandler",value:function(){var e=this;e.removeAttribute("hover"),e._isElementHovered=!1,"auto"!==e.dropDownOpenMode||e.disabled||e.readonly||e._autoClose()}},{key:"_autoClose",value:function(){var e=this;e._autoCloseTimeout=setTimeout(function(){e._isElementHovered||e.close(),clearTimeout(e._autoCloseTimeout)}.bind(e),e.autoCloseDelay)}},{key:"_documentMoveHandler",value:function(e){function t(){if(d=e.pageY-n._resizeDetails.y,"bottom"===s)n._resizeDetails.height=Math.min(i.clientHeight-a.top-6,Math.max(0,n._resizeDetails.height+d)),n._resizeDetails.y=Math.max(a.top+i.scrollTop-n._resizeDetails.offsetY,Math.min(i.clientHeight+i.scrollTop-1.5*n._resizeDetails.offsetY,e.pageY));else{if(n._resizeDetails.height=Math.min(n._dropDownSize.maxHeight,Math.max(0,Math.min(l.top,n._resizeDetails.height-d))),d=Math.max(0,a.top+(a.height-Math.max(n._dropDownSize.minHeight,n._resizeDetails.height))),n.dropDownAppendTo&&n.dropDownAppendTo.length>0){var t=Math.abs(parseFloat(getComputedStyle(n.$.dropDownContainer).getPropertyValue("margin-bottom")))||0;n.$.dropDownContainer.style.top=n.dropDownAppendTo&&n.dropDownAppendTo.length>0?t+d+"px":""}var o=l.top+i.scrollTop+n._resizeDetails.offsetYtop;n._resizeDetails.y=Math.max(n._resizeDetails.offsetYtop,Math.min(o,Math.max(o-n._dropDownSize.maxHeight,e.pageY)))}n.$.dropDownContainer.style.height=n._resizeDetails.height+"px"}function o(){d=e.pageX-n._resizeDetails.x,n._resizeDetails.width=Math.min(i.clientWidth-a.left-6,Math.max(0,n._resizeDetails.width+d)),n.$.dropDownContainer.style.width=n._resizeDetails.width+"px",n._resizeDetails.x=Math.max(a.left+i.scrollLeft-n._resizeDetails.offsetXR,Math.min(i.clientWidth+i.scrollLeft-1.5*n._resizeDetails.offsetXR,e.pageX))}var n=this,r=n.enableShadowDOM?e.originalEvent.composedPath()[0]:e.originalEvent.target;if("auto"===n.dropDownOpenMode&&null!==n.dropDownAppendTo&&(n.contains(r)||n.$.dropDownContainer.contains(r)?n._isElementHovered=!0:(n._isElementHovered=!1,n._autoClose())),n._resizeDetails&&(!n._resizeDetails||n._resizeDetails.started)){n.setAttribute("resizing",""),n._resizeDetails.resizeEventFired||(n.$.fireEvent("resizeStart",{position:{left:e.pageX,top:e.pageY}}),n._resizeDetails.resizeEventFired=!0);var i=document.documentElement,a=n.$.dropDownContainer.getBoundingClientRect(),l=n.getBoundingClientRect(),s=n.$.dropDownContainer.hasAttribute("top")?"top":"bottom",d=void 0;switch(n.resizeMode){case"vertical":t();break;case"horizontal":o();break;case"both":o(),t()}}}},{key:"_documentDownHandler",value:function(e){var t=this;if(!t.disabled&&!t.readonly){var o=e.originalEvent.target;if(o===t._overlay&&(t._overlayDown=!0),t.enableShadowDOM){o=e.originalEvent.composedPath()[0];for(var n=o.getRootNode().host;n;)n.closest(".jqx-drop-down-container")===t.$.dropDownContainer&&(t._isDropDownClicked=!0),n=n.getRootNode().host}else t._isDropDownClicked=o.closest(".jqx-drop-down-container")===t.$.dropDownContainer;if(t._buttonClicked=o.closest(".jqx-action-button")||o.closest(".jqx-drop-down-button"),t._isDropDownClicked&&(t._preventDropDownClose=!0),o===t.$.resizeBar&&"none"!==t.resizeMode){t._resizeDetails||(t._resizeDetails={});var r=t.$.dropDownContainer.getBoundingClientRect();t._resizeDetails.started=!0,t._resizeDetails.x=e.pageX,t._resizeDetails.y=e.pageY,t._resizeDetails.width=t.$.dropDownContainer.offsetWidth,t._resizeDetails.height=t.$.dropDownContainer.offsetHeight,t._resizeDetails.offsetXL=e.clientX-r.left,t._resizeDetails.offsetXR=r.left+t.$.dropDownContainer.offsetWidth-e.clientX,t._resizeDetails.offsetY=r.top+t.$.dropDownContainer.offsetHeight-e.clientY,t._resizeDetails.offsetYtop=e.clientY-r.top,t._preventDropDownClose=!0}}}},{key:"_resizeHandler",value:function(){var e=this;"none"===e.resizeMode&&(e._calculateDropDownSize(),e._setDropDownSize())}},{key:"_resizeBarMoveHandler",value:function(e){"touchmove"===e.originalEvent.type&&e.originalEvent.preventDefault()}},{key:"_styleChangedHandler",value:function(e){var t=this;if(t.dropDownAppendTo&&t.dropDownAppendTo.length>0)for(var o=e.detail.styleProperties,n=["font-size","font-family","font-style","font-weight"],r=0;r<n.length;r++)o[n[r]]&&(t.$.dropDownContainer.style[n[r]]=o[n[r]].value);"auto"===t._dropDownSize.height&&t._setDropDownSize()}},{key:"_buttonsDownHandler",value:function(e){var t=this;if(!t.disabled){if(t.hasRippleAnimation)if("dropDownButton"===t.dropDownOpenMode)JQX.Utilities.Animation.Ripple.animate(e.target,e.pageX,e.pageY);else if(e.target===t.$.dropDownButton||!t.editable){var o=t.$.buttonsContainer;o.firstElementChild.noRipple=!0,JQX.Utilities.Animation.Ripple.animate(o,e.pageX,e.pageY),o.firstElementChild.noRipple=!1}t._preventsSelectStart=!0,"dropDownButton"===t.dropDownOpenMode&&e.target===t.$.actionButton&&t.$.actionButton.setAttribute("active",""),t.opened&&(t._preventDropDownClose=!0)}}},{key:"_buttonsMouseEventsHandler",value:function(e){var t=this;t.disabled||("mouseenter"===e.type?(t.setAttribute("hover",""),e.target.setAttribute("hover","")):(t.removeAttribute("hover"),e.target.removeAttribute("hover")))}},{key:"_selectStartHandler",value:function(e){this._preventsSelectStart&&e.preventDefault()}}],[{key:"properties",get:function(){return{autoCloseDelay:{value:100,type:"number"},dropDownAppendTo:{value:null,type:"any"},dropDownButtonPosition:{allowedValues:["none","left","right","top","bottom"],value:"right",type:"string"},dropDownHeight:{value:"",type:"any",validator:"_propertyValidator"},dropDownMaxHeight:{value:"",type:"any",validator:"_propertyValidator"},dropDownMaxWidth:{value:"",type:"any",validator:"_propertyValidator"},dropDownMinHeight:{value:"",type:"any",validator:"_propertyValidator"},dropDownMinWidth:{value:"",type:"any",validator:"_propertyValidator"},dropDownOpenMode:{allowedValues:["none","default","dropDownButton","auto"],value:"default",type:"string"},dropDownOverlay:{value:!1,type:"boolean"},dropDownPlaceholder:{value:"No Items",type:"string"},dropDownPosition:{allowedValues:["auto","top","bottom","overlay-top","overlay-center","overlay-bottom","center-bottom","center-top"],value:"auto",type:"string"},dropDownWidth:{value:"",type:"any",validator:"_propertyValidator"},hint:{value:"",type:"string"},horizontalScrollBarVisibility:{type:"string",value:"auto",allowedValues:["auto","disabled","hidden","visible"]},label:{value:"",type:"string"},messages:{extend:!0,value:{en:{invalidNode:'jqx-drop-down-button: Invalid parameter "{{node}}" when calling {{method}}.'}},type:"object"},opened:{value:!1,type:"boolean"},placeholder:{value:"",type:"string"},resizeIndicator:{value:!1,type:"boolean"},resizeMode:{value:"none",allowedValues:["none","horizontal","vertical","both"],type:"string"},verticalScrollBarVisibility:{type:"string",value:"auto",allowedValues:["auto","disabled","hidden","visible"]}}}},{key:"listeners",get:function(){return{"actionButton.down":"_buttonsDownHandler","actionButton.mouseenter":"_buttonsMouseEventsHandler","actionButton.mouseleave":"_buttonsMouseEventsHandler","actionButton.focus":"_buttonsFocusHandler","actionButton.blur":"_buttonsFocusHandler","document.selectstart":"_selectStartHandler","document.dragstart":"_dragStartHandler","document.down":"_documentDownHandler","document.up":"_documentUpHandler","document.move":"_documentMoveHandler","dropDownButton.down":"_buttonsDownHandler","dropDownButton.mouseenter":"_buttonsMouseEventsHandler","dropDownButton.mouseleave":"_buttonsMouseEventsHandler",keydown:"_keyDownHandler",focus:"_focusEventHandler",blur:"_blurEventHandler","dropDownButton.focus":"_buttonsFocusHandler","dropDownButton.blur":"_buttonsFocusHandler","dropDownContainer.transitionend":"_dropDownTransitionendHandler",mouseenter:"_mouseEnterHandler",mouseleave:"_mouseLeaveHandler",resize:"_resizeHandler","resizeBar.move":"_resizeBarMoveHandler",styleChanged:"_styleChangedHandler"}}}]),t}(JQX.ContentElement));
//# sourceMappingURL=jqxdropdownbutton.js.map

"use strict";JQX.Utilities.Assign("Draw",function(){function t(e,i){babelHelpers.classCallCheck(this,t);var r=this;r.host=e,r.renderEngine=i||"",r.refresh();var a=["clear","removeElement","attr","getAttr","line","circle","rect","path","pieslice","pieSlicePath","text","measureText"];for(var n in a)r._addFn(JQX.Utilities.Draw.prototype,a[n])}return babelHelpers.createClass(t,[{key:"_addFn",value:function(t,e){t[e]||(t[e]=function(){return this.renderer[e].apply(this.renderer,arguments)})}},{key:"_initRenderer",value:function(t){return this.createRenderer(this,t)}},{key:"_internalRefresh",value:function(){var t=this;if(t.renderer||(t.host.innerHTML="",t._initRenderer(t.host)),"none"!==window.getComputedStyle(t.host).display){var e=t.renderer;if(e){var i=e.getRect();t._render({x:1,y:1,width:i.width,height:i.height})}}}},{key:"_render",value:function(t){this._plotRect=t}},{key:"refresh",value:function(){this._internalRefresh()}},{key:"getSize",value:function(){var t=this._plotRect;return{width:t.width,height:t.height}}},{key:"toGreyScale",value:function(t){if(-1===t.indexOf("#"))return t;var e=this.cssToRgb(t);e[0]=e[1]=e[2]=Math.round(.3*e[0]+.59*e[1]+.11*e[2]);var i=this.rgbToHex(e[0],e[1],e[2]);return"#"+i[0]+i[1]+i[2]}},{key:"decToHex",value:function(t){return t.toString(16)}},{key:"hexToDec",value:function(t){return parseInt(t,16)}},{key:"rgbToHex",value:function(t,e,i){return[this.decToHex(t),this.decToHex(e),this.decToHex(i)]}},{key:"hexToRgb",value:function(t,e,i){return[this.hexToDec(t),this.hexToDec(e),this.hexToDec(i)]}},{key:"cssToRgb",value:function(t){return t.indexOf("rgb")<=-1?this.hexToRgb(t.substring(1,3),t.substring(3,5),t.substring(5,7)):t.substring(4,t.length-1).split(",")}},{key:"hslToRgb",value:function(t){var e=void 0,i=void 0,r=void 0,a=parseFloat(t[0]),n=parseFloat(t[1]),s=parseFloat(t[2]);if(0===n)e=i=r=s;else{var h=s<.5?s*(1+n):s+n-s*n,o=2*s-h;e=this.hueToRgb(o,h,a+1/3),i=this.hueToRgb(o,h,a),r=this.hueToRgb(o,h,a-1/3)}return[255*e,255*i,255*r]}},{key:"hueToRgb",value:function(t,e,i){return i<0&&(i+=1),i>1&&(i-=1),i<1/6?t+6*(e-t)*i:i<.5?e:i<2/3?t+(e-t)*(2/3-i)*6:t}},{key:"rgbToHsl",value:function(t){var e=parseFloat(t[0])/255,i=parseFloat(t[1])/255,r=parseFloat(t[2])/255,a=Math.max(e,i,r),n=Math.min(e,i,r),s=void 0,h=void 0,o=(a+n)/2;if(a===n)s=h=0;else{var l=a-n;switch(h=o>.5?l/(2-a-n):l/(a+n),a){case e:s=(i-r)/l+(i<r?6:0);break;case i:s=(r-e)/l+2;break;case r:s=(e-i)/l+4}s/=6}return[s,h,o]}},{key:"swap",value:function(t,e){var i=t;t=e,e=i}},{key:"getNum",value:function(t){if(t.constructor!==Array){if(isNaN(t))return 0}else for(var e=0;e<t.length;e++)if(!isNaN(t[e]))return t[e];return 0}},{key:"_ptRotate",value:function(t,e,i,r,a){var n=Math.sqrt(Math.pow(Math.abs(t-i),2)+Math.pow(Math.abs(e-r),2)),s=Math.asin((t-i)/n),h=s+a;return t=i+Math.cos(h)*n,e=r+Math.sin(h)*n,{x:t,y:e}}},{key:"log",value:function(t,e){return Math.log(t)/(e?Math.log(e):1)}},{key:"_mod",value:function(t,e){var i=Math.abs(t>e?e:t),r=1;if(0!==i)for(;i*r<100;)r*=10;return t*=r,e*=r,t%e/r}},{key:"createRenderer",value:function(t,e){var i=t,r=i.renderer=null;return document.createElementNS&&"HTML5"!==i.renderEngine&&(r=new JQX.Utilities.SvgRenderer(this)),null!==r||"HTML5"!==i.renderEngine&&void 0!==i.renderEngine||(r=new JQX.Utilities.HTML5Renderer(this)),r.init(e),i.renderer=r,r}},{key:"getByPriority",value:function(t){for(var e=void 0,i=0;i<t.length;i++){var r=t[i];if(void 0!==r&&null!==r&&""!==r){e=r;break}}return e}},{key:"get",value:function(t,e,i){return void 0!==i?t[e][i]:t[e]}},{key:"min",value:function(t,e){for(var i=NaN,r=0;r<t.length;r++){var a=this.get(t,r,e);(isNaN(i)||a<i)&&(i=a)}return i}},{key:"max",value:function(t,e){for(var i=NaN,r=0;r<t.length;r++){var a=this.get(t,r,e);(isNaN(i)||a>i)&&(i=a)}return i}},{key:"sum",value:function(t,e){for(var i=0,r=0;r<t.length;r++){var a=this.get(t,r,e);isNaN(a)||(i+=a)}return i}},{key:"count",value:function(t,e){for(var i=0,r=0;r<t.length;r++){var a=this.get(t,r,e);isNaN(a)||i++}return i}},{key:"avg",value:function(t,e){return this.sum(t,e)/Math.max(1,this.count(t,e))}},{key:"filter",value:function(t,e){if(!e)return t;for(var i=[],r=0;r<t.length;r++)e(t[r])&&i.push(t[r]);return i}},{key:"scale",value:function(t,e,i,r){if(isNaN(t))return NaN;if((t<Math.min(e.min,e.max)||t>Math.max(e.min,e.max))&&(!r||!0!==r.ignore_range))return NaN;var a=NaN,n=1;if(void 0===e.type||"logarithmic"!==e.type){var s=Math.abs(e.max-e.min);s||(s=1),n=Math.abs(t-Math.min(e.min,e.max))/s}else if("logarithmic"===e.type){var h=e.base;isNaN(h)&&(h=10);var o=Math.min(e.min,e.max);o<=0&&(o=1);var l=Math.max(e.min,e.max);l<=0&&(l=1);var u=this.log(l,h);l=Math.pow(h,u);var c=this.log(o,h);o=Math.pow(h,c);var d=this.log(t,h);n=Math.abs(d-c)/(u-c)}if("logarithmic"===i.type){var v=i.base;isNaN(v)&&(v=10);var f=this.log(i.max,v),p=this.log(i.min,v);i.flip&&(n=1-n);var g=Math.min(p,f)+n*Math.abs(f-p);a=Math.pow(v,g)}else a=Math.min(i.min,i.max)+n*Math.abs(i.max-i.min),i.flip&&(a=Math.max(i.min,i.max)-a+i.min);return a}},{key:"axis",value:function(t,e,i){if(i<=1)return[e,t];(isNaN(i)||i<2)&&(i=2);for(var r=0;Math.round(t)!==t&&Math.round(e)!==e&&r<10;)t*=10,e*=10,r++;for(var a=(e-t)/i;r<10&&Math.round(a)!==a;)t*=10,e*=10,a*=10,r++;for(var n=[1,2,5],s=0,h=void 0;;){var o=s%n.length,l=Math.floor(s/n.length),u=Math.pow(10,l)*n[o];if(o=(s+1)%n.length,l=Math.floor((s+1)/n.length),h=Math.pow(10,l)*n[o],a>=u&&a<h)break;s++}for(var c=h,d=[],v=this.renderer._rnd(t,c,!1),f=r<=0?1:Math.pow(10,r);v<e+c;)d.push(v/f),v+=c;return d}},{key:"_widgetToImage",value:function(t,e,i,r,a){var n=t;if(!n)return!1;void 0!==i&&""!==i||(i="image."+e);var s=n.renderEngine,h=n.animation;if(n.animation="none",n.renderEngine="HTML5",n.renderEngine!==s)try{n.refresh()}catch(t){return n.renderEngine=s,n.refresh(),n.animation=h,!1}var o=n.renderer.getContainer().firstElementChild,l=!0;"function"==typeof r&&(l=r(t,o));var u=!0;return l&&(u=this.exportImage(t,o,e,i,a)),n.renderEngine!==s&&(n.renderEngine=s,n.refresh(),n.animation=h),u}},{key:"_saveAsImage",value:function(t,e){return this._widgetToImage(this,t,e)}},{key:"saveAsPNG",value:function(t){return this._saveAsImage("png",t)}},{key:"saveAsJPEG",value:function(t){return this._saveAsImage("jpeg",t)}},{key:"exportImage",value:function(t,e,i,r,a){if(!e)return!1;var n="pdf"===i.toLowerCase();n&&(i="jpeg"),void 0!==r&&""!==r||(r="image."+i);var s=!0;if("print"!==i){try{if(e)if(n){a=a||"portrait";var h=e.toDataURL("image/"+i),o={content:{image:h,width:Math.min(e.width/1.35,"portrait"===a?515:762)},pageOrientation:a};try{pdfMake.createPdf(o).download(r)}catch(e){t.error(t.localize("missingReference",{files:"pdfmake.min.js"}))}}else{JQX.Utilities.DataExporter||t.error(t.localize("missingReference",{files:"jqxexport.js"}));var l=new JQX.Utilities.DataExporter;e.toBlob(function(t){l.downloadFile(t,i,r)})}}catch(t){s=!1}return s}var u=window.open("","","width=800,height=500"),c=u.document.open(),d='<!DOCTYPE html><html><head><meta charset="utf-8" /><title>jQWidgets Chart</title></head><body><img src="'+e.toDataURL()+'" /></html>';try{c.write(d),c.close(),setTimeout(function(){u.print(),u.close()},100)}catch(t){}}}]),t}()),JQX.Utilities.Assign("Renderer",function(){function t(e){babelHelpers.classCallCheck(this,t);var i=this;i.draw=e,i._gradients={},i._toRadiansCoefficient=2*Math.PI/360}return babelHelpers.createClass(t,[{key:"pieSlicePath",value:function(t,e,i,r,a,n,s){r||(r=1);var h=Math.abs(a-n),o=h>180?1:0;h>=360&&(n=a+359.99);var l=a*this._toRadiansCoefficient,u=n*this._toRadiansCoefficient,c=t,d=t,v=e,f=e,p=!isNaN(i)&&i>0;p&&(s=0);var g=Math.cos(l),y=Math.sin(l),m=Math.cos(u),_=Math.sin(u);if(s+i>0){if(s>0){var x=h/2+a,M=x*this._toRadiansCoefficient;t+=s*Math.cos(M),e-=s*Math.sin(M)}p&&(c=t+i*g,v=e-i*y,d=t+i*m,f=e-i*_)}var k=t+r*g,b=t+r*m,w=e-r*y,N=e-r*_,C="",T=Math.abs(Math.abs(n-a)-360)>.02;return p?(C="M "+d+","+f,C+=" a"+i+","+i,C+=" 0 "+o+",1 "+(c-d)+","+(v-f),C+=T?" L"+k+","+w:" M"+k+","+w,C+=" a"+r+","+r,C+=" 0 "+o+",0 "+(b-k)+","+(N-w),T&&(C+=" Z")):(C="M "+b+","+N,C+=" a"+r+","+r,C+=" 0 "+o+",1 "+(k-b)+","+(w-N),T&&(C+=" L"+t+","+e,C+=" Z")),C}},{key:"measureText",value:function(t,e,i,r){var a=this._getTextParts(t,e,i),n=a.width,s=a.height;!1===r&&(s/=.6);var h={};if(isNaN(e)&&(e=0),0===e)h={width:this._rup(n),height:this._rup(s)};else{var o=e*Math.PI*2/360,l=Math.abs(Math.sin(o)),u=Math.abs(Math.cos(o)),c=Math.abs(n*l+s*u),d=Math.abs(n*u+s*l);h={width:this._rup(d),height:this._rup(c)}}return r&&(h.textPartsInfo=a),h}},{key:"alignTextInRect",value:function(t,e,i,r,a,n,s,h,o,l){var u=o*Math.PI*2/360,c=Math.sin(u),d=Math.cos(u),v=a*c,f=a*d;"center"===s||""===s||"undefined"===s?t+=i/2:"right"===s&&(t+=i),"center"===h||"middle"===h||""===h||"undefined"===h?e+=r/2:"bottom"===h?e+=r-n/2:"top"===h&&(e+=n/2),l=l||"";var p="middle";-1!==l.indexOf("top")?p="top":-1!==l.indexOf("bottom")&&(p="bottom");var g="center";return-1!==l.indexOf("left")?g="left":-1!==l.indexOf("right")&&(g="right"),"center"===g?(t-=f/2,e-=v/2):"right"===g&&(t-=f,e-=v),"top"===p?(t-=n*c,e+=n*d):"middle"===p&&(t-=n*c/2,e+=n*d/2),t=this._rup(t),e=this._rup(e),{x:t,y:e}}},{key:"adjustColor",value:function(t,e){if("string"!=typeof t)return"#000000";if(-1===t.indexOf("#"))return t;var i=this.draw,r=i.cssToRgb(t),a=i.rgbToHsl(r);a[2]=Math.min(1,a[2]*e),a[1]=Math.min(1,a[1]*e*1.1),r=i.hslToRgb(a),t="#";for(var n=0;n<3;n++){var s=Math.round(r[n]);s=i.decToHex(s),1===s.toString().length&&(t+="0"),t+=s}return t.toUpperCase()}},{key:"_rup",value:function(t){var e=Math.round(t);return t>e&&e++,e}},{key:"_ptdist",value:function(t,e,i,r){return Math.sqrt((i-t)*(i-t)+(r-e)*(r-e))}},{key:"_rnd",value:function(t,e,i,r){if(isNaN(t))return t;void 0===r&&(r=!0);var a=t-(!0===r?t%e:this._mod(t,e));return t===a?a:(i?t>a&&(a+=e):a>t&&(a-=e),1===e?Math.round(a):a)}},{key:"_ptrnd",value:function(t){if(!document.createElementNS)return Math.round(t)===t?t:this._rnd(t,1,!1,!0);var e=this._rnd(t,.5,!1,!0);return.5!==Math.abs(e-Math.round(e))?e>t?e-.5:e+.5:e}},{key:"_getContrastColor",value:function(t){if(void 0!==t){var e=this.draw.hexToRgb(t.slice(1,3),t.slice(3,5),t.slice(5,7));return(.299*e[0]+.587*e[1]+.114*e[2])/255>.6?"#000000":"#FFFFFF"}}}]),t}()),JQX.Utilities.Assign("SvgRenderer",function(t){function e(t){babelHelpers.classCallCheck(this,e);var i=babelHelpers.possibleConstructorReturn(this,(e.__proto__||Object.getPrototypeOf(e)).call(this,t)),r=i;return r._svgns="http://www.w3.org/2000/svg",r._openGroups=[],r._clipId=0,i}return babelHelpers.inherits(e,t),babelHelpers.createClass(e,[{key:"init",value:function(t){var e=document.createElement("div");e.className="drawContainer",e.onselectstart=function(){return!1},t.appendChild(e),this.host=t,this.container=e;try{var i=document.createElementNS(this._svgns,"svg");i.setAttribute("version","1.1"),i.setAttribute("width","100%"),i.setAttribute("height","100%"),i.setAttribute("overflow","hidden"),e.appendChild(i),this.canvas=i}catch(t){return!1}return this._id=(new Date).getTime(),this.clear(),!0}},{key:"getType",value:function(){return"SVG"}},{key:"refresh",value:function(){}},{key:"getRect",value:function(){return{x:0,y:0,width:Math.max(this._rup(this.host.offsetWidth)-1,0),height:Math.max(this._rup(this.host.offsetHeight)-1,0)}}},{key:"getContainer",value:function(){return this.container}},{key:"clear",value:function(){for(;this.canvas.childNodes.length>0;)this.removeElement(this.canvas.firstElementChild);this._defaultParent=void 0,this._defs=document.createElementNS(this._svgns,"defs"),this._gradients={},this.canvas.appendChild(this._defs)}},{key:"removeElement",value:function(t){if(void 0!==t)try{for(;t.firstChild;)this.removeElement(t.firstChild);t.parentNode?t.parentNode.removeChild(t):this.canvas.removeChild(t)}catch(t){}}},{key:"beginGroup",value:function(){var t=this._activeParent(),e=document.createElementNS(this._svgns,"g");return t.appendChild(e),this._openGroups.push(e),e}},{key:"endGroup",value:function(){0!==this._openGroups.length&&this._openGroups.pop()}},{key:"_activeParent",value:function(){return 0===this._openGroups.length?this.canvas:this._openGroups[this._openGroups.length-1]}},{key:"createClipRect",value:function(t){var e=document.createElementNS(this._svgns,"clipPath"),i=document.createElementNS(this._svgns,"rect");return this.attr(i,{x:t.x,y:t.y,width:t.width,height:t.height,fill:"none"}),this._clipId=this._clipId||0,e.id="cl"+this._id+"_"+(++this._clipId).toString(),e.appendChild(i),this._defs.appendChild(e),e}},{key:"getWindowHref",value:function(){var t=window.location.href;return t?(t=t.replace(/([\('\)])/g,"\\$1"),t=t.replace(/#.*$/,"")):t}},{key:"setClip",value:function(t,e){var i="url("+this.getWindowHref()+"#"+e.id+")";return this.attr(t,{"clip-path":i})}},{key:"addHandler",value:function(t,e,i){t.addEventListener(e,i)}},{key:"removeHandler",value:function(){}},{key:"on",value:function(t,e,i){this.addHandler(t,e,i)}},{key:"off",value:function(t,e,i){this.removeHandler(t,e,i)}},{key:"shape",value:function(t,e){var i=document.createElementNS(this._svgns,t);if(i){for(var r in e)i.setAttribute(r,e[r]);return this._activeParent().appendChild(i),i}}},{key:"_getTextParts",value:function(t,e,i){var r={width:0,height:0,parts:[]};if(void 0===t)return r;var a=t.toString().split("<br>"),n=this._activeParent(),s=document.createElementNS(this._svgns,"text");this.attr(s,i);for(var h=0;h<a.length;h++){var o=a[h],l=s.ownerDocument.createTextNode(o);s.appendChild(l),n.appendChild(s);var u=void 0;try{u=s.getBBox()}catch(t){}var c=this._rup(u.width),d=this._rup(.6*u.height);s.removeChild(l),r.width=Math.max(r.width,c),r.height+=d+(h>0?4:0),r.parts.push({width:c,height:d,text:o})}return n.removeChild(s),r}},{key:"_measureText",value:function(t,i,r,a){return babelHelpers.get(e.prototype.__proto__||Object.getPrototypeOf(e.prototype),"measureText",this).call(this,t,i,r,a)}},{key:"measureText",value:function(t,e,i){return this._measureText(t,e,i,!1)}},{key:"text",value:function(t,e,i,r,a,n,s,h,o,l,u){var c=this._measureText(t,n,s,!0,this),d=c.textPartsInfo,v=d.parts,f=this._getContrastColor(arguments[11]),p=void 0;if(o||(o="center"),l||(l="center"),(v.length>1||h)&&(p=this.beginGroup()),h){var g=this.createClipRect({x:this._rup(e)-1,y:this._rup(i)-1,width:this._rup(r)+2,height:this._rup(a)+2});this.setClip(p,g)}var y=this._activeParent(),m=0,_=0;m=d.width,_=d.height,(isNaN(r)||r<=0)&&(r=m),(isNaN(a)||a<=0)&&(a=_);var x=r||0,M=a||0,k=0;if(!n||0===n){i+=_,"center"===l||"middle"===l?i+=(M-_)/2:"bottom"===l&&(i+=M-_),r||(r=m),a||(a=_),y=this._activeParent();for(var b=void 0,w=v.length-1;w>=0;w--){b=document.createElementNS(this._svgns,"text"),this.attr(b,s),this.attr(b,{cursor:"default"});var N=b.ownerDocument.createTextNode(v[w].text);b.appendChild(N);var C=e,T=v[w].width,P=v[w].height;"center"===o?C+=(x-T)/2:"right"===o&&(C+=x-T),this.attr(b,{x:this._rup(C),y:this._rup(i+k),width:this._rup(T),height:this._rup(P)}),void 0!==f&&(b.style.fill=f),y.appendChild(b),k-=v[w].height+4}return p?(this.endGroup(),p):b}var R=this.alignTextInRect(e,i,r,a,m,_,o,l,n,u);e=R.x,i=R.y;var S=this.shape("g",{transform:"translate("+e+","+i+")"}),H=this.shape("g",{transform:"rotate("+n+")"});S.appendChild(H),k=0;for(var E=v.length-1;E>=0;E--){var I=document.createElementNS(this._svgns,"text");this.attr(I,s),this.attr(I,{cursor:"default"});var A=I.ownerDocument.createTextNode(v[E].text);I.appendChild(A);var G=0,F=v[E].width,L=v[E].height;"center"===o?G+=(d.width-F)/2:"right"===o&&(G+=d.width-F),this.attr(I,{x:this._rup(G),y:this._rup(k),width:this._rup(F),height:this._rup(L)}),H.appendChild(I),k-=L+4}return y.appendChild(S),p&&this.endGroup(),S}},{key:"line",value:function(t,e,i,r,a){var n=this.shape("line",{x1:t,y1:e,x2:i,y2:r});return this.attr(n,a),n}},{key:"path",value:function(t,e){var i=this.shape("path");return i.setAttribute("d",t),e&&this.attr(i,e),i}},{key:"rect",value:function(t,e,i,r,a){t=this._ptrnd(t),e=this._ptrnd(e),i=Math.max(1,this._rnd(i,1,!1)),r=Math.max(1,this._rnd(r,1,!1));var n=this.shape("rect",{x:t,y:e,width:i,height:r});return a&&this.attr(n,a),n}},{key:"circle",value:function(t,e,i,r){var a=this.shape("circle",{cx:t,cy:e,r:i});return r&&this.attr(a,r),a}},{key:"pieslice",value:function(t,e,i,r,a,n,s,h){var o=this.pieSlicePath(t,e,i,r,a,n,s),l=this.shape("path");return l.setAttribute("d",o),h&&this.attr(l,h),l}},{key:"attr",value:function(t,e){if(t&&e)for(var i in e)"textContent"===i?t.textContent=e[i]:t.setAttribute(i,e[i])}},{key:"removeAttr",value:function(t,e){if(t&&e)for(var i in e)"textContent"===i?t.textContent="":t.removeAttribute(e[i])}},{key:"getAttr",value:function(t,e){return t.getAttribute(e)}},{key:"_toLinearGradient",value:function(t,e,i){var r="grd"+this._id+t.replace("#","")+(e?"v":"h"),a="url("+this.getWindowHref()+"#"+r+")";if(this._gradients[a])return a;var n=document.createElementNS(this._svgns,"linearGradient");this.attr(n,{x1:"0%",y1:"0%",x2:e?"0%":"100%",y2:e?"100%":"0%",id:r});for(var s=0;s<i.length;s++){var h=i[s],o=document.createElementNS(this._svgns,"stop"),l="stop-color:"+this.adjustColor(t,h[1]);this.attr(o,{offset:h[0]+"%",style:l}),n.appendChild(o)}return this._defs.appendChild(n),this._gradients[a]=!0,a}},{key:"_toRadialGradient",value:function(t,e,i){var r="grd"+this._id+t.replace("#","")+"r"+(void 0!==i?i.key:""),a="url("+this.getWindowHref()+"#"+r+")";if(this._gradients[a])return a;var n=document.createElementNS(this._svgns,"radialGradient");void 0===i?this.attr(n,{cx:"50%",cy:"50%",r:"100%",fx:"50%",fy:"50%",id:r}):this.attr(n,{cx:i.x,cy:i.y,r:i.outerRadius,id:r,gradientUnits:"userSpaceOnUse"});for(var s=0;s<e.length;s++){var h=e[s],o=document.createElementNS(this._svgns,"stop"),l="stop-color:"+this.adjustColor(t,h[1]);this.attr(o,{offset:h[0]+"%",style:l}),n.appendChild(o)}return this._defs.appendChild(n),this._gradients[a]=!0,a}}]),e}(JQX.Utilities.Renderer)),JQX.Utilities.Assign("HTML5Renderer",function(t){function e(t){babelHelpers.classCallCheck(this,e);var i=babelHelpers.possibleConstructorReturn(this,(e.__proto__||Object.getPrototypeOf(e)).call(this,t)),r=i;return r._renderers=new JQX.Utilities.HTML5RenderHelpers(r),i}return babelHelpers.inherits(e,t),babelHelpers.createClass(e,[{key:"init",value:function(t){try{this.host=t;var e=document.createElement("div"),i=document.createElement("canvas");e.className="chartContainer",e.style.position="relative",e.onselectstart=function(){return!1},i.id="__jqxCanvasWrap",i.style.width="100%",i.style.height="100%",e.appendChild(i),t.appendChild(e),this.canvas=i,i.width=t.offsetWidth,i.height=t.offsetHeight,this.ctx=i.getContext("2d"),this._elements={},this._maxId=0,this._gradientId=0,this._gradients={},this._currentPoint={x:0,y:0},this._lastCmd="",this._pos=0}catch(t){return!1}return!0}},{key:"getType",value:function(){return"HTML5"}},{key:"getContainer",value:function(){return this.host.getElementsByClassName("chartContainer")[0]}},{key:"getRect",value:function(){return{x:0,y:0,width:this.canvas.width-1,height:this.canvas.height-1}}},{key:"beginGroup",value:function(){}},{key:"endGroup",value:function(){}},{key:"setClip",value:function(){}},{key:"createClipRect",value:function(){}},{key:"addHandler",value:function(){}},{key:"removeHandler",value:function(){}},{key:"on",value:function(t,e,i){this.addHandler(t,e,i)}},{key:"off",value:function(t,e,i){this.removeHandler(t,e,i)}},{key:"clear",value:function(){this._elements={},this._maxId=0,this._renderers._gradients={},this._gradientId=0}},{key:"removeElement",value:function(t){void 0!==t&&this._elements[t.id]&&delete this._elements[t.id]}},{key:"shape",value:function(t,e){var i={type:t,id:this._maxId++};for(var r in e)i[r]=e[r];return this._elements[i.id]=i,i}},{key:"attr",value:function(t,e){for(var i in e)t[i]=e[i]}},{key:"removeAttr",value:function(t,e){for(var i in e)delete t[e[i]]}},{key:"rect",value:function(t,e,i,r,a){if(isNaN(t))throw'Invalid value for "x"';if(isNaN(e))throw'Invalid value for "y"';if(isNaN(i))throw'Invalid value for "width"';if(isNaN(r))throw'Invalid value for "height"';var n=this.shape("rect",{x:t,y:e,width:i,height:r});return a&&this.attr(n,a),n}},{key:"path",value:function(t,e){var i=this.shape("path",e);return this.attr(i,{d:t}),i}},{key:"line",value:function(t,e,i,r,a){return this.path("M "+t+","+e+" L "+i+","+r,a)}},{key:"circle",value:function(t,e,i,r){var a=this.shape("circle",{x:t,y:e,r:i});return r&&this.attr(a,r),a}},{key:"pieslice",value:function(t,e,i,r,a,n,s,h){var o=this.path(this.pieSlicePath(t,e,i,r,a,n,s),h);return this.attr(o,{x:t,y:e,innerRadius:i,outerRadius:r,angleFrom:a,angleTo:n}),o}},{key:"_getCSSStyle",value:function(t){var e=document.createElement("div");e.className=t,e.style.position="absolute",e.style.visibility="hidden",this.host.appendChild(e);var i=window.getComputedStyle(e);return i={color:i.color,fontFamily:i.fontFamily,fontSize:i.fontSize,fontWeight:i.fontWeight},this.host.removeChild(e),i}},{key:"_getTextParts",value:function(t,e,i){var r="Arial",a="10pt",n="";if(i&&i.class){var s=this._getCSSStyle(i.class);s.fontSize&&(a=s.fontSize),s.fontFamily&&(r=s.fontFamily),s.fontWeight&&(n=s.fontWeight)}this.ctx.font=n+" "+a+" "+r;for(var h={width:0,height:0,parts:[]},o=t.toString().split("<br>"),l=0;l<o.length;l++){var u=o[l],c=this.ctx.measureText(u).width,d=document.createElement("span");d.className="jqxchart",d.font=this.ctx.font,d.textContent=u,this.host.appendChild(d);var v=.6*d.offsetHeight;this.host.removeChild(d),h.width=Math.max(h.width,this._rup(c)),h.height+=v+(l>0?4:0),h.parts.push({width:c,height:v,text:u})}return h}},{key:"_measureText",value:function(t,i,r,a){return babelHelpers.get(e.prototype.__proto__||Object.getPrototypeOf(e.prototype),"measureText",this).call(this,t,i,r,a)}},{key:"measureText",value:function(t,e,i){return this._measureText(t,e,i,!1)}},{key:"text",value:function(t,e,i,r,a,n,s,h,o,l,u){var c=this.shape("text",{text:t,x:e,y:i,width:r,height:a,angle:n,clip:h,halign:o,valign:l,rotateAround:u});if(s&&this.attr(c,s),c.fontFamily="Arial",c.fontSize="10pt",c.fontWeight="",c.color=this._getContrastColor(arguments[11]),s&&s.class){var d=this._getCSSStyle(s.class);c.fontFamily=d.fontFamily||c.fontFamily,c.fontSize=d.fontSize||c.fontSize,c.fontWeight=d.fontWeight||c.fontWeight,c.color=c.color||d.color}c.color=c.color||"#000000";var v=this._measureText(t,0,s,!0);return this.attr(c,{textPartsInfo:v.textPartsInfo,textWidth:v.width,textHeight:v.height}),(r<=0||isNaN(r))&&this.attr(c,{width:v.width}),(a<=0||isNaN(a))&&this.attr(c,{height:v.height}),c}},{key:"_toLinearGradient",value:function(t,e,i){if(this._renderers._gradients[t])return t;for(var r=[],a=0;a<i.length;a++)r.push({percent:i[a][0]/100,color:this.adjustColor(t,i[a][1])});var n="gr"+this._gradientId++;return this.createGradient(n,e?"vertical":"horizontal",r),n}},{key:"_toRadialGradient",value:function(t,e){if(this._renderers._gradients[t])return t;for(var i=[],r=0;r<e.length;r++)i.push({percent:e[r][0]/100,color:this.adjustColor(t,e[r][1])});var a="gr"+this._gradientId++;return this.createGradient(a,"radial",i),a}},{key:"createGradient",value:function(t,e,i){this._renderers.createGradient(this,t,e,i)}},{key:"refresh",value:function(){this.ctx.clearRect(0,0,this.canvas.width,this.canvas.height);for(var t in this._elements){var e=this._elements[t];this._renderers.setFillStyle(this,e),this._renderers.setStroke(this,e),this._renderers[this._elements[t].type](this.ctx,e)}}}]),e}(JQX.Utilities.Renderer)),JQX.Utilities.Assign("HTML5RenderHelpers",function(){function t(e){babelHelpers.classCallCheck(this,t),this.HTML5Renderer=e,this._cmds="mlcazq"}return babelHelpers.createClass(t,[{key:"ptrnd",value:function(t){if(.5===Math.abs(Math.round(t)-t))return t;var e=Math.round(t);return e<t&&(e-=1),e+.5}},{key:"createGradient",value:function(t,e,i,r){t._gradients[e]={orientation:i,colorStops:r}}},{key:"setStroke",value:function(t,e){var i=t.ctx,r=e["stroke-width"];i.strokeStyle=e.stroke||"transparent",i.lineWidth=0===r?.01:void 0!==r?r:1,void 0!==e["fill-opacity"]?i.globalAlpha=e["fill-opacity"]:void 0!==e.opacity?i.globalAlpha=e.opacity:i.globalAlpha=1,i.setLineDash&&(e["stroke-dasharray"]?i.setLineDash(e["stroke-dasharray"].split(",")):i.setLineDash([]))}},{key:"setFillStyle",value:function(t,e){var i=t.ctx;if(i.fillStyle="transparent",void 0!==e["fill-opacity"]?i.globalAlpha=e["fill-opacity"]:void 0!==e.opacity?i.globalAlpha=e.opacity:i.globalAlpha=1,e.fill&&-1===e.fill.indexOf("#")&&t._gradients[e.fill]){var r="horizontal"!==t._gradients[e.fill].orientation,a="radial"===t._gradients[e.fill].orientation,n=this.ptrnd(e.x),s=this.ptrnd(e.y),h=this.ptrnd(e.x+(r?0:e.width)),o=this.ptrnd(e.y+(r?e.height:0)),l=void 0;if(("circle"===e.type||"path"===e.type||"rect"===e.type)&&a){var u=this.ptrnd(e.x),c=this.ptrnd(e.y),d=e.innerRadius||0,v=e.outerRadius||e.r||0;"rect"===e.type&&(u+=e.width/2,c+=e.height/2),l=i.createRadialGradient(u,c,d,u,c,v)}a||((isNaN(n)||isNaN(h)||isNaN(s)||isNaN(o))&&(n=0,s=0,h=r?0:i.canvas.width,o=r?i.canvas.height:0),l=i.createLinearGradient(n,s,h,o));for(var f=t._gradients[e.fill].colorStops,p=0;p<f.length;p++)l.addColorStop(f[p].percent,f[p].color);i.fillStyle=l}else e.fill&&(i.fillStyle=e.fill)}},{key:"rect",value:function(t,e){0!==e.width&&0!==e.height&&(t.fillRect(this.ptrnd(e.x),this.ptrnd(e.y),e.width,e.height),t.strokeRect(this.ptrnd(e.x),this.ptrnd(e.y),e.width,e.height))}},{key:"circle",value:function(t,e){0!==e.r&&(t.beginPath(),t.arc(this.ptrnd(e.x),this.ptrnd(e.y),e.r,0,2*Math.PI,!1),t.closePath(),t.fill(),t.stroke())}},{key:"_parsePoint",value:function(t){return{x:this._parseNumber(t),y:this._parseNumber(t)}}},{key:"_parseNumber",value:function(t){var e=!1,i=void 0;for(i=this._pos;i<t.length;i++)if(t[i]>="0"&&t[i]<="9"||"."===t[i]||"e"===t[i]||"-"===t[i]&&!e||"-"===t[i]&&i>=1&&"e"===t[i-1])e=!0;else{if(e||" "!==t[i]&&","!==t[i])break;this._pos++}var r=parseFloat(t.substring(this._pos,i));if(!isNaN(r))return this._pos=i,r}},{key:"_isRelativeCmd",value:function(t){return-1!==this._cmds.indexOf(t)}},{key:"_parseCmd",value:function(t){for(var e=this._pos;e<t.length;e++){if(-1!==this._cmds.toLowerCase().indexOf(t[e].toLowerCase()))return this._pos=e+1,this._lastCmd=t[e],this._lastCmd;if(" "!==t[e]){if(t[e]>="0"&&t[e]<="9"){if(this._pos=e,""===this._lastCmd)break;return this._lastCmd}}else this._pos++}}},{key:"_toAbsolutePoint",value:function(t){return{x:this._currentPoint.x+t.x,y:this._currentPoint.y+t.y}}},{key:"path",value:function(t,e){var i=this,r=e.d;this._pos=0,this._lastCmd="";var a=void 0;for(this._currentPoint={x:0,y:0},t.beginPath();this._pos<r.length;){var n=this._parseCmd(r);if(void 0===n)break;if("M"!==n&&"m"!==n)if("L"!==n&&"l"!==n){if("A"===n||"a"===n){var s=function(){var e=i._parseNumber(r),a=i._parseNumber(r),s=i._parseNumber(r)*(Math.PI/180),h=i._parseNumber(r),o=i._parseNumber(r),l=i._parsePoint(r);if(i._isRelativeCmd(n)&&(l=i._toAbsolutePoint(l)),0===e||0===a)return"continue";var u=i._currentPoint,c={x:Math.cos(s)*(u.x-l.x)/2+Math.sin(s)*(u.y-l.y)/2,y:-Math.sin(s)*(u.x-l.x)/2+Math.cos(s)*(u.y-l.y)/2},d=Math.pow(c.x,2)/Math.pow(e,2)+Math.pow(c.y,2)/Math.pow(a,2);d>1&&(e*=Math.sqrt(d),a*=Math.sqrt(d));var v=(h===o?-1:1)*Math.sqrt((Math.pow(e,2)*Math.pow(a,2)-Math.pow(e,2)*Math.pow(c.y,2)-Math.pow(a,2)*Math.pow(c.x,2))/(Math.pow(e,2)*Math.pow(c.y,2)+Math.pow(a,2)*Math.pow(c.x,2)));isNaN(v)&&(v=0);var f={x:v*e*c.y/a,y:v*-a*c.x/e},p={x:(u.x+l.x)/2+Math.cos(s)*f.x-Math.sin(s)*f.y,y:(u.y+l.y)/2+Math.sin(s)*f.x+Math.cos(s)*f.y},g=function(t){return Math.sqrt(Math.pow(t[0],2)+Math.pow(t[1],2))},y=function(t,e){return(t[0]*e[0]+t[1]*e[1])/(g(t)*g(e))},m=function(t,e){return(t[0]*e[1]<t[1]*e[0]?-1:1)*Math.acos(y(t,e))},_=m([1,0],[(c.x-f.x)/e,(c.y-f.y)/a]),x=[(c.x-f.x)/e,(c.y-f.y)/a],M=[(-c.x-f.x)/e,(-c.y-f.y)/a],k=m(x,M);y(x,M)<=-1&&(k=Math.PI),y(x,M)>=1&&(k=0),0===o&&k>0&&(k-=2*Math.PI),1===o&&k<0&&(k+=2*Math.PI);var b=e>a?e:a,w=e>a?1:e/a,N=e>a?a/e:1;return t.translate(p.x,p.y),t.rotate(s),t.scale(w,N),t.arc(0,0,b,_,_+k,1-o),t.scale(1/w,1/N),t.rotate(-s),t.translate(-p.x,-p.y),"continue"}();if("continue"===s)continue}if("Z"!==n&&"z"!==n||void 0===a)if("C"!==n&&"c"!==n)if("Q"!==n&&"q"!==n);else{var h=this._parsePoint(r),o=this._parsePoint(r);t.quadraticCurveTo(h.x,h.y,o.x,o.y),this._currentPoint=o}else{var l=this._parsePoint(r),u=this._parsePoint(r),c=this._parsePoint(r);t.bezierCurveTo(l.x,l.y,u.x,u.y,c.x,c.y),this._currentPoint=c}else t.lineTo(a.x,a.y),this._currentPoint=a}else{var d=this._parsePoint(r);if(void 0===d)break;t.lineTo(d.x,d.y),this._currentPoint=d}else{var v=this._parsePoint(r);if(void 0===v)break;t.moveTo(v.x,v.y),this._currentPoint=v,void 0===a&&(a=v)}}t.fill(),t.stroke(),t.closePath()}},{key:"text",value:function(t,e){var i=this.ptrnd(e.x),r=this.ptrnd(e.y),a=this.ptrnd(e.width),n=this.ptrnd(e.height),s=e.halign,h=e.valign,o=e.angle,l=e.rotateAround,u=e.textPartsInfo,c=u.parts,d=e.clip;void 0===d&&(d=!0),t.save(),s||(s="center"),h||(h="center"),d&&(t.rect(i,r,a,n),t.clip());var v=e.textWidth,f=e.textHeight,p=a||0,g=n||0;if(t.fillStyle=e.color,t.font=e.fontWeight+" "+e.fontSize+" "+e.fontFamily,!o||0===o){r+=f,"center"===h||"middle"===h?r+=(g-f)/2:"bottom"===h&&(r+=g-f),a||(a=v),n||(n=f);for(var y=0,m=c.length-1;m>=0;m--){var _=c[m],x=i,M=c[m].width;"center"===s?x+=(p-M)/2:"right"===s&&(x+=p-M),t.fillText(_.text,x,r+y),y-=_.height+(m>0?4:0)}return void t.restore()}var k=this.HTML5Renderer.alignTextInRect(i,r,a,n,v,f,s,h,o,l);i=k.x,r=k.y;var b=o*Math.PI*2/360;t.translate(i,r),t.rotate(b);for(var w=0,N=u.width,C=c.length-1;C>=0;C--){var T=0;"center"===s?T+=(N-c[C].width)/2:"right"===s&&(T+=N-c[C].width),t.fillText(c[C].text,T,w),w-=c[C].height+4}t.restore()}}]),t}()),JQX.Utilities.Assign("Plot",function(){function t(e){babelHelpers.classCallCheck(this,t),this.renderer=e}return babelHelpers.createClass(t,[{key:"get",value:function(t,e,i){return void 0!==i?t[e][i]:t[e]}},{key:"min",value:function(t,e){for(var i=NaN,r=0;r<t.length;r++){var a=this.get(t,r,e);(isNaN(i)||a<i)&&(i=a)}return i}},{key:"max",value:function(t,e){for(var i=NaN,r=0;r<t.length;r++){var a=this.get(t,r,e);(isNaN(i)||a>i)&&(i=a)}return i}},{key:"sum",value:function(t,e){for(var i=0,r=0;r<t.length;r++){var a=this.get(t,r,e);isNaN(a)||(i+=a)}return i}},{key:"count",value:function(t,e){for(var i=0,r=0;r<t.length;r++){var a=this.get(t,r,e);isNaN(a)||i++}return i}},{key:"avg",value:function(t,e){return this.sum(t,e)/Math.max(1,this.count(t,e))}},{key:"filter",value:function(t,e){if(!e)return t;for(var i=[],r=0;r<t.length;r++)e(t[r])&&i.push(t[r]);return i}},{key:"scale",value:function(t,e,i,r){if(isNaN(t))return NaN;if((t<Math.min(e.min,e.max)||t>Math.max(e.min,e.max))&&(!r||!0!==r.ignore_range))return NaN;var a=NaN,n=1;if(void 0===e.type||"logarithmic"!==e.type){var s=Math.abs(e.max-e.min);s||(s=1),n=Math.abs(t-Math.min(e.min,e.max))/s}else if("logarithmic"===e.type){var h=e.base;isNaN(h)&&(h=10);var o=Math.min(e.min,e.max);o<=0&&(o=1);var l=Math.max(e.min,e.max);l<=0&&(l=1);var u=Math.log(l)/Math.log(h);l=Math.pow(h,u);var c=Math.log(o)/Math.log(h);o=Math.pow(h,c);var d=Math.log(t)/Math.log(h);n=Math.abs(d-c)/(u-c)}if("logarithmic"===i.type){var v=i.base;isNaN(v)&&(v=10);var f=Math.log(i.max)/Math.log(v),p=Math.log(i.min)/Math.log(v);i.flip&&(n=1-n);var g=Math.min(p,f)+n*Math.abs(f-p);a=Math.pow(v,g)}else a=Math.min(i.min,i.max)+n*Math.abs(i.max-i.min),i.flip&&(a=Math.max(i.min,i.max)-a+i.min);return a}},{key:"axis",value:function(t,e,i){if(i<=1)return[e,t];(isNaN(i)||i<2)&&(i=2);for(var r=0;Math.round(t)!==t&&Math.round(e)!==e&&r<10;)t*=10,e*=10,r++;for(var a=(e-t)/i;r<10&&Math.round(a)!==a;)t*=10,e*=10,a*=10,r++;for(var n=[1,2,5],s=0,h=void 0;;){var o=s%n.length,l=Math.floor(s/n.length),u=Math.pow(10,l)*n[o];if(o=(s+1)%n.length,l=Math.floor((s+1)/n.length),h=Math.pow(10,l)*n[o],a>=u&&a<h)break;s++}for(var c=h,d=[],v=this.renderer._rnd(t,c,!1),f=r<=0?1:Math.pow(10,r);v<e+c;)d.push(v/f),v+=c;return d}}]),t}());
//# sourceMappingURL=jqxdraw.js.map

"use strict";JQX("jqx-tooltip",function(e){function t(){return babelHelpers.classCallCheck(this,t),babelHelpers.possibleConstructorReturn(this,(t.__proto__||Object.getPrototypeOf(t)).apply(this,arguments))}return babelHelpers.inherits(t,e),babelHelpers.createClass(t,[{key:"template",value:function(){return'<div id="container">\n                    <div id="content" class="jqx-tooltip-content" inner-h-t-m-l="[[innerHTML]]">\n                        <content></content>\n                    </div>\n                </div>'}},{key:"propertyChangedHandler",value:function(e,n,o){babelHelpers.get(t.prototype.__proto__||Object.getPrototypeOf(t.prototype),"propertyChangedHandler",this).call(this,e,n,o);var l=this,i=void 0;switch(e){case"openMode":l.close(),l._handleEventListeners(n),l._handleResize();break;case"selector":l._oldOwnerElement=l._ownerElement,l._handleSelector(o),l._handleEventListeners();break;case"tooltipTemplate":l._handleTemplate(n);break;case"value":l.tooltipTemplate?l._handleTemplate():l.$.content.innerHTML=l.value;break;case"visible":i=o?"open":"close",l.$.fireEvent(i,{owner:l._ownerElement})}l._applyPosition()}},{key:"ready",value:function(){var e=this;babelHelpers.get(t.prototype.__proto__||Object.getPrototypeOf(t.prototype),"ready",this).call(this),e._isParentPositionStatic="static"===window.getComputedStyle(e.parentElement||document.querySelector("body")).position,e._handleSelector(e.selector),e._applyPosition(),e._handleEventListeners(),e._handleResize(),e.value=e.$.content.innerHTML=e.value?e.value:e.innerHTML,e._handleTemplate()}},{key:"appendChild",value:function(e){var t=this;if(!t.isCompleted){var n=Array.prototype.slice.call(arguments,2);return HTMLElement.prototype.appendChild.apply(t,n.concat(Array.prototype.slice.call(arguments)))}if(!e)return void t.error(t.localize("invalidNode",{elementType:t.nodeName.toLowerCase(),method:"appendChild",node:"node"}));t.$.content.appendChild(e),t._applyPosition()}},{key:"close",value:function(){var e=this;e._isOpening&&clearTimeout(e._isOpening),e.visible&&(e.$.fireEvent("close",{owner:e._ownerElement}),e.visible=!1)}},{key:"insertBefore",value:function(e,t){var n=this;if(!n.isCompleted){var o=Array.prototype.slice.call(arguments,2);return HTMLElement.prototype.insertBefore.apply(n,o.concat(Array.prototype.slice.call(arguments)))}if(!e||!t)return void n.error(n.localize("invalidNode",{elementType:n.nodeName.toLowerCase(),method:"insertBefore",node:"newNode/referenceNode"}));n.$.content.insertBefore(e,t),n._applyPosition()}},{key:"open",value:function(){var e=this;e.disabled||e.readonly||e.visible||(e._isOpening=setTimeout(function(){e._applyPosition(),e.$.fireEvent("open",{owner:e._ownerElement});var t=e.context;e.context=e,e.visible=!0,e.context=t},e.delay))}},{key:"removeChild",value:function(e){var t=this;if(!t.isCompleted){var n=Array.prototype.slice.call(arguments,2);return HTMLElement.prototype.insertBefore.apply(t,n.concat(Array.prototype.slice.call(arguments)))}if(!e)return void t.error(t.localize("invalidNode",{elementType:t.nodeName.toLowerCase(),method:"removeChild",node:"node"}));t.$.content.removeChild(e),t._applyPosition()}},{key:"toggle",value:function(){var e=this;e.visible?e.close():e.open()}},{key:"_applyPosition",value:function(){function e(e){for(var n=[],o=e.parentElement;o&&"BODY"!==o.nodeName;)n.push(o),o=!t.enableShadowDOM||o.parentElement?o.parentElement:o.getRootNode().host;return n}var t=this;if(t._ownerElement&&t.parentElement){t._isParentPositionStatic="static"===window.getComputedStyle(t.parentElement).position;var n=t._ownerElement.getBoundingClientRect(),o=t.parentElement?t.parentElement.getBoundingClientRect():{top:0,left:0},l=void 0,i=void 0;t.parentElement&&"BODY"===t.parentElement.nodeName.toUpperCase()?(l=n.top+window.scrollY+parseInt(t.offset[1]),i=n.left+window.scrollX+parseInt(t.offset[0])):(l=n.top-o.top+parseInt(t.offset[1]),i=n.left-o.left+parseInt(t.offset[0]));var r=function(){for(var n=e(t),o=n.length,l=null,i=t._ownerElement.getBoundingClientRect(),r=0;r<o;r++){if("static"!==window.getComputedStyle(n[r]).getPropertyValue("position")){l=n[r];break}}return{top:i.top,left:i.left,nonStaticParent:l}}();switch(t.position){case"bottom":if(t.arrowDirection="top",null===r.nonStaticParent){t.style.top=r.top+window.scrollY+t._ownerElement.offsetHeight+"px",t.style.left=r.left+window.scrollX-t.offsetWidth/2+t._ownerElement.offsetWidth/2+"px";break}if(t._isParentPositionStatic){t.style.top=t._ownerElement.offsetTop+t._ownerElement.offsetHeight+"px",t.style.left=t._ownerElement.offsetLeft-t.offsetWidth/2+t._ownerElement.offsetWidth/2+"px";break}t.style.top=l+t._ownerElement.offsetHeight+"px",t.style.left=i-t.offsetWidth/2+t._ownerElement.offsetWidth/2+"px";break;case"top":if(t.arrowDirection="bottom",null===r.nonStaticParent){t.style.top=r.top+window.scrollY-t.offsetHeight+"px",t.style.left=r.left+window.scrollX-t.offsetWidth/2+t._ownerElement.offsetWidth/2+"px";break}if(t._isParentPositionStatic){if(t.style.top=t._ownerElement.offsetTop-t.offsetHeight+"px",t.style.left=t._ownerElement.offsetLeft-t.offsetWidth/2+t._ownerElement.offsetWidth/2+"px",t._ownerElement instanceof SVGElement){var s=t._ownerElement.getBoundingClientRect(),a=t._ownerElement.parentNode.getBoundingClientRect();t.style.top=s.top-a.top-t.offsetHeight/2+"px",t.style.left=s.left-t.offsetWidth/2+a.left/2+"px"}break}if(t._ownerElement instanceof SVGElement&&t._ownerElement.parentElement){var p=t._ownerElement.getBoundingClientRect(),f=t._ownerElement.parentNode.getBoundingClientRect();t.style.top=p.top-f.top-t.offsetHeight+"px",t.style.left=p.left-f.left-t.offsetWidth/2+p.width/2+"px";break}t.style.top=l-t.offsetHeight+"px",t.style.left=i-t.offsetWidth/2+t._ownerElement.offsetWidth/2+"px";break;case"left":if(t.arrowDirection="right",null===r.nonStaticParent){t.style.top=r.top+window.scrollY+t._ownerElement.offsetHeight/2-t.$.content.offsetHeight/2+"px",t.style.left=r.left+window.scrollX-t.offsetWidth+"px";break}if(t._isParentPositionStatic){t.style.top=t._ownerElement.offsetTop+t._ownerElement.offsetHeight/2-t.$.content.offsetHeight/2+"px",t.style.left=t._ownerElement.offsetLeft-t.offsetWidth+"px";break}t.style.top=l+t._ownerElement.offsetHeight/2-t.$.content.offsetHeight/2+"px",t.style.left=i-t.offsetWidth+"px";break;case"right":if(t.arrowDirection="left",null===r.nonStaticParent){t.style.top=r.top+window.scrollY+t._ownerElement.offsetHeight/2-t.$.content.offsetHeight/2+"px",t.style.left=r.left+window.scrollX+t._ownerElement.offsetWidth+"px";break}if(t._isParentPositionStatic){t.style.top=t._ownerElement.offsetTop+t._ownerElement.offsetHeight/2-t.$.content.offsetHeight/2+"px",t.style.left=t._ownerElement.offsetLeft+t._ownerElement.offsetWidth+"px";break}t.style.top=l+t._ownerElement.offsetHeight/2-t.$.content.offsetHeight/2+"px",t.style.left=i+t._ownerElement.offsetWidth+"px";break;case"absolute":t.style.top=(parseInt(t.offset[1])||0)+"px",t.style.left=(parseInt(t.offset[0])||0)+"px";break;default:t.arrowDirection="bottom",t.style.top=t.style.left=""}}}},{key:"_eventsHandler",value:function(e){var t=this;if(!t.disabled&&!t.readonly)return"click"===e.type?void(t.visible?this.close():this.open()):void("mouseenter"===e.type||"focus"===e.type?this.open():this.close())}},{key:"_handleEventListeners",value:function(e){var t=this;if(t._oldOwnerElement&&"manual"!==t.openMode&&(t._oldOwnerElement.$.unlisten("mouseenter.tooltip"),t._oldOwnerElement.$.unlisten("mouseleave.tooltip"),t._oldOwnerElement.$.unlisten("focus.tooltip"),t._oldOwnerElement.$.unlisten("blur.tooltip"),t._oldOwnerElement.$.unlisten("click.tooltip"),t._oldOwnerElement=null),t._ownerElement){if(e)switch(e){case"hover":t._ownerElement.$.unlisten("mouseenter.tooltip"),t._ownerElement.$.unlisten("mouseleave.tooltip");break;case"focus":t._ownerElement.$.unlisten("focus.tooltip"),t._ownerElement.$.unlisten("blur.tooltip");break;case"click":t._ownerElement.$.unlisten("click.tooltip")}if("manual"!==t.openMode)switch(t._ownerElement instanceof JQX.BaseElement||(t._ownerElement.$=JQX.Utilities.Extend(t._ownerElement)),t.openMode){case"hover":t._ownerElement.$.listen("mouseenter.tooltip",t._eventsHandler.bind(t)),t._ownerElement.$.listen("mouseleave.tooltip",t._eventsHandler.bind(t));break;case"focus":t._ownerElement.$.listen("focus.tooltip",t._eventsHandler.bind(t)),t._ownerElement.$.listen("blur.tooltip",t._eventsHandler.bind(t));break;case"click":t._ownerElement.$.listen("click.tooltip",t._eventsHandler.bind(t))}}}},{key:"_handleResize",value:function(){function e(){t._applyPosition()}var t=this;"click"===t.openMode?window.addEventListener("resize",e):window.removeEventListener("resize",e)}},{key:"_handleSelector",value:function(e){var t=this;return"string"==typeof e?void(t._ownerElement=e.length>0?document.getElementById(e):void 0):e instanceof HTMLElement||e instanceof SVGElement?void(t._ownerElement=e):null===e?void(t._ownerElement=void 0):void t.error(t.localize("invalidSelector",{elementType:t.nodeName.toLowerCase(),property:"selector"}))}},{key:"_handleTemplate",value:function(e){var t=this,n=t.tooltipTemplate;if(e&&(t.$.content.innerHTML=t.value?t.value:""),null!==n&&n){if("function"==typeof t.tooltipTemplate)return void t.tooltipTemplate(t.$.content,{value:t.value});if(!("content"in document.createElement("template")))return void t.error(t.localize("htmlTemplateNotSuported",{elementType:t.nodeName.toLowerCase()}));if(null===(n=document.getElementById(n))||!("content"in n))return void t.error(t.localize("invalidTemplate",{elementType:t.nodeName.toLowerCase(),property:"template"}));for(var o=n.content,l=o.childNodes.length,i=/{{\w+}}/g,r=void 0,s=[],a=0;a<l;a++)for(r=i.exec(o.childNodes[a].innerHTML);r;)s.push({childNodeIndex:a,bindingString:r[0]}),r=i.exec(o.childNodes[a].innerHTML);for(var p=s.length,f=document.importNode(n.content,!0),d=void 0,c=void 0,m=0;m<p;m++){d=f.childNodes[s[m].childNodeIndex],c=s.length;for(var u=0;u<c;u++)d.innerHTML=d.innerHTML.replace(s[m].bindingString,t.value)}t.$.content.innerHTML="";for(var h=0;h<f.childNodes.length;h++)f.childNodes[h].outerHTML&&(t.$.content.innerHTML+=f.childNodes[h].outerHTML)}}}],[{key:"properties",get:function(){return{arrow:{value:!1,type:"boolean"},arrowDirection:{allowedValues:["bottom","top","left","right"],value:"bottom",type:"string"},delay:{value:0,type:"number"},messages:{extend:!0,value:{en:{invalidSelector:'{{elementType}}: "{{property}}" must be a String, an HTMLElement or null.',htmlTemplateNotSuported:"{{elementType}}: Browser doesn't support HTMLTemplate elements.",invalidTemplate:'{{elementType}}: "{{property}}" property accepts a string that must match the id of an HTMLTemplate element from the DOM.',invalidNode:'{{elementType}}: Invalid parameter "{{node}}" when calling {{method}}.'}},type:"object"},offset:{value:[0,0],type:"array"},openMode:{allowedValues:["click","focus","hover","manual"],value:"hover",type:"string"},position:{allowedValues:["bottom","top","left","right","absolute"],value:"top",type:"string"},selector:{value:null,type:"any?"},tooltipTemplate:{value:null,type:"any"},value:{value:"",type:"string",reflectToAttribute:!1},visible:{value:!1,type:"boolean"}}}},{key:"styleUrls",get:function(){return["jqx.tooltip.css"]}}]),t}(JQX.ContentElement));
//# sourceMappingURL=jqxtooltip.js.map

"use strict";JQX("jqx-color-panel",function(e){function a(){return babelHelpers.classCallCheck(this,a),babelHelpers.possibleConstructorReturn(this,(a.__proto__||Object.getPrototypeOf(a)).apply(this,arguments))}return babelHelpers.inherits(a,e),babelHelpers.createClass(a,[{key:"template",value:function(){return'<div id="container">\n                    <div id="gridModeContainer" class ="grid-mode-container">\n                        <div id="defaultSamplesContainer" class ="default-samples-container"></div>\n                        <div id="gridSamplesContainer" class ="grid-samples-container"></div>\n                        <div id="materialGridSamplesContainer" class ="material-grid-samples-container"></div>\n                        <div id="spectrumGridSamplesContainer" class ="spectrum-grid-samples-container"></div>\n                        <jqx-button id="buttonCustom" class ="button-custom-color primary" disabled="[[disabled]]" theme="[[theme]]" animation="[[animation]]"></jqx-button>\n                        <div id="userSamplesContainer" class ="user-samples-container"></div>\n                        <jqx-tooltip id="tooltip" arrow></jqx-tooltip>\n                    </div>\n                    <div id="paletteModeContainer" class ="palette-mode-container">\n                        <div id="colorPaletteContainer" class ="color-palette-container">\n                            <div id="colorPalette" class ="color-palette">\n                                <div id="colorPaletteThumb" class ="color-palette-thumb"></div>\n                            </div>\n                            <div id="hueScale" class ="hue-scale">\n                                <div id="hueScaleThumb" class ="hue-scale-thumb"></div>\n                            </div>\n                            <div id="colorPaletteRadial" class ="color-palette-radial">\n                                <span class="canvas-radial" id="canvasRadial"></span>\n                                <span class="white-radial-gradient"></span>\n                                <div id="colorPaletteRadialThumb" class ="color-palette-radial-thumb"></div>\n                            </div>\n                            <div id="colorPaletteHexagonal" class ="color-palette-hexagonal"></div>\n                            <div id="brightnessScale" class ="brightness-scale">\n                                <div id="brightnessScaleThumb" class ="brightness-scale-thumb"></div>\n                            </div>\n                            <div id="colorControlsContainer" class ="color-controls-container">\n                                <div id="previewContainer" class ="preview-container gradient-background">\n                                       <span id="previewContainerTop" class ="preview-container-top"></span>\n                                       <span id="previewContainerBottom" class ="preview-container-bottom"></span>\n                                </div>\n                                <label for="rChannelInput" id="rChannelLabel" class ="r-channel"></label><input type="number" min="0" max="255" id="rChannelInput" class ="color-input r-channel" value="255" disabled="[[disabled]]" theme="[[theme]]">\n                                <label for="gChannelInput" id="gChannelLabel" class ="g-channel"></label><input type="number" min="0" max="255" id="gChannelInput" class ="color-input g-channel" value="255" disabled="[[disabled]]" theme="[[theme]]">\n                                <label for="bChannelInput" id="bChannelLabel" class ="b-channel"></label><input type="number" min="0" max="255" id="bChannelInput" class ="color-input b-channel" value="255" disabled="[[disabled]]" theme="[[theme]]">\n                                <label for="hexInput" id="hexLabel" class ="hex"></label><input type="text" id="hexInput" class ="color-input hex" value="FFFFFF" disabled="[[disabled]]" theme="[[theme]]" maxlength="6">\n                            </div>\n                        <span id="hexModeResizeTrigger" class ="color-sample hex-mode-resize-trigger"></span>\n                        </div>\n                        <div id="alphaChannelContainer" class ="alpha-channel-container">\n                            <div id="alphaChannelScale" class ="alpha-channel-scale">\n                                <div id="alphaChannelThumb" class ="alpha-channel-thumb"></div>\n                            </div>\n                            <label for="aChannelInput" id="alphaChannelLabel" class ="a-channel"></label>\n                            <input type="number" step="0.01" id="aChannelInput" class ="color-input a-channel" value="1" min="0" max="1" disabled="[[disabled]]" theme="[[theme]]">\n                        </div>\n                    </div>\n                    <div id="buttonsContainer" class ="buttons-container">\n                        <jqx-button id="buttonOk" class ="button-ok primary" disabled="[[disabled]]" theme="[[theme]]" animation="[[animation]]"></jqx-button>\n                        <jqx-button id="buttonCancel" class ="button-cancel primary outlined" disabled="[[disabled]]" theme="[[theme]]" animation="[[animation]]"></jqx-button>\n                    </div>\n                    <input id="hiddenInput" type="hidden" name="[[name]]">\n                </div>'}},{key:"propertyChangedHandler",value:function(e,t,l){function r(){o._generateGridStructures(),o._applyValue(o.value)}var o=this;switch(e){case"applyValueMode":"instantly"!==l||o.value||(o._HSV={h:0,s:0,v:1},o._selectedItem&&o._selectedItem.classList.contains("selected")&&(o._selectedItem.classList.remove("selected"),o._selectedItem.style.stroke=null)),"palette"!==o.displayMode&&"radial"!==o.displayMode&&"hexagonal"!==o.displayMode||o._handleCancelButtonClick();break;case"paletteColors":o._customPalette=o._mapDataSourceToPalette(),r(o.displayMode);break;case"inverted":var n=o.$.hueScaleThumb.offsetHeight,i=o._validateInRange(n/2,0,o.$.hueScale.offsetHeight-n)/o.$.brightnessScale.offsetHeight;l?(o._HSV.v=o._HSV.s,o._HSV.s=1-i):(o._HSV.s=o._HSV.v,o._HSV.v=1-i),o.value=o._HSVtoRGBA(o._HSV),o.$.colorPaletteRadial.style.setProperty("--jqx-color-panel-brightness",o.$.brightnessScaleThumb.s||0),r(o.displayMode);break;case"palette":r(o.displayMode),o._updatePreviewContainerValues(o.value);break;case"displayMode":case"gridThemeColors":case"gridShadeColors":case"gridStandardColors":if("displayMode"===e){var s=o.value;if(o.$.container.className.indexOf("custom-color-selection")>-1&&o._handleCancelButtonClick(),null!==o.value&&"palette"!==l&&"hexagonal"!==l&&"radial"!==l){o.$.alphaChannelThumb.style.left=0,o.$.alphaChannelThumb.a=o._RGBA.a=1,o.value=o._getValue(o.valueFormat),r(),o.$.fireEvent("change",{oldValue:s,value:o.value});break}if(null===o.value&&("palette"===l||"hexagonal"===l||"radial"===l)){o._RGBA={r:255,g:255,b:255,a:1},o._HSV={h:0,s:0,v:1},o.value=o._getValue(o.valueFormat),r(),o.$.fireEvent("change",{oldValue:s,value:o.value});break}}r(o.displayMode);break;case"locale":case"messages":o._localizeLabels();break;case"paletteCustomColors":o._userPalette=l||[],(o.displayMode.toLowerCase().indexOf("grid")>-1||"default"===o.displayMode)&&o._generatePaletteUserColorGrid(!0);break;case"editAlphaChannel":if(!l&&(o._RGBA.a=1),!o.value)return;var d=o.value;o.value=o._getValue(o.valueFormat),o.value!==d&&o.$.fireEvent("change",{oldValue:d,value:o.value});break;case"value":if(l="string"==typeof l?l.trim():l,!o._isValidColor(l))return void o._reset();o._applyValue(l),o.value=o._getValue(o.valueFormat),"hexagonal"===o.displayMode&&o._generateHoneycomb(o.columnCount,o.inverted?{s:o._HSV.s}:{v:o._HSV.v}),t!==o.value&&o.$.fireEvent("change",{oldValue:t,value:o.value});break;case"columnCount":var u=o.$.container.style;l&&8!==l?u.setProperty("--jqx-color-panel-grid-mode-column-count",l):u.removeProperty("--jqx-color-panel-grid-mode-column-count"),o._generatePaletteUserColorGrid(),o._generateSpectrumGrid(parseInt(l)),"hexagonal"===o.displayMode&&o._generateHoneycomb(l,o._HSV);break;case"valueFormat":if(!o.value)return;var c=o.value;o.value=o._getValue(l),o.$.fireEvent("change",{oldValue:c,value:o.value});break;case"tooltipDisplayMode":"none"===l?(o.$.tooltip.close(),o.$.tooltip.disabled=!0):o.$.tooltip.disabled=!1;break;default:babelHelpers.get(a.prototype.__proto__||Object.getPrototypeOf(a.prototype),"propertyChangedHandler",this).call(this,e,t,l)}}},{key:"ready",value:function(){babelHelpers.get(a.prototype.__proto__||Object.getPrototypeOf(a.prototype),"ready",this).call(this);var e=this;e._initializeBaseVars(),e._localizeLabels(),e._generateGridStructures(),e._generatePaletteUserColorGrid(),e.value||"hexagonal"!==e.displayMode&&"radial"!==e.displayMode&&"palette"!==e.displayMode||(e.value=e._getValue(e.valueFormat)),e._applyValue(e.value),e._hideControlsByPriority()}},{key:"_getColorBrightness",value:function(){var e=this._RGBA;if(e)return Math.min(255,Math.sqrt(e.r*e.r*.241+e.g*e.g*.691+e.b*e.b*.068))}},{key:"_containerClickHandler",value:function(e){var a=this;if(!a.disabled&&!a.readonly&&e.target){if(e.target.classList.contains("color-sample"))return void a._handleSampleClick(e);var t=e.target.closest("jqx-button");return t===a.$.buttonCancel?void a._handleCancelButtonClick():t===a.$.buttonCustom?(a.$container.addClass("custom-color-selection"),a._applyValueInPaletteMode(),a._customColorSelection=!0,void(1===a._RGBA.a&&(a.$.alphaChannelThumb.style.left=0,a.$.alphaChannelThumb.a=a._RGBA.a))):t===a.$.buttonOk?void a._handleOkButtonClick():void(e.target!==a.$.previewContainerTop||"useButtons"!==a.applyValueMode||a.disableUndo||a._applyValue(a.value))}}},{key:"_reset",value:function(){var e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:this.value,a=this;a._RGBA={r:255,g:255,b:255,a:1},a._HSV={h:0,s:0,v:1},a.$.hueScaleThumb.h=0,a.$.colorPaletteThumb.s=0,a.$.colorPaletteThumb.v=1,a.$.colorPaletteRadialThumb.h=0,a.$.colorPaletteRadialThumb.s=0,a.$.brightnessScaleThumb.v=1,a.$.brightnessScaleThumb.s=0,a.$.alphaChannelThumb.a=1,"hexagonal"!==a.displayMode&&"radial"!==a.displayMode&&"palette"!==a.displayMode?(a.value=null,a._selectedItem&&a._selectedItem.classList.contains("selected")&&(a._selectedItem.classList.remove("selected"),a._selectedItem.style.stroke=null)):a.value=a._getValue(a.valueFormat),a._applyValue(a.value),a.$.fireEvent("change",{oldValue:e,value:a.value})}},{key:"_handleColorPaletteDown",value:function(e){var a=this,t=a._getXYcoordinates(e);if(t){var l="palette"===a.displayMode||"grid"===a.displayMode?a.$.colorPaletteThumb:a.$.colorPaletteRadialThumb;if(a._activeComponent=t.container,"palette"===a.displayMode||a.$.container.className.indexOf("custom-color-selection")>-1){if(l.s=a._HSV.s=t.x/t.container.offsetWidth,l.v=a._HSV.v=1-t.y/t.container.offsetHeight,"grid"===a.displayMode)return a._moveThumbHandler(e,!0),void a._applyValueInPaletteMode(e)}else if("radial"===a.displayMode){var r=a.$.colorPaletteRadial.offsetWidth,o=t.x-r/2,n=t.y-r/2;l.h=a._HSV.h=a._calcHueAngle(o,n)<0?360+a._calcHueAngle(o,n):a._calcHueAngle(o,n);var i=a.$.brightnessScaleThumb,s=a.$.brightnessScale,d=a._validateInRange(2*a._calcSatDistance(o,n)/r,0,1),u=a._validateInRange(i.offsetTop-i.offsetHeight/2,0,s.offsetHeight-i.offsetHeight)/s.offsetHeight;a.inverted?(l.v=a._HSV.v=d,l.s=a._HSV.s=1-u):(l.s=a._HSV.s=d,l.v=a._HSV.v=1-u)}a._applyValue(a._HSVtoRGBA(a._HSV),e),a._instantUpdate()}}},{key:"_handleScalesDown",value:function(e){var a=this,t=a._getXYcoordinates(e),l=void 0,r=void 0;t&&(a._activeComponent=t.container,t.container===a.$.hueScale?a._updateHueScale(t):t.container===a.$.brightnessScale?(a._updateBrightnessScale(t),"hexagonal"===a.displayMode&&a._generateHoneycomb(a.columnCount,a._HSV)):(l=t.x-a.$.alphaChannelThumb.offsetWidth/2,r=a.$.alphaChannelScale.offsetWidth-a.$.alphaChannelThumb.offsetWidth,a.$.alphaChannelThumb.style.left=100*a._validateInRange(l,0,r)/a.$.alphaChannelScale.offsetWidth+"%",a.$.alphaChannelThumb.a=a._RGBA.a=(t.container.offsetWidth-t.x)/t.container.offsetWidth,a._applyAlphaValue(a._RGBA.a,"alphaScale")),a._applyValue(a._HSVtoRGBA(a._HSV),e),a._instantUpdate())}},{key:"_updateBrightnessScale",value:function(e){var a=this,t=e.y-a.$.brightnessScaleThumb.offsetHeight/2,l=a.$.brightnessScale.offsetHeight-a.$.brightnessScaleThumb.offsetHeight,r=Math.min(Math.max(parseFloat(t),0),parseFloat(l))/l;a.inverted?a.$.brightnessScaleThumb.s=a._HSV.s=1-r:a.$.brightnessScaleThumb.v=a._HSV.v=1-r,a.$.brightnessScaleThumb.style.top=l*r+"px",a.$.colorPaletteRadial.style.setProperty("--jqx-color-panel-brightness",r)}},{key:"_updateHueScale",value:function(e){var a=this,t=e.y-a.$.hueScaleThumb.offsetHeight/2,l=a.$.hueScale.offsetHeight,r=l-a.$.hueScaleThumb.offsetHeight;a.$.hueScaleThumb.h=a._HSV.h=360*(l-e.y)/l,a.$.hueScaleThumb.style.top=r*Math.min(Math.max(parseFloat(t),0),parseFloat(r))/r+"px"}},{key:"_trackMoveHandler",value:function(e){var a=this;JQX.Utilities.Core.isMobile||e.stopPropagation(),"touchmove"===e.originalEvent.type&&a._dragDetails&&e.originalEvent.preventDefault()}},{key:"_moveThumbHandler",value:function(e,a){var t=this,l=e.pageX-window.pageXOffset,r=e.pageY-window.pageYOffset;if(!t.disabled&&!t.readonly&&t._activeComponent&&t._dragDetails&&(t._dragDetails.x!==l||t._dragDetails.y!==r||a)){var o=t._getXYcoordinates(e);if(o){var n=t._activeComponent.offsetWidth,i=t._activeComponent.offsetHeight;switch(t._activeComponent){case t.$.colorPalette:t.$.colorPaletteThumb.style.left=100*o.x/n+"%",t.$.colorPaletteThumb.style.top=100*o.y/i+"%",t.$.colorPaletteThumb.s=t._HSV.s=o.x/n,t.$.colorPaletteThumb.v=t._HSV.v=1-o.y/i;break;case t.$.colorPaletteRadial:var s=n,d=o.x-s/2,u=o.y-s/2;t.$.colorPaletteRadialThumb.h=t._HSV.h=t._calcHueAngle(d,u)<0?360+t._calcHueAngle(d,u):t._calcHueAngle(d,u),t.inverted?t.$.colorPaletteRadialThumb.v=t._HSV.v=t._validateInRange(2*t._calcSatDistance(d,u)/s,0,1):t.$.colorPaletteRadialThumb.s=t._HSV.s=t._validateInRange(2*t._calcSatDistance(d,u)/s,0,1),t.$.previewContainerBottom.style.backgroundColor=t._HSVtoRGBA();break;case t.$.hueScale:t._updateHueScale(o);break;case t.$.brightnessScale:if(t._updateBrightnessScale(o),"hexagonal"===t.displayMode){var c=t.inverted?{s:t._HSV.s}:{v:t._HSV.v};t._generateHoneycomb(t.columnCount,c)}break;case t.$.alphaChannelScale:var g=o.x-t.$.alphaChannelThumb.offsetWidth/2,h=n-t.$.alphaChannelThumb.offsetWidth;t.$.alphaChannelThumb.a=t._RGBA.a=(n-o.x)/n,t.$.alphaChannelThumb.style.left=100*t._validateInRange(g,0,h)/n+"%"}t._applyValue(t._HSVtoRGBA(t._HSV),e),t._instantUpdate()}}}},{key:"_releaseThumbUpHandler",value:function(){var e=this,a=!!e._activeComponent;e._activeComponent=null,e.disabled||e.readonly||!a||e._dragDetails&&e._dragDetails.isPalettePressed||e._instantUpdate()}},{key:"_handleCancelButtonClick",value:function(){var e=this,a=e.value;if("palette"!==e.displayMode&&"radial"!==e.displayMode&&"hexagonal"!==e.displayMode?(e.value=a,e._HSV=e._getValue("hsv",e.value)||{h:1,s:0,v:1},e._RGBA=e._getValue("HSVtoRGBAarray",e.value)):(e._HSV=e._getValue("hsv",e.value)||{h:1,s:0,v:1},e._RGBA=e._getValue("HSVtoRGBAarray",e.value),e.value=e._getValue(e.valueFormat)),e._applyValue(e.value),null===e.value&&e._selectedItem&&e._selectedItem.classList.contains("selected")&&e._selectedItem.classList.remove("selected"),a!==e.value&&e.$.fireEvent("change",{oldValue:a,value:e.value}),e.$.container.className.indexOf("custom-color-selection")>-1&&e._applyValueInPaletteMode(),e.$.fireEvent("cancelButtonClick"),!1===e._customColorSelection){e._updatePreviewContainerValues(e.value);for(var t="hexagonal"===e.displayMode?e.$.colorPaletteHexagonal:e.$.gridModeContainer,l=t.getElementsByClassName("selected"),r=0;r<l.length;r++)!l[r]||e.value&&e._equalValues(l[r].colorCode,e.value)||(l[r].style.stroke=null,l[r].classList.remove("selected"))}else e.$container.removeClass("custom-color-selection");e._customColorSelection=!1,e._customTempColor=void 0,"palette"!==e.displayMode&&"radial"!==e.displayMode||(e.$.previewContainerTop.style.backgroundColor=e.value)}},{key:"_handleOkButtonClick",value:function(){var e=this,a=e.value;if(!1!==e._customColorSelection&&void 0!==e._customColorSelection){var t=e._getValue(e.valueFormat);return"useButtons"!==e.applyValueMode&&(e.value=t),e.$container.removeClass("custom-color-selection"),e._userPalette.unshift(t),e._generatePaletteUserColorGrid(),e._customColorSelection=!1,void(a!==e.value&&e.$.fireEvent("change",{oldValue:a,value:e.value}))}if(e._customTempColor&&(e._userPalette.unshift(e._customTempColor),e._generatePaletteUserColorGrid(),e._generateNewPalette=!1,e._customTempColor=""),"palette"===e.displayMode||"radial"===e.displayMode||"hexagonal"===e.displayMode||e._selectedItem&&e._selectedItem.classList.contains("selected")?e.value=e._getValue(e.valueFormat):e.value=null,null===e.value)if("palette"===e.displayMode)e._applyValue(e._HSVtoRGBA(e._HSV),event);else for(var l=e.$.gridModeContainer.getElementsByClassName("selected"),r=0;r<l.length;r++)l[r]&&l[r].classList.remove("selected");a!==e.value&&e.$.fireEvent("change",{oldValue:a,value:e.value}),"useButtons"!==e.applyValueMode||e._equalValues(e.value,e._HSVtoRGBA())||(e.$.fireEvent("okButtonClick",{}),e._customColorSelection=!1,e._updatePreviewContainerValues(e._getValue("rgba"),!0))}},{key:"_handleInputChange",value:function(e){var a=this,t=a.value,l=e.target;if(!a.disabled&&!a.readonly){e.preventDefault(),e.stopPropagation();var r=[a.$.rChannelInput,a.$.gChannelInput,a.$.bChannelInput].indexOf(l)>-1,o=a.$.aChannelInput===l;if(r||o)l.value=r?Math.min(255,Math.max(0,l.value)):Math.min(1,Math.max(0,parseFloat(l.value)||0)),a._RGBA=a._getRGBAFromInputs(),a._HSV=a._getValue("hsv","rgba("+a._RGBA.r+", "+a._RGBA.g+", "+a._RGBA.b+", "+a._RGBA.a+")");else if(l===a.$.hexInput){var n=a.value?a._getValue("hex"):null,i="#"+l.value;a._isHEX(i)?(a._RGBA.a=1,a._applyValue(a.editAlphaChannel?a._toRGBA(i):a._toHEX(i))):l.value=n?n.substring(1):"ffffff"}a._applyValue(a.editAlphaChannel?a._getValue("rgba"):a._getValue("hex")),"useButtons"===a.applyValueMode||a.$.container.className.indexOf("custom-color-selection")>-1||(a.value=a._getValue(a.valueFormat),a.$.fireEvent("change",{oldValue:t,value:a.value}))}}},{key:"_applyValue",value:function(e,a){var t=this;if(!e||null===e||"rgba(NaN, NaN, NaN, 1)"===e)return t._RGBA={r:255,g:255,b:255,a:1},void(t.$.hiddenInput.value=t.value);t._HSVRGBArefresh(e.trim()),"palette"===t.displayMode||t.$.container.className.indexOf("custom-color-selection")>-1?t._applyValueInPaletteMode(a):"radial"===t.displayMode?t._applyValueInRadialMode(a):"hexagonal"===t.displayMode?t._applyValueInHexagonalMode(a):t._applyValueInAnyGridMode(e.trim()),t._applyAlphaValue(t._RGBA.a),t.$.hiddenInput.value=t.value}},{key:"_applyAlphaValue",value:function(e,a){var t=this;if(e=t._toFixed(e),"alphaScale"!==a){var l=t.$.alphaChannelThumb.offsetWidth,r=t.$.alphaChannelScale.offsetWidth,o=(1-e)*r>l?(1-e)*l:0;t.$.alphaChannelThumb.style.left="calc("+100*(1-e)+"% - "+o+"px)"}"alphaInput"!==a&&(t.$.aChannelInput.value=e),t._RGBA.a=e,t._updatePreviewContainerValues(t._getValue("rgba"))}},{key:"_applyValueInPaletteMode",value:function(e){var a=this,t=a._getValue("hex"),l=a.$.hueScale.offsetHeight,r=a.$.hueScaleThumb.offsetHeight,o=a._HSV.h?a.$.hueScale.offsetHeight*(360-a._HSV.h)/360:0,n=o-r>0?o/l*r:0;a._setRGBAToInputs(),a.$.hexInput.value=t.substring(1),a.$.alphaChannelScale.style.setProperty("--jqx-color-panel-alpha-channel-color",t),a._activeComponent||(a.$.alphaChannelThumb.style.left="calc("+100*(1-a._RGBA.a)+"% - 3px)",a.$.hueScaleThumb.style.top="calc("+100*o/l+"% - "+n+"px)",a._setPalettePointerXYPosition()),a._activeComponent===a.$.hueScale&&(a.$.colorPalette.style.backgroundColor=a._rgbaToRGB(a._HSVtoRGBA({h:a.$.hueScaleThumb.h,s:1,v:1}))),a._activeComponent&&a._activeComponent!==a.$.colorPalette||a._setPalettePointerXYPosition(e),a.event?a._HSV.h=a.$.hueScaleThumb.h:(a.$.hueScaleThumb.h=a._HSV.h,a.$.colorPalette.style.backgroundColor=a._rgbaToRGB(a._HSVtoRGBA({h:a._HSV.h,s:1,v:1}))),a._updatePreviewContainerValues(a._getValue("rgba"))}},{key:"_applyValueInRadialMode",value:function(e){var a=this,t=a._getValue("hex");if(a._setRGBAToInputs(),a.$.hexInput.value=t.substring(1),a.$.alphaChannelScale.style.setProperty("--jqx-color-panel-alpha-channel-color",t),!a._activeComponent){var l=a.$.brightnessScale.offsetHeight-a.$.brightnessScaleThumb.offsetHeight;a.$.alphaChannelThumb.style.left="calc("+100*(1-a._RGBA.a)+"% - 3px)",a.$.brightnessScaleThumb.style.top=l*(a.inverted?a._HSV.v:1-a._HSV.v)+"px"}if(a._activeComponent&&a._activeComponent!==a.$.colorPaletteRadial||a._setPalettePointerXYPosition(e),a._updatePreviewContainerValues(a._getValue("rgba")),a.inverted){var r=null===a.value?"black":a._HSVtoRGBA({h:a._HSV.h,s:1,v:a._HSV.v});a.$.brightnessScale.style.backgroundImage="linear-gradient("+r+", white)"}else{var o=null===a.value?"white":a._HSVtoRGBA({h:a._HSV.h,s:a._HSV.s,v:1});a.$.brightnessScale.style.backgroundImage="linear-gradient("+o+", black)"}}},{key:"_applyValueInHexagonalMode",value:function(){var e=this,a=e._getValue("hex");if(e._setRGBAToInputs(),e.$.hexInput.value=a?a.substring(1):null,e.$.alphaChannelScale.style.setProperty("--jqx-color-panel-alpha-channel-color",a),!e._activeComponent&&!e._targetItem){var t=e.$.brightnessScale.offsetHeight-e.$.brightnessScaleThumb.offsetHeight;e.$.alphaChannelThumb.style.left="calc("+100*(1-e._RGBA.a)+"% - 3px)",e.$.brightnessScaleThumb.style.top=t*(e.inverted?e._HSV.v:1-e._HSV.v)+"px"}var l=e._getValue("rgba");if(e._updatePreviewContainerValues(l||e._getValue("hex")),e.inverted){var r=e._HSVtoRGBA({h:e._HSV.h,s:1,v:e._HSV.v},1);e.$.brightnessScale.style.backgroundImage="linear-gradient("+r+", white)"}else{var o=e._HSVtoRGBA({h:e._HSV.h,s:e._HSV.s,v:1},1);e.$.brightnessScale.style.backgroundImage="linear-gradient("+o+", black)"}e._applyValueInAnyGridMode(a,e.$.colorPaletteHexagonal)}},{key:"_radialThumbPoint",value:function(e,a,t,l){return{x:Math.round(Math.cos(t*Math.PI/180)*l*e+e),y:Math.round(Math.sin(t*Math.PI/180)*l*e+a)}}},{key:"_updatePreviewContainerValues",value:function(e,a){var t=this;("instantly"===t.applyValueMode||a)&&(t.$.previewContainerTop.style.backgroundColor=e),t.$.previewContainerBottom.style.backgroundColor=e}},{key:"_applyValueInAnyGridMode",value:function(e,a){var t=this;if(e||null===e){if(!a)switch(t.displayMode){case"default":a=t.$.defaultSamplesContainer;break;case"grid":a=t.$.gridSamplesContainer;break;case"materialGrid":a=t.$.materialGridSamplesContainer;break;case"spectrumGrid":a=t.$.spectrumGridSamplesContainer;break;default:a=t.$.gridModeContainer}var l=Array.from(a.getElementsByClassName("color-sample")),r=t._targetItem;if(void 0===r||null===r)for(var o=0;o<l.length;o++){var n=l[o];if(t._equalValues(n.colorCode,e)){r=l[o];break}}t.$.container.className.indexOf("custom-color-selection")>-1&&t._HSV.h&&t._applyValueInPaletteMode(),t._changeSampleSelection(r)}}},{key:"_generatePaletteGrid",value:function(){for(var e=this,a=e["_"+e.palette+"Palette"],t=document.createDocumentFragment(),l=0;l<a.length;l++){var r=document.createElement("span"),o=a[l];r.className="color-sample",r.colorCode=o,r.style.backgroundColor=o,t.appendChild(r)}e.$.gridSamplesContainer.innerHTML="",e.$.gridSamplesContainer.appendChild(t)}},{key:"_generatePaletteUserColorGrid",value:function(e){var a=this;if(!a._userPalette||!a._userPalette.length)return void(a.$.userSamplesContainer.innerHTML="");var t=a._userPalette.filter(function(e){return""!==e}).slice(0,a.columnCount||1),l=document.createDocumentFragment(),r=void 0;t=[].concat(babelHelpers.toConsumableArray(new Set(t)));for(var o=0;o<t.length;o++)if(t[o]){var n=a._createColorSample(t[o],"user-color");l.appendChild(n),r||(r=n)}a.$.userSamplesContainer.innerHTML="",a.$.userSamplesContainer.appendChild(l),!e&&r.colorCode&&a._changeSampleSelection(r),a.paletteCustomColors=a._userPalette.slice(0)}},{key:"_initializeBaseVars",value:function(){var e=this;e._draw=new JQX.Utilities.Draw(e.$.colorPaletteHexagonal),e._renderer=new JQX.Utilities.Renderer(e._draw),e._RGBA={r:255,g:255,b:255,a:1},e._HSV={h:0,s:0,v:1},e.$.hueScaleThumb.h=0,e.$.colorPaletteThumb.s=0,e.$.colorPaletteThumb.v=1,e.$.colorPaletteRadialThumb.h=0,e.$.colorPaletteRadialThumb.s=0,e.$.alphaChannelThumb.a=1,e._defaultPalette=["rgb(0, 0, 0)","rgb(153, 51, 0)","rgb(51, 51, 0)","rgb(0, 51, 0)","rgb(0, 51, 102)","rgb(0, 0, 128)","rgb(51, 51, 153)","rgb(51, 51, 51)","rgb(128, 0, 0)","rgb(255, 102, 0)","rgb(128, 128, 0)","rgb(0, 128, 0)","rgb(0, 128, 128)","rgb(0, 0, 255)","rgb(102, 102, 153)","rgb(128, 128, 128)","rgb(255, 0, 0)","rgb(255, 153, 0)","rgb(153, 204, 0)","rgb(51, 153, 102)","rgb(51, 204, 204)","rgb(51, 102, 255)","rgb(128, 0, 128)","rgb(153, 153, 153)","rgb(255, 0, 255)","rgb(255, 204, 0)","rgb(255, 255, 0)","rgb(0, 255, 0)","rgb(0, 255, 255)","rgb(0, 204, 255)","rgb(153, 51, 102)","rgb(192, 192, 192)","rgb(255, 153, 204)","rgb(255, 204, 153)","rgb(255, 255, 153)","rgb(204, 255, 204)","rgb(204, 255, 255)","rgb(153, 204, 255)","rgb(204, 153, 255)","rgb(255, 255, 255)"],e._grayPalette=e._generateShades(40,"gray"),e._redPalette=e._generateShades(40,"red"),e._greenPalette=e._generateShades(40,"green"),e._bluePalette=e._generateShades(40,"blue"),e._customPalette=e._mapDataSourceToPalette(),e._userPalette=e.paletteCustomColors||[],e._colorPalette={},e._cssColorNamesHEX={aliceblue:"#f0f8ff",antiquewhite:"#faebd7",aqua:"#00ffff",aquamarine:"#7fffd4",azure:"#f0ffff",beige:"#f5f5dc",bisque:"#ffe4c4",black:"#000000",blanchedalmond:"#ffebcd",blue:"#0000ff",blueviolet:"#8a2be2",brown:"#a52a2a",burlywood:"#deb887",cadetblue:"#5f9ea0",chartreuse:"#7fff00",chocolate:"#d2691e",coral:"#ff7f50",cornflowerblue:"#6495ed",cornsilk:"#fff8dc",crimson:"#dc143c",cyan:"#00ffff",darkblue:"#00008b",darkcyan:"#008b8b",darkgoldenrod:"#b8860b",darkgray:"#a9a9a9",darkgreen:"#006400",darkkhaki:"#bdb76b",darkmagenta:"#8b008b",darkolivegreen:"#556b2f",darkorange:"#ff8c00",darkorchid:"#9932cc",darkred:"#8b0000",darksalmon:"#e9967a",darkseagreen:"#8fbc8f",darkslateblue:"#483d8b",darkslategray:"#2f4f4f",darkturquoise:"#00ced1",darkviolet:"#9400d3",deeppink:"#ff1493",deepskyblue:"#00bfff",dimgray:"#696969",dodgerblue:"#1e90ff",firebrick:"#b22222",floralwhite:"#fffaf0",forestgreen:"#228b22",fuchsia:"#ff00ff",gainsboro:"#dcdcdc",ghostwhite:"#f8f8ff",gold:"#ffd700",goldenrod:"#daa520",gray:"#808080",green:"#008000",greenyellow:"#adff2f",honeydew:"#f0fff0",hotpink:"#ff69b4","indianred ":"#cd5c5c",indigo:"#4b0082",ivory:"#fffff0",khaki:"#f0e68c",lavender:"#e6e6fa",lavenderblush:"#fff0f5",lawngreen:"#7cfc00",lemonchiffon:"#fffacd",lightblue:"#add8e6",lightcoral:"#f08080",lightcyan:"#e0ffff",lightgoldenrodyellow:"#fafad2",lightgrey:"#d3d3d3",lightgreen:"#90ee90",lightpink:"#ffb6c1",lightsalmon:"#ffa07a",lightseagreen:"#20b2aa",lightskyblue:"#87cefa",lightslategray:"#778899",lightsteelblue:"#b0c4de",lightyellow:"#ffffe0",lime:"#00ff00",limegreen:"#32cd32",linen:"#faf0e6",magenta:"#ff00ff",maroon:"#800000",mediumaquamarine:"#66cdaa",mediumblue:"#0000cd",mediumorchid:"#ba55d3",mediumpurple:"#9370d8",mediumseagreen:"#3cb371",mediumslateblue:"#7b68ee",mediumspringgreen:"#00fa9a",mediumturquoise:"#48d1cc",mediumvioletred:"#c71585",midnightblue:"#191970",mintcream:"#f5fffa",mistyrose:"#ffe4e1",moccasin:"#ffe4b5",navajowhite:"#ffdead",navy:"#000080",oldlace:"#fdf5e6",olive:"#808000",olivedrab:"#6b8e23",orange:"#ffa500",orangered:"#ff4500",orchid:"#da70d6",palegoldenrod:"#eee8aa",palegreen:"#98fb98",paleturquoise:"#afeeee",palevioletred:"#d87093",papayawhip:"#ffefd5",peachpuff:"#ffdab9",peru:"#cd853f",pink:"#ffc0cb",plum:"#dda0dd",powderblue:"#b0e0e6",purple:"#800080",rebeccapurple:"#663399",red:"#ff0000",rosybrown:"#bc8f8f",royalblue:"#4169e1",saddlebrown:"#8b4513",salmon:"#fa8072",sandybrown:"#f4a460",seagreen:"#2e8b57",seashell:"#fff5ee",sienna:"#a0522d",silver:"#c0c0c0",skyblue:"#87ceeb",slateblue:"#6a5acd",slategray:"#708090",snow:"#fffafa",springgreen:"#00ff7f",steelblue:"#4682b4",tan:"#d2b48c",teal:"#008080",thistle:"#d8bfd8",tomato:"#ff6347",turquoise:"#40e0d0",violet:"#ee82ee",wheat:"#f5deb3",white:"#ffffff",whitesmoke:"#f5f5f5",yellow:"#ffff00",yellowgreen:"#9acd32"},e._defaultModeThemeColors=null===e.gridThemeColors?["#FFFFFF","#000000","#E6E6E6","#495469","#5671C2","#D48439","#A5A5A5","#EEC328","#7399D3","#85AA4C"]:e.gridThemeColors,e._defaultModeStandardColors=null===e.gridStandardColors?["#A52A0D","#DB3A15","#EEC328","#FEFE33","#A6CD57","#62AC54","#65ADEE","#3F6FBE","#10205F","#64379E"]:e.gridStandardColors,e._defaultModeShadesColors=null===e.gridShadeColors?["#F2F2F2","#808080","#D0CECE","#D6DCE4","#DDEBF7","#FCE4D6","#EBEBEB","#FFF2CC","#DDE5F7","#E2EFDA","#D8D8D8","#595959","#AEAAAA","#ACB9CA","#BDD7EE","#F6CAAD","#DBDBDB","#FFE699","#B4C6E7","#C6E0B4","#BFBFBF","#404040","#757171","#8497B0","#9BC2E6","#F4B084","#C0C0C0","#FFD966","#8EA9DB","#A9D08E","#A6A6A6","#262626","#312F2F","#333F4F","#2F75B5","#C65911","#7B7B7B","#BF8F00","#305496","#548235","#808080","#0D0D0D","#161616","#222B35","#1F4E78","#833C0C","#525252","#806000","#203764","#375623"]:e.gridShadeColors,e._materialColors={Red:{50:"rgb(255, 235, 238)",100:"rgb(255, 205, 210)",200:"rgb(239, 154, 154)",300:"rgb(229, 115, 115)",400:"rgb(239, 83, 80)",500:"rgb(244, 67, 54)",600:"rgb(229, 57, 53)",700:"rgb(211, 47, 47)",800:"rgb(198, 40, 40)",900:"rgb(183, 28, 28)","A 100":"rgb(255, 138, 128)","A 200":"rgb(255, 82, 82)","A 400":"rgb(255, 23, 68)","A 700":"rgb(213, 0, 0)"},Pink:{50:"rgb(252, 228, 236)",100:"rgb(248, 187, 208)",200:"rgb(244, 143, 177)",300:"rgb(240, 98, 146)",400:"rgb(236, 64, 122)",500:"rgb(233, 30, 99)",600:"rgb(216, 27, 96)",700:"rgb(194, 24, 91)",800:"rgb(173, 20, 87)",900:"rgb(136, 14, 79)","A 100":"rgb(255, 128, 171)","A 200":"rgb(255, 64, 129)","A 400":"rgb(245, 0, 87)","A 700":"rgb(197, 17, 98)"},Purple:{50:"rgb(243, 229, 245)",100:"rgb(225, 190, 231)",200:"rgb(206, 147, 216)",300:"rgb(186, 104, 200)",400:"rgb(171, 71, 188)",500:"rgb(156, 39, 176)",600:"rgb(142, 36, 170)",700:"rgb(123, 31, 162)",800:"rgb(106, 27, 154)",900:"rgb(74, 20, 140)","A 100":"rgb(234, 128, 252)","A 200":"rgb(224, 64, 251)","A 400":"rgb(213, 0, 249)","A 700":"rgb(170, 0, 255)"},"Deep Purple":{50:"rgb(237, 231, 246)",100:"rgb(209, 196, 233)",200:"rgb(179, 157, 219)",300:"rgb(149, 117, 205)",400:"rgb(126, 87, 194)",500:"rgb(103, 58, 183)",600:"rgb(94, 53, 177)",700:"rgb(81, 45, 168)",800:"rgb(69, 39, 160)",900:"rgb(49, 27, 146)","A 100":"rgb(179, 136, 255)","A 200":"rgb(124, 77, 255)","A 400":"rgb(101, 31, 255)","A 700":"rgb(98, 0, 234)"},Indigo:{50:"rgb(232, 234, 246)",100:"rgb(197, 202, 233)",200:"rgb(159, 168, 218)",300:"rgb(121, 134, 203)",400:"rgb(92, 107, 192)",500:"rgb(63, 81, 181)",600:"rgb(57, 73, 171)",700:"rgb(48, 63, 159)",800:"rgb(40, 53, 147)",900:"rgb(26, 35, 126)","A 100":"rgb(140, 158, 255)","A 200":"rgb(83, 109, 254)","A 400":"rgb(61, 90, 254)","A 700":"rgb(48, 79, 254)"},Blue:{50:"rgb(227, 242, 253)",100:"rgb(187, 222, 251)",200:"rgb(144, 202, 249)",300:"rgb(100, 181, 246)",400:"rgb(66, 165, 245)",500:"rgb(33, 150, 243)",600:"rgb(30, 136, 229)",700:"rgb(25, 118, 210)",800:"rgb(21, 101, 192)",900:"rgb(13, 71, 161)","A 100":"rgb(130, 177, 255)","A 200":"rgb(68, 138, 255)","A 400":"rgb(41, 121, 255)","A 700":"rgb(41, 98, 255)"},"Light Blue":{50:"rgb(225, 245, 254)",100:"rgb(179, 229, 252)",200:"rgb(129, 212, 250)",300:"rgb(79, 195, 247)",400:"rgb(41, 182, 246)",500:"rgb(3, 169, 244)",600:"rgb(3, 155, 229)",700:"rgb(2, 136, 209)",800:"rgb(2, 119, 189)",900:"rgb(1, 87, 155)","A 100":"rgb(128, 216, 255)","A 200":"rgb(64, 196, 255)","A 400":"rgb(0, 176, 255)","A 700":"rgb(0, 145, 234)"},Cyan:{50:"rgb(224, 247, 250)",100:"rgb(178, 235, 242)",200:"rgb(128, 222, 234)",300:"rgb(77, 208, 225)",400:"rgb(38, 198, 218)",500:"rgb(0, 188, 212)",600:"rgb(0, 172, 193)",700:"rgb(0, 151, 167)",800:"rgb(0, 131, 143)",900:"rgb(0, 96, 100)","A 100":"rgb(132, 255, 255)","A 200":"rgb(24, 255, 255)","A 400":"rgb(0, 229, 255)","A 700":"rgb(0, 184, 212)"},Teal:{
50:"rgb(224, 242, 241)",100:"rgb(178, 223, 219)",200:"rgb(128, 203, 196)",300:"rgb(77, 182, 172)",400:"rgb(38, 166, 154)",500:"rgb(0, 150, 136)",600:"rgb(0, 137, 123)",700:"rgb(0, 121, 107)",800:"rgb(0, 105, 92)",900:"rgb(0, 77, 64)","A 100":"rgb(167, 255, 235)","A 200":"rgb(100, 255, 218)","A 400":"rgb(29, 233, 182)","A 700":"rgb(0, 191, 165)"},Green:{50:"rgb(232, 245, 233)",100:"rgb(200, 230, 201)",200:"rgb(165, 214, 167)",300:"rgb(129, 199, 132)",400:"rgb(102, 187, 106)",500:"rgb(76, 175, 80)",600:"rgb(67, 160, 71)",700:"rgb(56, 142, 60)",800:"rgb(46, 125, 50)",900:"rgb(27, 94, 32)","A 100":"rgb(185, 246, 202)","A 200":"rgb(105, 240, 174)","A 400":"rgb(0, 230, 118)","A 700":"rgb(0, 200, 83)"},"Light Green":{50:"rgb(241, 248, 233)",100:"rgb(220, 237, 200)",200:"rgb(197, 225, 165)",300:"rgb(174, 213, 129)",400:"rgb(156, 204, 101)",500:"rgb(139, 195, 74)",600:"rgb(124, 179, 66)",700:"rgb(104, 159, 56)",800:"rgb(85,139,47)",900:"rgb(51,105,30)","A 100":"rgb(204,255,144)","A 200":"rgb(178,255,89)","A 400":"rgb(118,255,3)","A 700":"rgb(100, 221, 23)"},Lime:{50:"rgb(249, 251, 231)",100:"rgb(255, 249, 196)",200:"rgb(255, 245, 157)",300:"rgb(255, 241, 118)",400:"rgb(255, 238, 88)",500:"rgb(255, 235, 59)",600:"rgb(253, 216, 53)",700:"rgb(251, 192, 45)",800:"rgb(249, 168, 37)",900:"rgb(245, 127, 23)","A 100":"rgb(244, 255, 129)","A 200":"rgb(238, 255, 65)","A 400":"rgb(198, 255, 0)","A 700":"rgb(174, 234, 0)"},Yellow:{50:"rgb(255, 253, 231)",100:"rgb(255, 249, 196)",200:"rgb(255, 245, 157)",300:"rgb(255, 241, 118)",400:"rgb(255, 238, 88)",500:"rgb(255, 235, 59)",600:"rgb(253, 216, 53)",700:"rgb(251, 192, 45)",800:"rgb(249, 168, 37)",900:"rgb(245, 127, 23)","A 100":"rgb(255, 255, 141)","A 200":"rgb(255, 255, 0)","A 400":"rgb(255, 234, 0)","A 700":"rgb(255, 214, 0)"},Amber:{50:"rgb(255, 248, 225)",100:"rgb(255, 236, 179)",200:"rgb(255, 224, 130)",300:"rgb(255, 213, 79)",400:"rgb(255, 202, 40)",500:"rgb(255, 193, 7)",600:"rgb(255, 179, 0)",700:"rgb(255, 160, 0)",800:"rgb(255, 143, 0)",900:"rgb(255, 111, 0)","A 100":"rgb(255, 229, 127)","A 200":"rgb(255, 215, 64)","A 400":"rgb(255, 196, 0)","A 700":"rgb(255, 171, 0)"},Orange:{50:"rgb(255, 243, 224)",100:"rgb(255, 224, 178)",200:"rgb(255, 204, 128)",300:"rgb(255, 183, 77)",400:"rgb(255, 167, 38)",500:"rgb(255, 152, 0)",600:"rgb(251, 140, 0)",700:"rgb(245, 124, 0)",800:"rgb(239, 108, 0)",900:"rgb(230, 81, 0)","A 100":"rgb(255, 209, 128)","A 200":"rgb(255, 171, 64)","A 400":"rgb(255, 145, 0)","A 700":"rgb(255, 109, 0)"},"Deep Orange":{50:"rgb(251, 233, 231)",100:"rgb(255, 204, 188)",200:"rgb(255, 171, 145)",300:"rgb(255, 138, 101)",400:"rgb(255, 112, 67)",500:"rgb(255, 87, 34)",600:"rgb(244, 81, 30)",700:"rgb(230, 74, 25)",800:"rgb(216, 67, 21)",900:"rgb(191, 54, 12)","A 100":"rgb(255, 158, 128)","A 200":"rgb(255, 110, 64)","A 400":"rgb(255, 61, 0)","A 700":"rgb(221, 44, 0)"},Brown:{50:"rgb(239, 235, 233)",100:"rgb(215, 204, 200)",200:"rgb(188, 170, 164)",300:"rgb(161, 136, 127)",400:"rgb(141, 110, 99)",500:"rgb(121, 85, 72)",600:"rgb(109, 76, 65)",700:"rgb(93, 64, 55)",800:"rgb(78, 52, 46)",900:"rgb(62, 39, 35)","A 100":"","A 200":"","A 400":"","A 700":""},Grey:{50:"rgb(250, 250, 250)",100:"rgb(245, 245, 245)",200:"rgb(238, 238, 238)",300:"rgb(224, 224, 224)",400:"rgb(189, 189, 189)",500:"rgb(158, 158, 158)",600:"rgb(117, 117, 117)",700:"rgb(97, 97, 97)",800:"rgb(66, 66, 66)",900:"rgb(33, 33, 33)","A 100":"","A 200":"","A 400":"","A 700":""},"Blue Grey":{50:"rgb(236, 239, 241)",100:"rgb(207, 216, 220)",200:"rgb(176, 190, 197)",300:"rgb(144, 164, 174)",400:"rgb(120, 144, 156)",500:"rgb(96, 125, 139)",600:"rgb(84, 110, 122)",700:"rgb(69, 90, 100)",800:"rgb(55, 71, 79)",900:"rgb(38, 50, 56)","A 100":"","A 200":"","A 400":"","A 700":""}}}},{key:"_mapDataSourceToPalette",value:function(){var e=this,a=[];if(!e.paletteColors||!Array.isArray(e.paletteColors)||0===e.paletteColors.length)return[];for(var t=0;t<e.paletteColors.length;t++){var l=e.paletteColors[t];"string"==typeof l?a.push(e.paletteColors[t]):("object"===(void 0===l?"undefined":babelHelpers.typeof(l))&&(l.value&&"string"==typeof l||l[e.valueMember]&&l[e.valueMember]),a.push(e.paletteColors[t]))}return a}},{key:"_handleSampleClick",value:function(e){var a=this,t=e.target,l=a.value,r=t.colorCode;"hexagonal"===a.displayMode?(r=a._HSVtoRGBA({h:t.h,s:t.s,v:t.v},a._RGBA.a),a._hexagonItems.indexOf(t)>-1&&(a._HSV.h=t.h,a.inverted,a._HSV.s=t.s,a._HSV.v=t.v,a._targetItem=t,a._applyValue(a._HSVtoRGBA(a._HSV),e),delete a._targetItem)):a._changeSampleSelection(t),a._HSVRGBArefresh(t.classList.contains("selected")?r:null),"instantly"===a.applyValueMode&&(a.$.hiddenInput.value=a.value=a._getValue(a.valueFormat,t.classList.contains("selected")?r:null),a.$.fireEvent("change",{oldValue:l,value:a.value}))}},{key:"_changeSampleSelection",value:function(e){var a=this;if(a._selectedItem&&"radial"!==a.displayMode&&"hexagonal"!==a.displayMode&&(!e||a._selectedItem===e&&e.classList.contains("selected")))return a._selectedItem.classList.remove("selected"),void(a._selectedItem.style.stroke=null);if(e){var t=a._renderer._getContrastColor(a._rgbaToHEX(a._toRGBA(e.colorCode))),l=e.closest("svg");return Array.from(a.getElementsByClassName("selected")).forEach(function(e){e.classList.remove("selected"),e.style.stroke=null}),e.classList.add("selected"),a._selectedItem=e,l&&(e.style.stroke=t,l.appendChild(e)),!0}}},{key:"_getXYcoordinates",value:function(e){if(e){var a=this,t=a._activeComponent||(e.originalEvent||e).target;if(t.closest){var l=t.closest(".color-palette")||t.closest(".color-palette-radial")||t.closest(".hue-scale")||t.closest(".brightness-scale")||t.closest(".alpha-channel-scale");if(l&&!a.disabled&&!a.readonly){var r=l.getBoundingClientRect(),o=e.pageX-window.pageXOffset-r.left,n=e.pageY-window.pageYOffset-r.top;return o<0?o=0:o>l.offsetWidth&&(o=l.offsetWidth),n<0?n=0:n>l.offsetHeight&&(n=l.offsetHeight),{x:o,y:n,container:l}}}}}},{key:"_inputWheelHandler",value:function(e){var a=this,t=a.value,l=e.target;if(e.target instanceof HTMLInputElement){e.preventDefault();var r=void 0;if(l===a.$.aChannelInput?(r=parseFloat(l.value)||0,r=e.deltaY<0?r+.01:r-.01,l.value=a._toFixed(a._validateInRange(r,0,1)),a._RGBA=a._getRGBAFromInputs(),a._applyAlphaValue(a._RGBA.a,"alphaInput")):(r=parseInt(l.value)||0,r=e.deltaY<0?r+1:r-1,l.value=a._validateInRange(r,0,255),a._RGBA=a._getRGBAFromInputs(),a._HSV=a._getValue("hsv","rgba("+a._RGBA.r+", "+a._RGBA.g+", "+a._RGBA.b+", "+a._RGBA.a+")")),a._updatePreviewContainerValues(a._getValue(a.valueFormat)),a._setPalettePointerXYPosition(),a.$.container.className.indexOf("custom-color-selection")>-1)return void a._applyValue(a._HSVtoRGBA(a._HSV));"useButtons"!==a.applyValueMode&&(a.value=a._getValue(a.valueFormat),a._applyValue(a.value,e),a.$.fireEvent("change",{oldValue:t,value:a.value}))}}},{key:"_paletteDownHandler",value:function(e){var a=this;if(!(!JQX.Utilities.Core.isMobile&&0!==e.button||a.disabled||a.readonly)){a._dragDetails={x:e.pageX-window.pageXOffset,y:e.pageY-window.pageYOffset};var t=(e.originalEvent||e).target;if(t&&t.closest){if(a._dragDetails.target=t.closest(".color-palette")||t.closest(".color-palette-radial"),t.closest(".color-palette")||t.closest(".color-palette-radial"))return a._handleColorPaletteDown(e.originalEvent),void(a._dragDetails.isPalettePressed=!0);(t.closest(".hue-scale")||t.closest(".alpha-channel-scale")||t.closest(".brightness-scale"))&&a._handleScalesDown(e.originalEvent)}}}},{key:"_setPalettePointerXYPosition",value:function(e){var a=this,t=void 0;if("palette"===a.displayMode||a.$.container.className.indexOf("custom-color-selection")>-1)t=a._getXYcoordinates(e),a.$.colorPaletteThumb.style.left=e&&t&&t.x?100*t.x/t.container.offsetWidth+"%":100*a._HSV.s+"%",a.$.colorPaletteThumb.style.top=e&&t&&t.y?100*t.y/t.container.offsetHeight+"%":100*(1-a._HSV.v)+"%";else if("radial"===a.displayMode){if(e){if(!(t=a._getXYcoordinates(e)))return;var l=t.container.offsetWidth?t.container.offsetWidth:a.$.colorPaletteRadial.offsetWidth,r=t.container.offsetHeight?t.container.offsetHeight:a.$.colorPaletteRadial.offsetHeight,o=Math.round(Math.cos(a._HSV.h*Math.PI/180)*l/2+l/2),n=Math.round(Math.sin(a._HSV.h*Math.PI/180)*l/2+r/2);return Math.abs(l/2-t.x)<5?(a.$.colorPaletteRadialThumb.style.left=100*t.x/a.$.colorPaletteRadial.offsetWidth+"%",void(a.$.colorPaletteRadialThumb.style.top=100*t.y/a.$.colorPaletteRadial.offsetHeight+"%")):(a.$.colorPaletteRadialThumb.style.left=100*(t.x<l/2?Math.max(o,t.x):Math.min(o,t.x))/l+"%",void(a.$.colorPaletteRadialThumb.style.top=100*(t.y<r/2?Math.max(n,t.y):Math.min(n,t.y))/r+"%"))}var i=a._radialThumbPoint(a.$.colorPaletteRadial.offsetWidth/2,a.$.colorPaletteRadial.offsetHeight/2,a._HSV.h,a._HSV.s);a.$.colorPaletteRadialThumb.style.left=100*i.x/a.$.colorPaletteRadial.offsetWidth+"%",a.$.colorPaletteRadialThumb.style.top=100*i.y/a.$.colorPaletteRadial.offsetHeight+"%"}}},{key:"_handleGridModeCellHover",value:function(e){var a=this,t=e.target.closest(".color-sample");if(!a.disabled&&t&&"none"!==a.tooltipDisplayMode){if(a.$.tooltip.arrow="hexagonal"!==a.displayMode,!a._isValidColor(t.colorCode))return void(a.$.tooltip.disabled=!0);a.$.tooltip.disabled=!1,a.$.tooltip.selector=t;var l=t.h&&t.s&&t.v?a._HSVtoRGBA({h:t.h,s:t.s,v:t.v},a._RGBA.a):a._toRGBA(t.colorCode);switch(a.tooltipDisplayMode){case"rgba":a.$.tooltip.value=l||"";break;case"rgb":a.$.tooltip.value=a._rgbaToRGB(l)||"";break;case"hex":a.$.tooltip.value=a._rgbaToHEX(l)||""}}}},{key:"_localizeLabels",value:function(){var e=this;e.$.rChannelLabel.innerHTML=e.localize("redPrefix"),e.$.gChannelLabel.innerHTML=e.localize("greenPrefix"),e.$.bChannelLabel.innerHTML=e.localize("bluePrefix"),e.$.hexLabel.innerHTML=e.localize("hexPrefix"),e.$.alphaChannelLabel.innerHTML=e.localize("alphaPrefix"),e.$.buttonCustom.content=e.localize("customColor"),e.$.buttonOk.content=e.localize("ok"),e.$.buttonCancel.content=e.localize("cancel");var a=e.$.defaultSamplesContainer.querySelector(".theme-colors-label"),t=e.$.defaultSamplesContainer.querySelector(".standard-colors-label");a&&(a.innerHTML=e.localize("themeColors")),t&&(t.innerHTML=e.localize("standardColors"))}},{key:"_generateHoneycomb",value:function(e,a){var t=this,l=parseInt(getComputedStyle(t).getPropertyValue("--jqx-color-panel-grid-mode-item-size"))/4,r=Math.sqrt(5*Math.pow(l,2)),o=e%2==0?parseInt(e)+1:parseInt(e),n=a&&void 0!==a.s?a.s:1,i=a&&void 0!==a.v?a.v:1,s=t._calculateHexagonCoords(o,r,1),d=s[Math.floor(s.length/2)],u=t._getHoneycomb30degDimmensions(s.length,r,1);t._draw&&t._draw.clear(),t._hexagonItems=[],t.$materialGridSamplesContainer.addClass("jqx-hidden");for(var c=0;c<s.length;c++){var g=s[c].x-d.x,h=s[c].y-d.y,b=t._validateInRange(t._calcSatDistance(g,h)/d.x,0,1),p=t._calcHueAngle(g,h)<0?360+t._calcHueAngle(g,h):t._calcHueAngle(g,h),v=void 0,f=void 0;switch(t.inverted?(v=n,f=b):(v=b,f=i),t.palette){case"red":p=0;break;case"green":p=120;break;case"blue":p=240;break;case"gray":v=0,f=t.inverted?b:1-b}var m={offsetX:s[c].x,offsetY:s[c].y,style:{fill:t._HSVtoRGBA({h:p,s:v,v:f},1),class:"color-sample"}},_=t._hexagon(r,m);_.colorCode=t._HSVtoRGBA({h:p,s:v,v:f}),_.h=p,_.s=v,_.v=f,t._hexagonItems.push(_)}t._draw.host.style.width=u.width+"px",t._draw.host.style.height=u.height+"px",t.$.container.style.setProperty("--jqx-color-panel-palette-width",u.width+"px"),t.$.container.style.setProperty("--jqx-color-panel-palette-height",u.height+"px"),t._applyValueInHexagonalMode(),t._hideControlsByPriority()}},{key:"_hexagon",value:function(e,a){var t=this,l=t._shortStepHexagon(e),r=2*l,o=r+(a.offsetX||0),n=a.offsetY||0,i=o+r,s=n+l,d=i,u=s+e,c=d-r,g=u+l,h=c-r,b=g-l,p=h,v=b-e,f="M "+o+","+n+" L "+i+","+s+" L "+d+","+u+" L "+c+","+g+" L "+h+","+b+" L "+p+","+v+" Z";return t._draw.path(f,a.style||{class:"color-sample"})}},{key:"_shortStepHexagon",value:function(e){return Math.sqrt(Math.pow(e,2)/5)}},{key:"_getHoneycomb30degDimmensions",value:function(e,a,t){var l=this,r=.5*(1+Math.sqrt(1-(1-e)/3*4)),o=l._shortStepHexagon(a);return{width:4*o*(2*r-1)+2*r*2*t,height:(2*r-1)*a+2*r*o+2*r*t}}},{key:"_generateShades",value:function(e,a){var t=this,l=a||"gray",r=void 0,o=[];e=Math.max(parseInt(e),2);for(var n=255/(e-1),i=0;i<e;i++){var s=Math.max(parseInt(255-i*n),0);switch(t.inverted&&(s=255-s),l){case"red":r="rgb("+s+", 0, 0)";break;case"green":r="rgb(0, "+s+", 0)";break;case"blue":r="rgb(0, 0, "+s+")";break;default:r="rgb("+s+", "+s+", "+s+")"}o.push(r)}return o}},{key:"_generateColorSpectrum",value:function(e){var a=this,t=[];e=Math.max(parseInt(e),2);for(var l=360/(e-1),r=2/e,o=0,n=1,i=1,s=0;s<e;s++){a.inverted?0===s?n=1:s<e/2?n=Math.max(n-r,r/2):s<e-1?(i=Math.max(i-r,r/2),n=Math.min(n+r,1)):(i=Math.max(i-r,r/2),n=Math.min(n+r/4,1)):0===s?i=1:s<e/2?i=Math.max(i-r,r/2):s<e-1?(n=Math.max(n-r,r/2),i=Math.min(i+r,1)):(n=Math.max(n-r,r/2),i=Math.min(i+r/4,1));for(var d=0;d<e;d++)o=parseInt(l*d),o=360===o?360-l/2:o,t.push(a._HSVtoRGBA({h:o,s:n,v:i},1))}return t}},{key:"_generateSpectrumGrid",value:function(e){var a=this,t=Math.pow(e,2),l=document.createDocumentFragment(),r={},o=["grayShadesBox","spectrumBox","customColorsBox"],n=a._generateShades(e,"gray"),i=a._customPalette,s=void 0;o.forEach(function(e){r[e]=document.createElement("div"),r[e].className=JQX.Utilities.Core.toDash(e),l.appendChild(r[e])}),s="default"===a.palette?a._generateColorSpectrum(e):["gray","red","green","blue"].indexOf(a.palette)>-1?a._generateShades(t,a.palette):a._generateColorSpectrum(e);for(var d=0;d<e;d++){var u=a._createColorSample(n[d],"gray-shade");r.grayShadesBox.appendChild(u)}for(var c=0;c<t;c++){var g=a._createColorSample(s[c],"spectrum");r.spectrumBox.appendChild(g)}for(var h=0;h<e;h++){var b=i[h];if(!b)break;var p=a._createColorSample(b,"custom-color");r.customColorsBox.appendChild(p)}a.$.spectrumGridSamplesContainer.innerHTML="",a.$.spectrumGridSamplesContainer.appendChild(l)}},{key:"_generateDefaultGrid",value:function(){var e=this,a={},t=["themeColorsLabel","themeColorsBox","themeShadesBox","standardColorsLabel","standardColorsBox"],l=null===e.gridThemeColors?e._defaultModeThemeColors:e.gridThemeColors,r=null===e.gridShadeColors?e._defaultModeShadesColors:e.gridShadeColors,o=null===e.gridStandardColors?e._defaultModeStandardColors:e.gridStandardColors,n=document.createDocumentFragment();t.forEach(function(e){a[e]=document.createElement("div"),a[e].className=JQX.Utilities.Core.toDash(e),n.appendChild(a[e])}),a.themeColorsLabel.innerHTML=e.localize("themeColors"),a.standardColorsLabel.innerHTML=e.localize("standardColors");for(var i=0;i<e._defaultModeShadesColors.length;i++)a.themeShadesBox.appendChild(e._createColorSample(r[i],"shades-color"));for(var s=0;s<10;s++)a.themeColorsBox.appendChild(e._createColorSample(l[s],"theme-color")),a.standardColorsBox.appendChild(e._createColorSample(o[s],"standard-color"));e.$.defaultSamplesContainer.innerHTML="",e.$.defaultSamplesContainer.appendChild(n)}},{key:"_mixColors",value:function(e,a,t){var l=function(e){return parseInt(e,16)},r=void 0,o="#";t=void 0!==t?t:.5,e=e.replace(/#/g,""),a=a.replace(/#/g,"");for(var n=0;n<=5;n+=2){var i=l(e.substr(n,2)),s=l(a.substr(n,2));for(r=function(e){return e.toString(16)}(Math.round(s+(i-s)*t));r.length<2;)r="0"+r;o+=r}return o}},{key:"_generateMaterialGrid",value:function(){var e=this,a=document.createDocumentFragment();e.$materialGridSamplesContainer.removeClass("jqx-hidden");var t=e._createColorSample("rgb(255, 255, 255, 0)","material-color label-column");a.appendChild(t),Object.entries(e._materialColors.Red).forEach(function(t){var l=e._createColorSample("rgb(255, 255, 255, 0)","material-color header");l.innerText=t[0],a.appendChild(l)}),Object.entries(e._materialColors).forEach(function(t){var l=e._createColorSample("rgb(255, 255, 255, 0)","material-color label-column");l.innerText=t[0],a.appendChild(l),Object.entries(t[1]).forEach(function(t){var l=e._createColorSample(t[1],"material-color");a.appendChild(l)})}),e.$.materialGridSamplesContainer.innerHTML="",e.$.materialGridSamplesContainer.appendChild(a)}},{key:"_createColorSample",value:function(e,a){var t=document.createElement("div"),l=e?"":" empty";return t.className="color-sample "+a+l,t.colorCode=e,t.style.backgroundColor=e,t}},{key:"_calculateHexagonCoords",value:function(e,a,t){for(var l=this,r=e,o=function(e){return((e=e%2==0?e+1:e)+1)/2}(e),n=l._shortStepHexagon(a),i=4*n+2*t,s=2*n+t,d=a+n+t,u=s*(r-1)/2,c=[],g=0;g<r;g++)for(var h=g<o?o+g:e-1-(g-o),b=g<o?u-g*s:u-(e-g-1)*s,p=g*d,v=0;v<h;v++){var f=b+v*i;c.push({x:f,y:p})}return c}},{key:"_generateGridStructures",value:function(){var e=this;switch(e.displayMode){case"spectrumGrid":e._generateSpectrumGrid(e.columnCount);break;case"materialGrid":e._generateMaterialGrid();break;case"default":e._generateDefaultGrid();break;case"hexagonal":e._generateHoneycomb(e.columnCount,e._HSV);break;case"grid":e._generatePaletteGrid();break;case"radial":e._generateRadialCanvas()}}},{key:"_generateRadialCanvas",value:function(){var e=this,a=getComputedStyle(e).getPropertyValue("--jqx-color-panel-palette-size"),t=a?Math.round(a.slice(0,-2)):300,l=t/2;document.querySelector(".white-radial-gradient").style.width=t+"px",document.querySelector(".white-radial-gradient").style.height=t+"px",e.$.canvasRadial.innerHTML='<canvas height="'+t+'" id="canvas" width="'+t+'"></canvas>';var r=document.getElementById("canvas"),o=r.getContext("2d");e._drawCircle(o,l)}},{key:"_drawCircle",value:function(e,a){for(var t=this,l=e.createImageData(2*a,2*a),r=l.data,o=-a;o<a;o++)for(var n=-a;n<a;n++){var i=t._xy2polar(o,n),s=babelHelpers.slicedToArray(i,2),d=s[0],u=s[1];if(!(d>a)){var c=t._rad2deg(u),g=2*a,h=o+a,b=n+a,p=4*(h+b*g),v=c,f=t._hsv2rgb(v,1,1),m=babelHelpers.slicedToArray(f,3),_=m[0],y=m[1],C=m[2];r[p]=_,r[p+1]=y,r[p+2]=C,r[p+3]=255}}e.putImageData(l,0,0)}},{key:"_xy2polar",value:function(e,a){return[Math.sqrt(e*e+a*a),Math.atan2(a,e)]}},{key:"_rad2deg",value:function(e){return(e+Math.PI)/(2*Math.PI)*360}},{key:"_hsv2rgb",value:function(e,a,t){var l=t*a,r=e/60,o=l*(1-Math.abs(r%2-1)),n=void 0,i=void 0,s=void 0;r>=0&&r<=1?(n=l,i=o,s=0):r>=1&&r<=2?(n=o,i=l,s=0):r>=2&&r<=3?(n=0,i=l,s=o):r>=3&&r<=4?(n=0,i=o,s=l):r>=4&&r<=5?(n=o,i=0,s=l):r>=5&&r<=6&&(n=l,i=0,s=o);var d=t-l;return[255*(n+d),255*(i+d),255*(s+d)]}},{key:"_hideControlsByPriority",value:function(){var e=this,a=e.hideContentToFit.slice().reverse(),t=["hexLabel","hexInput","rChannelLabel","rChannelInput","gChannelLabel","gChannelInput","bChannelLabel","bChannelInput","previewContainer","alphaChannelLabel","aChannelInput"],l=a.length;for(t.forEach(function(a){return e["$"+a].removeClass("jqx-hidden")});e.$.colorControlsContainer.scrollHeight>e.$.colorControlsContainer.offsetHeight&&l>0;)switch(l--,a[l]){case"HEX":t.slice(0,2).forEach(function(a){return e["$"+a].addClass("jqx-hidden")});break;case"RGB":t.slice(2,8).forEach(function(a){return e["$"+a].addClass("jqx-hidden")});break;case"previewContainer":e.$previewContainer.addClass("jqx-hidden");break;case"alpha":t.slice(9,11).forEach(function(a){return e["$"+a].addClass("jqx-hidden")})}e._generateRadialCanvas()}},{key:"_resizeHoneycombItems",value:function(){var e=this;"hexagonal"===e.displayMode&&e._generateHoneycomb(e.columnCount,e._HSV)}},{key:"_getValue",value:function(e,a){var t=this,l=t._RGBA,r=null,o=void 0;switch(e){case"hex":r=t._rgbArrayToHEX([l.r,l.g,l.b,l.a]);break;case"rgb":r="rgb("+l.r+", "+l.g+", "+l.b+")";break;case"rgba":r=null!==l.r&&null!==l.g&&null!==l.b?"rgba("+l.r+", "+l.g+", "+l.b+", "+l.a+")":null;break;case"HSVtoRGBAarray":var n="hexagonal"===t.displayMode||"radial"===t.displayMode||"palette"===t.displayMode?t._RGBA.a:1;a&&(t._isRGBA(a)&&/rgba\((\d*.\d+|\d+),(\d*.\d+|\d+),(\d*.\d+|\d+)\,(\d*.\d+|\d+)\)/gi.test(a.replace(/\s/g,""))?n=/rgba\((\d*.\d+|\d+),(\d*.\d+|\d+),(\d*.\d+|\d+)\,(\d*.\d+|\d+)\)/gi.exec(a.replace(/\s/g,""))[4]:t._isHEX(a)&&/(^#[0-9A-F]{8}$)/gi.test(a.replace(/\s/g,""))&&(n=parseInt(/(^#[0-9A-F]{2})([0-9A-F]{2})([0-9A-F]{2})([0-9A-F]{2}$)/gi.exec(a.replace(/\s/g,""))[4],16)/255),n=Math.min(1,Math.max(0,parseFloat(n))),isNaN(n)&&(n=t._RGBA.a)),r=t._HSVtoRGBA(t._HSV,n),o=/rgba\((\d*.\d+|\d+),(\d*.\d+|\d+),(\d*.\d+|\d+)\,(\d*.\d+|\d+)\)/gi.exec(r.replace(/\s/g,"")),r={r:parseInt(o[1]),g:parseInt(o[2]),b:parseInt(o[3]),a:t._toFixed(o[4])};break;case"hsv":a&&t._isValidColor(a)&&(r=t._colorToHSV(a));break;default:"radial"===t.displayMode||"hexagonal"===t.displayMode||"palette"===t.displayMode?(r="rgba("+l.r+", "+l.g+", "+l.b+", "+l.a+")",t.editAlphaChannel||(r=t._rgbaToRGB(r))):r=null!==a?t._rgbArrayToHEX([l.r,l.g,l.b,l.a]):null}return r||null}},{key:"_instantUpdate",value:function(){var e=this,a=e.value;"instantly"!==e.applyValueMode||e.$.container.className.indexOf("custom-color-selection")>-1||(e.value=e._getValue(e.valueFormat),e.$.fireEvent("change",{oldValue:a,value:e.value}))}},{key:"_equalValues",value:function(e,a){var t=this;return e===a||!(!e||!a)&&t._toRGBA(e,!0)===t._toRGBA(a,!0)}},{key:"_toHEX",value:function(e){if(!this._isHEX(e))return!1;var a=/^#(.)(.)(.)$/gi.exec(e),t=/^#?([a-f\d]{2})([a-f\d]{2})([a-f\d]{2})$/i.exec(e);return a||t?e:void 0}},{key:"_toRGBA",value:function(e,a){function t(e){var t=/^#(.)(.)(.)$/gi.exec(e),l=/^#?([a-f\d]{2})([a-f\d]{2})([a-f\d]{2})([a-f\d]{2})?$/i.exec(e),r=t?parseInt(t[1]+t[1],16):parseInt(l[1],16),o=t?parseInt(t[2]+t[2],16):parseInt(l[2],16),n=t?parseInt(t[3]+t[3],16):parseInt(l[3],16),i=t?parseInt(t[4]+t[4],16):parseInt(l[4],16);return a?"rgba("+r+", "+o+", "+n+", 1)":"rgba("+r+", "+o+", "+n+", "+(isNaN(i)?"1":(i/255).toFixed(2))+")"}var l=this,r=l.value;if(l._isRGBA(e)){if(a){return"rgba("+e.match(/(\d{1,3})\s*,\s*(\d{1,3})\s*,\s*(\d{1,3})/gi)+", 1)"}return e}if(l._isValidColorName(e))r=t(l._cssColorNamesHEX[e.trim().toLowerCase()]);else if(l._isHEX(e))r=t(e);else{if(!l._isRGB(e))return!1;r=e.toLowerCase(),r=r.replace("rgb","rgba"),r=l.editAlphaChannel?r.replace(")",", "+(l._RGBA.a||1)+")"):r.replace(")",", 1)")}return r}},{key:"_rgbaToRGB",value:function(e){var a=/rgba\((\d*.\d+|\d+),(\d*.\d+|\d+),(\d*.\d+|\d+)\,(\d*.\d+|\d+)\)/gi.exec(e.replace(/\s/g,""));return"rgb("+a[1].trim()+", "+a[2].trim()+", "+a[3].trim()+")"}},{key:"_rgbaToHEX",value:function(e){var a=this,t=/rgba\((\d*.\d+|\d+),(\d*.\d+|\d+),(\d*.\d+|\d+)\,(\d*.\d+|\d+)\)/gi.exec(e.replace(/\s/g,""));return a._rgbArrayToHEX([t[1],t[2],t[3],t[4]])}},{key:"_rgbArrayToHEX",value:function(e){var a="#";if(Array.isArray(e)&&null===e[0])return null;for(var t=0;t<3;t++){var l=parseInt(e[t]).toString(16).toUpperCase();l=1===l.length?0+l:l,a+=l}var r=parseFloat(e[3]);return isNaN(r)||"FF"!==(r=parseInt(255*r).toString(16).toUpperCase())&&(a+=r),a}},{key:"_colorToHSV",value:function(e){var a=this;if(a._isValidColor(e)){e=a._toRGBA(e).replace(/\s/g,"");var t=/rgba\((\d*.\d+|\d+),(\d*.\d+|\d+),(\d*.\d+|\d+)\,(\d*.\d+|\d+)\)/gi.exec(e),l=Math.min(255,Math.max(0,parseFloat(t[1])))/255,r=Math.min(255,Math.max(0,parseFloat(t[2])))/255,o=Math.min(255,Math.max(0,parseFloat(t[3])))/255,n={h:0,s:0,v:0},i=0,s=0;if(l>=r&&l>=o?(s=l,i=r>o?o:r):r>=o&&r>=l?(s=r,i=l>o?o:l):(s=o,i=r>l?l:r),n.v=s,n.s=s?(s-i)/s:0,n.s){var d=s-i;n.h=l===s?(r-o)/d:r===s?2+(o-l)/d:4+(l-r)/d,n.h=60*n.h,n.h<0&&(n.h+=360)}else n.h=a._HSV.h?a._HSV.h:0;return n.s=parseFloat(n.s),n.v=parseFloat(n.v),n}}},{key:"_HSVtoRGBA",value:function(e,a){e=e||{h:0,s:0,v:0};var t=this,l=e&&e.h>=0?e.h:t._HSV.h,r=e&&e.s>=0?e.s:t._HSV.s,o=e&&e.v>=0?e.v:t._HSV.v,n=o*r,i=l/60,s=n*(1-Math.abs(i%2-1)),d=void 0,u=void 0,c=void 0;i>=0&&i<=1?(d=n,u=s,c=0):i>=1&&i<=2?(d=s,u=n,c=0):i>=2&&i<=3?(d=0,u=n,c=s):i>=3&&i<=4?(d=0,u=s,c=n):i>=4&&i<=5?(d=s,u=0,c=n):i>=5&&i<=6&&(d=n,u=0,c=s);var g=o-n;return"rgba("+Math.round(255*(d+g))+", "+Math.round(255*(u+g))+", "+Math.round(255*(c+g))+", "+(a||t._RGBA.a||0)+")"}},{key:"_HSVRGBArefresh",value:function(e){var a=this;a._HSV=a._getValue("hsv",e)||{h:1,s:0,v:1},a._RGBA=a._getValue("HSVtoRGBAarray",e)}},{key:"_toFixed",value:function(e,a){return parseFloat(parseFloat(e).toFixed(a||2))}},{key:"_validateInRange",value:function(e,a,t){return Math.min(Math.max(parseFloat(e),parseFloat(a)),parseFloat(t))}},{key:"_isHEX",value:function(e){return/(^#[0-9A-F]{3}$)|(^#[0-9A-F]{6}$)|(^#[0-9A-F]{8}$)/i.test(e)}},{key:"_isRGB",value:function(e){return/rgb\((\d{1,3})\s*,\s*(\d{1,3})\s*,\s*(\d{1,3})\)/i.test(e)}},{key:"_isRGBA",value:function(e){return/rgba\((\d*.\d+|\d+)\s*,\s*(\d*.\d+|\d+)\s*,\s*(\d*.\d+|\d+)\s*,\s*(\d*.\d+|\d+)\)/i.test(e)}},{key:"_isValidColorName",value:function(e){return!(!e||void 0===this._cssColorNamesHEX[e.trim().toLowerCase()])}},{key:"_isValidColor",value:function(e){return this._isHEX(e)||this._isRGB(e)||this._isRGBA(e)||this._isValidColorName(e)}},{key:"_getRGBAFromInputs",value:function(){return{r:parseInt(this.$.rChannelInput.value),g:parseInt(this.$.gChannelInput.value),b:parseInt(this.$.bChannelInput.value),a:this.$.aChannelInput.value}}},{key:"_setRGBAToInputs",value:function(){var e=this;Object.entries(e._RGBA).forEach(function(a){return e.$[a[0]+"ChannelInput"].value=e._RGBA[a[0]]})}},{key:"_calcHueAngle",value:function(e,a){return 180*Math.atan2(a,e)/Math.PI}},{key:"_calcSatDistance",value:function(e,a){return Math.sqrt(Math.pow(e,2)+Math.pow(a,2))}}],[{key:"properties",get:function(){return{applyValueMode:{value:"instantly",allowedValues:["instantly","useButtons"],type:"string"},columnCount:{value:8,type:"number"},gridThemeColors:{value:null,type:"array?",reflectToAttribute:!1},gridShadeColors:{value:null,type:"array?",reflectToAttribute:!1},gridStandardColors:{value:null,type:"array?",reflectToAttribute:!1},paletteColors:{value:null,type:"array?",reflectToAttribute:!1},paletteCustomColors:{value:null,type:"array?",reflectToAttribute:!1},displayMode:{value:"default",allowedValues:["default","grid","palette","radial","hexagonal","spectrumGrid","materialGrid"],type:"string"},editAlphaChannel:{value:!1,type:"boolean"},enableCustomColors:{value:!1,type:"boolean"},disableUndo:{value:!1,type:"boolean"},hideAlphaEditor:{value:!1,type:"boolean"},hideContentToFit:{value:["RGB","HEX","alpha","previewContainer"],type:"array"},hideHEXEditor:{value:!1,type:"boolean"},hidePreviewContainer:{value:!1,type:"boolean"},hideRGBEditor:{value:!1,type:"boolean"},inverted:{value:!1,type:"boolean"},messages:{value:{en:{redPrefix:"R:",greenPrefix:"G:",bluePrefix:"B:",hexPrefix:"#:",alphaPrefix:"Alpha:",ok:"OK",cancel:"CANCEL",customColor:"CUSTOM COLOR",standardColors:"Standard colors",themeColors:"Theme colors"}},type:"object",extend:!0},name:{value:"",type:"string"},palette:{value:"default",allowedValues:["default","gray","red","green","blue","custom"],type:"string"},tooltipDisplayMode:{value:"hex",allowedValues:["none","rgba","rgb","hex"],type:"string"},value:{value:null,type:"string?"},valueFormat:{value:"default",allowedValues:["rgb","rgba","hex","hsv","default"],type:"string"},valueMember:{value:"value",type:"string?"}}}},{key:"listeners",get:function(){return{"container.click":"_containerClickHandler","container.mouseover":"_handleGridModeCellHover","paletteModeContainer.down":"_paletteDownHandler","container.change":"_handleInputChange","document.move":"_moveThumbHandler","document.up":"_releaseThumbUpHandler","paletteModeContainer.wheel":"_inputWheelHandler",resize:"_hideControlsByPriority","hexModeResizeTrigger.resize":"_resizeHoneycombItems","paletteModeContainer.move":"_trackMoveHandler"}}},{key:"requires",get:function(){return{"JQX.Utilities.Draw":"jqxdraw.js","JQX.Button":"jqxbutton.js","JQX.Tooltip":"jqxtooltip.js"}}}]),a}(JQX.BaseElement));
//# sourceMappingURL=jqxcolorpanel.js.map

"use strict";JQX("jqx-color-picker",function(e){function l(){return babelHelpers.classCallCheck(this,l),babelHelpers.possibleConstructorReturn(this,(l.__proto__||Object.getPrototypeOf(l)).apply(this,arguments))}return babelHelpers.inherits(l,e),babelHelpers.createClass(l,[{key:"template",value:function(){return'<div id="container">\n                    <span class="jqx-label" id="label">[[label]]</span>\n                    <div id="content" class="jqx-content">\n                        <div id="buttonsContainer" class ="jqx-buttons-container">\n                            <div id="actionButton" class ="jqx-input jqx-action-button">\n                                <div id="colorSampleContainer" class="color-picker-sample-container">\n                                    <div id="colorSample" class="color-picker-sample"></div>\n                                </div>\n                                <input type="text" id="input" class ="color-picker-action-input" placeholder="[[placeholder]]"/>\n                            </div>\n                            <span id="dropDownButton" class ="jqx-drop-down-button">\n                                <span id="arrow"></span>\n                            </span>\n                        </div>\n                        <div id="dropDownContainer" class ="jqx-drop-down jqx-drop-down-color-picker jqx-drop-down-container jqx-visibility-hidden">\n                            <jqx-scroll-viewer id="scrollViewer"\n                                right-to-left="[[right-to-left]]" \n                                horizontal-scroll-bar-visibility="[[horizontalScrollBarVisibility]]"\n                                vertical-scroll-bar-visibility="[[verticalScrollBarVisibility]]">\n                                    <jqx-color-panel id="colorPanel"></jqx-color-panel>\n                            </jqx-scroll-viewer>\n                            <div id="resizeBar" class="jqx-drop-down-resize-bar">\n                                <div></div>\n                            </div>\n                         </div>\n                    </div>\n                    <span class="jqx-hint" id="hint">[[hint]]</span>\n                </div>'}},{key:"propertyChangedHandler",value:function(e,o,a){var t=this;switch(t._bindProperties(e),e){case"editable":case"disabled":case"readonly":t.$.input.readOnly=t.disabled||t.readonly||!t.editable;break;case"value":t.$.colorPanel._isValidColor(t.value)&&t._applyValue(t.value);break;default:babelHelpers.get(l.prototype.__proto__||Object.getPrototypeOf(l.prototype),"propertyChangedHandler",this).call(this,e,o,a)}}},{key:"_createElement",value:function(){var e=this;e._bindProperties(),e.$.input.readOnly=e.disabled||e.readonly||!e.editable,e._applyValue(e.$.colorPanel.value),e._setFocusable()}},{key:"_colorPanelChangeHandler",value:function(e){var l=this;l._applyValue(e.detail.value),l.dropDownAppendTo&&l.dropDownAppendTo.length>0&&l.$.fireEvent("change",e.detail)}},{key:"_cancelButtonHandler",value:function(){var e=this;e.$.colorPanel.$.container.className.indexOf("custom-color-selection")>-1||e.close()}},{key:"_okButtonHandler",value:function(){var e=this;e._applyValue(e.$.colorPanel.value),e.close()}},{key:"_setFocusable",value:function(){var e=this;if(!e.disabled&&!e.unfocusable){var l=e.tabIndex>0?e.tabIndex:0;return e.$.input.tabIndex=l,void("dropDownButton"===e.dropDownOpenMode?e.$.dropDownButton.setAttribute("tabindex",l):e.$.dropDownButton.removeAttribute("tabindex"))}e.$.input.tabIndex=-1,e.$.dropDownButton.removeAttribute("tabindex")}},{key:"_bindProperties",value:function(e){var l=this,o=["columnCount","gridThemeColors","gridShadeColors","gridStandardColors","paletteCustomColors","name","hideContentToFit","applyValueMode","inverted","paletteColors","displayMode","tooltipDisplayMode","editAlphaChannel","enableCustomColors","hidePreviewContainer","hideRGBEditor","hideHEXEditor","hideAlphaEditor","hideContentToFit","messages","theme","animation","theme","locale","palette","valueMember","disabled","valueFormat"];if(e)return(o.indexOf(e)>-1||"value"===e)&&(l.$.colorPanel[e]=l[e]),void l.$.scrollViewer.refresh();o.forEach(function(e){return l.$.colorPanel[e]=l[e]}),l.$.colorPanel._isValidColor(l.value)&&l._applyValue(l.value)}},{key:"_inputChangeHandler",value:function(){var e=this;event.preventDefault(),event.stopPropagation(),e.value=e.$.colorPanel.value=e.$.input.value}},{key:"_applyValue",value:function(e){var l=this;l.value=l.$.colorPanel.value=l.$.colorSample.style.backgroundColor=l.$.input.value=e,l.value?l.$colorSampleContainer.removeClass("no-color"):l.$colorSampleContainer.addClass("no-color")}},{key:"_keyDownHandler",value:function(e){var l=this,o=document.activeElement;if(!(l.disabled||l.readonly||o!==l&&o!==l.$.dropDownButton&&o!==l.$.input))switch(e.key){case"Enter":case" ":e.target!==l.$.input?l.opened&&"Enter"===e.key?(e.preventDefault(),l.close()):l.opened||l.readonly||"none"===l.dropDownOpenMode||(e.preventDefault(),l.open()):"Enter"===e.key&&(e.preventDefault(),l.$.colorPanel.value=l.$.input.value);break;case"End":l.$.scrollViewer.scrollTop=l.$.scrollViewer.scrollHeight;break;case"Home":l.$.scrollViewer.scrollTop=0;break;case"PageUp":case"PageDown":l.$.scrollViewer.scrollTop+=(e.key.indexOf("Down")>-1?1:-1)*l.$.dropDownContainer.offsetHeight;break;case"ArrowUp":case"ArrowDown":if(e.altKey)return void(l.disabled||l.readonly||"none"===l.dropDownOpenMode||(l.$dropDownContainer.hasClass("jqx-visibility-hidden")?l.open():l.close()));e.preventDefault();break;case"Escape":e.preventDefault(),l.close()}}}],[{key:"properties",get:function(){return{editable:{value:!1,type:"boolean"},applyValueMode:{value:"instantly",allowedValues:["instantly","useButtons"],type:"string"},columnCount:{value:8,type:"number"},gridThemeColors:{value:null,type:"array?",reflectToAttribute:!1},gridShadeColors:{value:null,type:"array?",reflectToAttribute:!1},gridStandardColors:{value:null,type:"array?",reflectToAttribute:!1},paletteColors:{value:null,type:"array?",reflectToAttribute:!1},paletteCustomColors:{value:null,type:"array?",reflectToAttribute:!1},disableUndo:{value:!1,type:"boolean"},displayMode:{value:"default",allowedValues:["default","grid","palette","radial","hexagonal","spectrumGrid","materialGrid"],type:"string"},dropDownAppendTo:{value:null,type:"any"},dropDownHeight:{value:"auto",type:"string"},dropDownWidth:{value:"auto",type:"string"},editAlphaChannel:{value:!1,type:"boolean"},enableCustomColors:{value:!1,type:"boolean"},hidePreviewContainer:{value:!1,type:"boolean"},hideRGBEditor:{value:!1,type:"boolean"},hideHEXEditor:{value:!1,type:"boolean"},hideAlphaEditor:{value:!1,type:"boolean"},messages:{value:{en:{redPrefix:"R:",greenPrefix:"G:",bluePrefix:"B:",hexPrefix:"#:",alphaPrefix:"Alpha:",ok:"OK",cancel:"CANCEL",customColor:"CUSTOM COLOR",standardColors:"Standard colors",themeColors:"Theme colors"}},type:"object",extend:!0},name:{value:"",type:"string"},palette:{value:"default",allowedValues:["default","gray","red","green","blue","custom"],type:"string"},placeholder:{value:"Please Select Color",type:"string"},tooltipDisplayMode:{value:"hex",allowedValues:["none","rgba","rgb","hex"],type:"string"},value:{value:null,type:"string?"},valueDisplayMode:{value:"default",allowedValues:["default","colorBox","colorCode","none"],type:"string"},valueFormat:{value:"default",allowedValues:["default","rgb","rgba","hex"],type:"string"},inverted:{value:!1,type:"boolean"},hideContentToFit:{value:["RGB","HEX","alpha","previewContainer"],type:"array"}}}},{key:"listeners",get:function(){return{"input.change":"_inputChangeHandler","input.focus":"_focusEventHandler","input.blur":"_blurEventHandler","colorPanel.cancelButtonClick":"_cancelButtonHandler","colorPanel.okButtonClick":"_okButtonHandler","colorPanel.change":"_colorPanelChangeHandler",keydown:"_keyDownHandler"}}},{key:"requires",get:function(){return{"JQX.ColorPanel":"jqxcolorpanel.js","JQX.DropDownButton":"jqxdropdownbutton.js"}}}]),l}(JQX.DropDownButton));
//# sourceMappingURL=jqxcolorpicker.js.map

"use strict";!function(){var e=function(e){function t(){return babelHelpers.classCallCheck(this,t),babelHelpers.possibleConstructorReturn(this,(t.__proto__||Object.getPrototypeOf(t)).apply(this,arguments))}return babelHelpers.inherits(t,e),babelHelpers.createClass(t,[{key:"findGraph",value:function(){return document.querySelector("ni-cartesian-graph[graph-ref='"+this.graphRef+"']")||document.querySelector("ni-chart[graph-ref='"+this.graphRef+"']")||document.querySelector("ni-intensity-graph[graph-ref='"+this.graphRef+"']")||document.querySelector("ni-cartesian-graph[ni-control-id='"+this.graphRef+"']")||document.querySelector("ni-chart[ni-control-id='"+this.graphRef+"']")||document.querySelector("ni-intensity-graph[ni-control-id='"+this.graphRef+"']")}},{key:"isDisabledOrInEditMode",value:function(){return this.disabled||this.isInEditMode}},{key:"template",value:function(){return""}}],[{key:"properties",get:function(){return Object.assign({},babelHelpers.get(t.__proto__||Object.getPrototypeOf(t),"properties",this),{graphRef:{value:"",type:"string"},isInEditMode:{value:!1,type:"boolean"}})}}]),t}(window.JQX.BaseElement);NationalInstruments.HtmlVI.Elements.GraphLegend=e}(),function(){var e=NationalInstruments.HtmlVI.NISupport;NationalInstruments.HtmlVI.Elements.LegendHelpers=function(e,t){this.helpers=e,this.legendItemDisplay=t};var t=NationalInstruments.HtmlVI.Elements.LegendHelpers,i=t.prototype;i.createJQXButton=function(e){var t=arguments.length>1&&void 0!==arguments[1]&&arguments[1],i=document.createElement(t?"jqx-toggle-button":"jqx-button");return i.className=e,i.animation="none",i.unfocusable=!0,i},i.addButtons=function(e,t,i){var n,s,a=this;e.children.forEach(function(e){n=a.createJQXButton("ni-button",!0),n.checked=!1,""!==e.cssClass&&n.classList.add(e.cssClass),n.addEventListener("change",function(){if(s===this)return void(this.checked=!0);if(this.checked){var t=s;s=this,t.checked=!1,a.helpers.handleClick(e.name,null,i),a.legendItemDisplay.updateShape(i)}});var l=a.helpers.getState(e.name,i);void 0!==l&&(n.checked=l,!0===l&&(s=n)),t.appendChild(n)})},i.addComboBox=function(t,i,n,s,a){var l,r,o=this,d=0,c=!0,h=document.createElement("jqx-drop-down-list");for(i.appendChild(h),i.appendChild(h),h.itemHeight=32,h.dropDownHeight="auto",(l=h.classList).add.apply(l,babelHelpers.toConsumableArray(a.split(" "))),r=0;r<t.children.length;r++){var p=e.i18n(t.children[r].tag);"[msg_"===p.substring(0,5)&&(p=t.name);var u='<label class="ni-selector-title">'+p+'</label><icon class="ni-selector-icon '+t.children[r].cssClass+'" style="background-size: '+s+"px 16px; width: "+(s+4)+'px; "></icon>';h.insert(r,u);!0===this.helpers.getState(t.children[r].name,n)&&(d=r)}h.addEventListener("change",function(e){!0!==c&&(o.helpers.handleClick(t.children[e.detail.index].name,null,n),o.legendItemDisplay.updateShape(n))}),h.selectedIndexes=[d],c=!1},i.addColorBox=function(e,t,i,n){var s,a=this,l=document.createElement("jqx-color-picker");l.style.width="inherit",l.displayMode="palette",l.valueFormat="hex",l.hidePreviewContainer=!0,l.classList.add("legend-colorbox-colorbox"),(s=l.classList).add.apply(s,babelHelpers.toConsumableArray(n.split(" "))),t.appendChild(l);var r=a.helpers.getState(e.name,i);l.value=r||"",l.addEventListener("change",function(){a.helpers.handleClick(e.name,l.value,i),a.legendItemDisplay.updateShape(i)})},i.addCheckBox=function(e,t,i,n){var s=this,a=document.createElement("jqx-check-box");a.animation="none",a.unfocusable=!0,a.className=n,a.classList.add("legend-checkbox"),a.addEventListener("change",function(t){s.helpers.handleClick(e.name,t.detail.value,i)}),t.appendChild(a);var l=s.helpers.getState(e.name,i);void 0!==l&&(a.checked=l)}}(),function(){var e=function(e){function t(){return babelHelpers.classCallCheck(this,t),babelHelpers.possibleConstructorReturn(this,(t.__proto__||Object.getPrototypeOf(t)).apply(this,arguments))}return babelHelpers.inherits(t,e),babelHelpers.createClass(t,[{key:"findGraph",value:function(){return document.querySelector("ni-cartesian-graph[graph-ref='"+this.graphRef+"']")||document.querySelector("ni-chart[graph-ref='"+this.graphRef+"']")}},{key:"propertyChangedHandler",value:function(e,i,n){babelHelpers.get(t.prototype.__proto__||Object.getPrototypeOf(t.prototype),"propertyChangedHandler",this).call(this,e,i,n);var s=this.findGraph();switch(e){case"position":case"show":for(;this.hasChildNodes();)this.removeChild(this.firstChild)}s&&s.updateGraphConfig()}}],[{key:"properties",get:function(){return Object.assign({},babelHelpers.get(t.__proto__||Object.getPrototypeOf(t),"properties",this),{show:{value:!1,type:"boolean"},graphRef:{value:"",type:"string"},position:{value:"container",type:"string"}})}}]),t}(window.JQX.BaseElement);JQX("ni-light-plot-legend",e)}();var NILightLegendModule=function(){function e(){babelHelpers.classCallCheck(this,e)}return babelHelpers.createClass(e,[{key:"getSettings",value:function(){var e=this.ownerElement.getSettingsWorkaround(),t=this.findLegend(this.ownerElement.graphRef);if(!t)return e;var i={show:t.show,container:function(e){var t=null;return"nw"!==e.position&&"ne"!==e.position&&"sw"!==e.position&&"se"!==e.position&&(e.hasChildNodes()?t=e.lastChild:(t=document.createElement("div"),e.appendChild(t))),t}(t),position:t.position,margin:5};return e.legend=i,e}},{key:"findLegend",value:function(e){return document.querySelector("ni-light-plot-legend[graph-ref='"+e+"']")}}],[{key:"moduleName",get:function(){return"NILightLegendModule"}}]),e}();JQX.Elements.whenRegistered("ni-cartesian-graph",function(e){e.addModule(NILightLegendModule)}),JQX.Elements.whenRegistered("ni-chart",function(e){e.addModule(NILightLegendModule)}),function(){var e=NationalInstruments.HtmlVI.NISupport,t=NationalInstruments.Globals.jQuery,i=function(e){e.createRow(e.expanderWrapper,e.nPlots),e.helpers.addRenderer(e.nPlots),e.nPlots++},n=function(e,t){e.removeRow(e.expanderWrapper,t),e.helpers.clearRenderer(t),e.nPlots--},s=function(s){function a(){return babelHelpers.classCallCheck(this,a),babelHelpers.possibleConstructorReturn(this,(a.__proto__||Object.getPrototypeOf(a)).apply(this,arguments))}return babelHelpers.inherits(a,s),babelHelpers.createClass(a,[{key:"created",value:function(){babelHelpers.get(a.prototype.__proto__||Object.getPrototypeOf(a.prototype),"created",this).call(this),this.expanderWrapper=void 0,this.nPlots=0,this.helpers=new NationalInstruments.HtmlVI.Elements.PlotLegendHelpers,this.plotLegendItemDisplay=new NationalInstruments.HtmlVI.Elements.PlotLegendItemDisplay(this.helpers),this.uihelpers=new NationalInstruments.HtmlVI.Elements.LegendHelpers(this.helpers,this.plotLegendItemDisplay),this.deferLegendUpdates=!1}},{key:"plotAdded",value:function(){this.deferLegendUpdates||i(this)}},{key:"plotRemoved",value:function(e){this.deferLegendUpdates||n(this,e)}},{key:"syncPlotLegendWithGraph",value:function(){if(this.deferLegendUpdates){var e=this.findGraph();if(!e)return;for(var t=e.plots.length;t<this.nPlots;){var s=this.nPlots-1;n(this,s)}for(;t>this.nPlots;)i(this)}}},{key:"createRows",value:function(){var e;for(e=0;e<this.nPlots;e++)this.createRow(this.expanderWrapper,e)}},{key:"removeRows",value:function(){var e;for(e=this.nPlots-1;e>=0;e--)this.removeRow(this.expanderWrapper,e)}},{key:"throttlePlotUpdates",value:function(e){var t=this.findGraph();null!==t&&(t.throttlePlotUpdates(e),this.deferLegendUpdates=e)}},{key:"attachToGraph",value:function(e){this.detachFromGraph(),e&&e.isReady&&(this.helpers.graph=e,this.nPlots=e.plots.length,this.createRows(),e.registerPlotLegend(this))}},{key:"detachFromGraph",value:function(){this.helpers.clearCache(),this.helpers.graph=null,this.removeRows(),this.nPlots=0}},{key:"attached",value:function(){var e,t,s=this;babelHelpers.get(a.prototype.__proto__||Object.getPrototypeOf(a.prototype),"attached",this).call(this),this.helpers.graph=this.findGraph(),this.helpers.isInEditMode=this.isInEditMode,e=document.createElement("div"),e.style.width="100%",e.style.height="100%",this.appendChild(e),t=document.createElement("jqx-accordion"),t.style.width="100%",t.style.height="100%",t.animation="none","full"===this.mode?t.expandMode="toggle":t.expandMode="none",t.disabled=this.isDisabledOrInEditMode(),e.appendChild(t),this.expanderWrapper=t,this.addEventListener("ni-cartesian-plot-attached",function(){s.plotAdded(),s.helpers.clearCache()}),this.addEventListener("ni-cartesian-plot-detached",function(e){var t,i=e.detail.originalSource;t=s.helpers.getIndex(i),s.plotRemoved(t),s.helpers.clearCache()}),this.addEventListener("ni-cartesian-plot-changed",function(e){var t,i=e.detail.originalSource;t=s.helpers.getIndex(i),s.updatePlotName(t,s.helpers.getPlotName(t))}),this.addEventListener("ni-cartesian-plot-renderer-changed",function(e){var t,i=e.detail.originalSource;t=s.helpers.rendererToIndex(i),s.plotLegendItemDisplay.updateShape(t)}),this.addEventListener("ni-cartesian-plot-renderer-attached",function(e){var t,i=e.detail.originalSource;s.helpers.clearCache(),t=s.helpers.rendererToIndex(i),s.plotLegendItemDisplay.updateShape(t)}),this.addEventListener("ni-cartesian-plot-renderer-detached",function(e){var t,i=e.detail.originalSource;s.helpers.clearCache(),t=s.helpers.rendererToIndex(i),s.plotLegendItemDisplay.updateShape(t)}),this.addEventListener("ni-plot-count-changed",function(e){var t=e.detail.originalSource;if("compact"===s.mode){for(;t.plotCount<s.nPlots;){var a=s.nPlots-1;n(s,a)}for(;t.plotCount>s.nPlots;)i(s)}});var l=this.findGraph();null!==l&&this.attachToGraph(l)}},{key:"createRow",value:function(e,t){var i,n,s,a,l,r,o,d=this;i=document.createElement("jqx-accordion-item"),i.animation="none",i.id="expander"+t,i.className="ni-plot-legend-box",e.appendChild(i),n=document.createElement("div"),n.id="header"+t,n.className="ni-master-row",i.querySelector(".jqx-label").appendChild(n),a=document.createElement("div"),a.className="ni-plot-display",n.appendChild(a),this.plotLegendItemDisplay.createHeaderDisplay(a,t),this.plotLegendItemDisplay.updateShape(t),o=document.createElement("span"),o.className="ni-plot-title",l=this.helpers.getPlotName(t),"compact"===this.mode&&(this.helpers.getPlot(t)||(l="Plot "+(t+1))),this.tooltips&&(o.title=l),r=document.createTextNode(l),o.appendChild(r),n.appendChild(o),s=document.createElement("div"),s.id="content"+t,s.className="ni-details-box",i.querySelector(".jqx-content-container").appendChild(s),"full"===this.mode&&(i.expanded=!1,d.loadContent(s,t)),this.applyFont()}},{key:"updatePlotName",value:function(e,i){var n=t(this.expanderWrapper).find(".ni-plot-title");t(n[e]).text(i)}},{key:"loadContent",value:function(t,i){var n,s,a,l,r,o,d;for(n=document.createElement("table"),n.className="ni-details",t.appendChild(n),a=0;a<this.helpers.menu.length;a++){var c=this.helpers.menu[a];s=document.createElement("tr"),s.className="ni-details-row "+(c.cssClass||""),n.appendChild(s),o=document.createElement("td"),o.className="ni-detail-row-title-box",s.appendChild(o),l=document.createElement("span"),l.className="ni-detail-row-title",o.appendChild(l);var h=e.i18n(c.tag);switch("[msg_"===h.substring(0,5)&&(h=c.name+"!"),r=document.createTextNode(h),l.appendChild(r),d=document.createElement("td"),d.className="ni-details-row-operations-box",s.appendChild(d),c.type){case"buttons":this.uihelpers.addButtons(c,d,i);break;case"combobox":this.uihelpers.addComboBox(c,d,i,24,"ni-selector");break;case"colorbox":this.uihelpers.addColorBox(c,d,i,"ni-colorbox-selector ni-selector");break;case"checkbox":this.uihelpers.addCheckBox(c,d,i,"ni-hover-box")}}}},{key:"removeRow",value:function(e,t){this.plotLegendItemDisplay.removeHeaderDisplay(null,t),e.remove(t)}},{key:"setFont",value:function(e,i,n,s,a){var l=this.firstElementChild,r=t(this),o=t(l).find(" .jqx-widget-content"),d=t(l).find(" .ni-plot-title"),c=t(l).find(" .ni-detail-row-title");r.css({"font-size":e,"font-family":i,"font-weight":n,"font-style":s}),o.css({"font-size":e,"font-family":i,"font-weight":n,"font-style":s}),d.css({"font-size":e,"font-family":i,"font-weight":n,"font-style":s}),c.css({"font-size":e,"font-family":i,"font-weight":n,"font-style":s})}},{key:"applyFont",value:function(){var e=this.firstElementChild,i=t(e).find(" .jqx-widget-content"),n=t(e).find(" .ni-plot-title"),s=t(e).find(" .ni-detail-row-title"),a=t(this).css("font-size"),l=t(this).css("font-family"),r=t(this).css("font-weight"),o=t(this).css("font-style");i.css({"font-size":a,"font-family":l,"font-weight":r,"font-style":o}),n.css({"font-size":a,"font-family":l,"font-weight":r,"font-style":o}),s.css({"font-size":a,"font-family":l,"font-weight":r,"font-style":o})}},{key:"propertyChangedHandler",value:function(e,i,n){babelHelpers.get(a.prototype.__proto__||Object.getPrototypeOf(a.prototype),"propertyChangedHandler",this).call(this,e,i,n);var s=this;switch(e){case"graphRef":this.helpers.graph.plotLegend=null;var l=this.findGraph();this.attachToGraph(l);break;case"disabled":case"isInEditMode":this.helpers.isInEditMode=this.isInEditMode,t(this.expanderWrapper)[0].disabled=this.isDisabledOrInEditMode(),t(this.expanderWrapper).find(".ni-details-box").each(function(){t(this).find(".ni-button").each(function(){this.disabled=s.isDisabledOrInEditMode()}),t(this).find(".ni-selector").each(function(){this.disabled=s.isDisabledOrInEditMode()}),t(this).find(".ni-colorbox-selector").each(function(){this.disabled=s.isDisabledOrInEditMode()}),t(this).find(".ni-hover-box").each(function(){this.disabled=s.isDisabledOrInEditMode()})});break;case"tooltips":t(this).find(".ni-plot-title").each(function(e,t){t.title=this.tooltips?this.helpers.getPlotName(e):""}.bind(this))}}}],[{key:"properties",get:function(){return Object.assign({},babelHelpers.get(a.__proto__||Object.getPrototypeOf(a),"properties",this),{mode:{value:"full",type:"string"},tooltips:{value:!1,type:"boolean"}})}}]),a}(NationalInstruments.HtmlVI.Elements.GraphLegend);JQX("ni-plot-legend",s)}(),function(){var e=NationalInstruments.HtmlVI.NISupport;NationalInstruments.HtmlVI.Elements.PlotLegendHelpers=function(){this.graph=null,this.isInEditMode=!1,this.defaultPlotColors=window.JQX.CartesianGraph.defaultPlotColors,this.lineStyleValues={dot:"1, 2",dashdot:"3, 3, 1, 3",mediumdash:"3, 3",largedash:"5, 4",solid:"0"},this.renderers=[]};var t=NationalInstruments.HtmlVI.Elements.PlotLegendHelpers,i=t.prototype;i.menu=[{name:"Plot Style",tag:"msg_plotstyle",type:"buttons",children:[{name:"Line",tag:"msg_line",cssClass:"ni-line-style-icon"},{name:"Point",tag:"msg_point",cssClass:"ni-point-style-icon"},{name:"Line & Point",tag:"msg_lineandpoint",cssClass:"ni-line-and-point-style-icon"},{name:"Bar",tag:"msg_bar",cssClass:"ni-bar-style-icon"},{name:"Fill",tag:"msg_fill",cssClass:"ni-fill-style-icon"}]},{name:"Point Style",tag:"msg_pointstyle",type:"buttons",children:[{name:"Ellipse",tag:"msg_ellipse",cssClass:"ni-ellipse-point-style-icon"},{name:"Rectangle",tag:"msg_rectangle",cssClass:"ni-rect-point-style-icon"},{name:"Diamond",tag:"msg_diamond",cssClass:"ni-diamond-point-style-icon"},{name:"Cross",tag:"msg_cross",cssClass:"ni-cross-point-style-icon"},{name:"Plus",tag:"msg_plus",cssClass:"ni-plus-point-style-icon"}]},{name:"Line Width",tag:"msg_linewidth",cssClass:"line_width",type:"combobox",children:[{name:"No line",tag:"msg_noline",cssClass:""},{name:"1-pixel",tag:"msg_1pixel",cssClass:"ni-1-pixel-line-width-icon"},{name:"2-pixels",tag:"msg_2pixels",cssClass:"ni-2-pixels-line-width-icon"},{name:"3-pixels",tag:"msg_3pixels",cssClass:"ni-3-pixels-line-width-icon"},{name:"4-pixels",tag:"msg_4pixels",cssClass:"ni-4-pixels-line-width-icon"},{name:"5-pixels",tag:"msg_5pixels",cssClass:"ni-5-pixels-line-width-icon"}]},{name:"Line Style",tag:"msg_linestyle",cssClass:"line_style",type:"combobox",children:[{name:"No style",tag:"msg_nostyle",cssClass:""},{name:"Solid",tag:"msg_solid",cssClass:"ni-solid-line-style-icon"},{name:"Dot",tag:"msg_dot",cssClass:"ni-dot-line-style-icon"},{name:"Dot-dash",tag:"msg_dashdot",cssClass:"ni-dot-dash-line-style-icon"},{name:"Medium dash",tag:"msg_mediumdash",cssClass:"ni-medium-dash-line-style-icon"},{name:"Large dash",tag:"msg_largedash",cssClass:"ni-large-dash-line-style-icon"}]},{name:"Fill Baseline",tag:"msg_fillbaseline",type:"buttons",children:[{name:"Zero",tag:"msg_zero",cssClass:"ni-fill-to-zero-style-icon"},{name:"-Inf",tag:"msg_neginf",cssClass:"ni-fill-base-line-negative-infinity-icon"},{name:"Inf",tag:"msg_inf",cssClass:"ni-fill-base-line-positive-infinity-icon"}]},{name:"Color",tag:"msg_color",type:"colorbox",children:[]},{name:"Hover",tag:"msg_hover",cssClass:"hover",type:"checkbox",children:[]}],i.addRenderer=function(){},i.clearRenderer=function(e){this.renderers[e]=null},i.clearCache=function(){for(var e=0;e<this.renderers.length;e++)this.renderers[e]=null},i.getPlot=function(e){var i=0,n=null,s=this.graph;if(null!==s)for(t in s.childNodes)if("ni-cartesian-plot"===s.childNodes[t].localName){if(i===e){n=s.childNodes[t];break}i++}return n},i.getIndex=function(e){var t,i;return i=e._parentGraph,null!==i&&(t=i.plots.indexOf(e)),t},i.getPlotName=function(t){var i=this.getPlot(t);return i&&"string"==typeof i.label?i.label:e.i18n("msg_defaultplotname")},i.getRenderer=function(e){var t=null,i=null;if(null===this.renderers[e]||void 0===this.renderers[e]){if(t=this.getPlot(e),null!==t&&(i=t.lastElementChild),null===i)return null;this.renderers[e]=i}return this.renderers[e]},i.rendererToIndex=function(e){var t,i,n,s=0;if(null!==(i=this.graph))for(n in i.childNodes)if("ni-cartesian-plot"===i.childNodes[n].localName){if(i.childNodes[n].lastElementChild===e){t=s;break}s++}return t},i.handleClick=function(e,t,i){if(!0!==this.isInEditMode){var n,s="",a=this.getRenderer(i);if(null===a)return;switch(""!==a.lineStroke&&(s=a.lineStroke),""!==a.pointColor&&(s=a.pointColor),""!==a.barFill&&(s=a.barFill),""!==a.areaFill&&(s=a.areaFill),e){case"No line":a.lineWidth=0;break;case"1-pixel":a.lineWidth=1;break;case"2-pixels":a.lineWidth=2;break;case"3-pixels":a.lineWidth=3;break;case"4-pixels":a.lineWidth=4;break;case"5-pixels":a.lineWidth=5;break;case"Line":a.lineStroke=s,a.pointColor="",a.barFill="",a.areaFill="";break;case"Point":a.lineStroke="",a.pointColor=s,a.barFill="",a.areaFill="";break;case"Line & Point":a.lineStroke=s,a.pointColor=s,a.barFill="",a.areaFill="";break;case"Bar":a.lineStroke="",a.pointColor="",a.barFill=s,a.areaFill="";break;case"Fill":a.lineStroke="",a.pointColor="",a.barFill="",a.areaFill=s;break;case"Ellipse":a.pointShape="ellipse";break;case"Rectangle":a.pointShape="rectangle";break;case"Diamond":a.pointShape="diamond";break;case"Cross":a.pointShape="cross";break;case"Plus":a.pointShape="plus";break;case"No style":a.lineStyle="";break;case"Solid":a.lineStyle="solid";break;case"Dot":a.lineStyle="dot";break;case"Dot-dash":a.lineStyle="dashdot";break;case"Medium dash":a.lineStyle="mediumdash";break;case"Large dash":a.lineStyle="largedash";break;case"Zero":a.areaBaseLine="zero",a.barBaseLine="zero";break;case"-Inf":a.areaBaseLine="negativeinfinity",a.barBaseLine="negativeinfinity";break;case"Inf":a.areaBaseLine="positiveinfinity",a.barBaseLine="positiveinfinity";break;case"Color":""!==a.lineStroke&&(a.lineStroke=t),""!==a.pointColor?a.pointColor=t:""!==a.barFill?a.barFill=t:""!==a.areaFill&&(a.areaFill=t);break;case"Hover":n=this.getPlot(i),n.enableHover=t}}},i.getState=function(e,t){var i,n=this.getRenderer(t);if(null!==n){var s;switch(e){case"No line":s=0===n.lineWidth;break;case"1-pixel":s=1===n.lineWidth;break;case"2-pixels":s=2===n.lineWidth;break;case"3-pixels":s=3===n.lineWidth;break;case"4-pixels":s=4===n.lineWidth;break;case"5-pixels":s=5===n.lineWidth;break;case"Line":s=""!==n.lineStroke&&""===n.pointColor;break;case"Point":s=""===n.lineStroke&&""!==n.pointColor;break;case"Line & Point":s=""!==n.lineStroke&&""!==n.pointColor;break;case"Bar":s=""!==n.barFill;break;case"Fill":s=""!==n.areaFill;break;case"Ellipse":s="ellipse"===n.pointShape;break;case"Rectangle":s="rectangle"===n.pointShape;break;case"Diamond":s="diamond"===n.pointShape;break;case"Cross":s="cross"===n.pointShape;break;case"Plus":s="plus"===n.pointShape;break;case"No style":s=""===n.lineStyle;break;case"Solid":s="solid"===n.lineStyle;break;case"Dot":s="dot"===n.lineStyle;break;case"Dot-dash":s="dashdot"===n.lineStyle;break;case"Medium dash":s="mediumdash"===n.lineStyle;break;case"Large dash":s="largedash"===n.lineStyle;break;case"Zero":s=""!==n.barFill?"zero"===n.barBaseLine||""===n.barBaseLine:"zero"===n.areaBaseLine||""===n.areaBaseLine;break;case"-Inf":s=""!==n.barFill?"negativeinfinity"===n.barBaseLine:"negativeinfinity"===n.areaBaseLine;break;case"Inf":s=""!==n.barFill?"positiveinfinity"===n.barBaseLine:"positiveinfinity"===n.areaBaseLine;break;case"Color":s=this.getPlotColorFromRenderer(n);break;case"Hover":i=this.getPlot(t),s=i.enableHover}return s}},i.getPlotColor=function(e){var t=this.getRenderer(e);return null!==t?this.getPlotColorFromRenderer(t):this.defaultPlotColors[e%this.defaultPlotColors.length]},i.getPlotColorFromRenderer=function(e){var t="rgba(0, 0, 0, 1)";return""!==e.lineStroke?t=e.lineStroke:""!==e.pointColor?t=e.pointColor:""!==e.barFill?t=e.barFill:""!==e.areaFill&&(t=e.areaFill),t},i.getLineWidth=function(e){var t=this.getRenderer(e);return null!==t?t.lineWidth:1},i.getLineShape=function(e){var t="line",i=this.getRenderer(e);return null!==i&&(""!==i.lineStroke&&""===i.pointColor?t="line":""===i.lineStroke&&""!==i.pointColor?t="points":""!==i.lineStroke&&""!==i.pointColor?t="line & point":""!==i.barFill?t="bar":""!==i.areaFill&&(t="fill")),t},i.getLineStyle=function(e){var t=this.getRenderer(e);if(null!==t)switch(t.lineStyle){case"dot":return this.lineStyleValues.dot;case"dashdot":return this.lineStyleValues.dashdot;case"mediumdash":return this.lineStyleValues.mediumdash;case"largedash":return this.lineStyleValues.largedash;default:return this.lineStyleValues.solid}return"0"},i.getPointShape=function(e){var t=this.getRenderer(e);return null!==t?t.pointShape:"ellipse"}}(),function(){NationalInstruments.HtmlVI.Elements.PlotLegendItemDisplay=function(e){this.pointTypes=[{name:"ellipse",creator:r},{name:"rectangle",creator:o},{name:"diamond",creator:d},{name:"cross",creator:c},{name:"plus",creator:h}],this.lineTypes=[{name:"line",creator:n},{name:"fill",creator:s},{name:"bar",creator:a},{name:"points",creator:l}],this.shapes=[],this.helpers=e};var e=NationalInstruments.HtmlVI.Elements.PlotLegendItemDisplay,t=e.prototype;t.createHeaderDisplay=function(e,t){var n,s;n="http://www.w3.org/2000/svg",s=document.createElementNS(n,"svg"),s.setAttribute("width","16"),s.setAttribute("height","16"),s.setAttribute("viewBox","0,0,16,16"),s.setAttributeNS("http://www.w3.org/2000/xmlns/","xmlns:xlink","http://www.w3.org/1999/xlink"),e.appendChild(s);var a=document.createElementNS(n,"g"),l=this;s.appendChild(a),this.shapes[t]={},this.shapes[t].shapesGroup=a,i(t,a,n,l),a.setAttribute("stroke","rgba(255, 0, 0, 1)")},t.removeHeaderDisplay=function(e,t){this.shapes.splice(t,1)};var i=function(e,t,i,n){var s;for(s=0;s<n.lineTypes.length;s++)n.lineTypes[s].creator(e,t,i,n)},n=function(e,t,i,n){var s=document.createElementNS(i,"polyline");s.setAttribute("points","0,15 5,5 10,10 15,0"),s.setAttribute("fill","none"),s.setAttribute("stroke-width",n.helpers.getLineWidth(e)),s.setAttribute("stroke-dasharray",n.helpers.getLineStyle(e)),t.appendChild(s),n.shapes[e].shapesGroup.line=s},s=function(e,t,i,n){var s=document.createElementNS(i,"polyline");s.setAttribute("points","0,15 5,5 10,10 15,0, 15,15, 0,15"),s.setAttribute("fill",n.helpers.getPlotColor(e)),s.setAttribute("stroke-width",n.helpers.getLineWidth(e)),s.setAttribute("visibility","hidden"),t.appendChild(s),n.shapes[e].shapesGroup.fill=s},a=function(e,t,i,n){var s=document.createElementNS(i,"polyline");s.setAttribute("points","1.5,15.5 1.5,12.5, 4.5,12.5 4.5,15.5 6.5,15.5 6.5,3.5, 9.5,3.5 9.5,15.5 11.5,15.5 11.5,7.5 14.5,7.5 14.5,15.5 1.5,15.5"),s.setAttribute("fill",n.helpers.getPlotColor(e)),s.setAttribute("stroke-width",1),s.setAttribute("visibility","hidden"),t.appendChild(s),n.shapes[e].shapesGroup.bar=s},l=function(e,t,i,n){var s,a,l,r,o=[{x:.5,y:15.5},{x:10.5,y:10.5},{x:5.5,y:5.5},{x:15.5,y:.5}],d=document.createElementNS(i,"g");for(n.shapes[e].shapesGroup.points=d,a=0;a<n.pointTypes.length;a++){for(l=document.createElementNS(i,"g"),s=0;s<4;s++)r=n.pointTypes[a].creator(i,o[s],4),l.appendChild(r);l.setAttribute("fill",n.helpers.getPlotColor(e)),l.setAttribute("stroke-width",1),l.setAttribute("visibility","hidden"),d.appendChild(l),n.shapes[e].shapesGroup.points[n.pointTypes[a].name]=l}t.appendChild(d)},r=function(e,t,i){var n=document.createElementNS(e,"circle");return n.setAttribute("cx",t.x),n.setAttribute("cy",t.y),n.setAttribute("r",i/2),n},o=function(e,t,i){var n=document.createElementNS(e,"rect");return n.setAttribute("x",t.x-i/2),n.setAttribute("y",t.y-i/2),n.setAttribute("width",i),n.setAttribute("height",i),n},d=function(e,t,i){var n=document.createElementNS(e,"path"),s="M"+(t.x-i/2)+","+t.y;return s+=" L"+t.x+","+(t.y-i/2),s+=" L"+(t.x+i/2)+","+t.y,s+=" L"+t.x+","+(t.y+i/2),s+=" Z",n.setAttribute("d",s),n},c=function(e,t,i){var n=document.createElementNS(e,"path"),s="M"+(t.x-i/2)+","+(t.y-i/2);return s+=" L"+(t.x+i/2)+","+(t.y+i/2),s+="M"+(t.x+i/2)+","+(t.y-i/2),s+=" L"+(t.x-i/2)+","+(t.y+i/2),n.setAttribute("d",s),n},h=function(e,t,i){var n=document.createElementNS(e,"path"),s="M"+t.x+","+(t.y-i/2);return s+=" L"+t.x+","+(t.y+i/2),s+="M"+(t.x-i/2)+","+t.y,s+=" L"+(t.x+i/2)+","+t.y,n.setAttribute("d",s),n};t.updateLinesAttributes=function(e,t,i){var n=this.helpers.getLineShape(e);"line"!==n&&"line & point"!==n||(t.line.setAttribute("stroke-width",this.helpers.getLineWidth(e)),t.line.setAttribute("stroke-dasharray",this.helpers.getLineStyle(e))),t.fill.setAttribute("fill",i),t.bar.setAttribute("fill",i);for(var s=0;s<this.pointTypes.length;s++)t.points[this.pointTypes[s].name].setAttribute("fill",i)},t.updatePointVisibility=function(e,t,i){for(var n=this.helpers.getPointShape(e),s=0;s<this.pointTypes.length;s++)n!==this.pointTypes[s].name||"line & point"!==i&&"points"!==i?t.points[this.pointTypes[s].name].setAttribute("visibility","hidden"):t.points[this.pointTypes[s].name].setAttribute("visibility","visible")},t.updateVisibility=function(e,t){for(var i=this.helpers.getLineShape(e),n=0;n<this.lineTypes.length;n++)i===this.lineTypes[n].name?t[this.lineTypes[n].name].setAttribute("visibility","visible"):t[this.lineTypes[n].name].setAttribute("visibility","hidden");"line & point"===i&&(t.line.setAttribute("visibility","visible"),t.points.setAttribute("visibility","visible")),this.updatePointVisibility(e,t,i)},t.updateShape=function(e){var t=this.shapes[e];if(void 0!==t&&null!==t){var i=this.helpers.getPlotColor(e);this.updateLinesAttributes(e,t.shapesGroup,i),this.updateVisibility(e,t.shapesGroup),t.shapesGroup.setAttribute("stroke",i)}}}(),function(){var e=NationalInstruments.Globals.jQuery,t=NationalInstruments.HtmlVI.NISupport,i=function(i){function n(){return babelHelpers.classCallCheck(this,n),babelHelpers.possibleConstructorReturn(this,(n.__proto__||Object.getPrototypeOf(n)).apply(this,arguments))}return babelHelpers.inherits(n,i),babelHelpers.createClass(n,[{key:"created",value:function(){babelHelpers.get(n.prototype.__proto__||Object.getPrototypeOf(n.prototype),"created",this).call(this),this.table=void 0,this.selectedRow=null,this.addButton=null,this.deleteButton=null,this.centerButton=null,this.currentRow=null,this.currentBtn=null,this.observer=null,this.helpers=new NationalInstruments.HtmlVI.Elements.CursorLegendHelpers,this.cursorLegendItemDisplay=new NationalInstruments.HtmlVI.Elements.CursorLegendItemDisplay(this.helpers),this.uihelpers=new NationalInstruments.HtmlVI.Elements.LegendHelpers(this.helpers,this.cursorLegendItemDisplay)}},{key:"cursorAdded",value:function(e){var t=this;t.createRow(t.table,e),t.helpers.cursorAdded(e),t.helpers.cursorPositionChanged(e,function(i){t.updatePosition(e,i)})}},{key:"updatePosition",value:function(e,t){if(e._parentGraph){var i=e.niControlId,n=this.querySelector("#x_"+i),s=this.querySelector("#y_"+i),a=e._parentGraph.graph,l=a.formatCursorPosition(a,e.cursor);null!==n&&(n.innerText=l.xTextValue),null!==s&&(s.innerText=l.yTextValue)}}},{key:"cursorRemoved",value:function(t){var i=this.helpers.getIndex(t);i>=0&&(e(this).find(".ni-master-row").eq(i).remove(),e(this).find(".ni-details-box").eq(i).remove(),this.cursorLegendItemDisplay.clearShape(i),this.helpers.cursorRemoved(t))}},{key:"cursorChanged",value:function(e){this.cursorLegendItemDisplay.updateShape(e),this.updateName(e),this.updateVisible(e)}},{key:"updateName",value:function(t){e("#name_"+t.niControlId).text(this.helpers.getState("name",t))}},{key:"updateVisible",value:function(t){this.helpers.getState("visible",t)?e("#visible_"+t.niControlId).removeClass("ni-visibility-off-icon").addClass("ni-visibility-on-icon"):e("#visible_"+t.niControlId).removeClass("ni-visibility-on-icon").addClass("ni-visibility-off-icon")}},{key:"attachToGraph",value:function(e){this.detachFromGraph(),e&&e.isReady&&(this.helpers.graph=e,e.registerCursorLegend(this))}},{key:"detachFromGraph",value:function(){this.removeRows(),this.helpers.clearCache(),this.helpers.graph=null}},{key:"attached",value:function(){babelHelpers.get(n.prototype.__proto__||Object.getPrototypeOf(n.prototype),"attached",this).call(this);var i=this;i.helpers.graph=i.findGraph(),i.helpers.isInEditMode=i.isInEditMode;var s=document.createElement("div");s.style.width="100%",s.style.height="100%",s.id="div"+t.uniqueId(),i.appendChild(s),i.table=document.createElement("table"),i.table.className="ni-cursors-box",s.appendChild(i.table);var a=document.createElement("div");s.appendChild(a);var l=this.uihelpers.createJQXButton("ni-add-icon ni-command-button",!1);l.disabled=i.isDisabledOrInEditMode(),a.appendChild(l),i.addButton=l,e(l).on("click",function(){i.helpers.addCursor()}),i.addEventListener("ni-cursor-attached",function(e){i.cursorAdded(e.detail.originalSource)}),i.addEventListener("ni-cursor-detached",function(e){i.cursorRemoved(e.detail.originalSource)}),i.addEventListener("ni-cursor-changed",function(e){i.cursorChanged(e.detail.originalSource)});var r=this.findGraph();null!==r&&this.attachToGraph(r)}},{key:"removeRows",value:function(){var e;for(e=this.helpers.cursors.length-1;e>=0;e--){var t=this.helpers.getCursor(e);this.cursorRemoved(t)}}},{key:"createRow",value:function(t,i){var n=this,s=n.createMainRow(t,i),a=n.createDetailsRow(t,i);e(s).on("click",function(){if(n.currentRow!==a){var e=n.currentRow,t=n.currentBtn;a.style.display="table-row",n.currentRow=a,s.classList.remove("ni-closed-icon"),s.classList.add("ni-open-icon"),n.currentBtn=s,null!==e&&(e.style.display="none"),null!==t&&(t.classList.remove("ni-open-icon"),t.classList.add("ni-closed-icon"))}else a.style.display="none",s.classList.remove("ni-open-icon"),s.classList.add("ni-closed-icon"),n.currentRow=null,n.currentBtn=null}),n.applyFont()}},{key:"createMainRow",value:function(t,i){var n,s=this;n=i.niControlId;var a,l,r,o,d,c,h,p,u,m,f,b;return a=document.createElement("tr"),a.className="ni-master-row",t.appendChild(a),l=document.createElement("td"),l.className="ni-expand-box",a.appendChild(l),f=this.uihelpers.createJQXButton("ni-expand-button ni-closed-icon",!1),f.id="details_"+n,l.appendChild(f),f.width=20,f.height=20,f.disabled=s.isDisabledOrInEditMode(),r=document.createElement("td"),r.className="ni-cursor-box",a.appendChild(r),u=s.cursorLegendItemDisplay.createHeaderDisplay(i),null!==u&&(u.id="display_"+n,r.appendChild(u)),h=document.createElement("span"),h.className="ni-cursor-title",h.id="name_"+n,p=document.createTextNode(s.helpers.getState("name",i)),h.appendChild(p),r.appendChild(h),o=document.createElement("td"),o.className="ni-x-box",a.appendChild(o),h=document.createElement("span"),h.className="ni-x-title",h.id="x_"+n,p=document.createTextNode(parseFloat(s.helpers.getState("x",i))),h.appendChild(p),o.appendChild(h),
d=document.createElement("td"),d.className="ni-y-box",a.appendChild(d),h=document.createElement("span"),h.className="ni-y-title",h.id="y_"+n,p=document.createTextNode(parseFloat(s.helpers.getState("y",i))),h.appendChild(p),d.appendChild(h),c=document.createElement("td"),c.className="ni-actions-box",a.appendChild(c),m=this.uihelpers.createJQXButton("ni-delete-icon ni-action-button",!1),m.id="delete"+n,c.appendChild(m),e(m).on("click",function(){s.helpers.handleClick("delete","",i)}),m.disabled=s.isDisabledOrInEditMode(),m=this.uihelpers.createJQXButton("ni-center-icon ni-action-button",!1),m.id="center"+n,c.appendChild(m),e(m).on("click",function(){s.helpers.handleClick("center","",i)}),m.disabled=s.isDisabledOrInEditMode(),m=this.uihelpers.createJQXButton("ni-snap-icon ni-action-button",!0),m.id="snap_"+n,c.appendChild(m),e(m).on("click",function(){s.helpers.handleClick("snap","",i)}),m.disabled=s.isDisabledOrInEditMode(),m=this.uihelpers.createJQXButton("ni-visibility-button ni-action-button",!0),m.id="visible_"+n,b=s.helpers.getState("visible",i),b?m.classList.add("ni-visibility-on-icon"):m.classList.add("ni-visibility-off-icon"),e(m).on("click",function(){s.helpers.handleClick("visible","",i)}),c.appendChild(m),m.disabled=s.isDisabledOrInEditMode(),f}},{key:"createDetailsItem",value:function(e,t){var i,n,s,a,l;return i=document.createElement("tr"),i.className="ni-details-row",e.appendChild(i),n=document.createElement("td"),n.className="ni-details-row-title-box",i.appendChild(n),a=document.createElement("span"),a.class="ni-details-row-title",n.appendChild(a),l=document.createTextNode(t),a.appendChild(l),s=document.createElement("td"),s.className="ni-details-row-control-box",i.appendChild(s),s}},{key:"createDetailsRow",value:function(e,t){var i,n,s,a;return n=document.createElement("tr"),n.className="ni-details-box",n.style.display="none",e.appendChild(n),s=document.createElement("td"),s.colSpan=5,n.appendChild(s),i=document.createElement("table"),i.className="ni-details",s.appendChild(i),a=this.createDetailsItem(i,"Color"),this.uihelpers.addColorBox({name:"Color"},a,t,"ni-colorbox-selector ni-selector"),a=this.createDetailsItem(i,"Shape"),this.uihelpers.addComboBox(this.helpers.getMenuItem("shape"),a,t,16,"ni-shape-selector ni-selector"),a=this.createDetailsItem(i,"Crosshair"),this.uihelpers.addComboBox(this.helpers.getMenuItem("crosshair"),a,t,16,"ni-crosshair-selector ni-selector"),n}},{key:"setFont",value:function(t,i,n,s,a){var l=this.firstElementChild,r=e(this),o=e("#"+l.id+" .jqx-widget-content"),d=e("#"+l.id+" .ni-cursor-title"),c=e("#"+l.id+" .ni-x-title"),h=e("#"+l.id+" .ni-y-title"),p=e("#"+l.id+" .ni-details-title");r.css({"font-size":t,"font-family":i,"font-weight":n,"font-style":s}),o.css({"font-size":t,"font-family":i,"font-weight":n,"font-style":s}),d.css({"font-size":t,"font-family":i,"font-weight":n,"font-style":s}),c.css({"font-size":t,"font-family":i,"font-weight":n,"font-style":s}),h.css({"font-size":t,"font-family":i,"font-weight":n,"font-style":s}),p.css({"font-size":t,"font-family":i,"font-weight":n,"font-style":s})}},{key:"applyFont",value:function(){var t=this.firstElementChild,i=e("#"+t.id+" .jqx-widget-content"),n=e("#"+t.id+" .ni-cursor-title"),s=e("#"+t.id+" .ni-x-title"),a=e("#"+t.id+" .ni-y-title"),l=e("#"+t.id+" .ni-details-title"),r=e(this).css("font-size"),o=e(this).css("font-family"),d=e(this).css("font-weight"),c=e(this).css("font-style");i.css({"font-size":r,"font-family":o,"font-weight":d,"font-style":c}),n.css({"font-size":r,"font-family":o,"font-weight":d,"font-style":c}),s.css({"font-size":r,"font-family":o,"font-weight":d,"font-style":c}),a.css({"font-size":r,"font-family":o,"font-weight":d,"font-style":c}),l.css({"font-size":r,"font-family":o,"font-weight":d,"font-style":c})}},{key:"propertyChangedHandler",value:function(t,i,s){var a=this;switch(babelHelpers.get(n.prototype.__proto__||Object.getPrototypeOf(n.prototype),"propertyChangedHandler",this).call(this,t,i,s),t){case"graphRef":this.helpers.graph.cursorLegend=null;var l=this.findGraph();this.attachToGraph(l);break;case"disabled":case"isInEditMode":this.helpers.isInEditMode=this.isInEditMode,null!==this.addButton&&(this.addButton.disabled=this.isDisabledOrInEditMode()),e(this.table).find(".ni-center-icon").each(function(){this.disabled=a.isDisabledOrInEditMode()}),e(this.table).find(".ni-expand-button").each(function(){this.disabled=a.isDisabledOrInEditMode()}),e(this.table).find(".ni-snap-icon").each(function(){this.disabled=a.isDisabledOrInEditMode()}),e(this.table).find(".ni-delete-icon").each(function(){this.disabled=a.isDisabledOrInEditMode()}),e(this.table).find(".ni-visibility-button").each(function(){this.disabled=a.isDisabledOrInEditMode()}),e(this.table).find(".ni-colorbox-selector").each(function(){this.disabled=a.isDisabledOrInEditMode()}),e(this.table).find(".ni-shape-selector").each(function(){this.disabled=a.isDisabledOrInEditMode()}),e(this.table).find(".ni-crosshair-selector").each(function(){this.disabled=a.isDisabledOrInEditMode()})}}}]),n}(NationalInstruments.HtmlVI.Elements.GraphLegend);JQX("ni-cursor-legend",i)}(),function(){NationalInstruments.HtmlVI.Elements.CursorLegendItemDisplay=function(e){this.helpers=e,this.items=[]};var e=NationalInstruments.HtmlVI.Elements.CursorLegendItemDisplay,t=e.prototype,i="http://www.w3.org/2000/svg";t.clearShape=function(e){this.items.splice(e,1)},t.createHeaderDisplay=function(e){var t;return void 0===e?null:(t=document.createElementNS(i,"svg"),t.setAttribute("class","ni-cursor-display"),t.setAttribute("width","16"),t.setAttribute("height","16"),t.setAttribute("viewBox","0,0,16,16"),t.setAttributeNS("http://www.w3.org/2000/xmlns/","xmlns:xlink","http://www.w3.org/1999/xlink"),this.addShapes(e,t,i),this.items.push(t),t)},t.addShapes=function(e,t,i){this.makeShape(e,t,i),this.makeCursorCross(e,t,i)},t.makeCursorCross=function(e,t,i){switch(e.crosshairStyle){case"none":break;case"vertical":this.makeLine(e,t,i,"8","1","8","4"),this.makeLine(e,t,i,"8","12","8","15");break;case"horizontal":this.makeLine(e,t,i,"12","8","15","8"),this.makeLine(e,t,i,"1","8","4","8");break;default:this.makeLine(e,t,i,"8","1","8","4"),this.makeLine(e,t,i,"12","8","15","8"),this.makeLine(e,t,i,"8","12","8","15"),this.makeLine(e,t,i,"1","8","4","8")}},t.makeShape=function(e,t,i){var n,s,a=e.targetShape,l=window.getComputedStyle(e),r=l.color;switch(a){case"ellipse":s=document.createElementNS(i,"circle"),s.setAttribute("cx","8"),s.setAttribute("cy","8"),s.setAttribute("r","4"),s.setAttribute("stroke",r),s.setAttribute("stroke-width","1"),s.setAttribute("fill","rgba(0, 0, 0, 0)"),t.appendChild(s);break;case"rectangle":n=document.createElementNS(i,"rect"),n.setAttribute("x","4"),n.setAttribute("y","4"),n.setAttribute("width","8"),n.setAttribute("height","8"),n.setAttribute("stroke",r),n.setAttribute("stroke-width","1"),n.setAttribute("fill","rgba(0, 0, 0, 0)"),t.appendChild(n);break;case"diamond":this.makeLine(e,t,i,"8","4","12","8"),this.makeLine(e,t,i,"12","8","8","12"),this.makeLine(e,t,i,"8","12","4","8"),this.makeLine(e,t,i,"4","8","8","4");break;case"cross":this.makeLine(e,t,i,"4","4","12","12"),this.makeLine(e,t,i,"4","12","12","4");break;case"plus":this.makeLine(e,t,i,"8","4","8","12"),this.makeLine(e,t,i,"4","8","12","8")}},t.makeLine=function(e,t,i,n,s,a,l){var r=document.createElementNS(i,"line"),o=window.getComputedStyle(e),d=o.color;r.setAttribute("x1",n),r.setAttribute("y1",s),r.setAttribute("x2",a),r.setAttribute("y2",l),r.setAttribute("stroke",d),r.setAttribute("stroke-width",1),t.appendChild(r)},t.updateShape=function(e){var t=this.helpers.getIndex(e),n=this.items[t];if(void 0===e)return null;if(void 0===n)return null;for(;n.firstChild;)n.removeChild(n.firstChild);this.addShapes(e,n,i)}}(),function(){var e=NationalInstruments.HtmlVI.NISupport,t=NationalInstruments.Globals.jQuery;NationalInstruments.HtmlVI.Elements.CursorLegendHelpers=function(){this.graph=null,this.isInEditMode=!1,this.cursors=[],this.defaultCursorName=e.i18n("msg_defaultcursorname")};var i=NationalInstruments.HtmlVI.Elements.CursorLegendHelpers,n=i.prototype;n.getMenuItem=function(e){return"shape"===e?{name:"Target Shape",tag:"msg_targetshape",children:[{name:"Ellipse",tag:"msg_ellipse",cssClass:"ni-ellipse-point-style-icon"},{name:"Rectangle",tag:"msg_rectangle",cssClass:"ni-rect-point-style-icon"},{name:"Diamond",tag:"msg_diamond",cssClass:"ni-diamond-point-style-icon"},{name:"Cross",tag:"msg_cross",cssClass:"ni-cross-point-style-icon"},{name:"Plus",tag:"msg_plus",cssClass:"ni-plus-point-style-icon"}]}:"crosshair"===e?{name:"Crosshair Style",tag:"msg_crosshairstyle",children:[{name:"No style",tag:"msg_nostyle",cssClass:"ni-no-crosshair-icon"},{name:"Vertical",tag:"msg_vertical",cssClass:"ni-vertical-crosshair-icon"},{name:"Horizontal",tag:"msg_horizontal",cssClass:"ni-horizontal-crosshair-icon"},{name:"Both",tag:"msg_both",cssClass:"ni-both-crosshair-icon"}]}:void 0},n.cursorAdded=function(e){var t;for(t=0;t<this.cursors.length;t++)if(this.cursors[t]===e||null!=e.niControlId&&this.cursors[t].niControlId===e.niControlId)return;this.cursors.push(e)},n.cursorRemoved=function(e){var t;for(t=0;t<this.cursors.length;t++)if(this.cursors[t].niControlId===e.niControlId)return void this.cursors.splice(t,1)},n.addCursor=function(){var t=this.graph,i=document.createElement("ni-cursor");i.niControlId=e.uniqueId(),i.show=!0,i.showValue=!0,this.cursors.push(i),i.label=this.nextCursorName(),t.appendChild(i)},n.cursorPositionChanged=function(e,i){if(void 0===e)throw new Error("cursor is undefined");t(e).on("cursorUpdated",function(e,t){i(t)})},n.clearCache=function(){this.cursors.length=0},n.getCursor=function(e){var t,i,n=0,s=null;if(null===this.cursors[e]||void 0===this.cursors[e]){if(null!==(t=this.graph))for(i in t.childNodes)if("ni-cursor"===t.childNodes[i].localName){if(n===e){s=t.childNodes[i];break}n++}null!==s&&(this.cursors[e]=s)}return this.cursors[e]},n.nextCursorName=function(){var e,t,n=0,s=this.graph;if(null!==s)for(i in s.childNodes)"ni-cursor"===s.childNodes[i].localName&&(t=s.childNodes[i],(e=parseInt(t.label.substring(this.defaultCursorName.length)))>n&&(n=e));return this.defaultCursorName+" "+(n+1)},n.deleteCursor=function(e){var t=this.graph;null!==e&&void 0!==e&&t.removeChild(e)},n.getIndex=function(e){var t,i=-1;for(t=0;t<this.cursors.length;t++)null!==this.cursors[t]&&e.niControlId===this.cursors[t].niControlId&&(i=t);return i},n.handleClick=function(e,t,i){if(null!==i||void 0!==i)switch(e){case"name":case"x":case"y":break;case"visible":i.show=!i.show;break;case"snap":i.snapToPlot=-1!==i.snapToPlot?-1:void 0;break;case"center":i.snapToPlot=void 0,i.x=.5,i.y=.5;break;case"delete":this.deleteCursor(i);break;case"Ellipse":i.targetShape="ellipse";break;case"Rectangle":i.targetShape="rectangle";break;case"Diamond":i.targetShape="diamond";break;case"Cross":i.targetShape="cross";break;case"Plus":i.targetShape="plus";break;case"No style":i.crosshairStyle="none";break;case"Vertical":i.crosshairStyle="vertical";break;case"Horizontal":i.crosshairStyle="horizontal";break;case"Both":i.crosshairStyle="both";break;case"Color":i.setColor(t)}},n.getState=function(e,t){if(null!==t&&void 0!==t){var i;switch(e){case"name":i=t.label;break;case"x":i=t.x;break;case"y":i=t.y;break;case"visible":i=t.show;break;case"snap":i=-1===t.snapToPlot;break;case"center":case"delete":break;case"Ellipse":i="ellipse"===t.targetShape;break;case"Rectangle":i="rectangle"===t.targetShape;break;case"Diamond":i="diamond"===t.targetShape;break;case"Cross":i="cross"===t.targetShape;break;case"Plus":i="plus"===t.targetShape;break;case"No style":i="none"===t.crosshairStyle;break;case"Vertical":i="vertical"===t.crosshairStyle;break;case"Horizontal":i="horizontal"===t.crosshairStyle;break;case"Both":i="both"===t.crosshairStyle;break;case"Color":i=window.getComputedStyle(t).color}return i}},n.getTargetShape=function(e){var t=this.getCursor(e);return null!==t&&void 0!==t?t.targetShape:"ellipse"},n.getCrosshair=function(e){var t=this.getCursor(e);if(null!==t&&void 0!==t)return t.crosshairStyle}}(),function(){var e=NationalInstruments.Globals.jQuery,t=function(t){function i(){return babelHelpers.classCallCheck(this,i),babelHelpers.possibleConstructorReturn(this,(i.__proto__||Object.getPrototypeOf(i)).apply(this,arguments))}return babelHelpers.inherits(i,t),babelHelpers.createClass(i,[{key:"created",value:function(){babelHelpers.get(i.prototype.__proto__||Object.getPrototypeOf(i.prototype),"created",this).call(this),this.tbl=void 0,this.nScales=0,this.currentExpander=null,this.helpers=new NationalInstruments.HtmlVI.Elements.ScaleLegendHelpers,this.uihelpers=new NationalInstruments.HtmlVI.Elements.LegendHelpers(this.helpers,null)}},{key:"scaleAdded",value:function(e){this.helpers.scaleToIndex(e)<this.nScales||(this.createRow(this.tbl,this.nScales),this.helpers.addScale(this.nScales),this.nScales++)}},{key:"scaleRemoved",value:function(e){var t,i,n,s,a,l=null;for(s=0,n=0;n<this.tbl.childNodes.length;n++){if("tr"===this.tbl.childNodes[n].localName&&(t=this.tbl.childNodes[n],i=t.childNodes[0],i.innerText===e.label)){l=t,a=s;break}s++}null!==l&&(this.tbl.removeChild(l),this.helpers.clearScale(a)),this.nScales--}},{key:"createRows",value:function(){var e;for(e=0;e<this.nScales;e++)this.createRow(this.tbl,e)}},{key:"removeRows",value:function(){var e;for(e=this.nScales-1;e>=0;e--){var t=this.helpers.getScale(e);this.scaleRemoved(t)}}},{key:"attachToGraph",value:function(e){this.detachFromGraph(),e&&e.isReady&&(this.helpers.graph=e,e.registerScaleLegend(this))}},{key:"detachFromGraph",value:function(){this.helpers.graph=null,this.helpers.clearScale(),this.removeRows()}},{key:"attached",value:function(){babelHelpers.get(i.prototype.__proto__||Object.getPrototypeOf(i.prototype),"attached",this).call(this);var t=document.createElement("div"),n=this;this.helpers.graph=this.findGraph(),this.helpers.isInEditMode=this.isInEditMode,t.style.width="100%",t.style.height="100%",this.appendChild(t),this.tbl=document.createElement("table"),this.tbl.className="ni-scale-legend-box",t.appendChild(this.tbl),this.addEventListener("ni-cartesian-axis-attached",function(e){var t=e.detail.originalSource;n.scaleAdded(t)}),this.addEventListener("ni-cartesian-axis-detached",function(e){n.scaleRemoved(e.detail.originalSource)}),this.addEventListener("ni-axis-changed",function(t){var i=t.detail.originalSource,s=n.helpers.scaleToIndex(i),a=e(this.tbl).find(".ni-row-title"),l=e(this.tbl).find(".ni-lock-button");e(a[s]).first().text(i.label),this.setLockBackground(l[s],!1,s)});var s=this.findGraph();null!==s&&this.attachToGraph(s)}},{key:"createRow",value:function(t,i){var n,s,a,l,r,o,d,c,h=this;n=document.createElement("tr"),t.appendChild(n),s=document.createElement("td"),s.className="ni-row-title-box",n.appendChild(s),r=document.createElement("span"),r.className="ni-row-title",s.appendChild(r);var p=h.helpers.getState("name",i);o=document.createTextNode(p),r.appendChild(o),a=document.createElement("td"),a.className="ni-lock-box",n.appendChild(a),d=this.uihelpers.createJQXButton("ni-lock-button ni-button",!0),d.disabled=!this.helpers.getState("canLock",i)||h.isDisabledOrInEditMode(),e(d).on("click",function(){h.helpers.handleClick("lock",i),h.setLockBackground(d,!1,i)}),h.setLockBackground(d,!0,i),a.appendChild(d),l=document.createElement("td"),l.className="ni-reset-offset-box",n.appendChild(l),c=this.uihelpers.createJQXButton("ni-reset-offset-icon ni-button",!1),c.disabled=h.isDisabledOrInEditMode(),e(c).on("click",function(){h.helpers.handleClick("resetOffset",i),h.setLockBackground(d,!1,i)}),l.appendChild(c),this.applyFont()}},{key:"setLockBackground",value:function(e,t,i){var n=this.helpers.getState("lock",i);void 0!==n&&(!0===t&&(e.checked=n),!0===n?(e.classList.remove("ni-locked-icon"),e.classList.add("ni-unlocked-icon")):(e.classList.remove("ni-unlocked-icon"),e.classList.add("ni-locked-icon")))}},{key:"setFont",value:function(t,i,n,s,a){var l=this.firstElementChild,r=e(this),o=e(l).find(" .ni-row-title");r.css({"font-size":t,"font-family":i,"font-weight":n,"font-style":s}),o.css({"font-size":t,"font-family":i,"font-weight":n,"font-style":s})}},{key:"applyFont",value:function(){var t=this.firstElementChild,i=e(t).find(" .ni-row-title"),n=e(this).css("font-size"),s=e(this).css("font-family"),a=e(this).css("font-weight"),l=e(this).css("font-style");i.css({"font-size":n,"font-family":s,"font-weight":a,"font-style":l})}},{key:"updateDisabledState",value:function(){var t=this;e(this.tbl).find(".ni-lock-button").each(function(){this.disabled=t.isDisabledOrInEditMode()}),e(this.tbl).find(".ni-reset-offset-icon").each(function(){this.disabled=t.isDisabledOrInEditMode()})}},{key:"propertyChangedHandler",value:function(e,t,n){switch(babelHelpers.get(i.prototype.__proto__||Object.getPrototypeOf(i.prototype),"propertyChangedHandler",this).call(this,e,t,n),e){case"graphRef":this.helpers.graph.scaleLegend=null;var s=this.findGraph();this.attachToGraph(s);break;case"disabled":case"isInEditMode":this.helpers.isInEditMode=this.isInEditMode,this.updateDisabledState()}}}]),i}(NationalInstruments.HtmlVI.Elements.GraphLegend);JQX("ni-scale-legend",t)}(),function(){NationalInstruments.HtmlVI.Elements.ScaleLegendHelpers=function(){this.graph=null,this.isInEditMode=!1,this.scales=[]};var e=NationalInstruments.HtmlVI.Elements.ScaleLegendHelpers,t=e.prototype;t.addScale=function(){},t.clearScale=function(e){this.scales[e]=null},t.getScale=function(e){var t,i,n=0,s=null;if(null===this.scales[e]||void 0===this.scales[e]){if(null!==(t=this.graph))for(i in t.childNodes)if("ni-cartesian-axis"===t.childNodes[i].localName||"ni-color-scale"===t.childNodes[i].localName){if(n===e){s=t.childNodes[i];break}n++}if(null===s)return null;this.scales[e]=s}return this.scales[e]},t.scaleToIndex=function(e){var t,i,n=0,s=-1;if(null!==(t=this.graph))for(i in t.childNodes)if("ni-cartesian-axis"===t.childNodes[i].localName||"ni-color-scale"===t.childNodes[i].localName){if(t.childNodes[i]===e){s=n;break}n++}return s},t.handleClick=function(e,t){if(!0!==this.isInEditMode){var i=this.getScale(t);if(null===i)return;switch(e){case"lock":"none"!==i.autoScale?(i.initialAutoscale=i.autoScale,i.autoScale="none",i.resetOffset()):i.autoScale=i.initialAutoscale?i.initialAutoscale:"loose";break;case"resetOffset":i.resetOffset&&i.resetOffset()}var n=i._parentGraph.graph;n.setupGrid("none"!==i.autoScale),n.draw()}},t.getState=function(e,t){var i=this.getScale(t);if(null!==i){var n;switch(e){case"canLock":n="ni-color-scale"!==i.localName;break;case"lock":n="none"!==i.autoScale;break;case"resetOffset":break;case"name":n=i.label}return n}}}(),function(){var e=Object.freeze({LOCKED:"locked",PAN:"pan",ZOOM:"zoom"}),t=e,i=NationalInstruments.Globals.jQuery,n=NationalInstruments.HtmlVI.NISupport,s={};s[t.LOCKED]=[!0,!1,!1],s[t.PAN]=[!1,!0,!1],s[t.ZOOM]=[!1,!1,!0];var a=function(e){function a(){return babelHelpers.classCallCheck(this,a),babelHelpers.possibleConstructorReturn(this,(a.__proto__||Object.getPrototypeOf(a)).apply(this,arguments))}return babelHelpers.inherits(a,e),babelHelpers.createClass(a,[{key:"created",value:function(){babelHelpers.get(a.prototype.__proto__||Object.getPrototypeOf(a.prototype),"created",this).call(this),this._parentGraph=void 0,this.lockButton=null,this.panButton=null,this.zoomButton=null,this.zoomOutButton=null,this.snapshotButton=null,this.rangeMismatch=!0,this.uihelpers=new NationalInstruments.HtmlVI.Elements.LegendHelpers(this.helpers,null)}},{key:"ready",value:function(){babelHelpers.get(a.prototype.__proto__||Object.getPrototypeOf(a.prototype),"ready",this).call(this),this.addListeners()}},{key:"attachToGraph",value:function(e){e.isReady&&(this._parentGraph=e,e.registerGraphTools(this))}},{key:"updateCartesianAxesFromFlot",value:function(){this._parentGraph.axes.forEach(function(e){e instanceof JQX.CartesianAxis&&e.syncWithFlot()}),this.rangeMismatch=!1}},{key:"addListeners",value:function(){var e=this,t=function(e,t){var i=e.options,n=t.from-e.min,s=t.to-e.max;i.offset?(i.offset.below=(i.offset.below||0)+n,i.offset.above=(i.offset.above||0)+s):i.offset={above:s,below:n}};this.addEventListener("ni-cartesian-graph-box-selected",function(n){var s=n.detail.originalSource.ranges,a=e._parentGraph.graph;i.each(a.getAxes(),function(i,n){!0!==n.options.disableZoom&&s[i]&&(e.rangeMismatch&&"y"===n.direction&&(a.autoScaleAxis(n),n.min=n.autoScaledMin,n.max=n.autoScaledMax),t(n,s[i]))}),a.setupGrid(),a.draw(),a.clearSelection(),this.updateCartesianAxesFromFlot()}),this.addEventListener("ni-cartesian-graph-interaction",function(){this.updateCartesianAxesFromFlot()}),this.addEventListener("ni-axis-reset",function(){this.rangeMismatch=!0})}},{key:"attached",value:function(){babelHelpers.get(a.prototype.__proto__||Object.getPrototypeOf(a.prototype),"attached",this).call(this);var e;e=document.createElement("div"),e.id="div"+n.uniqueId(),e.style.width="100%",e.style.height="100%",this.appendChild(e),this.table=document.createElement("table"),this.table.className="ni-graph-tools-box",e.appendChild(this.table),this.createRow(this.table),this.updateDisabledState();var t=this.findGraph();null!==t&&t instanceof NationalInstruments.HtmlVI.Elements.CartesianGraphBase&&this.attachToGraph(t)}},{key:"detached",value:function(){babelHelpers.get(a.prototype.__proto__||Object.getPrototypeOf(a.prototype),"detached",this).call(this),this._parentGraph=void 0,this.table=void 0,i(this).empty()}},{key:"asyncProcessAllImagesForComposition",value:function(e){function t(){}var n,s,a=this,l=a._parentGraph.graph.getCanvas(),r=document.createElementNS("http://www.w3.org/2000/svg","svg"),o=a._parentGraph.graph.getSurface().SVGContainer.childNodes[0],d=a._parentGraph.graph.getEventHolder(),c=function(e){var t=e.graph.getPlaceholder();return t&&t.find(".flot-thumbs")[0]?t.find(".flot-thumbs")[0].firstChild:null}(a._parentGraph),h=function(e){for(var t=["ni-light-plot-legend","ni-chart","ni-cartesian-graph","ni-intensity-graph"],i=null,n="",s=0;s<t.length&&(n=t[s]+'[graph-ref="'+e+'"] svg.legendLayer',null===(i=document.querySelector(n))||void 0===i);s++);return i}(a._parentGraph.graphRef);!function(e,t){var n=i.plot.browser.getPixelRatio(t.getContext("2d")),s=20*n;document.body.insertBefore(e,document.body.childNodes[0]),n<1?(e.setAttributeNS(null,"width",t.width/n+s),e.setAttributeNS(null,"height",t.height/n+s)):(e.setAttributeNS(null,"width",t.width+s),e.setAttributeNS(null,"height",t.height+s)),e.style.width=t.style.width+s,e.style.height=t.style.height+s,e.style.position="absolute";var a=t.getBoundingClientRect().left+window.scrollX-10,l=t.getBoundingClientRect().top+window.scrollY-10;e.style.left=a+"px",e.style.top=l+"px"}(r,l),s=void 0!==e?e:window.getComputedStyle(a._parentGraph).backgroundColor,function(e,t){var i=document.createElementNS(e,"rect");i.setAttributeNS(null,"x",0),i.setAttributeNS(null,"y",0),i.setAttributeNS(null,"style","fill:"+t),i.setAttributeNS(null,"width",e.width.baseVal.value+"px"),i.setAttributeNS(null,"height",e.height.baseVal.value+"px"),e.appendChild(i)}(r,s),n=[r,l,o,d,c,h];var p=document.createElement("canvas");return a._parentGraph.takeGraphSnapshot(n,p).then(function(e){return function(t){e.parentNode.removeChild(e)}}(r),t).then(function(){return p},t)}},{key:"downloadSnapshot",value:function(){function e(){return function(e){var n=document.createElement("img");n.width=e.width,n.height=e.height,n.src=e.toDataURL("image/png");var s=function(e){var i=URL.createObjectURL(e);n.src=i;var s=document.createElement("A");s.download="Snapshot_"+t()+".png",s.href=n.src;var a=new MouseEvent("click");s.dispatchEvent(a)};return i.plot.browser.isEdge()?s(e.msToBlob()):e.toBlob(s),e}}function t(){var e=new Date,t=e.getFullYear(),i=e.getMonth()+1,n=e.getDate(),s=e.getHours(),a=e.getMinutes(),l=e.getSeconds();return i<10&&(i="0"+i),n<10&&(n="0"+n),s<10&&(s="0"+s),a<10&&(a="0"+a),l<10&&(l="0"+l),t+"."+i+"."+n+"_"+s+"."+a+"."+l}function n(){}var s=this,a=function t(){s.asyncProcessAllImagesForComposition().then(e(),n),s._parentGraph.graph.getEventHolder().removeEventListener("onDrawingDone",t)};s._parentGraph.graph.getEventHolder().addEventListener("onDrawingDone",a),s._parentGraph.updateGraphConfig()}},{key:"createRow",value:function(e){function n(e,t,i){a(),m.disabled=e,e&&m.classList.add("ni-active-button"),f.disabled=t,t&&f.classList.add("ni-active-button"),b.disabled=i,i&&b.classList.add("ni-active-button")}function a(){m.classList.remove("ni-active-button"),f.classList.remove("ni-active-button"),b.classList.remove("ni-active-button")}function l(e){var t=s[e];t&&(n.apply(null,t),v.mode=e)}function r(){v.downloadSnapshot()}var o,d,c,h,p,u,m,f,b,g,y,v=this;o=document.createElement("tr"),e.appendChild(o),d=document.createElement("td"),d.className="ni-button-box",o.appendChild(d),m=this.uihelpers.createJQXButton("ni-locked-icon ni-button",!1),i(m).on("click",function(){l(t.LOCKED)}),d.appendChild(m),v.lockButton=m,c=document.createElement("td"),c.className="ni-button-box",o.appendChild(c),f=this.uihelpers.createJQXButton("ni-pan-icon ni-button",!1),i(f).on("click",function(){l(t.PAN)}),c.appendChild(f),v.panButton=f,h=document.createElement("td"),h.className="ni-button-box",o.appendChild(h),b=this.uihelpers.createJQXButton("ni-zoom-region-icon ni-button",!1),i(b).on("click",function(){l(t.ZOOM)}),h.appendChild(b),v.zoomButton=b,l(this.mode),p=document.createElement("td"),p.className="ni-button-box",o.appendChild(p),g=this.uihelpers.createJQXButton("ni-zoom-out-icon ni-button",!1),g.disabled=!1,i(g).on("click",function(){v._parentGraph.axes.forEach(function(e){e.resetOffset&&e.resetOffset()});var e=v._parentGraph.graph;e.setupGrid(),e.draw()}),p.appendChild(g),v.zoomOutButton=g,u=document.createElement("td"),u.className="ni-button-box",o.appendChild(u),y=this.uihelpers.createJQXButton("ni-snapshot-icon ni-button",!1),y.disabled=!1,i(y).on("click",function(){r()}),u.appendChild(y),v.snapshotButton=y}},{key:"allowsScrollWheelZoom",value:function(){return this.mode===t.PAN||this.mode===t.ZOOM}},{key:"allowsPan",value:function(){return this.mode===t.PAN}},{key:"sendEventToParentGraph",value:function(e){var t;void 0!==this._parentGraph&&(t={bubbles:!0,cancelable:!0,detail:{element:this}},this._parentGraph.dispatchEvent(new CustomEvent(e,t)))}},{key:"updateDisabledState",value:function(){null!==this.lockButton&&(this.lockButton.disabled=this.disabled),null!==this.panButton&&(this.panButton.disabled=this.disabled),null!==this.zoomButton&&(this.zoomButton.disabled=this.disabled),null!==this.zoomOutButton&&(this.zoomOutButton.disabled=this.disabled),null!==this.snapshotButton&&(this.snapshotButton.disabled=this.disabled)}},{key:"propertyChangedHandler",value:function(e,t,i){switch(babelHelpers.get(a.prototype.__proto__||Object.getPrototypeOf(a.prototype),"propertyChangedHandler",this).call(this,e,t,i),e){case"graphRef":var n=this.findGraph();null!=n&&this.attachToGraph(n);break;case"mode":this.sendEventToParentGraph("ni-graph-tools-changed");break;case"disabled":this.updateDisabledState()}}}],[{key:"properties",get:function(){return Object.assign({},babelHelpers.get(a.__proto__||Object.getPrototypeOf(a),"properties",this),{mode:{value:t.PAN,type:"string"}})}}]),a}(NationalInstruments.HtmlVI.Elements.GraphLegend);JQX("ni-graph-tools",a)}();
//# sourceMappingURL=webcharts-legends.min.js.map

!function(){"use strict";NationalInstruments.JQXElement._registerElements=function(){window.JQX.Elements.registerElements()}}(),function(){"use strict";var t=NationalInstruments.HtmlVI.NISupport,n=t.InternationalizationInitializer.TaskTrackerEnum;t.InternationalizationInitializer.TaskTracker.complete(n.ELEMENT_PROTOTYPES_READY)}();
//# sourceMappingURL=element_registration.min.js.map
